/* Generated by Cython 3.0.8 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "NPY_NO_DEPRECATED_API",
                "0"
            ]
        ],
        "depends": [
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/npy_common.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "pandas/_libs/tslibs/src/datetime/np_datetime.h",
            "pandas/_libs/tslibs/src/datetime/np_datetime_strings.h"
        ],
        "include_dirs": [
            "pandas/_libs/tslibs",
            "/usr/lib/python3.12/site-packages/numpy/core/include"
        ],
        "language": "c",
        "name": "pandas._libs.tslibs.offsets",
        "sources": [
            "pandas/_libs/tslibs/offsets.pyx",
            "pandas/_libs/tslibs/src/datetime/np_datetime.c"
        ]
    },
    "module_name": "pandas._libs.tslibs.offsets"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_8" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030008F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pandas___libs__tslibs__offsets
#define __PYX_HAVE_API__pandas___libs__tslibs__offsets
/* Early includes */
#include <string.h>
#include <stdio.h>

    /* Using NumPy API declarations from "numpy/__init__.cython-30.pxd" */
    
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"
#include "datetime.h"

    /* Backport for Python 2.x */
    #if PY_MAJOR_VERSION < 3
        #ifndef PyDateTime_DELTA_GET_DAYS
            #define PyDateTime_DELTA_GET_DAYS(o) (((PyDateTime_Delta*)o)->days)
        #endif
        #ifndef PyDateTime_DELTA_GET_SECONDS
            #define PyDateTime_DELTA_GET_SECONDS(o) (((PyDateTime_Delta*)o)->seconds)
        #endif
        #ifndef PyDateTime_DELTA_GET_MICROSECONDS
            #define PyDateTime_DELTA_GET_MICROSECONDS(o) (((PyDateTime_Delta*)o)->microseconds)
        #endif
    #endif

    /* Backport for Python < 3.6 */
    #if PY_VERSION_HEX < 0x030600a4
        #ifndef PyDateTime_TIME_GET_FOLD
            #define PyDateTime_TIME_GET_FOLD(o) ((void)(o), 0)
        #endif
        #ifndef PyDateTime_DATE_GET_FOLD
            #define PyDateTime_DATE_GET_FOLD(o) ((void)(o), 0)
        #endif
    #endif

    /* Backport for Python < 3.6 */
    #if PY_VERSION_HEX < 0x030600a4
        #define __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             ((void)(fold), PyDateTimeAPI->DateTime_FromDateAndTime(year, month, day, hour, minute, second,                 microsecond, tz, PyDateTimeAPI->DateTimeType))
        #define __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             ((void)(fold), PyDateTimeAPI->Time_FromTime(hour, minute, second, microsecond, tz, PyDateTimeAPI->TimeType))
    #else /* For Python 3.6+ so that we can pass tz */
        #define __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             PyDateTimeAPI->DateTime_FromDateAndTimeAndFold(year, month, day, hour, minute, second,                 microsecond, tz, fold, PyDateTimeAPI->DateTimeType)
        #define __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             PyDateTimeAPI->Time_FromTimeAndFold(hour, minute, second, microsecond, tz, fold, PyDateTimeAPI->TimeType)
    #endif

    /* Backport for Python < 3.7 */
    #if PY_VERSION_HEX < 0x030700b1
        #define __Pyx_TimeZone_UTC NULL
        #define __Pyx_TimeZone_FromOffsetAndName(offset, name) ((void)(offset), (void)(name), (PyObject*)NULL)
    #else
        #define __Pyx_TimeZone_UTC PyDateTime_TimeZone_UTC
        #define __Pyx_TimeZone_FromOffsetAndName(offset, name) PyTimeZone_FromOffsetAndName(offset, name)
    #endif

    /* Backport for Python < 3.10 */
    #if PY_VERSION_HEX < 0x030a00a1
        #ifndef PyDateTime_TIME_GET_TZINFO
            #define PyDateTime_TIME_GET_TZINFO(o)                 ((((PyDateTime_Time*)o)->hastzinfo) ? ((PyDateTime_Time*)o)->tzinfo : Py_None)
        #endif
        #ifndef PyDateTime_DATE_GET_TZINFO
            #define PyDateTime_DATE_GET_TZINFO(o)                 ((((PyDateTime_DateTime*)o)->hastzinfo) ? ((PyDateTime_DateTime*)o)->tzinfo : Py_None)
        #endif
    #endif
    
#include "numpy/npy_common.h"
#include "src/datetime/np_datetime.h"
#include "src/datetime/np_datetime_strings.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif (defined(_Complex_I) && !defined(_MSC_VER)) || ((defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) && !defined(__STDC_NO_COMPLEX__) && !defined(_MSC_VER))
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "pandas/_libs/tslibs/offsets.pyx",
  "__init__.cython-30.pxd",
  "datetime.pxd",
  "pandas/_libs/tslibs/util.pxd",
  "pandas/_libs/tslibs/offsets.pxd",
  "<stringsource>",
  "type.pxd",
  "pandas/_libs/tslibs/base.pxd",
  "pandas/_libs/tslibs/timestamps.pxd",
  "pandas/_libs/tslibs/conversion.pxd",
  "pandas/_libs/tslibs/dtypes.pxd",
  "pandas/_libs/tslibs/nattype.pxd",
  "pandas/_libs/tslibs/timedeltas.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* #### Code section: numeric_typedefs ### */

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":730
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":731
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":732
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":733
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":737
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":738
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":739
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":740
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":744
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":745
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":754
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":755
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":757
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":758
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":760
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":761
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":763
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":764
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":765
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* #### Code section: complex_type_declarations ### */
/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6pandas_5_libs_6tslibs_4base_ABCTimestamp;
struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp;
struct __pyx_obj_6pandas_5_libs_6tslibs_10conversion__TSObject;
struct __pyx_obj_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase;
struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT;
struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply;
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":767
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":768
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":769
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":771
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_opt_args_7cpython_8datetime_time_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_new;
struct __pyx_opt_args_7cpython_8datetime_timezone_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp;

/* "cpython/datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */
struct __pyx_opt_args_7cpython_8datetime_time_new {
  int __pyx_n;
  int fold;
};

/* "cpython/datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */
struct __pyx_opt_args_7cpython_8datetime_datetime_new {
  int __pyx_n;
  int fold;
};

/* "cpython/datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */
struct __pyx_opt_args_7cpython_8datetime_timezone_new {
  int __pyx_n;
  PyObject *name;
};

/* "cpython/datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp {
  int __pyx_n;
  PyObject *tz;
};
struct __pyx_ctuple_0fa544____dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__etc;
typedef struct __pyx_ctuple_0fa544____dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__etc __pyx_ctuple_0fa544____dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__etc;

/* "pandas/_libs/tslibs/ccalendar.pxd":7
 * )
 * 
 * ctypedef (int32_t, int32_t, int32_t) iso_calendar_t             # <<<<<<<<<<<<<<
 * 
 * cdef int dayofweek(int y, int m, int d) nogil
 */
struct __pyx_ctuple_0fa544____dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__etc {
  __pyx_t_5numpy_int32_t f0;
  __pyx_t_5numpy_int32_t f1;
  __pyx_t_5numpy_int32_t f2;
};
typedef __pyx_ctuple_0fa544____dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__and___dunderpyx_t_5numpy_int32_t__etc __pyx_t_6pandas_5_libs_6tslibs_9ccalendar_iso_calendar_t;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_check_dts_bounds;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_pydatetime_to_dt64;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dt64;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_string_to_dts;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_astype_overflowsafe;

/* "pandas/_libs/tslibs/np_datetime.pxd":76
 * cdef bint cmp_scalar(int64_t lhs, int64_t rhs, int op) except -1
 * 
 * cdef check_dts_bounds(npy_datetimestruct *dts, NPY_DATETIMEUNIT unit=?)             # <<<<<<<<<<<<<<
 * 
 * cdef int64_t pydatetime_to_dt64(
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_check_dts_bounds {
  int __pyx_n;
  NPY_DATETIMEUNIT unit;
};

/* "pandas/_libs/tslibs/np_datetime.pxd":78
 * cdef check_dts_bounds(npy_datetimestruct *dts, NPY_DATETIMEUNIT unit=?)
 * 
 * cdef int64_t pydatetime_to_dt64(             # <<<<<<<<<<<<<<
 *     datetime val, npy_datetimestruct *dts, NPY_DATETIMEUNIT reso=?
 * )
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_pydatetime_to_dt64 {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
};

/* "pandas/_libs/tslibs/np_datetime.pxd":82
 * )
 * cdef void pydatetime_to_dtstruct(datetime dt, npy_datetimestruct *dts)
 * cdef int64_t pydate_to_dt64(             # <<<<<<<<<<<<<<
 *     date val, npy_datetimestruct *dts, NPY_DATETIMEUNIT reso=?
 * )
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dt64 {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
};

/* "pandas/_libs/tslibs/np_datetime.pxd":91
 * cdef NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil
 * 
 * cdef int string_to_dts(             # <<<<<<<<<<<<<<
 *     str val,
 *     npy_datetimestruct* dts,
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_string_to_dts {
  int __pyx_n;
  PyObject *format;
  int exact;
};

/* "pandas/_libs/tslibs/np_datetime.pxd":104
 * cdef NPY_DATETIMEUNIT get_unit_from_dtype(cnp.dtype dtype)
 * 
 * cpdef cnp.ndarray astype_overflowsafe(             # <<<<<<<<<<<<<<
 *     cnp.ndarray values,  # ndarray[datetime64[anyunit]]
 *     cnp.dtype dtype,  # ndarray[datetime64[anyunit]]
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_11np_datetime_astype_overflowsafe {
  int __pyx_n;
  int copy;
  int round_ok;
  int is_coerce;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_create_timestamp_from_ts;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp_to_pydatetime;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp__as_creso;

/* "pandas/_libs/tslibs/timestamps.pxd":15
 * 
 * 
 * cdef _Timestamp create_timestamp_from_ts(int64_t value,             # <<<<<<<<<<<<<<
 *                                          npy_datetimestruct dts,
 *                                          tzinfo tz,
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_create_timestamp_from_ts {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
};

/* "pandas/_libs/tslibs/timestamps.pxd":32
 *     cdef bint _can_compare(self, datetime other)
 *     cpdef to_datetime64(self)
 *     cpdef datetime to_pydatetime(_Timestamp self, bint warn=*)             # <<<<<<<<<<<<<<
 *     cdef bint _compare_outside_nanorange(_Timestamp self, datetime other,
 *                                          int op) except -1
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp_to_pydatetime {
  int __pyx_n;
  int warn;
};

/* "pandas/_libs/tslibs/timestamps.pxd":36
 *                                          int op) except -1
 *     cdef bint _compare_mismatched_resos(_Timestamp self, _Timestamp other, int op)
 *     cdef _Timestamp _as_creso(_Timestamp self, NPY_DATETIMEUNIT creso, bint round_ok=*)             # <<<<<<<<<<<<<<
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp__as_creso {
  int __pyx_n;
  int round_ok;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_9_TSObject_ensure_reso;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_to_tsobject;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_datetime_to_tsobject;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_str_to_tsobject;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_cast_from_unit;
struct __pyx_ctuple___dunderpyx_t_5numpy_int64_t__and_int;
typedef struct __pyx_ctuple___dunderpyx_t_5numpy_int64_t__and_int __pyx_ctuple___dunderpyx_t_5numpy_int64_t__and_int;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_precision_from_unit;

/* "pandas/_libs/tslibs/conversion.pxd":27
 *         NPY_DATETIMEUNIT creso
 * 
 *     cdef int64_t ensure_reso(self, NPY_DATETIMEUNIT creso, str val=*) except? -1             # <<<<<<<<<<<<<<
 * 
 * 
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_9_TSObject_ensure_reso {
  int __pyx_n;
  PyObject *val;
};

/* "pandas/_libs/tslibs/conversion.pxd":30
 * 
 * 
 * cdef _TSObject convert_to_tsobject(object ts, tzinfo tz, str unit,             # <<<<<<<<<<<<<<
 *                                    bint dayfirst, bint yearfirst,
 *                                    int32_t nanos=*)
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_to_tsobject {
  int __pyx_n;
  __pyx_t_5numpy_int32_t nanos;
};

/* "pandas/_libs/tslibs/conversion.pxd":34
 *                                    int32_t nanos=*)
 * 
 * cdef _TSObject convert_datetime_to_tsobject(datetime ts, tzinfo tz,             # <<<<<<<<<<<<<<
 *                                             int32_t nanos=*,
 *                                             NPY_DATETIMEUNIT reso=*)
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_datetime_to_tsobject {
  int __pyx_n;
  __pyx_t_5numpy_int32_t nanos;
  NPY_DATETIMEUNIT reso;
};

/* "pandas/_libs/tslibs/conversion.pxd":38
 *                                             NPY_DATETIMEUNIT reso=*)
 * 
 * cdef _TSObject convert_str_to_tsobject(str ts, tzinfo tz, str unit,             # <<<<<<<<<<<<<<
 *                                        bint dayfirst=*,
 *                                        bint yearfirst=*)
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_convert_str_to_tsobject {
  int __pyx_n;
  int dayfirst;
  int yearfirst;
};

/* "pandas/_libs/tslibs/conversion.pxd":45
 * 
 * cpdef datetime localize_pydatetime(datetime dt, tzinfo tz)
 * cdef int64_t cast_from_unit(object ts, str unit, NPY_DATETIMEUNIT out_reso=*) except? -1             # <<<<<<<<<<<<<<
 * cpdef (int64_t, int) precision_from_unit(str unit, NPY_DATETIMEUNIT out_reso=*)
 * 
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_cast_from_unit {
  int __pyx_n;
  NPY_DATETIMEUNIT out_reso;
};

/* "pandas/_libs/tslibs/conversion.pxd":46
 * cpdef datetime localize_pydatetime(datetime dt, tzinfo tz)
 * cdef int64_t cast_from_unit(object ts, str unit, NPY_DATETIMEUNIT out_reso=*) except? -1
 * cpdef (int64_t, int) precision_from_unit(str unit, NPY_DATETIMEUNIT out_reso=*)             # <<<<<<<<<<<<<<
 * 
 * cdef maybe_localize_tso(_TSObject obj, tzinfo tz, NPY_DATETIMEUNIT reso)
 */
struct __pyx_ctuple___dunderpyx_t_5numpy_int64_t__and_int {
  __pyx_t_5numpy_int64_t f0;
  int f1;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_precision_from_unit {
  int __pyx_n;
  NPY_DATETIMEUNIT out_reso;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day;

/* "pandas/_libs/tslibs/dtypes.pxd":17
 * cdef dict attrname_to_npy_unit
 * 
 * cdef enum c_FreqGroup:             # <<<<<<<<<<<<<<
 *     # Mirrors FreqGroup in the .pyx file
 *     FR_ANN = 1000
 */
enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_c_FreqGroup {
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_ANN = 0x3E8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_QTR = 0x7D0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_MTH = 0xBB8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_WK = 0xFA0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_BUS = 0x1388,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_DAY = 0x1770,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_HR = 0x1B58,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_MIN = 0x1F40,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_SEC = 0x2328,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_MS = 0x2710,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_US = 0x2AF8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_NS = 0x2EE0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_FR_UND = -10000L
};

/* "pandas/_libs/tslibs/dtypes.pxd":34
 * 
 * 
 * cdef enum c_Resolution:             # <<<<<<<<<<<<<<
 *     # Mirrors Resolution in the .pyx file
 *     RESO_NS = 0
 */
enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_c_Resolution {
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_NS = 0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_US = 1,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_MS = 2,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_SEC = 3,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_MIN = 4,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_HR = 5,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_DAY = 6,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_MTH = 7,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_QTR = 8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_RESO_YR = 9
};

/* "pandas/_libs/tslibs/dtypes.pxd":48
 * 
 * 
 * cdef enum PeriodDtypeCode:             # <<<<<<<<<<<<<<
 *     # Annual freqs with various fiscal year ends.
 *     # eg, 2005 for A_FEB runs Mar 1, 2004 to Feb 28, 2005
 */
enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode {
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A = 0x3E8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_DEC = 0x3E8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_JAN = 0x3E9,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_FEB = 0x3EA,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_MAR = 0x3EB,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_APR = 0x3EC,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_MAY = 0x3ED,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_JUN = 0x3EE,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_JUL = 0x3EF,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_AUG = 0x3F0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_SEP = 0x3F1,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_OCT = 0x3F2,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_A_NOV = 0x3F3,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_DEC = 0x7D0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_JAN = 0x7D1,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_FEB = 0x7D2,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_MAR = 0x7D3,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_APR = 0x7D4,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_MAY = 0x7D5,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_JUN = 0x7D6,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_JUL = 0x7D7,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_AUG = 0x7D8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_SEP = 0x7D9,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_OCT = 0x7DA,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_NOV = 0x7DB,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_M = 0xBB8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_SUN = 0xFA0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_MON = 0xFA1,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_TUE = 0xFA2,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_WED = 0xFA3,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_THU = 0xFA4,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_FRI = 0xFA5,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_SAT = 0xFA6,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_B = 0x1388,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_D = 0x1770,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_H = 0x1B58,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_T = 0x1F40,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_S = 0x2328,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_L = 0x2710,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_U = 0x2AF8,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_N = 0x2EE0,
  __pyx_e_6pandas_5_libs_6tslibs_6dtypes_UNDEFINED = -10000L
};

/* "pandas/_libs/tslibs/dtypes.pxd":9
 * cpdef NPY_DATETIMEUNIT abbrev_to_npy_unit(str abbrev)
 * cdef NPY_DATETIMEUNIT freq_group_code_to_npy_unit(int freq) nogil
 * cpdef int64_t periods_per_day(NPY_DATETIMEUNIT reso=*) except? -1             # <<<<<<<<<<<<<<
 * cpdef int64_t periods_per_second(NPY_DATETIMEUNIT reso) except? -1
 * cpdef NPY_DATETIMEUNIT get_supported_reso(NPY_DATETIMEUNIT reso)
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_10_Timedelta__as_creso;

/* "timedeltas.pxd":8
 * 
 * # Exposed for tslib, not intended for outside use.
 * cpdef int64_t delta_to_nanoseconds(             # <<<<<<<<<<<<<<
 *     delta, NPY_DATETIMEUNIT reso=*, bint round_ok=*
 * ) except? -1
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
  int round_ok;
};

/* "timedeltas.pxd":27
 *     cdef _ensure_components(_Timedelta self)
 *     cdef bint _compare_mismatched_resos(self, _Timedelta other, op)
 *     cdef _Timedelta _as_creso(self, NPY_DATETIMEUNIT reso, bint round_ok=*)             # <<<<<<<<<<<<<<
 *     cpdef _maybe_cast_to_matching_resos(self, _Timedelta other)
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_10_Timedelta__as_creso {
  int __pyx_n;
  int round_ok;
};
struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays;
struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;

/* "pandas/_libs/tslibs/offsets.pyx":1604
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 *     cdef ndarray _shift_bdays(             # <<<<<<<<<<<<<<
 *         self,
 *         ndarray i8other,
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays {
  int __pyx_n;
  NPY_DATETIMEUNIT reso;
};

/* "pandas/_libs/tslibs/offsets.pyx":4255
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ndarray shift_quarters(             # <<<<<<<<<<<<<<
 *     ndarray dtindex,
 *     int quarters,
 */
struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters {
  int __pyx_n;
  int modby;
  NPY_DATETIMEUNIT reso;
};
struct __pyx_defaults {
  NPY_DATETIMEUNIT __pyx_arg_reso;
};

/* "pandas/_libs/tslibs/base.pxd":4
 * 
 * 
 * cdef class ABCTimestamp(datetime):             # <<<<<<<<<<<<<<
 *     pass
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_4base_ABCTimestamp {
  PyDateTime_DateTime __pyx_base;
};


/* "pandas/_libs/tslibs/timestamps.pxd":22
 * 
 * 
 * cdef class _Timestamp(ABCTimestamp):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t _value, nanosecond, year
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp {
  struct __pyx_obj_6pandas_5_libs_6tslibs_4base_ABCTimestamp __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_vtab;
  __pyx_t_5numpy_int64_t _value;
  __pyx_t_5numpy_int64_t nanosecond;
  __pyx_t_5numpy_int64_t year;
  NPY_DATETIMEUNIT _creso;
};


/* "pandas/_libs/tslibs/conversion.pxd":19
 * 
 * 
 * cdef class _TSObject:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         npy_datetimestruct dts      # npy_datetimestruct
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_10conversion__TSObject {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10conversion__TSObject *__pyx_vtab;
  npy_datetimestruct dts;
  __pyx_t_5numpy_int64_t value;
  PyDateTime_TZInfo *tzinfo;
  int fold;
  NPY_DATETIMEUNIT creso;
};


/* "pandas/_libs/tslibs/dtypes.pxd":102
 * 
 * 
 * cdef class PeriodDtypeBase:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         PeriodDtypeCode _dtype_code
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase {
  PyObject_HEAD
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase *__pyx_vtab;
  enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode _dtype_code;
};


/* "pandas/_libs/tslibs/nattype.pxd":9
 * cdef set c_nat_strings
 * 
 * cdef class _NaT(datetime):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t _value
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT {
  PyDateTime_DateTime __pyx_base;
  __pyx_t_5numpy_int64_t _value;
};


/* "timedeltas.pxd":15
 * 
 * 
 * cdef class _Timedelta(timedelta):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t _value      # nanoseconds
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta {
  PyDateTime_Delta __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *__pyx_vtab;
  __pyx_t_5numpy_int64_t _value;
  int _is_populated;
  __pyx_t_5numpy_int64_t _d;
  __pyx_t_5numpy_int64_t _h;
  __pyx_t_5numpy_int64_t _m;
  __pyx_t_5numpy_int64_t _s;
  __pyx_t_5numpy_int64_t _ms;
  __pyx_t_5numpy_int64_t _us;
  __pyx_t_5numpy_int64_t _ns;
  NPY_DATETIMEUNIT _creso;
};


/* "pandas/_libs/tslibs/offsets.pxd":8
 * cdef bint is_tick_object(object obj)
 * 
 * cdef class BaseOffset:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t n
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset {
  PyObject_HEAD
  __pyx_t_5numpy_int64_t n;
  int normalize;
  PyObject *_cache;
};


/* "pandas/_libs/tslibs/offsets.pyx":886
 * 
 * 
 * cdef class SingleConstructorOffset(BaseOffset):             # <<<<<<<<<<<<<<
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":909
 * # Tick Offsets
 * 
 * cdef class Tick(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _adjust_dst = False
 *     _prefix = "undefined"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_vtab;
};


/* "pandas/_libs/tslibs/offsets.pyx":1089
 * 
 * 
 * cdef class Day(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 24 * 3600 * 1_000_000_000
 *     _prefix = "D"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1097
 * 
 * 
 * cdef class Hour(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 3600 * 1_000_000_000
 *     _prefix = "H"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1105
 * 
 * 
 * cdef class Minute(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 60 * 1_000_000_000
 *     _prefix = "T"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1113
 * 
 * 
 * cdef class Second(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1_000_000_000
 *     _prefix = "S"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1121
 * 
 * 
 * cdef class Milli(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1_000_000
 *     _prefix = "L"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1129
 * 
 * 
 * cdef class Micro(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1000
 *     _prefix = "U"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1137
 * 
 * 
 * cdef class Nano(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1
 *     _prefix = "N"
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1170
 * # --------------------------------------------------------------------
 * 
 * cdef class RelativeDeltaOffset(BaseOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass backed by a dateutil relativedelta object.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1437
 * 
 * 
 * cdef class BusinessMixin(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Mixin to business types to provide related functions.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_vtab;
  PyDateTime_Delta *_offset;
  PyObject *weekmask;
  PyObject *holidays;
  PyObject *calendar;
};


/* "pandas/_libs/tslibs/offsets.pyx":1505
 * 
 * 
 * cdef class BusinessDay(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n business days.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":1697
 * 
 * 
 * cdef class BusinessHour(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n business hours.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
  PyObject *start;
  PyObject *end;
};


/* "pandas/_libs/tslibs/offsets.pyx":2126
 * 
 * 
 * cdef class WeekOfMonthMixin(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Mixin for methods common to WeekOfMonth and LastWeekOfMonth.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  int weekday;
  int week;
};


/* "pandas/_libs/tslibs/offsets.pyx":2169
 * # Year-Based Offset Classes
 * 
 * cdef class YearOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset that just needs a month.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_vtab;
  int month;
};


/* "pandas/_libs/tslibs/offsets.pyx":2236
 * 
 * 
 * cdef class BYearEnd(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of the year.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2262
 * 
 * 
 * cdef class BYearBegin(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the first business day of the year.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2286
 * 
 * 
 * cdef class YearEnd(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between calendar year ends.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
  int _period_dtype_code;
};


/* "pandas/_libs/tslibs/offsets.pyx":2311
 * 
 * 
 * cdef class YearBegin(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one year at beginning.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2346
 * # Quarter-Based Offset Classes
 * 
 * cdef class QuarterOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "startingMonth"])
 *     # TODO: Consider combining QuarterOffset and YearOffset __init__ at some
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_vtab;
  int startingMonth;
};


/* "pandas/_libs/tslibs/offsets.pyx":2423
 * 
 * 
 * cdef class BQuarterEnd(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of each Quarter.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2451
 * 
 * 
 * cdef class BQuarterBegin(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the first business day of each Quarter.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2479
 * 
 * 
 * cdef class QuarterEnd(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between Quarter end dates.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
  int _period_dtype_code;
};


/* "pandas/_libs/tslibs/offsets.pyx":2507
 * 
 * 
 * cdef class QuarterBegin(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between Quarter start dates.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2530
 * # Month-Based Offset Classes
 * 
 * cdef class MonthOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_vtab;
};


/* "pandas/_libs/tslibs/offsets.pyx":2557
 * 
 * 
 * cdef class MonthEnd(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month end.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2588
 * 
 * 
 * cdef class MonthBegin(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month at beginning.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2602
 * 
 * 
 * cdef class BusinessMonthEnd(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of the month.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2628
 * 
 * 
 * cdef class BusinessMonthBegin(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month at the first business day.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2650
 * # Semi-Month Based Offsets
 * 
 * cdef class SemiMonthOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _default_day_of_month = 15
 *     _min_day_of_month = 2
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_vtab;
  int day_of_month;
};


/* "pandas/_libs/tslibs/offsets.pyx":2783
 * 
 * 
 * cdef class SemiMonthEnd(SemiMonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Two DateOffset's per month repeating on the last day of the month & day_of_month.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2823
 * 
 * 
 * cdef class SemiMonthBegin(SemiMonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Two DateOffset's per month repeating on the first day of the month & day_of_month.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":2852
 * 
 * 
 * cdef class Week(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Weekly offset.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_vtab;
  PyObject *weekday;
  int _period_dtype_code;
};


/* "pandas/_libs/tslibs/offsets.pyx":3024
 * 
 * 
 * cdef class WeekOfMonth(WeekOfMonthMixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes monthly dates like "the Tuesday of the 2nd week of each month".
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_vtab;
};


/* "pandas/_libs/tslibs/offsets.pyx":3096
 * 
 * 
 * cdef class LastWeekOfMonth(WeekOfMonthMixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes monthly dates in last week of month.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_vtab;
};


/* "pandas/_libs/tslibs/offsets.pyx":3169
 * # Special Offset Classes
 * 
 * cdef class FY5253Mixin(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int startingMonth
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_vtab;
  int startingMonth;
  int weekday;
  PyObject *variation;
};


/* "pandas/_libs/tslibs/offsets.pyx":3222
 * 
 * 
 * cdef class FY5253(FY5253Mixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes 52-53 week fiscal year. This is also known as a 4-4-5 calendar.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":3396
 * 
 * 
 * cdef class FY5253Quarter(FY5253Mixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between business quarter dates for 52-53 week fiscal year.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_base;
  int qtr_with_extra_week;
};


/* "pandas/_libs/tslibs/offsets.pyx":3629
 * 
 * 
 * cdef class Easter(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset for the Easter holiday using logic defined in dateutil.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_vtab;
};


/* "pandas/_libs/tslibs/offsets.pyx":3685
 * 
 * 
 * cdef class CustomBusinessDay(BusinessDay):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing custom business days excluding holidays.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":3772
 * 
 * 
 * cdef class CustomBusinessHour(BusinessHour):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n custom business days.
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":3884
 * 
 * 
 * cdef class _CustomBusinessMonth(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing custom business month(s).
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":3981
 * 
 * 
 * cdef class CustomBusinessMonthEnd(_CustomBusinessMonth):             # <<<<<<<<<<<<<<
 *     _prefix = "CBM"
 * 
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":3985
 * 
 * 
 * cdef class CustomBusinessMonthBegin(_CustomBusinessMonth):             # <<<<<<<<<<<<<<
 *     _prefix = "CBMS"
 * 
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_base;
};


/* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps {
  PyObject_HEAD
  PyObject *__pyx_v_func;
};


/* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps {
  PyObject_HEAD
  PyObject *__pyx_v_func;
};


/* "pandas/_libs/tslibs/offsets.pyx":304
 * 
 * 
 * cdef _determine_offset(kwds):             # <<<<<<<<<<<<<<
 *     if not kwds:
 *         # GH 45643/45890: (historically) defaults to 1 day
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset {
  PyObject_HEAD
  PyObject *__pyx_v_kwds_use_relativedelta;
  PyObject *__pyx_v_kwds_use_timedelta;
  PyObject *__pyx_v_nanos;
};


/* "pandas/_libs/tslibs/offsets.pyx":320
 * 
 *     # nanos are handled by apply_wraps
 *     if all(k in nanos for k in kwds):             # <<<<<<<<<<<<<<
 *         return timedelta(days=0), False
 * 
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
};


/* "pandas/_libs/tslibs/offsets.pyx":337
 *     }
 * 
 *     if all(k in kwds_use_timedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         # Sub-daily offset - use timedelta (tz-aware)
 *         # This also handles "milliseconds" (plur): see GH 49897
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
};


/* "pandas/_libs/tslibs/offsets.pyx":347
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         return relativedelta(**kwds_no_nanos), True
 * 
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_k;
};


/* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset *__pyx_v_self;
};


/* "pandas/_libs/tslibs/offsets.pyx":900
 *         #  from attributes that do get pickled.
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None             # <<<<<<<<<<<<<<
 *             for attr in self._attributes
 *         )
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_attr;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};


/* "pandas/_libs/tslibs/offsets.pyx":1826
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr {
  PyObject_HEAD
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_en;
  PyObject *__pyx_v_st;
};


/* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self;
};


/* "pandas/_libs/tslibs/offsets.pyx":2023
 *         # get total business hours by sec in one business day
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_en;
  PyObject *__pyx_v_st;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};



/* "pandas/_libs/tslibs/timestamps.pxd":22
 * 
 * 
 * cdef class _Timestamp(ABCTimestamp):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t _value, nanosecond, year
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp {
  int (*_get_start_end_field)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, PyObject *, PyObject *);
  PyObject *(*_get_date_name_field)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, PyObject *, PyObject *);
  __pyx_t_5numpy_int64_t (*_maybe_convert_value_to_local)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *);
  int (*_can_compare)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, PyDateTime_DateTime *);
  PyObject *(*to_datetime64)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, int __pyx_skip_dispatch);
  PyDateTime_DateTime *(*to_pydatetime)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp_to_pydatetime *__pyx_optional_args);
  int (*_compare_outside_nanorange)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, PyDateTime_DateTime *, int);
  int (*_compare_mismatched_resos)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, int);
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *(*_as_creso)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *, NPY_DATETIMEUNIT, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timestamps_10_Timestamp__as_creso *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_vtabptr_6pandas_5_libs_6tslibs_10timestamps__Timestamp;


/* "pandas/_libs/tslibs/conversion.pxd":19
 * 
 * 
 * cdef class _TSObject:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         npy_datetimestruct dts      # npy_datetimestruct
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10conversion__TSObject {
  __pyx_t_5numpy_int64_t (*ensure_reso)(struct __pyx_obj_6pandas_5_libs_6tslibs_10conversion__TSObject *, NPY_DATETIMEUNIT, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10conversion_9_TSObject_ensure_reso *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10conversion__TSObject *__pyx_vtabptr_6pandas_5_libs_6tslibs_10conversion__TSObject;


/* "pandas/_libs/tslibs/dtypes.pxd":102
 * 
 * 
 * cdef class PeriodDtypeBase:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         PeriodDtypeCode _dtype_code
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase {
  int (*_get_to_timestamp_base)(struct __pyx_obj_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase *__pyx_vtabptr_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase;


/* "timedeltas.pxd":15
 * 
 * 
 * cdef class _Timedelta(timedelta):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int64_t _value      # nanoseconds
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta {
  PyDateTime_Delta *(*to_pytimedelta)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, int __pyx_skip_dispatch);
  int (*_has_ns)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *);
  int (*_is_in_pytimedelta_bounds)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *);
  PyObject *(*_ensure_components)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *);
  int (*_compare_mismatched_resos)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, PyObject *);
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *(*_as_creso)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, NPY_DATETIMEUNIT, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_10_Timedelta__as_creso *__pyx_optional_args);
  PyObject *(*_maybe_cast_to_matching_resos)(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *__pyx_vtabptr_6pandas_5_libs_6tslibs_10timedeltas__Timedelta;


/* "pandas/_libs/tslibs/offsets.pyx":909
 * # Tick Offsets
 * 
 * cdef class Tick(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _adjust_dst = False
 *     _prefix = "undefined"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *(*_next_higher_resolution)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;


/* "pandas/_libs/tslibs/offsets.pyx":1089
 * 
 * 
 * cdef class Day(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 24 * 3600 * 1_000_000_000
 *     _prefix = "D"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Day {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Day *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Day;


/* "pandas/_libs/tslibs/offsets.pyx":1097
 * 
 * 
 * cdef class Hour(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 3600 * 1_000_000_000
 *     _prefix = "H"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Hour {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Hour *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Hour;


/* "pandas/_libs/tslibs/offsets.pyx":1105
 * 
 * 
 * cdef class Minute(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 60 * 1_000_000_000
 *     _prefix = "T"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Minute {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Minute *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Minute;


/* "pandas/_libs/tslibs/offsets.pyx":1113
 * 
 * 
 * cdef class Second(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1_000_000_000
 *     _prefix = "S"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Second {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Second *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Second;


/* "pandas/_libs/tslibs/offsets.pyx":1121
 * 
 * 
 * cdef class Milli(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1_000_000
 *     _prefix = "L"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Milli {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Milli *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Milli;


/* "pandas/_libs/tslibs/offsets.pyx":1129
 * 
 * 
 * cdef class Micro(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1000
 *     _prefix = "U"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Micro {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Micro *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Micro;


/* "pandas/_libs/tslibs/offsets.pyx":1137
 * 
 * 
 * cdef class Nano(Tick):             # <<<<<<<<<<<<<<
 *     _nanos_inc = 1
 *     _prefix = "N"
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Nano {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Nano *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Nano;


/* "pandas/_libs/tslibs/offsets.pyx":1437
 * 
 * 
 * cdef class BusinessMixin(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Mixin to business types to provide related functions.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin {
  PyObject *(*_init_custom)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;


/* "pandas/_libs/tslibs/offsets.pyx":1505
 * 
 * 
 * cdef class BusinessDay(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n business days.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
  PyArrayObject *(*_shift_bdays)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *, PyArrayObject *, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays *__pyx_optional_args);
  int (*_adjust_ndays)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *, int, int);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessDay;


/* "pandas/_libs/tslibs/offsets.pyx":1697
 * 
 * 
 * cdef class BusinessHour(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n business hours.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessHour {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessHour;


/* "pandas/_libs/tslibs/offsets.pyx":2169
 * # Year-Based Offset Classes
 * 
 * cdef class YearOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset that just needs a month.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;


/* "pandas/_libs/tslibs/offsets.pyx":2236
 * 
 * 
 * cdef class BYearEnd(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of the year.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2262
 * 
 * 
 * cdef class BYearBegin(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the first business day of the year.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2286
 * 
 * 
 * cdef class YearEnd(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between calendar year ends.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2311
 * 
 * 
 * cdef class YearBegin(YearOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one year at beginning.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2346
 * # Quarter-Based Offset Classes
 * 
 * cdef class QuarterOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "startingMonth"])
 *     # TODO: Consider combining QuarterOffset and YearOffset __init__ at some
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;


/* "pandas/_libs/tslibs/offsets.pyx":2423
 * 
 * 
 * cdef class BQuarterEnd(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of each Quarter.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2451
 * 
 * 
 * cdef class BQuarterBegin(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the first business day of each Quarter.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2479
 * 
 * 
 * cdef class QuarterEnd(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between Quarter end dates.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2507
 * 
 * 
 * cdef class QuarterBegin(QuarterOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between Quarter start dates.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2530
 * # Month-Based Offset Classes
 * 
 * cdef class MonthOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;


/* "pandas/_libs/tslibs/offsets.pyx":2557
 * 
 * 
 * cdef class MonthEnd(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month end.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2588
 * 
 * 
 * cdef class MonthBegin(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month at beginning.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2602
 * 
 * 
 * cdef class BusinessMonthEnd(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between the last business day of the month.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2628
 * 
 * 
 * cdef class BusinessMonthBegin(MonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset of one month at the first business day.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2650
 * # Semi-Month Based Offsets
 * 
 * cdef class SemiMonthOffset(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     _default_day_of_month = 15
 *     _min_day_of_month = 2
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;


/* "pandas/_libs/tslibs/offsets.pyx":2783
 * 
 * 
 * cdef class SemiMonthEnd(SemiMonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Two DateOffset's per month repeating on the last day of the month & day_of_month.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;


/* "pandas/_libs/tslibs/offsets.pyx":2823
 * 
 * 
 * cdef class SemiMonthBegin(SemiMonthOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Two DateOffset's per month repeating on the first day of the month & day_of_month.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;


/* "pandas/_libs/tslibs/offsets.pyx":2852
 * 
 * 
 * cdef class Week(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     Weekly offset.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Week {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *, PyObject *, int __pyx_skip_dispatch);
  PyArrayObject *(*_end_apply_index)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *, PyArrayObject *, NPY_DATETIMEUNIT);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Week;


/* "pandas/_libs/tslibs/offsets.pyx":3024
 * 
 * 
 * cdef class WeekOfMonth(WeekOfMonthMixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes monthly dates like "the Tuesday of the 2nd week of each month".
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;


/* "pandas/_libs/tslibs/offsets.pyx":3096
 * 
 * 
 * cdef class LastWeekOfMonth(WeekOfMonthMixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes monthly dates in last week of month.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;


/* "pandas/_libs/tslibs/offsets.pyx":3169
 * # Special Offset Classes
 * 
 * cdef class FY5253Mixin(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         int startingMonth
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;


/* "pandas/_libs/tslibs/offsets.pyx":3222
 * 
 * 
 * cdef class FY5253(FY5253Mixin):             # <<<<<<<<<<<<<<
 *     """
 *     Describes 52-53 week fiscal year. This is also known as a 4-4-5 calendar.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253 {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253;


/* "pandas/_libs/tslibs/offsets.pyx":3396
 * 
 * 
 * cdef class FY5253Quarter(FY5253Mixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset increments between business quarter dates for 52-53 week fiscal year.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;


/* "pandas/_libs/tslibs/offsets.pyx":3629
 * 
 * 
 * cdef class Easter(SingleConstructorOffset):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset for the Easter holiday using logic defined in dateutil.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Easter {
  PyObject *(*__pyx___setstate__)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Easter;


/* "pandas/_libs/tslibs/offsets.pyx":3685
 * 
 * 
 * cdef class CustomBusinessDay(BusinessDay):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing custom business days excluding holidays.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;


/* "pandas/_libs/tslibs/offsets.pyx":3772
 * 
 * 
 * cdef class CustomBusinessHour(BusinessHour):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing possibly n custom business days.
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessHour __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;


/* "pandas/_libs/tslibs/offsets.pyx":3884
 * 
 * 
 * cdef class _CustomBusinessMonth(BusinessMixin):             # <<<<<<<<<<<<<<
 *     """
 *     DateOffset subclass representing custom business month(s).
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;


/* "pandas/_libs/tslibs/offsets.pyx":3981
 * 
 * 
 * cdef class CustomBusinessMonthEnd(_CustomBusinessMonth):             # <<<<<<<<<<<<<<
 *     _prefix = "CBM"
 * 
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;


/* "pandas/_libs/tslibs/offsets.pyx":3985
 * 
 * 
 * cdef class CustomBusinessMonthBegin(_CustomBusinessMonth):             # <<<<<<<<<<<<<<
 *     _prefix = "CBMS"
 * 
 */

struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin {
  struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_base;
};
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* ErrOccurredWithGIL.proto */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseClosureNameError.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* PySetContains.proto */
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq);

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* py_dict_pop.proto */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObject_Str.proto */
#define __Pyx_PyObject_Str(obj)\
    (likely(PyString_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* py_abs.proto */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *num);
#define __Pyx_PyNumber_Absolute(x)\
    ((likely(PyLong_CheckExact(x))) ?\
         (likely(__Pyx_PyLong_IsNonNeg(x)) ? (Py_INCREF(x), (x)) : __Pyx_PyLong_AbsNeg(x)) :\
         PyNumber_Absolute(x))
#else
#define __Pyx_PyNumber_Absolute(x)  PyNumber_Absolute(x)
#endif

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right)
    #endif
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_ConcatInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_ConcatInPlaceSafe(left, right) ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_ConcatInPlace(left, right))

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_RemainderObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceRemainder(op1, op2) : PyNumber_Remainder(op1, op2))
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_TrueDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceTrueDivide(op1, op2) : PyNumber_TrueDivide(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_FloorDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceFloorDivide(op1, op2) : PyNumber_FloorDivide(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_MultiplyCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* DivInt[long].proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectFormat.proto */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* s, PyObject* f);
#else
#define __Pyx_PyObject_Format(s, f) PyObject_Format(s, f)
#endif

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (1)
#elif CYTHON_COMPILING_IN_LIMITED_API  ||  (CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030C0000)
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_long(long value, Py_ssize_t width, char padding_char, char format_char);

/* ModInt[long].proto */
static CYTHON_INLINE long __Pyx_mod_long(long, long);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* SliceTupleAndList.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(PyObject* src, Py_ssize_t start, Py_ssize_t stop);
#else
#define __Pyx_PyList_GetSlice(seq, start, stop)   PySequence_GetSlice(seq, start, stop)
#define __Pyx_PyTuple_GetSlice(seq, start, stop)  PySequence_GetSlice(seq, start, stop)
#endif

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* pybytes_as_double.proto */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj);
static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length);
static CYTHON_INLINE double __Pyx_PyBytes_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyBytes_AS_STRING(obj);
    size = PyBytes_GET_SIZE(obj);
#else
    if (PyBytes_AsStringAndSize(obj, &as_c_string, &size) < 0) {
        return (double)-1;
    }
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}
static CYTHON_INLINE double __Pyx_PyByteArray_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
    as_c_string = PyByteArray_AS_STRING(obj);
    size = PyByteArray_GET_SIZE(obj);
#else
    as_c_string = PyByteArray_AsString(obj);
    if (as_c_string == NULL) {
        return (double)-1;
    }
    size = PyByteArray_Size(obj);
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}

/* pyunicode_as_double.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
static const char* __Pyx__PyUnicode_AsDouble_Copy(const void* data, const int kind, char* buffer, Py_ssize_t start, Py_ssize_t end) {
    int last_was_punctuation;
    Py_ssize_t i;
    last_was_punctuation = 1;
    for (i=start; i <= end; i++) {
        Py_UCS4 chr = PyUnicode_READ(kind, data, i);
        int is_punctuation = (chr == '_') | (chr == '.');
        *buffer = (char)chr;
        buffer += (chr != '_');
        if (unlikely(chr > 127)) goto parse_failure;
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyUnicode_AsDouble_inf_nan(const void* data, int kind, Py_ssize_t start, Py_ssize_t length) {
    int matches = 1;
    Py_UCS4 chr;
    Py_UCS4 sign = PyUnicode_READ(kind, data, start);
    int is_signed = (sign == '-') | (sign == '+');
    start += is_signed;
    length -= is_signed;
    switch (PyUnicode_READ(kind, data, start)) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'a') | (chr == 'A');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'n') | (chr == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'f') | (chr == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+3);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+4);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+5);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+6);
            matches &= (chr == 't') | (chr == 'T');
            chr = PyUnicode_READ(kind, data, start+7);
            matches &= (chr == 'y') | (chr == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static double __Pyx_PyUnicode_AsDouble_WithSpaces(PyObject *obj) {
    double value;
    const char *last;
    char *end;
    Py_ssize_t start, length = PyUnicode_GET_LENGTH(obj);
    const int kind = PyUnicode_KIND(obj);
    const void* data = PyUnicode_DATA(obj);
    start = 0;
    while (Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, start)))
        start++;
    while (start < length - 1 && Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, length - 1)))
        length--;
    length -= start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyUnicode_AsDouble_inf_nan(data, kind, start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    if (length < 40) {
        char number[40];
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((length + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}
#endif
static CYTHON_INLINE double __Pyx_PyUnicode_AsDouble(PyObject *obj) {
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(__Pyx_PyUnicode_READY(obj) == -1))
        return (double)-1;
    if (likely(PyUnicode_IS_ASCII(obj))) {
        const char *s;
        Py_ssize_t length;
        s = PyUnicode_AsUTF8AndSize(obj, &length);
        return __Pyx__PyBytes_AsDouble(obj, s, length);
    }
    return __Pyx_PyUnicode_AsDouble_WithSpaces(obj);
#else
    return __Pyx_SlowPyString_AsDouble(obj);
#endif
}

/* pynumber_float.proto */
static CYTHON_INLINE PyObject* __Pyx__PyNumber_Float(PyObject* obj);
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : __Pyx__PyNumber_Float(x))

/* ModInt[__pyx_t_5numpy_int32_t].proto */
static CYTHON_INLINE __pyx_t_5numpy_int32_t __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_5numpy_int32_t, __pyx_t_5numpy_int32_t);

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_8
#define __PYX_HAVE_RT_ImportType_proto_3_0_8
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_8(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_8(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_8 {
   __Pyx_ImportType_CheckSize_Error_3_0_8 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_8 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_8 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_8(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_8 check_size);
#endif

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* Py3UpdateBases.proto */
static PyObject* __Pyx_PEP560_update_bases(PyObject *bases);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* PyObjectCall2Args.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_LookupSpecialNoError(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 0)
#define __Pyx_PyObject_LookupSpecial(obj, attr_name)  __Pyx__PyObject_LookupSpecial(obj, attr_name, 1)
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error);
#else
#define __Pyx_PyObject_LookupSpecialNoError(o,n) __Pyx_PyObject_GetAttrStrNoError(o,n)
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* ClassMethod.proto */
#include "descrobject.h"
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int64 __Pyx_PyInt_As_npy_int64(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_DATETIMEUNIT value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE NPY_DATETIMEUNIT __Pyx_PyInt_As_NPY_DATETIMEUNIT(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* FunctionExport.proto */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_0_8(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_0_8(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self); /* proto*/
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Tick__next_higher_resolution(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__init_custom(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyArrayObject *__pyx_v_i8other, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays *__pyx_optional_args); /* proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__adjust_ndays(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, int __pyx_v_wday, int __pyx_v_weeks); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_10YearOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11MonthOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week__end_apply_index(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyArrayObject *__pyx_v_i8other, NPY_DATETIMEUNIT __pyx_v_reso); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "numpy" */

/* Module declarations from "numpy" */
static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *, PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_5numpy_import_array(void); /*proto*/

/* Module declarations from "cython" */

/* Module declarations from "cpython.version" */

/* Module declarations from "datetime" */

/* Module declarations from "cpython.datetime" */
static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void); /*proto*/

/* Module declarations from "pandas._libs.tslibs" */

/* Module declarations from "pandas._libs.tslibs.util" */
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_datetime64_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_array(PyObject *); /*proto*/
static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(PyObject *, Py_ssize_t *); /*proto*/

/* Module declarations from "pandas._libs.tslibs.ccalendar" */
static PyObject **__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_c_MONTH_NUMBERS = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_9ccalendar_c_MONTH_NUMBERS (*__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_c_MONTH_NUMBERS)
static __pyx_t_5numpy_int32_t **__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_month_offset = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_9ccalendar_month_offset (*__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_month_offset)
static int (*__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_dayofweek)(int, int, int); /*proto*/
static __pyx_t_5numpy_int32_t (*__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month)(int, Py_ssize_t, int __pyx_skip_dispatch); /*proto*/
static int (*__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_lastbday)(int, int, int __pyx_skip_dispatch); /*proto*/
static int (*__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_firstbday)(int, int, int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "pandas._libs.tslibs.np_datetime" */
static void (*__pyx_f_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dtstruct)(PyDateTime_Date *, npy_datetimestruct *); /*proto*/
static NPY_DATETIMEUNIT (*__pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype)(PyArray_Descr *); /*proto*/

/* Module declarations from "pandas._libs.tslibs.base" */

/* Module declarations from "pandas._libs.tslibs.timestamps" */

/* Module declarations from "pandas._libs.tslibs.timezones" */
static PyDateTime_TZInfo **__pyx_vp_6pandas_5_libs_6tslibs_9timezones_utc_stdlib = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_9timezones_utc_stdlib (*__pyx_vp_6pandas_5_libs_6tslibs_9timezones_utc_stdlib)
static int (*__pyx_f_6pandas_5_libs_6tslibs_9timezones_tz_compare)(PyDateTime_TZInfo *, PyDateTime_TZInfo *, int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "pandas._libs.tslibs.conversion" */
static PyDateTime_DateTime *(*__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime)(PyDateTime_DateTime *, PyDateTime_TZInfo *, int __pyx_skip_dispatch); /*proto*/

/* Module declarations from "pandas._libs.tslibs.dtypes" */
static PyObject **__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_abbrevs = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_6dtypes_attrname_to_abbrevs (*__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_abbrevs)
static PyObject **__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_npy_unit_to_attrname = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_6dtypes_npy_unit_to_attrname (*__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_npy_unit_to_attrname)
static PyObject **__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_npy_unit = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_6dtypes_attrname_to_npy_unit (*__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_npy_unit)
static __pyx_t_5numpy_int64_t (*__pyx_f_6pandas_5_libs_6tslibs_6dtypes_periods_per_day)(int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day *__pyx_optional_args); /*proto*/

/* Module declarations from "pandas._libs.tslibs.nattype" */
static __pyx_t_5numpy_int64_t *__pyx_vp_6pandas_5_libs_6tslibs_7nattype_NPY_NAT = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT (*__pyx_vp_6pandas_5_libs_6tslibs_7nattype_NPY_NAT)
static PyObject **__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_nat_strings = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_7nattype_c_nat_strings (*__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_nat_strings)
static struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT **__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_NaT = 0;
#define __pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT (*__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_NaT)

/* Module declarations from "pandas._libs.tslibs.timedeltas" */
static __pyx_t_5numpy_int64_t (*__pyx_f_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds)(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds *__pyx_optional_args); /*proto*/
static int (*__pyx_f_6pandas_5_libs_6tslibs_10timedeltas_is_any_td_scalar)(PyObject *); /*proto*/

/* Module declarations from "pandas._libs.tslibs.offsets" */
static PyObject *__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset;
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset(PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyDateTime_DateTime *__pyx_f_6pandas_5_libs_6tslibs_7offsets__as_datetime(PyDateTime_DateTime *); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(PyDateTime_DateTime *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__wrap_timedelta_result(PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__get_calendar(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__to_dt64D(PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__validate_business_time(PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyObject *); /*proto*/
static PyDateTime_DateTime *__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(PyDateTime_DateTime *, int); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(npy_datetimestruct, int); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(npy_datetimestruct, int); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_shift_quarters(PyArrayObject *, int, int, PyObject *, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters *__pyx_optional_args); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month(npy_datetimestruct *, PyObject *); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(int, int, int, int __pyx_skip_dispatch); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets__roll_qtrday(npy_datetimestruct *, int, int, PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_BaseOffset__set_state(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *, PyObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_RelativeDeltaOffset__set_state(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "pandas._libs.tslibs.offsets"
extern int __pyx_module_is_main_pandas___libs__tslibs__offsets;
int __pyx_module_is_main_pandas___libs__tslibs__offsets = 0;

/* Implementation of "pandas._libs.tslibs.offsets" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_staticmethod;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_NotImplementedError;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_NotImplemented;
static PyObject *__pyx_builtin_OverflowError;
static PyObject *__pyx_builtin_AssertionError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_reversed;
static PyObject *__pyx_builtin_sum;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_ImportError;
static PyObject *__pyx_builtin_RuntimeError;
/* #### Code section: string_decls ### */
static const char __pyx_k_A[] = "A";
static const char __pyx_k_B[] = "B";
static const char __pyx_k_C[] = "C";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_H[] = "H";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_M[] = "M";
static const char __pyx_k_N[] = "N";
static const char __pyx_k_Q[] = "Q";
static const char __pyx_k_S[] = "S";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_U[] = "U";
static const char __pyx_k_W[] = "W";
static const char __pyx_k_Y[] = "Y";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_d[] = "d";
static const char __pyx_k_h[] = "h";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_AS[] = "AS";
static const char __pyx_k_BA[] = "BA";
static const char __pyx_k_BH[] = "BH";
static const char __pyx_k_BM[] = "BM";
static const char __pyx_k_BQ[] = "BQ";
static const char __pyx_k_BY[] = "BY";
static const char __pyx_k_MS[] = "MS";
static const char __pyx_k_QS[] = "QS";
static const char __pyx_k_RE[] = "RE";
static const char __pyx_k_SM[] = "SM";
static const char __pyx_k_YS[] = "YS";
static const char __pyx_k__4[] = ".";
static const char __pyx_k_bd[] = "bd";
static const char __pyx_k_dt[] = "dt";
static const char __pyx_k_dy[] = "dy";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_ge[] = "__ge__";
static const char __pyx_k_gt[] = "__gt__";
static const char __pyx_k_i8[] = "i8";
static const char __pyx_k_le[] = "__le__";
static const char __pyx_k_lt[] = "__lt__";
static const char __pyx_k_mi[] = "mi";
static const char __pyx_k_ms[] = "ms";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_ns[] = "ns";
static const char __pyx_k_op[] = "op";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_st[] = "st";
static const char __pyx_k_td[] = "td";
static const char __pyx_k_to[] = " to ";
static const char __pyx_k_ts[] = "ts";
static const char __pyx_k_tz[] = "tz";
static const char __pyx_k_us[] = "us";
static const char __pyx_k_02d[] = "02d";
static const char __pyx_k_BAS[] = "BAS";
static const char __pyx_k_BMS[] = "BMS";
static const char __pyx_k_BQS[] = "BQS";
static const char __pyx_k_BYS[] = "BYS";
static const char __pyx_k_CBH[] = "CBH";
static const char __pyx_k_CBM[] = "CBM";
static const char __pyx_k_Day[] = "Day";
static const char __pyx_k_H_M[] = "%H:%M";
static const char __pyx_k_Min[] = "Min";
static const char __pyx_k_REQ[] = "REQ";
static const char __pyx_k_SMS[] = "SMS";
static const char __pyx_k_WOM[] = "WOM";
static const char __pyx_k__13[] = "_";
static const char __pyx_k__15[] = "";
static const char __pyx_k__16[] = " * ";
static const char __pyx_k__17[] = "<";
static const char __pyx_k__18[] = ">";
static const char __pyx_k__19[] = "=";
static const char __pyx_k__20[] = ": ";
static const char __pyx_k__21[] = ", ";
static const char __pyx_k__37[] = "+";
static const char __pyx_k__38[] = "-";
static const char __pyx_k__46[] = ":";
static const char __pyx_k__47[] = ",";
static const char __pyx_k__67[] = "*";
static const char __pyx_k_add[] = "__add__";
static const char __pyx_k_and[] = " and ";
static const char __pyx_k_cls[] = "cls";
static const char __pyx_k_day[] = "day";
static const char __pyx_k_dim[] = "dim";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_dts[] = "dts";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_err[] = "err";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_hrs[] = "hrs";
static const char __pyx_k_inc[] = "inc";
static const char __pyx_k_int[] = "int";
static const char __pyx_k_kwd[] = "kwd";
static const char __pyx_k_min[] = "min";
static const char __pyx_k_mts[] = "mts";
static const char __pyx_k_mul[] = "__mul__";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_ret[] = "ret";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sum[] = "sum";
static const char __pyx_k_tup[] = "tup";
static const char __pyx_k_val[] = "val";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_BDay[] = "BDay";
static const char __pyx_k_CBMS[] = "CBMS";
static const char __pyx_k_CDay[] = "CDay";
static const char __pyx_k_Hour[] = "Hour";
static const char __pyx_k_LWOM[] = "LWOM";
static const char __pyx_k_Nano[] = "Nano";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_Tick[] = "Tick";
static const char __pyx_k_Week[] = "Week";
static const char __pyx_k__284[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_attr[] = "attr";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_code[] = "code";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_date[] = "date";
static const char __pyx_k_days[] = "days";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_fabs[] = "fabs";
static const char __pyx_k_freq[] = "freq";
static const char __pyx_k_fstr[] = "fstr";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_hour[] = "hour";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_kwds[] = "kwds";
static const char __pyx_k_last[] = "last";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mend[] = "mend";
static const char __pyx_k_moff[] = "moff";
static const char __pyx_k_nadj[] = "nadj";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_nano[] = "nano";
static const char __pyx_k_ndim[] = "ndim";
static const char __pyx_k_nint[] = "nint";
static const char __pyx_k_norm[] = "norm";
static const char __pyx_k_qlen[] = "qlen";
static const char __pyx_k_qtrs[] = "qtrs";
static const char __pyx_k_reso[] = "reso";
static const char __pyx_k_roll[] = "roll";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sign[] = "sign";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_span[] = "span";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_td64[] = "td64";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_unit[] = "unit";
static const char __pyx_k_view[] = "view";
static const char __pyx_k_wday[] = "wday";
static const char __pyx_k_week[] = "week";
static const char __pyx_k_year[] = "year";
static const char __pyx_k_zero[] = "zero";
static const char __pyx_k_09_00[] = "09:00";
static const char __pyx_k_17_00[] = "17:00";
static const char __pyx_k_A_DEC[] = "A-DEC";
static const char __pyx_k_Micro[] = "Micro";
static const char __pyx_k_Milli[] = "Milli";
static const char __pyx_k_Q_DEC[] = "Q-DEC";
static const char __pyx_k_W_SUN[] = "W-SUN";
static const char __pyx_k_apply[] = "_apply";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_attrs[] = "attrs";
static const char __pyx_k_bhour[] = "bhour";
static const char __pyx_k_cache[] = "_cache";
static const char __pyx_k_cbday[] = "cbday";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_creso[] = "_creso";
static const char __pyx_k_day64[] = "day64";
static const char __pyx_k_delta[] = "delta";
static const char __pyx_k_dtarr[] = "dtarr";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_get_2[] = "__get__";
static const char __pyx_k_hours[] = "hours";
static const char __pyx_k_inc_2[] = "_inc";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_klass[] = "klass";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_modby[] = "modby";
static const char __pyx_k_month[] = "month";
static const char __pyx_k_nanos[] = "nanos";
static const char __pyx_k_new_2[] = "new";
static const char __pyx_k_np_dt[] = "np_dt";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_other[] = "other";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_stamp[] = "stamp";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_until[] = "until";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_value[] = "_value";
static const char __pyx_k_weeks[] = "weeks";
static const char __pyx_k_years[] = "years";
static const char __pyx_k_AS_JAN[] = "AS-JAN";
static const char __pyx_k_BA_DEC[] = "BA-DEC";
static const char __pyx_k_Easter[] = "Easter";
static const char __pyx_k_FY5253[] = "FY5253";
static const char __pyx_k_Minute[] = "Minute";
static const char __pyx_k_Prefix[] = "Prefix ";
static const char __pyx_k_Second[] = "Second";
static const char __pyx_k_anchor[] = "_anchor";
static const char __pyx_k_astype[] = "astype";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_easter[] = "easter";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_minute[] = "minute";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_months[] = "months";
static const char __pyx_k_mstart[] = "mstart";
static const char __pyx_k_name_2[] = "name";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_offset[] = "_offset";
static const char __pyx_k_params[] = "_params";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_prefix[] = "_prefix";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remain[] = "remain";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_second[] = "second";
static const char __pyx_k_suffix[] = "suffix";
static const char __pyx_k_tdelta[] = "tdelta";
static const char __pyx_k_tm_min[] = "tm_min";
static const char __pyx_k_to_day[] = "to_day";
static const char __pyx_k_tolist[] = "tolist";
static const char __pyx_k_tzinfo[] = "tzinfo";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_BAS_JAN[] = "BAS-JAN";
static const char __pyx_k_YearEnd[] = "YearEnd";
static const char __pyx_k_argsort[] = "argsort";
static const char __pyx_k_as_unit[] = "as_unit";
static const char __pyx_k_asarray[] = "asarray";
static const char __pyx_k_combine[] = "combine";
static const char __pyx_k_compare[] = "compare";
static const char __pyx_k_compile[] = "compile";
static const char __pyx_k_current[] = "current";
static const char __pyx_k_date_in[] = "date_in";
static const char __pyx_k_day_opt[] = "_day_opt";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_dt_date[] = "dt_date";
static const char __pyx_k_dtindex[] = "dtindex";
static const char __pyx_k_dtstart[] = "dtstart";
static const char __pyx_k_exclude[] = "exclude";
static const char __pyx_k_forward[] = "forward";
static const char __pyx_k_freqstr[] = "freqstr";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_get_str[] = "get_str";
static const char __pyx_k_i8other[] = "i8other";
static const char __pyx_k_isclose[] = "isclose";
static const char __pyx_k_isspace[] = "isspace";
static const char __pyx_k_minutes[] = "minutes";
static const char __pyx_k_ndarray[] = "ndarray";
static const char __pyx_k_nearest[] = "nearest";
static const char __pyx_k_off_str[] = "off_str";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_qtr_len[] = "qtr_len";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_res_val[] = "res_val";
static const char __pyx_k_result2[] = "result2";
static const char __pyx_k_seconds[] = "seconds";
static const char __pyx_k_setattr[] = "__setattr__";
static const char __pyx_k_shifted[] = "shifted";
static const char __pyx_k_skip_bd[] = "skip_bd";
static const char __pyx_k_td_nano[] = "td_nano";
static const char __pyx_k_tm_hour[] = "tm_hour";
static const char __pyx_k_truediv[] = "__truediv__";
static const char __pyx_k_value_2[] = "value";
static const char __pyx_k_weekday[] = "weekday";
static const char __pyx_k_wrapper[] = "wrapper";
static const char __pyx_k_BYearEnd[] = "BYearEnd";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_MonthEnd[] = "MonthEnd";
static const char __pyx_k_backward[] = "backward";
static const char __pyx_k_calendar[] = "calendar";
static const char __pyx_k_cur_year[] = "cur_year";
static const char __pyx_k_datetime[] = "datetime";
static const char __pyx_k_endswith[] = "endswith";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_holidays[] = "holidays";
static const char __pyx_k_is_start[] = "is_start";
static const char __pyx_k_issubset[] = "issubset";
static const char __pyx_k_m_offset[] = "m_offset";
static const char __pyx_k_num_nano[] = "num_nano";
static const char __pyx_k_num_qtrs[] = "num_qtrs";
static const char __pyx_k_offset_2[] = "offset";
static const char __pyx_k_offset_3[] = "offset=";
static const char __pyx_k_opattern[] = "opattern";
static const char __pyx_k_otherDay[] = "otherDay";
static const char __pyx_k_params_2[] = "params";
static const char __pyx_k_prefix_2[] = "prefix";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qtr_lens[] = "qtr_lens";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_rem_nano[] = "rem_nano";
static const char __pyx_k_reversed[] = "reversed";
static const char __pyx_k_rollback[] = "rollback";
static const char __pyx_k_rtruediv[] = "__rtruediv__";
static const char __pyx_k_set_name[] = "__set_name__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_strptime[] = "strptime";
static const char __pyx_k_weekmask[] = "weekmask";
static const char __pyx_k_year_end[] = "year_end";
static const char __pyx_k_BMonthEnd[] = "BMonthEnd";
static const char __pyx_k_Timedelta[] = "Timedelta";
static const char __pyx_k_Timestamp[] = "Timestamp";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_YearBegin[] = "YearBegin";
static const char __pyx_k_all_paras[] = "all_paras";
static const char __pyx_k_busdaycal[] = "busdaycal";
static const char __pyx_k_day_opt_2[] = "day_opt";
static const char __pyx_k_dt64other[] = "dt64other";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_from_name[] = "_from_name";
static const char __pyx_k_get_weeks[] = "get_weeks";
static const char __pyx_k_is_busday[] = "is_busday";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_mod_month[] = "mod_month";
static const char __pyx_k_nanos_inc[] = "_nanos_inc";
static const char __pyx_k_nb_offset[] = "nb_offset";
static const char __pyx_k_next_bday[] = "next_bday";
static const char __pyx_k_next_year[] = "next_year";
static const char __pyx_k_normalize[] = "normalize";
static const char __pyx_k_prev_open[] = "prev_open";
static const char __pyx_k_prev_year[] = "prev_year";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_roll_func[] = "roll_func";
static const char __pyx_k_rule_code[] = "rule_code";
static const char __pyx_k_td64_unit[] = "_td64_unit";
static const char __pyx_k_timedelta[] = "timedelta";
static const char __pyx_k_to_offset[] = "to_offset";
static const char __pyx_k_undefined[] = "undefined";
static const char __pyx_k_variation[] = "variation";
static const char __pyx_k_BYearBegin[] = "BYearBegin";
static const char __pyx_k_BaseOffset[] = "BaseOffset";
static const char __pyx_k_CBMonthEnd[] = "CBMonthEnd";
static const char __pyx_k_Cannot_add[] = "Cannot add ";
static const char __pyx_k_DateOffset[] = "DateOffset";
static const char __pyx_k_MonthBegin[] = "MonthBegin";
static const char __pyx_k_OffsetMeta[] = "OffsetMeta";
static const char __pyx_k_QuarterEnd[] = "QuarterEnd";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_YearOffset[] = "YearOffset";
static const char __pyx_k_adjust_dst[] = "_adjust_dst";
static const char __pyx_k_anchor_dom[] = "anchor_dom";
static const char __pyx_k_attributes[] = "_attributes";
static const char __pyx_k_cbday_kwds[] = "cbday_kwds";
static const char __pyx_k_cbday_roll[] = "cbday_roll";
static const char __pyx_k_datetime64[] = "datetime64";
static const char __pyx_k_get_offset[] = "_get_offset";
static const char __pyx_k_month_roll[] = "month_roll";
static const char __pyx_k_nanosecond[] = "nanosecond";
static const char __pyx_k_np_incr_dt[] = "np_incr_dt";
static const char __pyx_k_np_ndarray[] = "np.ndarray";
static const char __pyx_k_offset_map[] = "_offset_map";
static const char __pyx_k_offset_str[] = "_offset_str";
static const char __pyx_k_outputName[] = "_outputName";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_repr_attrs[] = "_repr_attrs";
static const char __pyx_k_shift_days[] = "shift_days";
static const char __pyx_k_startswith[] = "startswith";
static const char __pyx_k_timedeltas[] = "timedeltas";
static const char __pyx_k_timestamps[] = "timestamps";
static const char __pyx_k_validate_n[] = "_validate_n";
static const char __pyx_k_vectorized[] = "vectorized";
static const char __pyx_k_wkday_diff[] = "wkday_diff";
static const char __pyx_k_BMonthBegin[] = "BMonthBegin";
static const char __pyx_k_BQuarterEnd[] = "BQuarterEnd";
static const char __pyx_k_BusinessDay[] = "BusinessDay";
static const char __pyx_k_FY5253Mixin[] = "FY5253Mixin";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_MonthOffset[] = "MonthOffset";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_Tick__apply[] = "Tick._apply";
static const char __pyx_k_WeekOfMonth[] = "WeekOfMonth";
static const char __pyx_k_Week__apply[] = "Week._apply";
static const char __pyx_k_apply_array[] = "_apply_array";
static const char __pyx_k_apply_wraps[] = "apply_wraps";
static const char __pyx_k_compare_day[] = "compare_day";
static const char __pyx_k_init_custom[] = "_init_custom";
static const char __pyx_k_is_anchored[] = "is_anchored";
static const char __pyx_k_is_year_end[] = "is_year_end";
static const char __pyx_k_microsecond[] = "microsecond";
static const char __pyx_k_millisecond[] = "millisecond";
static const char __pyx_k_mro_entries[] = "__mro_entries__";
static const char __pyx_k_nanoseconds[] = "nanoseconds";
static const char __pyx_k_output_name[] = "_output_name";
static const char __pyx_k_roll_qtrday[] = "roll_qtrday";
static const char __pyx_k_rollforward[] = "rollforward";
static const char __pyx_k_shift_month[] = "shift_month";
static const char __pyx_k_target_date[] = "target_date";
static const char __pyx_k_timedelta64[] = "timedelta64";
static const char __pyx_k_tz_localize[] = "tz_localize";
static const char __pyx_k_varion_code[] = "varion_code";
static const char __pyx_k_BusinessHour[] = "BusinessHour";
static const char __pyx_k_CBMonthBegin[] = "CBMonthBegin";
static const char __pyx_k_QuarterBegin[] = "QuarterBegin";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_SemiMonthEnd[] = "SemiMonthEnd";
static const char __pyx_k_bhour_remain[] = "bhour_remain";
static const char __pyx_k_business_end[] = "business_end";
static const char __pyx_k_compare_date[] = "compare_date";
static const char __pyx_k_datetime64_D[] = "datetime64[D]";
static const char __pyx_k_day_of_month[] = "day_of_month";
static const char __pyx_k_days_forward[] = "days_forward";
static const char __pyx_k_get_year_end[] = "get_year_end";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_is_month_end[] = "is_month_end";
static const char __pyx_k_is_on_offset[] = "is_on_offset";
static const char __pyx_k_is_same_sign[] = "is_same_sign";
static const char __pyx_k_latest_start[] = "latest_start";
static const char __pyx_k_microseconds[] = "microseconds";
static const char __pyx_k_milliseconds[] = "milliseconds";
static const char __pyx_k_months_since[] = "months_since";
static const char __pyx_k_parse_suffix[] = "_parse_suffix";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_shift_months[] = "shift_months";
static const char __pyx_k_staticmethod[] = "staticmethod";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_weekday_code[] = "weekday_code";
static const char __pyx_k_BQuarterBegin[] = "BQuarterBegin";
static const char __pyx_k_BusinessMixin[] = "BusinessMixin";
static const char __pyx_k_Easter__apply[] = "Easter._apply";
static const char __pyx_k_FY5253Quarter[] = "FY5253Quarter";
static const char __pyx_k_FY5253__apply[] = "FY5253._apply";
static const char __pyx_k_MONTH_ALIASES[] = "MONTH_ALIASES";
static const char __pyx_k_N_cannot_be_0[] = "N cannot be 0";
static const char __pyx_k_OverflowError[] = "OverflowError";
static const char __pyx_k_QuarterOffset[] = "QuarterOffset";
static const char __pyx_k_busday_offset[] = "busday_offset";
static const char __pyx_k_businesshours[] = "businesshours";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_days_in_month[] = "days_in_month";
static const char __pyx_k_default_month[] = "_default_month";
static const char __pyx_k_delta_to_tick[] = "delta_to_tick";
static const char __pyx_k_init_subclass[] = "__init_subclass__";
static const char __pyx_k_instancecheck[] = "__instancecheck__";
static const char __pyx_k_is_year_start[] = "is_year_start";
static const char __pyx_k_next_year_end[] = "next_year_end";
static const char __pyx_k_prev_year_end[] = "prev_year_end";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_relativedelta[] = "relativedelta";
static const char __pyx_k_startingMonth[] = "startingMonth";
static const char __pyx_k_subclasscheck[] = "__subclasscheck__";
static const char __pyx_k_to_pydatetime[] = "to_pydatetime";
static const char __pyx_k_total_seconds[] = "total_seconds";
static const char __pyx_k_weeks_in_year[] = "weeks_in_year";
static const char __pyx_k_will_overflow[] = " will overflow";
static const char __pyx_k_ApplyTypeError[] = "ApplyTypeError";
static const char __pyx_k_AssertionError[] = "AssertionError";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_NotImplemented[] = "NotImplemented";
static const char __pyx_k_SemiMonthBegin[] = "SemiMonthBegin";
static const char __pyx_k_Unhandled_type[] = "Unhandled type: ";
static const char __pyx_k_array_priority[] = "__array_priority__";
static const char __pyx_k_busdaycalendar[] = "busdaycalendar";
static const char __pyx_k_business_start[] = "business_start";
static const char __pyx_k_cache_readonly[] = "cache_readonly";
static const char __pyx_k_current_easter[] = "current_easter";
static const char __pyx_k_dont_uppercase[] = "_dont_uppercase";
static const char __pyx_k_earliest_start[] = "earliest_start";
static const char __pyx_k_get_offset_day[] = "_get_offset_day";
static const char __pyx_k_int_to_weekday[] = "int_to_weekday";
static const char __pyx_k_is_month_start[] = "is_month_start";
static const char __pyx_k_is_on_offset_2[] = "_is_on_offset";
static const char __pyx_k_is_quarter_end[] = "is_quarter_end";
static const char __pyx_k_months_to_roll[] = "months_to_roll";
static const char __pyx_k_prefix_mapping[] = "prefix_mapping";
static const char __pyx_k_timedelta_kwds[] = "timedelta_kwds";
static const char __pyx_k_to_pytimedelta[] = "to_pytimedelta";
static const char __pyx_k_weekday_to_int[] = "weekday_to_int";
static const char __pyx_k_Bad_freq_suffix[] = "Bad freq suffix ";
static const char __pyx_k_BaseOffset_copy[] = "BaseOffset.copy";
static const char __pyx_k_BusinessYearEnd[] = "BusinessYearEnd";
static const char __pyx_k_LastWeekOfMonth[] = "LastWeekOfMonth";
static const char __pyx_k_SemiMonthOffset[] = "SemiMonthOffset";
static const char __pyx_k_Tick___setstate[] = "Tick.__setstate__";
static const char __pyx_k_Week___setstate[] = "Week.__setstate__";
static const char __pyx_k_Week__from_name[] = "Week._from_name";
static const char __pyx_k_dateutil_easter[] = "dateutil.easter";
static const char __pyx_k_lite_rule_alias[] = "_lite_rule_alias";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_roll_convention[] = "roll_convention";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_BusinessMonthEnd[] = "BusinessMonthEnd";
static const char __pyx_k_MONTH_TO_CAL_NUM[] = "MONTH_TO_CAL_NUM";
static const char __pyx_k_Tick__repr_attrs[] = "Tick._repr_attrs";
static const char __pyx_k_Tick_is_anchored[] = "Tick.is_anchored";
static const char __pyx_k_WeekOfMonthMixin[] = "WeekOfMonthMixin";
static const char __pyx_k_Week_is_anchored[] = "Week.is_anchored";
static const char __pyx_k_get_closing_time[] = "_get_closing_time";
static const char __pyx_k_is_quarter_start[] = "is_quarter_start";
static const char __pyx_k_min_day_of_month[] = "_min_day_of_month";
static const char __pyx_k_rollback_to_year[] = "_rollback_to_year";
static const char __pyx_k_BaseOffset__apply[] = "BaseOffset._apply";
static const char __pyx_k_BusinessYearBegin[] = "BusinessYearBegin";
static const char __pyx_k_CustomBusinessDay[] = "CustomBusinessDay";
static const char __pyx_k_Easter___setstate[] = "Easter.__setstate__";
static const char __pyx_k_FY5253__from_name[] = "FY5253._from_name";
static const char __pyx_k_Tick_is_on_offset[] = "Tick.is_on_offset";
static const char __pyx_k_Week__apply_array[] = "Week._apply_array";
static const char __pyx_k_Week_is_on_offset[] = "Week.is_on_offset";
static const char __pyx_k_YearOffset__apply[] = "YearOffset._apply";
static const char __pyx_k_apply_array_wraps[] = "apply_array_wraps";
static const char __pyx_k_get_suffix_prefix[] = "_get_suffix_prefix";
static const char __pyx_k_next_opening_time[] = "_next_opening_time";
static const char __pyx_k_period_dtype_code[] = "_period_dtype_code";
static const char __pyx_k_prev_opening_time[] = "_prev_opening_time";
static const char __pyx_k_requires_a_suffix[] = " requires a suffix.";
static const char __pyx_k_use_relativedelta[] = "_use_relativedelta";
static const char __pyx_k_BaseOffset__params[] = "BaseOffset._params";
static const char __pyx_k_BaseOffset_freqstr[] = "BaseOffset.freqstr";
static const char __pyx_k_BusinessDay__apply[] = "BusinessDay._apply";
static const char __pyx_k_BusinessMonthBegin[] = "BusinessMonthBegin";
static const char __pyx_k_BusinessQuarterEnd[] = "BusinessQuarterEnd";
static const char __pyx_k_CustomBusinessHour[] = "CustomBusinessHour";
static const char __pyx_k_MonthOffset__apply[] = "MonthOffset._apply";
static const char __pyx_k_Prefix_not_defined[] = "Prefix not defined";
static const char __pyx_k_apply_wrapper_core[] = "apply_wrapper_core";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_relativedelta_fast[] = "relativedelta_fast";
static const char __pyx_k_relativedelta_kwds[] = "_relativedelta_kwds";
static const char __pyx_k_startingMonth_code[] = "startingMonth_code";
static const char __pyx_k_BaseOffset_rollback[] = "BaseOffset.rollback";
static const char __pyx_k_BusinessHour__apply[] = "BusinessHour._apply";
static const char __pyx_k_CustomBusinessMonth[] = "_CustomBusinessMonth";
static const char __pyx_k_DateOffset_subclass[] = "DateOffset subclass ";
static const char __pyx_k_Easter_is_on_offset[] = "Easter.is_on_offset";
static const char __pyx_k_FY5253_get_year_end[] = "FY5253.get_year_end";
static const char __pyx_k_FY5253_is_on_offset[] = "FY5253.is_on_offset";
static const char __pyx_k_Invalid_frequency_0[] = "Invalid frequency: {0}";
static const char __pyx_k_Mon_Tue_Wed_Thu_Fri[] = "Mon Tue Wed Thu Fri";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_RelativeDeltaOffset[] = "RelativeDeltaOffset";
static const char __pyx_k_day_of_month_27_got[] = "<=day_of_month<=27, got ";
static const char __pyx_k_qtr_with_extra_week[] = "qtr_with_extra_week";
static const char __pyx_k_to_offset_line_4102[] = "to_offset (line 4102)";
static const char __pyx_k_year_has_extra_week[] = "year_has_extra_week";
static const char __pyx_k_BusinessQuarterBegin[] = "BusinessQuarterBegin";
static const char __pyx_k_DateOffset___setattr[] = "DateOffset.__setattr__";
static const char __pyx_k_FY5253Quarter__apply[] = "FY5253Quarter._apply";
static const char __pyx_k_FY5253__parse_suffix[] = "FY5253._parse_suffix";
static const char __pyx_k_INVALID_FREQ_ERR_MSG[] = "INVALID_FREQ_ERR_MSG";
static const char __pyx_k_QuarterOffset__apply[] = "QuarterOffset._apply";
static const char __pyx_k_apply_locals_genexpr[] = "_apply.<locals>.genexpr";
static const char __pyx_k_day_of_month_must_be[] = "day_of_month must be ";
static const char __pyx_k_default_day_of_month[] = "_default_day_of_month";
static const char __pyx_k_get_rule_code_suffix[] = "get_rule_code_suffix";
static const char __pyx_k_BaseOffset___getstate[] = "BaseOffset.__getstate__";
static const char __pyx_k_BaseOffset___setstate[] = "BaseOffset.__setstate__";
static const char __pyx_k_BusinessHour_rollback[] = "BusinessHour.rollback";
static const char __pyx_k_FY5253Quarter__offset[] = "FY5253Quarter._offset";
static const char __pyx_k_YearOffset___setstate[] = "YearOffset.__setstate__";
static const char __pyx_k_YearOffset__from_name[] = "YearOffset._from_name";
static const char __pyx_k_cur_month_offset_date[] = "cur_month_offset_date";
static const char __pyx_k_BaseOffset__offset_str[] = "BaseOffset._offset_str";
static const char __pyx_k_BaseOffset__repr_attrs[] = "BaseOffset._repr_attrs";
static const char __pyx_k_BaseOffset__validate_n[] = "BaseOffset._validate_n";
static const char __pyx_k_BaseOffset_is_anchored[] = "BaseOffset.is_anchored";
static const char __pyx_k_BaseOffset_is_year_end[] = "BaseOffset.is_year_end";
static const char __pyx_k_BaseOffset_rollforward[] = "BaseOffset.rollforward";
static const char __pyx_k_BusinessDay___setstate[] = "BusinessDay.__setstate__";
static const char __pyx_k_BusinessHour_next_bday[] = "BusinessHour.next_bday";
static const char __pyx_k_CustomBusinessMonthEnd[] = "CustomBusinessMonthEnd";
static const char __pyx_k_FY5253Mixin___setstate[] = "FY5253Mixin.__setstate__";
static const char __pyx_k_MonthOffset___setstate[] = "MonthOffset.__setstate__";
static const char __pyx_k_SemiMonthOffset__apply[] = "SemiMonthOffset._apply";
static const char __pyx_k_Unexpected_key__offset[] = "Unexpected key `_offset`";
static const char __pyx_k_WeekOfMonth___setstate[] = "WeekOfMonth.__setstate__";
static const char __pyx_k_WeekOfMonth__from_name[] = "WeekOfMonth._from_name";
static const char __pyx_k_d_d_d_s_A_Za_z_dA_Za_z[] = "([+\\-]?\\d*|[+\\-]?\\d*\\.\\d*)\\s*([A-Za-z]+([\\-][\\dA-Za-z\\-]+)?)";
static const char __pyx_k_dateutil_relativedelta[] = "dateutil.relativedelta";
static const char __pyx_k_default_starting_month[] = "_default_starting_month";
static const char __pyx_k_next_higher_resolution[] = "_next_higher_resolution";
static const char __pyx_k_BaseOffset__apply_array[] = "BaseOffset._apply_array";
static const char __pyx_k_BaseOffset_is_month_end[] = "BaseOffset.is_month_end";
static const char __pyx_k_BaseOffset_is_on_offset[] = "BaseOffset.is_on_offset";
static const char __pyx_k_BusinessDay__offset_str[] = "BusinessDay._offset_str";
static const char __pyx_k_BusinessHour___setstate[] = "BusinessHour.__setstate__";
static const char __pyx_k_Day_must_be_0_day_6_got[] = "Day must be 0<=day<=6, got ";
static const char __pyx_k_FY5253Mixin_is_anchored[] = "FY5253Mixin.is_anchored";
static const char __pyx_k_FY5253Quarter_get_weeks[] = "FY5253Quarter.get_weeks";
static const char __pyx_k_SingleConstructorOffset[] = "SingleConstructorOffset";
static const char __pyx_k_WeekOfMonthMixin__apply[] = "WeekOfMonthMixin._apply";
static const char __pyx_k_YearOffset__apply_array[] = "YearOffset._apply_array";
static const char __pyx_k_YearOffset_is_on_offset[] = "YearOffset.is_on_offset";
static const char __pyx_k_normalize_i8_timestamps[] = "normalize_i8_timestamps";
static const char __pyx_k_pandas__libs_properties[] = "pandas._libs.properties";
static const char __pyx_k_pyx_unpickle_BaseOffset[] = "__pyx_unpickle_BaseOffset";
static const char __pyx_k_reduce___locals_genexpr[] = "__reduce__.<locals>.genexpr";
static const char __pyx_k_BaseOffset_copy_line_532[] = "BaseOffset.copy (line 532)";
static const char __pyx_k_BaseOffset_is_year_start[] = "BaseOffset.is_year_start";
static const char __pyx_k_BusinessDay__apply_array[] = "BusinessDay._apply_array";
static const char __pyx_k_BusinessDay_is_on_offset[] = "BusinessDay.is_on_offset";
static const char __pyx_k_BusinessHour__repr_attrs[] = "BusinessHour._repr_attrs";
static const char __pyx_k_BusinessHour_rollforward[] = "BusinessHour.rollforward";
static const char __pyx_k_BusinessMixin___setstate[] = "BusinessMixin.__setstate__";
static const char __pyx_k_CustomBusinessDay__apply[] = "CustomBusinessDay._apply";
static const char __pyx_k_CustomBusinessMonthBegin[] = "CustomBusinessMonthBegin";
static const char __pyx_k_FY5253Quarter___setstate[] = "FY5253Quarter.__setstate__";
static const char __pyx_k_FY5253Quarter__from_name[] = "FY5253Quarter._from_name";
static const char __pyx_k_MonthOffset__apply_array[] = "MonthOffset._apply_array";
static const char __pyx_k_MonthOffset_is_on_offset[] = "MonthOffset.is_on_offset";
static const char __pyx_k_QuarterOffset___setstate[] = "QuarterOffset.__setstate__";
static const char __pyx_k_QuarterOffset__from_name[] = "QuarterOffset._from_name";
static const char __pyx_k_from_name_starting_month[] = "_from_name_starting_month";
static const char __pyx_k_is_a_non_fixed_frequency[] = " is a non-fixed frequency";
static const char __pyx_k_is_not_a_valid_variation[] = " is not a valid variation";
static const char __pyx_k_pass_as_a_string_instead[] = ", pass as a string instead";
static const char __pyx_k_separator_must_be_spaces[] = "separator must be spaces";
static const char __pyx_k_BaseOffset_is_month_start[] = "BaseOffset.is_month_start";
static const char __pyx_k_BaseOffset_is_quarter_end[] = "BaseOffset.is_quarter_end";
static const char __pyx_k_BusinessHour_is_on_offset[] = "BusinessHour.is_on_offset";
static const char __pyx_k_BusinessMixin__repr_attrs[] = "BusinessMixin._repr_attrs";
static const char __pyx_k_QuarterOffset_is_anchored[] = "QuarterOffset.is_anchored";
static const char __pyx_k_SemiMonthEnd_is_on_offset[] = "SemiMonthEnd.is_on_offset";
static const char __pyx_k_Week_must_be_0_week_3_got[] = "Week must be 0<=week<=3, got ";
static const char __pyx_k_get_business_hours_by_sec[] = "_get_business_hours_by_sec";
static const char __pyx_k_implemented_by_subclasses[] = "implemented by subclasses";
static const char __pyx_k_offset_str_locals_get_str[] = "_offset_str.<locals>.get_str";
static const char __pyx_k_repr_attrs_locals_genexpr[] = "_repr_attrs.<locals>.genexpr";
static const char __pyx_k_the_add_operation_between[] = "the add operation between ";
static const char __pyx_k_BaseOffset___reduce_cython[] = "BaseOffset.__reduce_cython__";
static const char __pyx_k_BaseOffset__get_offset_day[] = "BaseOffset._get_offset_day";
static const char __pyx_k_BusinessHour__is_on_offset[] = "BusinessHour._is_on_offset";
static const char __pyx_k_BusinessMixin__init_custom[] = "BusinessMixin._init_custom";
static const char __pyx_k_CustomBusinessMonth__apply[] = "_CustomBusinessMonth._apply";
static const char __pyx_k_FY5253Quarter_is_on_offset[] = "FY5253Quarter.is_on_offset";
static const char __pyx_k_LastWeekOfMonth___setstate[] = "LastWeekOfMonth.__setstate__";
static const char __pyx_k_LastWeekOfMonth__from_name[] = "LastWeekOfMonth._from_name";
static const char __pyx_k_Month_must_go_from_1_to_12[] = "Month must go from 1 to 12";
static const char __pyx_k_OffsetMeta___instancecheck[] = "OffsetMeta.__instancecheck__";
static const char __pyx_k_OffsetMeta___subclasscheck[] = "OffsetMeta.__subclasscheck__";
static const char __pyx_k_QuarterOffset__apply_array[] = "QuarterOffset._apply_array";
static const char __pyx_k_QuarterOffset_is_on_offset[] = "QuarterOffset.is_on_offset";
static const char __pyx_k_RelativeDeltaOffset__apply[] = "RelativeDeltaOffset._apply";
static const char __pyx_k_SemiMonthOffset___setstate[] = "SemiMonthOffset.__setstate__";
static const char __pyx_k_SemiMonthOffset__from_name[] = "SemiMonthOffset._from_name";
static const char __pyx_k_YearOffset__get_offset_day[] = "YearOffset._get_offset_day";
static const char __pyx_k_apply_wraps_locals_wrapper[] = "apply_wraps.<locals>.wrapper";
static const char __pyx_k_last_element_must_be_blank[] = "last element must be blank";
static const char __pyx_k_BaseOffset_freqstr_line_607[] = "BaseOffset.freqstr (line 607)";
static const char __pyx_k_BaseOffset_is_quarter_start[] = "BaseOffset.is_quarter_start";
static const char __pyx_k_SemiMonthBegin_is_on_offset[] = "SemiMonthBegin.is_on_offset";
static const char __pyx_k_Tick_nanos___get___line_953[] = "Tick.nanos.__get__ (line 953)";
static const char __pyx_k_Unable_to_parse_varion_code[] = "Unable to parse varion_code: ";
static const char __pyx_k_WeekOfMonth__get_offset_day[] = "WeekOfMonth._get_offset_day";
static const char __pyx_k_pandas__libs_tslibs_offsets[] = "pandas._libs.tslibs.offsets";
static const char __pyx_k_BaseOffset___setstate_cython[] = "BaseOffset.__setstate_cython__";
static const char __pyx_k_CustomBusinessDay___setstate[] = "CustomBusinessDay.__setstate__";
static const char __pyx_k_CustomBusinessMonth_m_offset[] = "_CustomBusinessMonth.m_offset";
static const char __pyx_k_SemiMonthOffset__apply_array[] = "SemiMonthOffset._apply_array";
static const char __pyx_k_Tick__next_higher_resolution[] = "Tick._next_higher_resolution";
static const char __pyx_k_WeekOfMonthMixin_is_on_offset[] = "WeekOfMonthMixin.is_on_offset";
static const char __pyx_k_pandas__libs_tslibs_ccalendar[] = "pandas._libs.tslibs.ccalendar";
static const char __pyx_k_BusinessHour__get_closing_time[] = "BusinessHour._get_closing_time";
static const char __pyx_k_CustomBusinessDay_is_on_offset[] = "CustomBusinessDay.is_on_offset";
static const char __pyx_k_CustomBusinessMonth_cbday_roll[] = "_CustomBusinessMonth.cbday_roll";
static const char __pyx_k_CustomBusinessMonth_month_roll[] = "_CustomBusinessMonth.month_roll";
static const char __pyx_k_FY5253Mixin__get_suffix_prefix[] = "FY5253Mixin._get_suffix_prefix";
static const char __pyx_k_RelativeDeltaOffset___getstate[] = "RelativeDeltaOffset.__getstate__";
static const char __pyx_k_RelativeDeltaOffset___setstate[] = "RelativeDeltaOffset.__setstate__";
static const char __pyx_k_Return_a_copy_of_the_frequency[] = "\n        Return a copy of the frequency.\n\n        Examples\n        --------\n        >>> freq = pd.DateOffset(1)\n        >>> freq_copy = freq.copy()\n        >>> freq is freq_copy\n        False\n        ";
static const char __pyx_k_Return_an_integer_of_the_total[] = "\n        Return an integer of the total number of nanoseconds.\n\n        Raises\n        ------\n        ValueError\n            If the frequency is non-fixed.\n\n        Examples\n        --------\n        >>> pd.offsets.Hour(5).nanos\n        18000000000000\n        ";
static const char __pyx_k_pyx_unpickle_RelativeDeltaOffs[] = "__pyx_unpickle_RelativeDeltaOffset";
static const char __pyx_k_BaseOffset_is_anchored_line_790[] = "BaseOffset.is_anchored (line 790)";
static const char __pyx_k_BaseOffset_is_year_end_line_872[] = "BaseOffset.is_year_end (line 872)";
static const char __pyx_k_BusinessHour__next_opening_time[] = "BusinessHour._next_opening_time";
static const char __pyx_k_BusinessHour__prev_opening_time[] = "BusinessHour._prev_opening_time";
static const char __pyx_k_FY5253Quarter__rollback_to_year[] = "FY5253Quarter._rollback_to_year";
static const char __pyx_k_LastWeekOfMonth__get_offset_day[] = "LastWeekOfMonth._get_offset_day";
static const char __pyx_k_Metaclass_that_allows_us_to_pre[] = "\n    Metaclass that allows us to pretend that all BaseOffset subclasses\n    inherit from DateOffset (which is needed for backward-compatibility).\n    ";
static const char __pyx_k_Return_DateOffset_object_from_s[] = "\n    Return DateOffset object from string or datetime.timedelta object.\n\n    Parameters\n    ----------\n    freq : str, datetime.timedelta, BaseOffset or None\n\n    Returns\n    -------\n    DateOffset or None\n\n    Raises\n    ------\n    ValueError\n        If freq is an invalid frequency\n\n    See Also\n    --------\n    BaseOffset : Standard kind of date increment used for a date range.\n\n    Examples\n    --------\n    >>> to_offset(\"5min\")\n    <5 * Minutes>\n\n    >>> to_offset(\"1D1H\")\n    <25 * Hours>\n\n    >>> to_offset(\"2W\")\n    <2 * Weeks: weekday=6>\n\n    >>> to_offset(\"2B\")\n    <2 * BusinessDays>\n\n    >>> to_offset(pd.Timedelta(days=1))\n    <Day>\n\n    >>> to_offset(Hour())\n    <Hour>\n    ";
static const char __pyx_k_Return_a_dict_of_extra_paramete[] = "\n        Return a dict of extra parameters for the offset.\n\n        Examples\n        --------\n        >>> pd.DateOffset(5).kwds\n        {}\n\n        >>> pd.offsets.FY5253Quarter().kwds\n        {'weekday': 0,\n         'startingMonth': 1,\n         'qtr_with_extra_week': 1,\n         'variation': 'nearest'}\n        ";
static const char __pyx_k_Return_a_string_representing_th[] = "\n        Return a string representing the base frequency.\n\n        Examples\n        --------\n        >>> pd.offsets.Hour().name\n        'H'\n\n        >>> pd.offsets.Hour(5).name\n        'H'\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest[] = "\n        Return boolean whether a timestamp intersects with this frequency.\n\n        Parameters\n        ----------\n        dt : datetime.datetime\n            Timestamp to check intersections with frequency.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Day(1)\n        >>> freq.is_on_offset(ts)\n        True\n\n        >>> ts = pd.Timestamp(2022, 8, 6)\n        >>> ts.day_name()\n        'Saturday'\n        >>> freq = pd.offsets.BusinessDay(1)\n        >>> freq.is_on_offset(ts)\n        False\n        ";
static const char __pyx_k_Return_boolean_whether_the_freq[] = "\n        Return boolean whether the frequency is a unit frequency (n=1).\n\n        Examples\n        --------\n        >>> pd.DateOffset().is_anchored()\n        True\n        >>> pd.DateOffset(2).is_anchored()\n        False\n        ";
static const char __pyx_k_Standard_kind_of_date_increment[] = "\n    Standard kind of date increment used for a date range.\n\n    Works exactly like the keyword argument form of relativedelta.\n    Note that the positional argument form of relativedelata is not\n    supported. Use of the keyword n is discouraged-- you would be better\n    off specifying n in the keywords you use, but regardless it is\n    there for you. n is needed for DateOffset subclasses.\n\n    DateOffset works as follows.  Each offset specify a set of dates\n    that conform to the DateOffset.  For example, Bday defines this\n    set to be the set of dates that are weekdays (M-F).  To test if a\n    date is in the set of a DateOffset dateOffset we can use the\n    is_on_offset method: dateOffset.is_on_offset(date).\n\n    If a date is not on a valid date, the rollback and rollforward\n    methods can be used to roll the date to the nearest valid date\n    before/after the date.\n\n    DateOffsets can be created to move dates forward a given number of\n    valid dates.  For example, Bday(2) can be added to a date to move\n    it two business days forward.  If the date does not start on a\n    valid date, first it is moved to a valid date.  Thus pseudo code\n    is::\n\n        def __add__(date):\n          date = rollback(date) # does nothing if date is valid\n          return date + <n number of periods>\n\n    When a date offset is created for a negative number of periods,\n    the date is first rolled forward.  The pseudo code is::\n\n        def __add__(date):\n          date = rollforward(date) # does nothing if date is valid\n          return date + <n number of periods>\n\n    Zero presents a problem.  Should it roll forward or back?  We\n    arbitrarily have it rollforward:\n\n    date + BDay(0) == BDay.rollforward(date)\n\n    Since 0 is a bit weird, we suggest avoiding its use.\n\n    Besides, adding a DateOffsets specified by the singular form of the date\n    component can be used to replace certain component of the timestamp.\n\n    Parameters""\n    ----------\n    n : int, default 1\n        The number of time periods the offset represents.\n        If specified without a temporal pattern, defaults to n days.\n    normalize : bool, default False\n        Whether to round the result of a DateOffset addition down to the\n        previous midnight.\n    **kwds\n        Temporal parameter that add to or replace the offset value.\n\n        Parameters that **add** to the offset (like Timedelta):\n\n        - years\n        - months\n        - weeks\n        - days\n        - hours\n        - minutes\n        - seconds\n        - milliseconds\n        - microseconds\n        - nanoseconds\n\n        Parameters that **replace** the offset value:\n\n        - year\n        - month\n        - day\n        - weekday\n        - hour\n        - minute\n        - second\n        - microsecond\n        - nanosecond.\n\n    See Also\n    --------\n    dateutil.relativedelta.relativedelta : The relativedelta type is designed\n        to be applied to an existing datetime an can replace specific components of\n        that datetime, or represents an interval of time.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import DateOffset\n    >>> ts = pd.Timestamp('2017-01-01 09:10:11')\n    >>> ts + DateOffset(months=3)\n    Timestamp('2017-04-01 09:10:11')\n\n    >>> ts = pd.Timestamp('2017-01-01 09:10:11')\n    >>> ts + DateOffset(months=2)\n    Timestamp('2017-03-01 09:10:11')\n    >>> ts + DateOffset(day=31)\n    Timestamp('2017-01-31 09:10:11')\n\n    >>> ts + pd.DateOffset(hour=8)\n    Timestamp('2017-01-01 08:10:11')\n    ";
static const char __pyx_k_Tick_offset_with_normalize_True[] = "Tick offset with `normalize=True` are not allowed.";
static const char __pyx_k_determine_offset_locals_genexpr[] = "_determine_offset.<locals>.genexpr";
static const char __pyx_k_does_not_have_a_vectorized_impl[] = " does not have a vectorized implementation";
static const char __pyx_k_n_argument_must_be_an_integer_g[] = "`n` argument must be an integer, got ";
static const char __pyx_k_not_able_to_be_applied_vectoriz[] = " not able to be applied vectorized";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_pandas__libs_tslibs_offsets_pyx[] = "pandas/_libs/tslibs/offsets.pyx";
static const char __pyx_k_time_data_must_match_H_M_format[] = "time data must match '%H:%M' format";
static const char __pyx_k_BaseOffset_is_month_end_line_820[] = "BaseOffset.is_month_end (line 820)";
static const char __pyx_k_BaseOffset_is_month_start_line_8[] = "BaseOffset.is_month_start (line 807)";
static const char __pyx_k_BaseOffset_is_on_offset_line_696[] = "BaseOffset.is_on_offset (line 696)";
static const char __pyx_k_BaseOffset_is_quarter_end_line_8[] = "BaseOffset.is_quarter_end (line 846)";
static const char __pyx_k_BaseOffset_is_quarter_start_line[] = "BaseOffset.is_quarter_start (line 833)";
static const char __pyx_k_BaseOffset_is_year_start_line_85[] = "BaseOffset.is_year_start (line 859)";
static const char __pyx_k_BaseOffset_kwds___get___line_449[] = "BaseOffset.kwds.__get__ (line 449)";
static const char __pyx_k_BaseOffset_name___get___line_584[] = "BaseOffset.name.__get__ (line 584)";
static const char __pyx_k_BusinessHour__get_business_hours[] = "BusinessHour._get_business_hours_by_sec";
static const char __pyx_k_Cannot_subtract_datetime_from_of[] = "Cannot subtract datetime from offset.";
static const char __pyx_k_Could_not_convert_to_integer_off[] = "Could not convert to integer offset at any resolution";
static const char __pyx_k_DateOffset_objects_are_immutable[] = "DateOffset objects are immutable.";
static const char __pyx_k_DateOffset_with_relativedelta_ke[] = "DateOffset with relativedelta keyword(s) ";
static const char __pyx_k_FY5253Mixin_get_rule_code_suffix[] = "FY5253Mixin.get_rule_code_suffix";
static const char __pyx_k_FY5253Quarter_year_has_extra_wee[] = "FY5253Quarter.year_has_extra_week";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))";
static const char __pyx_k_Invalid_argument_s_or_bad_combin[] = "Invalid argument/s or bad combination of arguments: ";
static const char __pyx_k_Must_include_at_least_1_end_time[] = "Must include at least 1 end time";
static const char __pyx_k_Must_include_at_least_1_start_ti[] = "Must include at least 1 start time";
static const char __pyx_k_Only_know_how_to_combine_busines[] = "Only know how to combine business day with datetime or timedelta.";
static const char __pyx_k_Only_know_how_to_combine_trading[] = "Only know how to combine trading day with datetime, datetime64 or timedelta.";
static const char __pyx_k_RelativeDeltaOffset___reduce_cyt[] = "RelativeDeltaOffset.__reduce_cython__";
static const char __pyx_k_RelativeDeltaOffset___setstate_c[] = "RelativeDeltaOffset.__setstate_cython__";
static const char __pyx_k_RelativeDeltaOffset__apply_array[] = "RelativeDeltaOffset._apply_array";
static const char __pyx_k_RelativeDeltaOffset_is_on_offset[] = "RelativeDeltaOffset.is_on_offset";
static const char __pyx_k_SingleConstructorOffset___reduce[] = "SingleConstructorOffset.__reduce__";
static const char __pyx_k_SingleConstructorOffset__from_na[] = "SingleConstructorOffset._from_name";
static const char __pyx_k_Time_zones_are_not_available_fro[] = "Time zones are not available from the C-API.";
static const char __pyx_k_Using_DateOffset_to_replace_mill[] = "Using DateOffset to replace `millisecond` component in datetime object is not supported. Use `microsecond=timestamp.microsecond % 1000 + ms * 1000` instead.";
static const char __pyx_k_apply_array_wraps_locals_wrapper[] = "apply_array_wraps.<locals>.wrapper";
static const char __pyx_k_day_must_be_None_start_end_busin[] = "day must be None, 'start', 'end', 'business_start', or 'business_end'";
static const char __pyx_k_invalid_starting_and_ending_time[] = "invalid starting and ending time(s): opening hours should not touch or overlap with one another";
static const char __pyx_k_number_of_starting_time_and_endi[] = "number of starting time and ending time must be the same";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_time_data_must_be_specified_only[] = "time data must be specified only with hour and minute";
static const char __pyx_k_time_data_must_be_string_or_date[] = "time data must be string or datetime.time";
static const char __pyx_k_to_offset_does_not_support_tuple[] = "to_offset does not support tuples ";
static const char __pyx_k_Return_a_string_representing_th_2[] = "\n        Return a string representing the frequency.\n\n        Examples\n        --------\n        >>> pd.DateOffset(5).freqstr\n        '<5 * DateOffsets>'\n\n        >>> pd.offsets.BusinessHour(2).freqstr\n        '2BH'\n\n        >>> pd.offsets.Nano().freqstr\n        'N'\n\n        >>> pd.offsets.Nano(-3).freqstr\n        '-3N'\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_2[] = "\n        Return boolean whether a timestamp occurs on the month start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_month_start(ts)\n        True\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_3[] = "\n        Return boolean whether a timestamp occurs on the month end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_month_end(ts)\n        False\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_4[] = "\n        Return boolean whether a timestamp occurs on the quarter start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_quarter_start(ts)\n        True\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_5[] = "\n        Return boolean whether a timestamp occurs on the quarter end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_quarter_end(ts)\n        False\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_6[] = "\n        Return boolean whether a timestamp occurs on the year start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_year_start(ts)\n        True\n        ";
static const char __pyx_k_Return_boolean_whether_a_timest_7[] = "\n        Return boolean whether a timestamp occurs on the year end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_year_end(ts)\n        False\n        ";
/* #### Code section: decls ### */
static PyArrayObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_apply_wrapper_core(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_wrapper(PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_2apply_array_wraps(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_wrapper(PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4apply_wraps(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_3genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_6genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_2__eq__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4__ne__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static Py_hash_t __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6__hash__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_10__add__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_12__radd__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_14__sub__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_16__rsub__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_18__mul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_20__rmul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_22__neg__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_26__repr__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_28_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix___get__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_32_offset_str(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_34_apply(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_36_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dtarr); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_dt); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_42_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n(PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_66__reduce_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_68__setstate_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset__from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_2__reduce__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_2_next_higher_resolution(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_4_repr_attrs(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_6is_on_offset(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, CYTHON_UNUSED PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_8is_anchored(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static Py_hash_t __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_10__hash__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_12__eq__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_14__ne__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_16__le__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_18__lt__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_20__ge__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_22__gt__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_24__mul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_26__rmul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_28__truediv__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_30__rtruediv__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_32__add__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_34__radd__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_36_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_38__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6delta_to_tick(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_Delta *__pyx_v_delta); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_kwds); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_10is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_12__reduce_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_14__setstate_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta___instancecheck__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_2__subclasscheck__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10DateOffset___setattr__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_2_init_custom(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_4_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_get_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_td); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_2_offset_str(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_4_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_6_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_8is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_start, PyObject *__pyx_v_end, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_4_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_start, PyObject *__pyx_v_end); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_sign); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_20_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_22is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_month); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_6is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_8_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_10_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_12_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_month); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_startingMonth); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_6is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_8is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_10_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_12_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_startingMonth); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_4_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_6__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_day_of_month); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_4is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_dtarr); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_10is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_12_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_week, PyObject *__pyx_v_weekday); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_6_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_6_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday, PyObject *__pyx_v_startingMonth, PyObject *__pyx_v_variation); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_4is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_6_get_suffix_prefix(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_8get_rule_code_suffix(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_4get_year_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_6_parse_suffix(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_varion_code, PyObject *__pyx_v_startingMonth_code, PyObject *__pyx_v_weekday_code); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_8_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday, PyObject *__pyx_v_startingMonth, PyObject *__pyx_v_qtr_with_extra_week, PyObject *__pyx_v_variation); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_4_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_8_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_10get_weeks(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_12year_has_extra_week(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_14is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_16_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_4is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_4_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_6is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_start, PyObject *__pyx_v_end, PyObject *__pyx_v_offset); /* proto */
static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_offset); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_4m_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_8_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other); /* proto */
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_8_get_offset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10to_offset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_freq); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_24__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12shift_months(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_dtindex, int __pyx_v_months, PyObject *__pyx_v_day_opt, NPY_DATETIMEUNIT __pyx_v_reso); /* proto */
static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_14shift_month(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_DateTime *__pyx_v_stamp, PyObject *__pyx_v_months, PyObject *__pyx_v_day_opt); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16roll_convention(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_other, int __pyx_v_n, int __pyx_v_compare); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_18roll_qtrday(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_DateTime *__pyx_v_other, PyObject *__pyx_v_n, PyObject *__pyx_v_month, PyObject *__pyx_v_day_opt, PyObject *__pyx_v_modby); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20__pyx_unpickle_BaseOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_22__pyx_unpickle_RelativeDeltaOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Day(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Hour(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Minute(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Second(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Milli(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Micro(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Nano(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessDay(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessHour(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Week(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Easter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_lower = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_upper = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_5numpy_dtype;
  PyTypeObject *__pyx_ptype_5numpy_flatiter;
  PyTypeObject *__pyx_ptype_5numpy_broadcast;
  PyTypeObject *__pyx_ptype_5numpy_ndarray;
  PyTypeObject *__pyx_ptype_5numpy_generic;
  PyTypeObject *__pyx_ptype_5numpy_number;
  PyTypeObject *__pyx_ptype_5numpy_integer;
  PyTypeObject *__pyx_ptype_5numpy_signedinteger;
  PyTypeObject *__pyx_ptype_5numpy_unsignedinteger;
  PyTypeObject *__pyx_ptype_5numpy_inexact;
  PyTypeObject *__pyx_ptype_5numpy_floating;
  PyTypeObject *__pyx_ptype_5numpy_complexfloating;
  PyTypeObject *__pyx_ptype_5numpy_flexible;
  PyTypeObject *__pyx_ptype_5numpy_character;
  PyTypeObject *__pyx_ptype_5numpy_ufunc;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_8datetime_date;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_time;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT;
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta;
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply;
  PyObject *__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr;
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr;
  PyObject *__pyx_kp_u_02d;
  PyObject *__pyx_kp_u_09_00;
  PyObject *__pyx_kp_u_17_00;
  PyObject *__pyx_n_u_A;
  PyObject *__pyx_n_u_AS;
  PyObject *__pyx_kp_u_AS_JAN;
  PyObject *__pyx_kp_u_A_DEC;
  PyObject *__pyx_n_s_ApplyTypeError;
  PyObject *__pyx_n_s_AssertionError;
  PyObject *__pyx_n_s_AttributeError;
  PyObject *__pyx_n_u_B;
  PyObject *__pyx_n_u_BA;
  PyObject *__pyx_n_u_BAS;
  PyObject *__pyx_kp_u_BAS_JAN;
  PyObject *__pyx_kp_u_BA_DEC;
  PyObject *__pyx_n_s_BDay;
  PyObject *__pyx_n_u_BH;
  PyObject *__pyx_n_u_BM;
  PyObject *__pyx_n_u_BMS;
  PyObject *__pyx_n_s_BMonthBegin;
  PyObject *__pyx_n_s_BMonthEnd;
  PyObject *__pyx_n_u_BQ;
  PyObject *__pyx_n_u_BQS;
  PyObject *__pyx_n_s_BQuarterBegin;
  PyObject *__pyx_n_s_BQuarterEnd;
  PyObject *__pyx_n_u_BY;
  PyObject *__pyx_n_u_BYS;
  PyObject *__pyx_n_s_BYearBegin;
  PyObject *__pyx_n_s_BYearEnd;
  PyObject *__pyx_kp_u_Bad_freq_suffix;
  PyObject *__pyx_n_s_BaseOffset;
  PyObject *__pyx_n_s_BaseOffset___getstate;
  PyObject *__pyx_n_s_BaseOffset___reduce_cython;
  PyObject *__pyx_n_s_BaseOffset___setstate;
  PyObject *__pyx_n_s_BaseOffset___setstate_cython;
  PyObject *__pyx_n_s_BaseOffset__apply;
  PyObject *__pyx_n_s_BaseOffset__apply_array;
  PyObject *__pyx_n_s_BaseOffset__get_offset_day;
  PyObject *__pyx_n_s_BaseOffset__offset_str;
  PyObject *__pyx_n_s_BaseOffset__params;
  PyObject *__pyx_n_s_BaseOffset__repr_attrs;
  PyObject *__pyx_n_s_BaseOffset__validate_n;
  PyObject *__pyx_n_s_BaseOffset_copy;
  PyObject *__pyx_kp_u_BaseOffset_copy_line_532;
  PyObject *__pyx_n_s_BaseOffset_freqstr;
  PyObject *__pyx_kp_u_BaseOffset_freqstr_line_607;
  PyObject *__pyx_n_s_BaseOffset_is_anchored;
  PyObject *__pyx_kp_u_BaseOffset_is_anchored_line_790;
  PyObject *__pyx_n_s_BaseOffset_is_month_end;
  PyObject *__pyx_kp_u_BaseOffset_is_month_end_line_820;
  PyObject *__pyx_n_s_BaseOffset_is_month_start;
  PyObject *__pyx_kp_u_BaseOffset_is_month_start_line_8;
  PyObject *__pyx_n_s_BaseOffset_is_on_offset;
  PyObject *__pyx_kp_u_BaseOffset_is_on_offset_line_696;
  PyObject *__pyx_n_s_BaseOffset_is_quarter_end;
  PyObject *__pyx_kp_u_BaseOffset_is_quarter_end_line_8;
  PyObject *__pyx_n_s_BaseOffset_is_quarter_start;
  PyObject *__pyx_kp_u_BaseOffset_is_quarter_start_line;
  PyObject *__pyx_n_s_BaseOffset_is_year_end;
  PyObject *__pyx_kp_u_BaseOffset_is_year_end_line_872;
  PyObject *__pyx_n_s_BaseOffset_is_year_start;
  PyObject *__pyx_kp_u_BaseOffset_is_year_start_line_85;
  PyObject *__pyx_kp_u_BaseOffset_kwds___get___line_449;
  PyObject *__pyx_kp_u_BaseOffset_name___get___line_584;
  PyObject *__pyx_n_s_BaseOffset_rollback;
  PyObject *__pyx_n_s_BaseOffset_rollforward;
  PyObject *__pyx_n_s_BusinessDay;
  PyObject *__pyx_n_s_BusinessDay___setstate;
  PyObject *__pyx_n_s_BusinessDay__apply;
  PyObject *__pyx_n_s_BusinessDay__apply_array;
  PyObject *__pyx_n_s_BusinessDay__offset_str;
  PyObject *__pyx_n_s_BusinessDay_is_on_offset;
  PyObject *__pyx_n_s_BusinessHour;
  PyObject *__pyx_n_s_BusinessHour___setstate;
  PyObject *__pyx_n_s_BusinessHour__apply;
  PyObject *__pyx_n_s_BusinessHour__get_business_hours;
  PyObject *__pyx_n_s_BusinessHour__get_closing_time;
  PyObject *__pyx_n_s_BusinessHour__is_on_offset;
  PyObject *__pyx_n_s_BusinessHour__next_opening_time;
  PyObject *__pyx_n_s_BusinessHour__prev_opening_time;
  PyObject *__pyx_n_s_BusinessHour__repr_attrs;
  PyObject *__pyx_n_s_BusinessHour_is_on_offset;
  PyObject *__pyx_n_s_BusinessHour_next_bday;
  PyObject *__pyx_n_s_BusinessHour_rollback;
  PyObject *__pyx_n_s_BusinessHour_rollforward;
  PyObject *__pyx_n_s_BusinessMixin;
  PyObject *__pyx_n_s_BusinessMixin___setstate;
  PyObject *__pyx_n_s_BusinessMixin__init_custom;
  PyObject *__pyx_n_s_BusinessMixin__repr_attrs;
  PyObject *__pyx_n_s_BusinessMonthBegin;
  PyObject *__pyx_n_s_BusinessMonthEnd;
  PyObject *__pyx_n_u_BusinessQuarterBegin;
  PyObject *__pyx_n_u_BusinessQuarterEnd;
  PyObject *__pyx_n_u_BusinessYearBegin;
  PyObject *__pyx_n_u_BusinessYearEnd;
  PyObject *__pyx_n_u_C;
  PyObject *__pyx_n_u_CBH;
  PyObject *__pyx_n_u_CBM;
  PyObject *__pyx_n_u_CBMS;
  PyObject *__pyx_n_s_CBMonthBegin;
  PyObject *__pyx_n_s_CBMonthEnd;
  PyObject *__pyx_n_s_CDay;
  PyObject *__pyx_kp_u_Cannot_add;
  PyObject *__pyx_kp_u_Cannot_subtract_datetime_from_of;
  PyObject *__pyx_kp_u_Could_not_convert_to_integer_off;
  PyObject *__pyx_n_s_CustomBusinessDay;
  PyObject *__pyx_n_s_CustomBusinessDay___setstate;
  PyObject *__pyx_n_s_CustomBusinessDay__apply;
  PyObject *__pyx_n_s_CustomBusinessDay_is_on_offset;
  PyObject *__pyx_n_s_CustomBusinessHour;
  PyObject *__pyx_n_s_CustomBusinessMonth;
  PyObject *__pyx_n_s_CustomBusinessMonthBegin;
  PyObject *__pyx_n_s_CustomBusinessMonthEnd;
  PyObject *__pyx_n_s_CustomBusinessMonth__apply;
  PyObject *__pyx_n_s_CustomBusinessMonth_cbday_roll;
  PyObject *__pyx_n_s_CustomBusinessMonth_m_offset;
  PyObject *__pyx_n_s_CustomBusinessMonth_month_roll;
  PyObject *__pyx_n_u_D;
  PyObject *__pyx_n_s_DateOffset;
  PyObject *__pyx_n_s_DateOffset___setattr;
  PyObject *__pyx_kp_u_DateOffset_objects_are_immutable;
  PyObject *__pyx_kp_u_DateOffset_subclass;
  PyObject *__pyx_kp_u_DateOffset_with_relativedelta_ke;
  PyObject *__pyx_n_s_Day;
  PyObject *__pyx_kp_u_Day_must_be_0_day_6_got;
  PyObject *__pyx_n_s_Easter;
  PyObject *__pyx_n_s_Easter___setstate;
  PyObject *__pyx_n_s_Easter__apply;
  PyObject *__pyx_n_s_Easter_is_on_offset;
  PyObject *__pyx_n_s_FY5253;
  PyObject *__pyx_n_s_FY5253Mixin;
  PyObject *__pyx_n_s_FY5253Mixin___setstate;
  PyObject *__pyx_n_s_FY5253Mixin__get_suffix_prefix;
  PyObject *__pyx_n_s_FY5253Mixin_get_rule_code_suffix;
  PyObject *__pyx_n_s_FY5253Mixin_is_anchored;
  PyObject *__pyx_n_s_FY5253Quarter;
  PyObject *__pyx_n_s_FY5253Quarter___setstate;
  PyObject *__pyx_n_s_FY5253Quarter__apply;
  PyObject *__pyx_n_s_FY5253Quarter__from_name;
  PyObject *__pyx_n_s_FY5253Quarter__offset;
  PyObject *__pyx_n_s_FY5253Quarter__rollback_to_year;
  PyObject *__pyx_n_s_FY5253Quarter_get_weeks;
  PyObject *__pyx_n_s_FY5253Quarter_is_on_offset;
  PyObject *__pyx_n_s_FY5253Quarter_year_has_extra_wee;
  PyObject *__pyx_n_s_FY5253__apply;
  PyObject *__pyx_n_s_FY5253__from_name;
  PyObject *__pyx_n_s_FY5253__parse_suffix;
  PyObject *__pyx_n_s_FY5253_get_year_end;
  PyObject *__pyx_n_s_FY5253_is_on_offset;
  PyObject *__pyx_n_u_H;
  PyObject *__pyx_kp_u_H_M;
  PyObject *__pyx_n_s_Hour;
  PyObject *__pyx_n_s_INVALID_FREQ_ERR_MSG;
  PyObject *__pyx_n_s_ImportError;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_kp_u_Invalid_argument_s_or_bad_combin;
  PyObject *__pyx_kp_u_Invalid_frequency_0;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_u_L;
  PyObject *__pyx_n_u_LWOM;
  PyObject *__pyx_n_s_LastWeekOfMonth;
  PyObject *__pyx_n_s_LastWeekOfMonth___setstate;
  PyObject *__pyx_n_s_LastWeekOfMonth__from_name;
  PyObject *__pyx_n_s_LastWeekOfMonth__get_offset_day;
  PyObject *__pyx_n_u_M;
  PyObject *__pyx_n_s_MONTH_ALIASES;
  PyObject *__pyx_n_s_MONTH_TO_CAL_NUM;
  PyObject *__pyx_n_u_MS;
  PyObject *__pyx_kp_s_Metaclass_that_allows_us_to_pre;
  PyObject *__pyx_n_s_Micro;
  PyObject *__pyx_n_s_Milli;
  PyObject *__pyx_n_u_Min;
  PyObject *__pyx_n_s_Minute;
  PyObject *__pyx_kp_u_Mon_Tue_Wed_Thu_Fri;
  PyObject *__pyx_n_s_MonthBegin;
  PyObject *__pyx_n_s_MonthEnd;
  PyObject *__pyx_n_s_MonthOffset;
  PyObject *__pyx_n_s_MonthOffset___setstate;
  PyObject *__pyx_n_s_MonthOffset__apply;
  PyObject *__pyx_n_s_MonthOffset__apply_array;
  PyObject *__pyx_n_s_MonthOffset_is_on_offset;
  PyObject *__pyx_kp_u_Month_must_go_from_1_to_12;
  PyObject *__pyx_kp_u_Must_include_at_least_1_end_time;
  PyObject *__pyx_kp_u_Must_include_at_least_1_start_ti;
  PyObject *__pyx_n_u_N;
  PyObject *__pyx_kp_u_N_cannot_be_0;
  PyObject *__pyx_n_s_Nano;
  PyObject *__pyx_kp_u_None;
  PyObject *__pyx_n_s_NotImplemented;
  PyObject *__pyx_n_s_NotImplementedError;
  PyObject *__pyx_n_s_OffsetMeta;
  PyObject *__pyx_n_s_OffsetMeta___instancecheck;
  PyObject *__pyx_n_s_OffsetMeta___subclasscheck;
  PyObject *__pyx_kp_u_Only_know_how_to_combine_busines;
  PyObject *__pyx_kp_u_Only_know_how_to_combine_trading;
  PyObject *__pyx_n_s_OverflowError;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_kp_u_Prefix;
  PyObject *__pyx_kp_u_Prefix_not_defined;
  PyObject *__pyx_n_u_Q;
  PyObject *__pyx_n_u_QS;
  PyObject *__pyx_kp_u_Q_DEC;
  PyObject *__pyx_n_s_QuarterBegin;
  PyObject *__pyx_n_s_QuarterEnd;
  PyObject *__pyx_n_s_QuarterOffset;
  PyObject *__pyx_n_s_QuarterOffset___setstate;
  PyObject *__pyx_n_s_QuarterOffset__apply;
  PyObject *__pyx_n_s_QuarterOffset__apply_array;
  PyObject *__pyx_n_s_QuarterOffset__from_name;
  PyObject *__pyx_n_s_QuarterOffset_is_anchored;
  PyObject *__pyx_n_s_QuarterOffset_is_on_offset;
  PyObject *__pyx_n_u_RE;
  PyObject *__pyx_n_u_REQ;
  PyObject *__pyx_n_s_RelativeDeltaOffset;
  PyObject *__pyx_n_s_RelativeDeltaOffset___getstate;
  PyObject *__pyx_n_s_RelativeDeltaOffset___reduce_cyt;
  PyObject *__pyx_n_s_RelativeDeltaOffset___setstate;
  PyObject *__pyx_n_s_RelativeDeltaOffset___setstate_c;
  PyObject *__pyx_n_s_RelativeDeltaOffset__apply;
  PyObject *__pyx_n_s_RelativeDeltaOffset__apply_array;
  PyObject *__pyx_n_s_RelativeDeltaOffset_is_on_offset;
  PyObject *__pyx_kp_u_Return_DateOffset_object_from_s;
  PyObject *__pyx_kp_u_Return_a_copy_of_the_frequency;
  PyObject *__pyx_kp_u_Return_a_dict_of_extra_paramete;
  PyObject *__pyx_kp_u_Return_a_string_representing_th;
  PyObject *__pyx_kp_u_Return_a_string_representing_th_2;
  PyObject *__pyx_kp_u_Return_an_integer_of_the_total;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_2;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_3;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_4;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_5;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_6;
  PyObject *__pyx_kp_u_Return_boolean_whether_a_timest_7;
  PyObject *__pyx_kp_u_Return_boolean_whether_the_freq;
  PyObject *__pyx_n_s_RuntimeError;
  PyObject *__pyx_n_u_S;
  PyObject *__pyx_n_u_SM;
  PyObject *__pyx_n_u_SMS;
  PyObject *__pyx_n_s_Second;
  PyObject *__pyx_n_s_SemiMonthBegin;
  PyObject *__pyx_n_s_SemiMonthBegin_is_on_offset;
  PyObject *__pyx_n_s_SemiMonthEnd;
  PyObject *__pyx_n_s_SemiMonthEnd_is_on_offset;
  PyObject *__pyx_n_s_SemiMonthOffset;
  PyObject *__pyx_n_s_SemiMonthOffset___setstate;
  PyObject *__pyx_n_s_SemiMonthOffset__apply;
  PyObject *__pyx_n_s_SemiMonthOffset__apply_array;
  PyObject *__pyx_n_s_SemiMonthOffset__from_name;
  PyObject *__pyx_n_s_SingleConstructorOffset;
  PyObject *__pyx_n_s_SingleConstructorOffset___reduce;
  PyObject *__pyx_n_s_SingleConstructorOffset__from_na;
  PyObject *__pyx_kp_s_Standard_kind_of_date_increment;
  PyObject *__pyx_n_u_T;
  PyObject *__pyx_n_s_Tick;
  PyObject *__pyx_n_s_Tick___setstate;
  PyObject *__pyx_n_s_Tick__apply;
  PyObject *__pyx_n_s_Tick__next_higher_resolution;
  PyObject *__pyx_n_s_Tick__repr_attrs;
  PyObject *__pyx_n_s_Tick_is_anchored;
  PyObject *__pyx_n_s_Tick_is_on_offset;
  PyObject *__pyx_kp_u_Tick_nanos___get___line_953;
  PyObject *__pyx_kp_u_Tick_offset_with_normalize_True;
  PyObject *__pyx_kp_u_Time_zones_are_not_available_fro;
  PyObject *__pyx_n_s_Timedelta;
  PyObject *__pyx_n_s_Timestamp;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_u_U;
  PyObject *__pyx_kp_u_Unable_to_parse_varion_code;
  PyObject *__pyx_kp_u_Unexpected_key__offset;
  PyObject *__pyx_kp_u_Unhandled_type;
  PyObject *__pyx_kp_u_Using_DateOffset_to_replace_mill;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_u_W;
  PyObject *__pyx_n_u_WOM;
  PyObject *__pyx_kp_u_W_SUN;
  PyObject *__pyx_n_s_Week;
  PyObject *__pyx_n_s_WeekOfMonth;
  PyObject *__pyx_n_s_WeekOfMonthMixin;
  PyObject *__pyx_n_s_WeekOfMonthMixin__apply;
  PyObject *__pyx_n_s_WeekOfMonthMixin_is_on_offset;
  PyObject *__pyx_n_s_WeekOfMonth___setstate;
  PyObject *__pyx_n_s_WeekOfMonth__from_name;
  PyObject *__pyx_n_s_WeekOfMonth__get_offset_day;
  PyObject *__pyx_n_s_Week___setstate;
  PyObject *__pyx_n_s_Week__apply;
  PyObject *__pyx_n_s_Week__apply_array;
  PyObject *__pyx_n_s_Week__from_name;
  PyObject *__pyx_n_s_Week_is_anchored;
  PyObject *__pyx_n_s_Week_is_on_offset;
  PyObject *__pyx_kp_u_Week_must_be_0_week_3_got;
  PyObject *__pyx_n_u_Y;
  PyObject *__pyx_n_u_YS;
  PyObject *__pyx_n_s_YearBegin;
  PyObject *__pyx_n_s_YearEnd;
  PyObject *__pyx_n_s_YearOffset;
  PyObject *__pyx_n_s_YearOffset___setstate;
  PyObject *__pyx_n_s_YearOffset__apply;
  PyObject *__pyx_n_s_YearOffset__apply_array;
  PyObject *__pyx_n_s_YearOffset__from_name;
  PyObject *__pyx_n_s_YearOffset__get_offset_day;
  PyObject *__pyx_n_s_YearOffset_is_on_offset;
  PyObject *__pyx_n_u__13;
  PyObject *__pyx_kp_u__15;
  PyObject *__pyx_kp_u__16;
  PyObject *__pyx_kp_u__17;
  PyObject *__pyx_kp_u__18;
  PyObject *__pyx_kp_u__19;
  PyObject *__pyx_kp_u__20;
  PyObject *__pyx_kp_u__21;
  PyObject *__pyx_n_s__284;
  PyObject *__pyx_kp_u__37;
  PyObject *__pyx_kp_u__38;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_kp_u__46;
  PyObject *__pyx_kp_u__47;
  PyObject *__pyx_n_s__67;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_n_s_add;
  PyObject *__pyx_n_s_adjust_dst;
  PyObject *__pyx_n_s_all_paras;
  PyObject *__pyx_n_s_anchor;
  PyObject *__pyx_n_s_anchor_dom;
  PyObject *__pyx_kp_u_and;
  PyObject *__pyx_n_s_apply;
  PyObject *__pyx_n_s_apply_array;
  PyObject *__pyx_n_s_apply_array_wraps;
  PyObject *__pyx_n_s_apply_array_wraps_locals_wrapper;
  PyObject *__pyx_n_s_apply_locals_genexpr;
  PyObject *__pyx_n_s_apply_wrapper_core;
  PyObject *__pyx_n_s_apply_wraps;
  PyObject *__pyx_n_s_apply_wraps_locals_wrapper;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_argsort;
  PyObject *__pyx_n_s_array;
  PyObject *__pyx_n_s_array_priority;
  PyObject *__pyx_n_s_as_unit;
  PyObject *__pyx_n_s_asarray;
  PyObject *__pyx_n_s_astype;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_attr;
  PyObject *__pyx_n_s_attributes;
  PyObject *__pyx_n_s_attrs;
  PyObject *__pyx_n_s_b;
  PyObject *__pyx_n_u_backward;
  PyObject *__pyx_n_s_bd;
  PyObject *__pyx_n_s_bhour;
  PyObject *__pyx_n_s_bhour_remain;
  PyObject *__pyx_n_s_bool;
  PyObject *__pyx_n_s_busday_offset;
  PyObject *__pyx_n_s_busdaycal;
  PyObject *__pyx_n_s_busdaycalendar;
  PyObject *__pyx_n_u_business_end;
  PyObject *__pyx_n_u_business_start;
  PyObject *__pyx_n_s_businesshours;
  PyObject *__pyx_n_u_cache;
  PyObject *__pyx_n_s_cache_readonly;
  PyObject *__pyx_n_s_calendar;
  PyObject *__pyx_n_u_calendar;
  PyObject *__pyx_n_s_cbday;
  PyObject *__pyx_n_s_cbday_kwds;
  PyObject *__pyx_n_s_cbday_roll;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_cls;
  PyObject *__pyx_n_s_code;
  PyObject *__pyx_n_s_combine;
  PyObject *__pyx_n_s_compare;
  PyObject *__pyx_n_s_compare_date;
  PyObject *__pyx_n_s_compare_day;
  PyObject *__pyx_n_s_compile;
  PyObject *__pyx_n_s_copy;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_creso;
  PyObject *__pyx_n_s_cur_month_offset_date;
  PyObject *__pyx_n_s_cur_year;
  PyObject *__pyx_n_s_current;
  PyObject *__pyx_n_s_current_easter;
  PyObject *__pyx_n_s_d;
  PyObject *__pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z;
  PyObject *__pyx_n_s_date;
  PyObject *__pyx_n_s_date_in;
  PyObject *__pyx_n_s_datetime;
  PyObject *__pyx_n_s_datetime64;
  PyObject *__pyx_kp_u_datetime64_D;
  PyObject *__pyx_n_s_dateutil_easter;
  PyObject *__pyx_n_s_dateutil_relativedelta;
  PyObject *__pyx_n_s_day;
  PyObject *__pyx_n_u_day;
  PyObject *__pyx_n_s_day64;
  PyObject *__pyx_kp_u_day_must_be_None_start_end_busin;
  PyObject *__pyx_n_s_day_of_month;
  PyObject *__pyx_n_u_day_of_month;
  PyObject *__pyx_kp_u_day_of_month_27_got;
  PyObject *__pyx_kp_u_day_of_month_must_be;
  PyObject *__pyx_n_s_day_opt;
  PyObject *__pyx_n_s_day_opt_2;
  PyObject *__pyx_n_s_days;
  PyObject *__pyx_n_u_days;
  PyObject *__pyx_n_s_days_forward;
  PyObject *__pyx_n_s_days_in_month;
  PyObject *__pyx_n_s_default_day_of_month;
  PyObject *__pyx_n_s_default_month;
  PyObject *__pyx_n_s_default_starting_month;
  PyObject *__pyx_n_s_delta;
  PyObject *__pyx_n_s_delta_to_tick;
  PyObject *__pyx_n_s_determine_offset_locals_genexpr;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_u_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_n_s_dim;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_doc;
  PyObject *__pyx_kp_u_does_not_have_a_vectorized_impl;
  PyObject *__pyx_n_s_dont_uppercase;
  PyObject *__pyx_n_s_dt;
  PyObject *__pyx_n_s_dt64other;
  PyObject *__pyx_n_s_dt_date;
  PyObject *__pyx_n_s_dtarr;
  PyObject *__pyx_n_s_dtindex;
  PyObject *__pyx_n_s_dts;
  PyObject *__pyx_n_s_dtstart;
  PyObject *__pyx_n_s_dtype;
  PyObject *__pyx_n_s_dy;
  PyObject *__pyx_n_s_earliest_start;
  PyObject *__pyx_n_s_easter;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_end;
  PyObject *__pyx_n_u_end;
  PyObject *__pyx_n_s_endswith;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_err;
  PyObject *__pyx_n_s_exclude;
  PyObject *__pyx_n_s_fabs;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_u_forward;
  PyObject *__pyx_n_s_freq;
  PyObject *__pyx_n_s_freqstr;
  PyObject *__pyx_n_s_from_name;
  PyObject *__pyx_n_s_from_name_starting_month;
  PyObject *__pyx_n_s_fstr;
  PyObject *__pyx_n_s_func;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_ge;
  PyObject *__pyx_n_s_genexpr;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_get_2;
  PyObject *__pyx_n_s_get_business_hours_by_sec;
  PyObject *__pyx_n_s_get_closing_time;
  PyObject *__pyx_n_s_get_offset;
  PyObject *__pyx_n_s_get_offset_day;
  PyObject *__pyx_n_s_get_rule_code_suffix;
  PyObject *__pyx_n_s_get_str;
  PyObject *__pyx_n_s_get_suffix_prefix;
  PyObject *__pyx_n_s_get_weeks;
  PyObject *__pyx_n_s_get_year_end;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_gt;
  PyObject *__pyx_n_u_h;
  PyObject *__pyx_n_s_holidays;
  PyObject *__pyx_n_u_holidays;
  PyObject *__pyx_n_s_hour;
  PyObject *__pyx_n_u_hour;
  PyObject *__pyx_n_s_hours;
  PyObject *__pyx_n_u_hours;
  PyObject *__pyx_n_s_hrs;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_u_i8;
  PyObject *__pyx_n_s_i8other;
  PyObject *__pyx_kp_u_implemented_by_subclasses;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_u_inc;
  PyObject *__pyx_n_s_inc_2;
  PyObject *__pyx_n_s_init;
  PyObject *__pyx_n_s_init_custom;
  PyObject *__pyx_n_s_init_subclass;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_instancecheck;
  PyObject *__pyx_n_s_int;
  PyObject *__pyx_n_s_int_to_weekday;
  PyObject *__pyx_kp_u_invalid_starting_and_ending_time;
  PyObject *__pyx_kp_u_is_a_non_fixed_frequency;
  PyObject *__pyx_n_s_is_anchored;
  PyObject *__pyx_n_s_is_busday;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_month_end;
  PyObject *__pyx_n_u_is_month_end;
  PyObject *__pyx_n_s_is_month_start;
  PyObject *__pyx_n_u_is_month_start;
  PyObject *__pyx_kp_u_is_not_a_valid_variation;
  PyObject *__pyx_n_s_is_on_offset;
  PyObject *__pyx_n_s_is_on_offset_2;
  PyObject *__pyx_n_s_is_quarter_end;
  PyObject *__pyx_n_u_is_quarter_end;
  PyObject *__pyx_n_s_is_quarter_start;
  PyObject *__pyx_n_u_is_quarter_start;
  PyObject *__pyx_n_s_is_same_sign;
  PyObject *__pyx_n_s_is_start;
  PyObject *__pyx_n_s_is_year_end;
  PyObject *__pyx_n_u_is_year_end;
  PyObject *__pyx_n_s_is_year_start;
  PyObject *__pyx_n_u_is_year_start;
  PyObject *__pyx_n_s_isclose;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_isspace;
  PyObject *__pyx_n_s_issubset;
  PyObject *__pyx_n_s_items;
  PyObject *__pyx_n_s_k;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_klass;
  PyObject *__pyx_n_s_kwargs;
  PyObject *__pyx_n_s_kwd;
  PyObject *__pyx_n_s_kwds;
  PyObject *__pyx_n_u_kwds;
  PyObject *__pyx_n_u_last;
  PyObject *__pyx_kp_u_last_element_must_be_blank;
  PyObject *__pyx_n_s_latest_start;
  PyObject *__pyx_n_s_le;
  PyObject *__pyx_n_s_lite_rule_alias;
  PyObject *__pyx_n_s_lower;
  PyObject *__pyx_n_s_lt;
  PyObject *__pyx_n_u_m;
  PyObject *__pyx_n_s_m_offset;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_mend;
  PyObject *__pyx_n_s_metaclass;
  PyObject *__pyx_n_s_mi;
  PyObject *__pyx_n_s_microsecond;
  PyObject *__pyx_n_u_microsecond;
  PyObject *__pyx_n_s_microseconds;
  PyObject *__pyx_n_u_microseconds;
  PyObject *__pyx_n_u_millisecond;
  PyObject *__pyx_n_u_milliseconds;
  PyObject *__pyx_n_u_min;
  PyObject *__pyx_n_s_min_day_of_month;
  PyObject *__pyx_n_s_minute;
  PyObject *__pyx_n_u_minute;
  PyObject *__pyx_n_s_minutes;
  PyObject *__pyx_n_u_minutes;
  PyObject *__pyx_n_s_mod_month;
  PyObject *__pyx_n_s_modby;
  PyObject *__pyx_n_s_module;
  PyObject *__pyx_n_s_moff;
  PyObject *__pyx_n_s_month;
  PyObject *__pyx_n_u_month;
  PyObject *__pyx_n_s_month_roll;
  PyObject *__pyx_n_s_months;
  PyObject *__pyx_n_u_months;
  PyObject *__pyx_n_s_months_since;
  PyObject *__pyx_n_s_months_to_roll;
  PyObject *__pyx_n_s_mro_entries;
  PyObject *__pyx_n_u_ms;
  PyObject *__pyx_n_s_mstart;
  PyObject *__pyx_n_s_mts;
  PyObject *__pyx_n_s_mul;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_u_n;
  PyObject *__pyx_kp_u_n_argument_must_be_an_integer_g;
  PyObject *__pyx_n_s_nadj;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_u_name_2;
  PyObject *__pyx_n_s_nano;
  PyObject *__pyx_n_s_nanos;
  PyObject *__pyx_n_s_nanos_inc;
  PyObject *__pyx_n_s_nanosecond;
  PyObject *__pyx_n_u_nanosecond;
  PyObject *__pyx_n_s_nanoseconds;
  PyObject *__pyx_n_u_nanoseconds;
  PyObject *__pyx_n_s_nb_offset;
  PyObject *__pyx_n_s_ndarray;
  PyObject *__pyx_n_s_ndim;
  PyObject *__pyx_n_u_nearest;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_new_2;
  PyObject *__pyx_n_s_next_bday;
  PyObject *__pyx_n_u_next_bday;
  PyObject *__pyx_n_s_next_higher_resolution;
  PyObject *__pyx_n_s_next_opening_time;
  PyObject *__pyx_n_s_next_year;
  PyObject *__pyx_n_s_next_year_end;
  PyObject *__pyx_n_s_nint;
  PyObject *__pyx_n_s_norm;
  PyObject *__pyx_n_s_normalize;
  PyObject *__pyx_n_u_normalize;
  PyObject *__pyx_n_s_normalize_i8_timestamps;
  PyObject *__pyx_kp_u_not_able_to_be_applied_vectoriz;
  PyObject *__pyx_n_s_np;
  PyObject *__pyx_n_s_np_dt;
  PyObject *__pyx_n_s_np_incr_dt;
  PyObject *__pyx_kp_s_np_ndarray;
  PyObject *__pyx_n_u_ns;
  PyObject *__pyx_n_s_num_nano;
  PyObject *__pyx_n_s_num_qtrs;
  PyObject *__pyx_kp_u_number_of_starting_time_and_endi;
  PyObject *__pyx_n_s_numpy;
  PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
  PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_off_str;
  PyObject *__pyx_n_s_offset;
  PyObject *__pyx_n_u_offset;
  PyObject *__pyx_n_s_offset_2;
  PyObject *__pyx_n_u_offset_2;
  PyObject *__pyx_kp_u_offset_3;
  PyObject *__pyx_n_s_offset_map;
  PyObject *__pyx_n_s_offset_str;
  PyObject *__pyx_n_s_offset_str_locals_get_str;
  PyObject *__pyx_n_s_op;
  PyObject *__pyx_n_s_opattern;
  PyObject *__pyx_n_s_other;
  PyObject *__pyx_n_s_otherDay;
  PyObject *__pyx_n_s_out;
  PyObject *__pyx_n_s_outputName;
  PyObject *__pyx_n_s_output_name;
  PyObject *__pyx_n_u_output_name;
  PyObject *__pyx_n_s_pandas__libs_properties;
  PyObject *__pyx_n_s_pandas__libs_tslibs_ccalendar;
  PyObject *__pyx_n_s_pandas__libs_tslibs_offsets;
  PyObject *__pyx_kp_s_pandas__libs_tslibs_offsets_pyx;
  PyObject *__pyx_n_s_params;
  PyObject *__pyx_n_s_params_2;
  PyObject *__pyx_n_s_parse_suffix;
  PyObject *__pyx_kp_u_pass_as_a_string_instead;
  PyObject *__pyx_n_s_period_dtype_code;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_pop;
  PyObject *__pyx_n_s_prefix;
  PyObject *__pyx_n_s_prefix_2;
  PyObject *__pyx_n_s_prefix_mapping;
  PyObject *__pyx_n_s_prepare;
  PyObject *__pyx_n_s_prev_open;
  PyObject *__pyx_n_s_prev_opening_time;
  PyObject *__pyx_n_s_prev_year;
  PyObject *__pyx_n_s_prev_year_end;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_BaseOffset;
  PyObject *__pyx_n_s_pyx_unpickle_RelativeDeltaOffs;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_qlen;
  PyObject *__pyx_n_s_qtr_len;
  PyObject *__pyx_n_s_qtr_lens;
  PyObject *__pyx_n_s_qtr_with_extra_week;
  PyObject *__pyx_n_u_qtr_with_extra_week;
  PyObject *__pyx_n_s_qtrs;
  PyObject *__pyx_n_s_qualname;
  PyObject *__pyx_n_s_r;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_re;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce___locals_genexpr;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_relativedelta;
  PyObject *__pyx_n_s_relativedelta_fast;
  PyObject *__pyx_n_s_relativedelta_kwds;
  PyObject *__pyx_n_s_rem_nano;
  PyObject *__pyx_n_s_remain;
  PyObject *__pyx_n_s_replace;
  PyObject *__pyx_n_s_repr_attrs;
  PyObject *__pyx_n_s_repr_attrs_locals_genexpr;
  PyObject *__pyx_kp_u_requires_a_suffix;
  PyObject *__pyx_n_s_res;
  PyObject *__pyx_n_s_res_val;
  PyObject *__pyx_n_s_reso;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_result2;
  PyObject *__pyx_n_s_ret;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_reversed;
  PyObject *__pyx_n_s_roll;
  PyObject *__pyx_n_s_roll_convention;
  PyObject *__pyx_n_s_roll_func;
  PyObject *__pyx_n_s_roll_qtrday;
  PyObject *__pyx_n_s_rollback;
  PyObject *__pyx_n_s_rollback_to_year;
  PyObject *__pyx_n_s_rollforward;
  PyObject *__pyx_n_s_rtruediv;
  PyObject *__pyx_n_s_rule_code;
  PyObject *__pyx_n_s_s;
  PyObject *__pyx_n_u_s;
  PyObject *__pyx_n_s_second;
  PyObject *__pyx_n_u_second;
  PyObject *__pyx_n_s_seconds;
  PyObject *__pyx_n_u_seconds;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_n_s_send;
  PyObject *__pyx_kp_u_separator_must_be_spaces;
  PyObject *__pyx_n_s_set_name;
  PyObject *__pyx_n_s_setattr;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_shift_days;
  PyObject *__pyx_n_s_shift_month;
  PyObject *__pyx_n_s_shift_months;
  PyObject *__pyx_n_s_shifted;
  PyObject *__pyx_n_s_sign;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_s_skip_bd;
  PyObject *__pyx_n_s_span;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_st;
  PyObject *__pyx_n_s_stamp;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_u_start;
  PyObject *__pyx_n_s_startingMonth;
  PyObject *__pyx_n_u_startingMonth;
  PyObject *__pyx_n_s_startingMonth_code;
  PyObject *__pyx_n_s_startswith;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_staticmethod;
  PyObject *__pyx_n_s_str;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_strptime;
  PyObject *__pyx_n_s_subclasscheck;
  PyObject *__pyx_n_s_suffix;
  PyObject *__pyx_n_s_sum;
  PyObject *__pyx_n_s_super;
  PyObject *__pyx_n_s_target_date;
  PyObject *__pyx_n_s_td;
  PyObject *__pyx_n_s_td64;
  PyObject *__pyx_n_s_td64_unit;
  PyObject *__pyx_n_s_td_nano;
  PyObject *__pyx_n_s_tdelta;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_kp_u_the_add_operation_between;
  PyObject *__pyx_n_s_throw;
  PyObject *__pyx_n_s_time;
  PyObject *__pyx_kp_u_time_data_must_be_specified_only;
  PyObject *__pyx_kp_u_time_data_must_be_string_or_date;
  PyObject *__pyx_kp_u_time_data_must_match_H_M_format;
  PyObject *__pyx_n_s_timedelta;
  PyObject *__pyx_n_s_timedelta64;
  PyObject *__pyx_n_s_timedelta_kwds;
  PyObject *__pyx_n_s_timedeltas;
  PyObject *__pyx_n_s_timestamps;
  PyObject *__pyx_n_s_tm_hour;
  PyObject *__pyx_n_s_tm_min;
  PyObject *__pyx_kp_u_to;
  PyObject *__pyx_n_s_to_day;
  PyObject *__pyx_n_s_to_offset;
  PyObject *__pyx_kp_u_to_offset_does_not_support_tuple;
  PyObject *__pyx_kp_u_to_offset_line_4102;
  PyObject *__pyx_n_s_to_pydatetime;
  PyObject *__pyx_n_s_to_pytimedelta;
  PyObject *__pyx_n_s_tolist;
  PyObject *__pyx_n_s_total_seconds;
  PyObject *__pyx_n_s_truediv;
  PyObject *__pyx_n_s_ts;
  PyObject *__pyx_n_s_tup;
  PyObject *__pyx_n_s_tz;
  PyObject *__pyx_n_s_tz_localize;
  PyObject *__pyx_n_s_tzinfo;
  PyObject *__pyx_n_u_tzinfo;
  PyObject *__pyx_n_u_undefined;
  PyObject *__pyx_n_s_unit;
  PyObject *__pyx_n_s_until;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_upper;
  PyObject *__pyx_n_u_us;
  PyObject *__pyx_n_s_use_relativedelta;
  PyObject *__pyx_n_u_use_relativedelta;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_val;
  PyObject *__pyx_n_s_validate_n;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_n_s_value_2;
  PyObject *__pyx_n_s_variation;
  PyObject *__pyx_n_u_variation;
  PyObject *__pyx_n_s_varion_code;
  PyObject *__pyx_n_s_vectorized;
  PyObject *__pyx_n_s_view;
  PyObject *__pyx_n_s_wday;
  PyObject *__pyx_n_s_week;
  PyObject *__pyx_n_u_week;
  PyObject *__pyx_n_s_weekday;
  PyObject *__pyx_n_u_weekday;
  PyObject *__pyx_n_s_weekday_code;
  PyObject *__pyx_n_s_weekday_to_int;
  PyObject *__pyx_n_s_weekmask;
  PyObject *__pyx_n_u_weekmask;
  PyObject *__pyx_n_s_weeks;
  PyObject *__pyx_n_u_weeks;
  PyObject *__pyx_n_s_weeks_in_year;
  PyObject *__pyx_kp_u_will_overflow;
  PyObject *__pyx_n_s_wkday_diff;
  PyObject *__pyx_n_s_wrapper;
  PyObject *__pyx_n_s_year;
  PyObject *__pyx_n_u_year;
  PyObject *__pyx_n_s_year_end;
  PyObject *__pyx_n_s_year_has_extra_week;
  PyObject *__pyx_n_s_years;
  PyObject *__pyx_n_u_years;
  PyObject *__pyx_n_s_zero;
  PyObject *__pyx_n_s_zip;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_4;
  PyObject *__pyx_int_5;
  PyObject *__pyx_int_6;
  PyObject *__pyx_int_7;
  PyObject *__pyx_int_12;
  PyObject *__pyx_int_13;
  PyObject *__pyx_int_14;
  PyObject *__pyx_int_15;
  PyObject *__pyx_int_27;
  PyObject *__pyx_int_52;
  PyObject *__pyx_int_53;
  PyObject *__pyx_int_60;
  PyObject *__pyx_int_1000;
  PyObject *__pyx_int_2014;
  PyObject *__pyx_int_3600;
  PyObject *__pyx_int_86400;
  PyObject *__pyx_int_1000000;
  PyObject *__pyx_int_10844460;
  PyObject *__pyx_int_171034093;
  PyObject *__pyx_int_213572416;
  PyObject *__pyx_int_1000000000;
  PyObject *__pyx_int_60000000000;
  PyObject *__pyx_int_3600000000000;
  PyObject *__pyx_int_0x4e94914f0000;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_k__33;
  NPY_DATETIMEUNIT __pyx_k__39;
  PyObject *__pyx_k__40;
  PyObject *__pyx_k__56;
  PyObject *__pyx_k__57;
  PyObject *__pyx_k__58;
  NPY_DATETIMEUNIT __pyx_k__64;
  PyObject *__pyx_tuple_;
  PyObject *__pyx_tuple__2;
  PyObject *__pyx_tuple__3;
  PyObject *__pyx_tuple__5;
  PyObject *__pyx_tuple__7;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_slice__53;
  PyObject *__pyx_slice__60;
  PyObject *__pyx_slice__61;
  PyObject *__pyx_slice__62;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__12;
  PyObject *__pyx_tuple__14;
  PyObject *__pyx_tuple__22;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__25;
  PyObject *__pyx_tuple__26;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__28;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__30;
  PyObject *__pyx_tuple__31;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__42;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__44;
  PyObject *__pyx_tuple__45;
  PyObject *__pyx_tuple__48;
  PyObject *__pyx_tuple__49;
  PyObject *__pyx_tuple__50;
  PyObject *__pyx_tuple__51;
  PyObject *__pyx_tuple__52;
  PyObject *__pyx_tuple__54;
  PyObject *__pyx_tuple__55;
  PyObject *__pyx_tuple__59;
  PyObject *__pyx_tuple__63;
  PyObject *__pyx_tuple__65;
  PyObject *__pyx_tuple__66;
  PyObject *__pyx_tuple__68;
  PyObject *__pyx_tuple__70;
  PyObject *__pyx_tuple__73;
  PyObject *__pyx_tuple__74;
  PyObject *__pyx_tuple__75;
  PyObject *__pyx_tuple__77;
  PyObject *__pyx_tuple__79;
  PyObject *__pyx_tuple__81;
  PyObject *__pyx_tuple__84;
  PyObject *__pyx_tuple__86;
  PyObject *__pyx_tuple__88;
  PyObject *__pyx_tuple__91;
  PyObject *__pyx_tuple__93;
  PyObject *__pyx_tuple__95;
  PyObject *__pyx_tuple__97;
  PyObject *__pyx_codeobj__6;
  PyObject *__pyx_codeobj__8;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__108;
  PyObject *__pyx_tuple__110;
  PyObject *__pyx_tuple__112;
  PyObject *__pyx_tuple__114;
  PyObject *__pyx_tuple__115;
  PyObject *__pyx_tuple__123;
  PyObject *__pyx_tuple__127;
  PyObject *__pyx_tuple__129;
  PyObject *__pyx_tuple__134;
  PyObject *__pyx_tuple__137;
  PyObject *__pyx_tuple__139;
  PyObject *__pyx_tuple__141;
  PyObject *__pyx_tuple__145;
  PyObject *__pyx_tuple__147;
  PyObject *__pyx_tuple__149;
  PyObject *__pyx_tuple__153;
  PyObject *__pyx_tuple__155;
  PyObject *__pyx_tuple__157;
  PyObject *__pyx_tuple__159;
  PyObject *__pyx_tuple__161;
  PyObject *__pyx_tuple__166;
  PyObject *__pyx_tuple__169;
  PyObject *__pyx_tuple__171;
  PyObject *__pyx_tuple__175;
  PyObject *__pyx_tuple__179;
  PyObject *__pyx_tuple__181;
  PyObject *__pyx_tuple__186;
  PyObject *__pyx_tuple__188;
  PyObject *__pyx_tuple__192;
  PyObject *__pyx_tuple__198;
  PyObject *__pyx_tuple__200;
  PyObject *__pyx_tuple__202;
  PyObject *__pyx_tuple__207;
  PyObject *__pyx_tuple__209;
  PyObject *__pyx_tuple__212;
  PyObject *__pyx_tuple__215;
  PyObject *__pyx_tuple__217;
  PyObject *__pyx_tuple__220;
  PyObject *__pyx_tuple__226;
  PyObject *__pyx_tuple__228;
  PyObject *__pyx_tuple__230;
  PyObject *__pyx_tuple__232;
  PyObject *__pyx_tuple__234;
  PyObject *__pyx_tuple__236;
  PyObject *__pyx_tuple__240;
  PyObject *__pyx_tuple__242;
  PyObject *__pyx_tuple__244;
  PyObject *__pyx_tuple__246;
  PyObject *__pyx_tuple__248;
  PyObject *__pyx_tuple__252;
  PyObject *__pyx_tuple__256;
  PyObject *__pyx_tuple__258;
  PyObject *__pyx_tuple__260;
  PyObject *__pyx_tuple__262;
  PyObject *__pyx_tuple__264;
  PyObject *__pyx_tuple__266;
  PyObject *__pyx_tuple__268;
  PyObject *__pyx_tuple__269;
  PyObject *__pyx_tuple__271;
  PyObject *__pyx_tuple__273;
  PyObject *__pyx_tuple__275;
  PyObject *__pyx_tuple__277;
  PyObject *__pyx_tuple__279;
  PyObject *__pyx_tuple__281;
  PyObject *__pyx_codeobj__35;
  PyObject *__pyx_codeobj__69;
  PyObject *__pyx_codeobj__71;
  PyObject *__pyx_codeobj__72;
  PyObject *__pyx_codeobj__76;
  PyObject *__pyx_codeobj__78;
  PyObject *__pyx_codeobj__80;
  PyObject *__pyx_codeobj__82;
  PyObject *__pyx_codeobj__83;
  PyObject *__pyx_codeobj__85;
  PyObject *__pyx_codeobj__87;
  PyObject *__pyx_codeobj__89;
  PyObject *__pyx_codeobj__90;
  PyObject *__pyx_codeobj__92;
  PyObject *__pyx_codeobj__94;
  PyObject *__pyx_codeobj__96;
  PyObject *__pyx_codeobj__98;
  PyObject *__pyx_codeobj__99;
  PyObject *__pyx_codeobj__100;
  PyObject *__pyx_codeobj__102;
  PyObject *__pyx_codeobj__103;
  PyObject *__pyx_codeobj__104;
  PyObject *__pyx_codeobj__105;
  PyObject *__pyx_codeobj__106;
  PyObject *__pyx_codeobj__107;
  PyObject *__pyx_codeobj__109;
  PyObject *__pyx_codeobj__111;
  PyObject *__pyx_codeobj__113;
  PyObject *__pyx_codeobj__116;
  PyObject *__pyx_codeobj__117;
  PyObject *__pyx_codeobj__118;
  PyObject *__pyx_codeobj__119;
  PyObject *__pyx_codeobj__120;
  PyObject *__pyx_codeobj__121;
  PyObject *__pyx_codeobj__122;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__125;
  PyObject *__pyx_codeobj__126;
  PyObject *__pyx_codeobj__128;
  PyObject *__pyx_codeobj__130;
  PyObject *__pyx_codeobj__131;
  PyObject *__pyx_codeobj__132;
  PyObject *__pyx_codeobj__133;
  PyObject *__pyx_codeobj__135;
  PyObject *__pyx_codeobj__136;
  PyObject *__pyx_codeobj__138;
  PyObject *__pyx_codeobj__140;
  PyObject *__pyx_codeobj__142;
  PyObject *__pyx_codeobj__143;
  PyObject *__pyx_codeobj__144;
  PyObject *__pyx_codeobj__146;
  PyObject *__pyx_codeobj__148;
  PyObject *__pyx_codeobj__150;
  PyObject *__pyx_codeobj__151;
  PyObject *__pyx_codeobj__152;
  PyObject *__pyx_codeobj__154;
  PyObject *__pyx_codeobj__156;
  PyObject *__pyx_codeobj__158;
  PyObject *__pyx_codeobj__160;
  PyObject *__pyx_codeobj__162;
  PyObject *__pyx_codeobj__163;
  PyObject *__pyx_codeobj__164;
  PyObject *__pyx_codeobj__165;
  PyObject *__pyx_codeobj__167;
  PyObject *__pyx_codeobj__168;
  PyObject *__pyx_codeobj__170;
  PyObject *__pyx_codeobj__172;
  PyObject *__pyx_codeobj__173;
  PyObject *__pyx_codeobj__174;
  PyObject *__pyx_codeobj__176;
  PyObject *__pyx_codeobj__177;
  PyObject *__pyx_codeobj__178;
  PyObject *__pyx_codeobj__180;
  PyObject *__pyx_codeobj__182;
  PyObject *__pyx_codeobj__183;
  PyObject *__pyx_codeobj__184;
  PyObject *__pyx_codeobj__185;
  PyObject *__pyx_codeobj__187;
  PyObject *__pyx_codeobj__189;
  PyObject *__pyx_codeobj__190;
  PyObject *__pyx_codeobj__191;
  PyObject *__pyx_codeobj__193;
  PyObject *__pyx_codeobj__194;
  PyObject *__pyx_codeobj__195;
  PyObject *__pyx_codeobj__196;
  PyObject *__pyx_codeobj__197;
  PyObject *__pyx_codeobj__199;
  PyObject *__pyx_codeobj__201;
  PyObject *__pyx_codeobj__203;
  PyObject *__pyx_codeobj__204;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__206;
  PyObject *__pyx_codeobj__208;
  PyObject *__pyx_codeobj__210;
  PyObject *__pyx_codeobj__211;
  PyObject *__pyx_codeobj__213;
  PyObject *__pyx_codeobj__214;
  PyObject *__pyx_codeobj__216;
  PyObject *__pyx_codeobj__218;
  PyObject *__pyx_codeobj__219;
  PyObject *__pyx_codeobj__221;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__223;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__225;
  PyObject *__pyx_codeobj__227;
  PyObject *__pyx_codeobj__229;
  PyObject *__pyx_codeobj__231;
  PyObject *__pyx_codeobj__233;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__237;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__241;
  PyObject *__pyx_codeobj__243;
  PyObject *__pyx_codeobj__245;
  PyObject *__pyx_codeobj__247;
  PyObject *__pyx_codeobj__249;
  PyObject *__pyx_codeobj__250;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__254;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__259;
  PyObject *__pyx_codeobj__261;
  PyObject *__pyx_codeobj__263;
  PyObject *__pyx_codeobj__265;
  PyObject *__pyx_codeobj__267;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__274;
  PyObject *__pyx_codeobj__276;
  PyObject *__pyx_codeobj__278;
  PyObject *__pyx_codeobj__280;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__283;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_dtype);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flatiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_broadcast);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ndarray);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_generic);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_number);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_integer);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_inexact);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_floating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flexible);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_character);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ufunc);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_02d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_09_00);
  Py_CLEAR(clear_module_state->__pyx_kp_u_17_00);
  Py_CLEAR(clear_module_state->__pyx_n_u_A);
  Py_CLEAR(clear_module_state->__pyx_n_u_AS);
  Py_CLEAR(clear_module_state->__pyx_kp_u_AS_JAN);
  Py_CLEAR(clear_module_state->__pyx_kp_u_A_DEC);
  Py_CLEAR(clear_module_state->__pyx_n_s_ApplyTypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_AssertionError);
  Py_CLEAR(clear_module_state->__pyx_n_s_AttributeError);
  Py_CLEAR(clear_module_state->__pyx_n_u_B);
  Py_CLEAR(clear_module_state->__pyx_n_u_BA);
  Py_CLEAR(clear_module_state->__pyx_n_u_BAS);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BAS_JAN);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BA_DEC);
  Py_CLEAR(clear_module_state->__pyx_n_s_BDay);
  Py_CLEAR(clear_module_state->__pyx_n_u_BH);
  Py_CLEAR(clear_module_state->__pyx_n_u_BM);
  Py_CLEAR(clear_module_state->__pyx_n_u_BMS);
  Py_CLEAR(clear_module_state->__pyx_n_s_BMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_BQ);
  Py_CLEAR(clear_module_state->__pyx_n_u_BQS);
  Py_CLEAR(clear_module_state->__pyx_n_s_BQuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BQuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_BY);
  Py_CLEAR(clear_module_state->__pyx_n_u_BYS);
  Py_CLEAR(clear_module_state->__pyx_n_s_BYearBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BYearEnd);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Bad_freq_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset___getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__get_offset_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__offset_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__params);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__repr_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset__validate_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_copy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_copy_line_532);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_freqstr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_freqstr_line_607);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_anchored_line_790);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_month_end);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_month_end_line_820);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_month_start);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_month_start_line_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_on_offset_line_696);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_quarter_end);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_quarter_end_line_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_quarter_start);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_quarter_start_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_year_end);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_year_end_line_872);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_is_year_start);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_is_year_start_line_85);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_kwds___get___line_449);
  Py_CLEAR(clear_module_state->__pyx_kp_u_BaseOffset_name___get___line_584);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_rollback);
  Py_CLEAR(clear_module_state->__pyx_n_s_BaseOffset_rollforward);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay__offset_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessDay_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__get_business_hours);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__get_closing_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__next_opening_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__prev_opening_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour__repr_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour_next_bday);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour_rollback);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessHour_rollforward);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMixin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMixin___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMixin__init_custom);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMixin__repr_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_BusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_BusinessQuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_n_u_BusinessQuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_BusinessYearBegin);
  Py_CLEAR(clear_module_state->__pyx_n_u_BusinessYearEnd);
  Py_CLEAR(clear_module_state->__pyx_n_u_C);
  Py_CLEAR(clear_module_state->__pyx_n_u_CBH);
  Py_CLEAR(clear_module_state->__pyx_n_u_CBM);
  Py_CLEAR(clear_module_state->__pyx_n_u_CBMS);
  Py_CLEAR(clear_module_state->__pyx_n_s_CBMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_CBMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_CDay);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_add);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_subtract_datetime_from_of);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Could_not_convert_to_integer_off);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessDay___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessDay__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessDay_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessHour);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonth);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonth__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonth_cbday_roll);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonth_m_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_CustomBusinessMonth_month_roll);
  Py_CLEAR(clear_module_state->__pyx_n_u_D);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_DateOffset___setattr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_DateOffset_objects_are_immutable);
  Py_CLEAR(clear_module_state->__pyx_kp_u_DateOffset_subclass);
  Py_CLEAR(clear_module_state->__pyx_kp_u_DateOffset_with_relativedelta_ke);
  Py_CLEAR(clear_module_state->__pyx_n_s_Day);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Day_must_be_0_day_6_got);
  Py_CLEAR(clear_module_state->__pyx_n_s_Easter);
  Py_CLEAR(clear_module_state->__pyx_n_s_Easter___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_Easter__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_Easter_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Mixin);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Mixin___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Mixin__get_suffix_prefix);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Mixin_get_rule_code_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Mixin_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter__offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter__rollback_to_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter_get_weeks);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253Quarter_year_has_extra_wee);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253__parse_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253_get_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_FY5253_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_u_H);
  Py_CLEAR(clear_module_state->__pyx_kp_u_H_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_Hour);
  Py_CLEAR(clear_module_state->__pyx_n_s_INVALID_FREQ_ERR_MSG);
  Py_CLEAR(clear_module_state->__pyx_n_s_ImportError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_argument_s_or_bad_combin);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_frequency_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_u_L);
  Py_CLEAR(clear_module_state->__pyx_n_u_LWOM);
  Py_CLEAR(clear_module_state->__pyx_n_s_LastWeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_n_s_LastWeekOfMonth___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_LastWeekOfMonth__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_LastWeekOfMonth__get_offset_day);
  Py_CLEAR(clear_module_state->__pyx_n_u_M);
  Py_CLEAR(clear_module_state->__pyx_n_s_MONTH_ALIASES);
  Py_CLEAR(clear_module_state->__pyx_n_s_MONTH_TO_CAL_NUM);
  Py_CLEAR(clear_module_state->__pyx_n_u_MS);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Metaclass_that_allows_us_to_pre);
  Py_CLEAR(clear_module_state->__pyx_n_s_Micro);
  Py_CLEAR(clear_module_state->__pyx_n_s_Milli);
  Py_CLEAR(clear_module_state->__pyx_n_u_Min);
  Py_CLEAR(clear_module_state->__pyx_n_s_Minute);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Mon_Tue_Wed_Thu_Fri);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_MonthOffset_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Month_must_go_from_1_to_12);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Must_include_at_least_1_end_time);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Must_include_at_least_1_start_ti);
  Py_CLEAR(clear_module_state->__pyx_n_u_N);
  Py_CLEAR(clear_module_state->__pyx_kp_u_N_cannot_be_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_Nano);
  Py_CLEAR(clear_module_state->__pyx_kp_u_None);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotImplemented);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotImplementedError);
  Py_CLEAR(clear_module_state->__pyx_n_s_OffsetMeta);
  Py_CLEAR(clear_module_state->__pyx_n_s_OffsetMeta___instancecheck);
  Py_CLEAR(clear_module_state->__pyx_n_s_OffsetMeta___subclasscheck);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Only_know_how_to_combine_busines);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Only_know_how_to_combine_trading);
  Py_CLEAR(clear_module_state->__pyx_n_s_OverflowError);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Prefix);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Prefix_not_defined);
  Py_CLEAR(clear_module_state->__pyx_n_u_Q);
  Py_CLEAR(clear_module_state->__pyx_n_u_QS);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Q_DEC);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_n_s_QuarterOffset_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_u_RE);
  Py_CLEAR(clear_module_state->__pyx_n_u_REQ);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset___getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset___reduce_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset___setstate_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_RelativeDeltaOffset_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_DateOffset_object_from_s);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_a_copy_of_the_frequency);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_a_dict_of_extra_paramete);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_a_string_representing_th);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_a_string_representing_th_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_an_integer_of_the_total);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_6);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Return_boolean_whether_the_freq);
  Py_CLEAR(clear_module_state->__pyx_n_s_RuntimeError);
  Py_CLEAR(clear_module_state->__pyx_n_u_S);
  Py_CLEAR(clear_module_state->__pyx_n_u_SM);
  Py_CLEAR(clear_module_state->__pyx_n_u_SMS);
  Py_CLEAR(clear_module_state->__pyx_n_s_Second);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthBegin_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthEnd_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_SemiMonthOffset__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_SingleConstructorOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_SingleConstructorOffset___reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_SingleConstructorOffset__from_na);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Standard_kind_of_date_increment);
  Py_CLEAR(clear_module_state->__pyx_n_u_T);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick__next_higher_resolution);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick__repr_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_n_s_Tick_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Tick_nanos___get___line_953);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Tick_offset_with_normalize_True);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Time_zones_are_not_available_fro);
  Py_CLEAR(clear_module_state->__pyx_n_s_Timedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_Timestamp);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_u_U);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unable_to_parse_varion_code);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unexpected_key__offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Unhandled_type);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Using_DateOffset_to_replace_mill);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_u_W);
  Py_CLEAR(clear_module_state->__pyx_n_u_WOM);
  Py_CLEAR(clear_module_state->__pyx_kp_u_W_SUN);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonth);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonthMixin);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonthMixin__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonthMixin_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonth___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonth__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_WeekOfMonth__get_offset_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_n_s_Week_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Week_must_be_0_week_3_got);
  Py_CLEAR(clear_module_state->__pyx_n_u_Y);
  Py_CLEAR(clear_module_state->__pyx_n_u_YS);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearBegin);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearEnd);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset__apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset__apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset__from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset__get_offset_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_YearOffset_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_u__13);
  Py_CLEAR(clear_module_state->__pyx_kp_u__15);
  Py_CLEAR(clear_module_state->__pyx_kp_u__16);
  Py_CLEAR(clear_module_state->__pyx_kp_u__17);
  Py_CLEAR(clear_module_state->__pyx_kp_u__18);
  Py_CLEAR(clear_module_state->__pyx_kp_u__19);
  Py_CLEAR(clear_module_state->__pyx_kp_u__20);
  Py_CLEAR(clear_module_state->__pyx_kp_u__21);
  Py_CLEAR(clear_module_state->__pyx_n_s__284);
  Py_CLEAR(clear_module_state->__pyx_kp_u__37);
  Py_CLEAR(clear_module_state->__pyx_kp_u__38);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_kp_u__46);
  Py_CLEAR(clear_module_state->__pyx_kp_u__47);
  Py_CLEAR(clear_module_state->__pyx_n_s__67);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_add);
  Py_CLEAR(clear_module_state->__pyx_n_s_adjust_dst);
  Py_CLEAR(clear_module_state->__pyx_n_s_all_paras);
  Py_CLEAR(clear_module_state->__pyx_n_s_anchor);
  Py_CLEAR(clear_module_state->__pyx_n_s_anchor_dom);
  Py_CLEAR(clear_module_state->__pyx_kp_u_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_array_wraps);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_array_wraps_locals_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_wrapper_core);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_wraps);
  Py_CLEAR(clear_module_state->__pyx_n_s_apply_wraps_locals_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_argsort);
  Py_CLEAR(clear_module_state->__pyx_n_s_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_array_priority);
  Py_CLEAR(clear_module_state->__pyx_n_s_as_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_asarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_astype);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_attr);
  Py_CLEAR(clear_module_state->__pyx_n_s_attributes);
  Py_CLEAR(clear_module_state->__pyx_n_s_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_b);
  Py_CLEAR(clear_module_state->__pyx_n_u_backward);
  Py_CLEAR(clear_module_state->__pyx_n_s_bd);
  Py_CLEAR(clear_module_state->__pyx_n_s_bhour);
  Py_CLEAR(clear_module_state->__pyx_n_s_bhour_remain);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_busday_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_busdaycal);
  Py_CLEAR(clear_module_state->__pyx_n_s_busdaycalendar);
  Py_CLEAR(clear_module_state->__pyx_n_u_business_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_business_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_businesshours);
  Py_CLEAR(clear_module_state->__pyx_n_u_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache_readonly);
  Py_CLEAR(clear_module_state->__pyx_n_s_calendar);
  Py_CLEAR(clear_module_state->__pyx_n_u_calendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_cbday);
  Py_CLEAR(clear_module_state->__pyx_n_s_cbday_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_s_cbday_roll);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_cls);
  Py_CLEAR(clear_module_state->__pyx_n_s_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_combine);
  Py_CLEAR(clear_module_state->__pyx_n_s_compare);
  Py_CLEAR(clear_module_state->__pyx_n_s_compare_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_compare_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_compile);
  Py_CLEAR(clear_module_state->__pyx_n_s_copy);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_creso);
  Py_CLEAR(clear_module_state->__pyx_n_s_cur_month_offset_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_cur_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_current);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_easter);
  Py_CLEAR(clear_module_state->__pyx_n_s_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z);
  Py_CLEAR(clear_module_state->__pyx_n_s_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_date_in);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_datetime64);
  Py_CLEAR(clear_module_state->__pyx_kp_u_datetime64_D);
  Py_CLEAR(clear_module_state->__pyx_n_s_dateutil_easter);
  Py_CLEAR(clear_module_state->__pyx_n_s_dateutil_relativedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_day);
  Py_CLEAR(clear_module_state->__pyx_n_u_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_day64);
  Py_CLEAR(clear_module_state->__pyx_kp_u_day_must_be_None_start_end_busin);
  Py_CLEAR(clear_module_state->__pyx_n_s_day_of_month);
  Py_CLEAR(clear_module_state->__pyx_n_u_day_of_month);
  Py_CLEAR(clear_module_state->__pyx_kp_u_day_of_month_27_got);
  Py_CLEAR(clear_module_state->__pyx_kp_u_day_of_month_must_be);
  Py_CLEAR(clear_module_state->__pyx_n_s_day_opt);
  Py_CLEAR(clear_module_state->__pyx_n_s_day_opt_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_days);
  Py_CLEAR(clear_module_state->__pyx_n_u_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_days_forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_days_in_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_default_day_of_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_default_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_default_starting_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta);
  Py_CLEAR(clear_module_state->__pyx_n_s_delta_to_tick);
  Py_CLEAR(clear_module_state->__pyx_n_s_determine_offset_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_u_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_dim);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_doc);
  Py_CLEAR(clear_module_state->__pyx_kp_u_does_not_have_a_vectorized_impl);
  Py_CLEAR(clear_module_state->__pyx_n_s_dont_uppercase);
  Py_CLEAR(clear_module_state->__pyx_n_s_dt);
  Py_CLEAR(clear_module_state->__pyx_n_s_dt64other);
  Py_CLEAR(clear_module_state->__pyx_n_s_dt_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtarr);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtindex);
  Py_CLEAR(clear_module_state->__pyx_n_s_dts);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtstart);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_dy);
  Py_CLEAR(clear_module_state->__pyx_n_s_earliest_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_easter);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_endswith);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_err);
  Py_CLEAR(clear_module_state->__pyx_n_s_exclude);
  Py_CLEAR(clear_module_state->__pyx_n_s_fabs);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_u_forward);
  Py_CLEAR(clear_module_state->__pyx_n_s_freq);
  Py_CLEAR(clear_module_state->__pyx_n_s_freqstr);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_from_name_starting_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_fstr);
  Py_CLEAR(clear_module_state->__pyx_n_s_func);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_ge);
  Py_CLEAR(clear_module_state->__pyx_n_s_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_business_hours_by_sec);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_closing_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_offset_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_rule_code_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_suffix_prefix);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_weeks);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_gt);
  Py_CLEAR(clear_module_state->__pyx_n_u_h);
  Py_CLEAR(clear_module_state->__pyx_n_s_holidays);
  Py_CLEAR(clear_module_state->__pyx_n_u_holidays);
  Py_CLEAR(clear_module_state->__pyx_n_s_hour);
  Py_CLEAR(clear_module_state->__pyx_n_u_hour);
  Py_CLEAR(clear_module_state->__pyx_n_s_hours);
  Py_CLEAR(clear_module_state->__pyx_n_u_hours);
  Py_CLEAR(clear_module_state->__pyx_n_s_hrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_u_i8);
  Py_CLEAR(clear_module_state->__pyx_n_s_i8other);
  Py_CLEAR(clear_module_state->__pyx_kp_u_implemented_by_subclasses);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_u_inc);
  Py_CLEAR(clear_module_state->__pyx_n_s_inc_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_init);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_custom);
  Py_CLEAR(clear_module_state->__pyx_n_s_init_subclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_instancecheck);
  Py_CLEAR(clear_module_state->__pyx_n_s_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_int_to_weekday);
  Py_CLEAR(clear_module_state->__pyx_kp_u_invalid_starting_and_ending_time);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_a_non_fixed_frequency);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_anchored);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_busday);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_month_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_month_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_month_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_month_start);
  Py_CLEAR(clear_module_state->__pyx_kp_u_is_not_a_valid_variation);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_on_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_on_offset_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_quarter_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_quarter_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_quarter_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_quarter_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_same_sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_year_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_is_year_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_isclose);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_isspace);
  Py_CLEAR(clear_module_state->__pyx_n_s_issubset);
  Py_CLEAR(clear_module_state->__pyx_n_s_items);
  Py_CLEAR(clear_module_state->__pyx_n_s_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_klass);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwd);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_u_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_u_last);
  Py_CLEAR(clear_module_state->__pyx_kp_u_last_element_must_be_blank);
  Py_CLEAR(clear_module_state->__pyx_n_s_latest_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_le);
  Py_CLEAR(clear_module_state->__pyx_n_s_lite_rule_alias);
  Py_CLEAR(clear_module_state->__pyx_n_s_lower);
  Py_CLEAR(clear_module_state->__pyx_n_s_lt);
  Py_CLEAR(clear_module_state->__pyx_n_u_m);
  Py_CLEAR(clear_module_state->__pyx_n_s_m_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_mend);
  Py_CLEAR(clear_module_state->__pyx_n_s_metaclass);
  Py_CLEAR(clear_module_state->__pyx_n_s_mi);
  Py_CLEAR(clear_module_state->__pyx_n_s_microsecond);
  Py_CLEAR(clear_module_state->__pyx_n_u_microsecond);
  Py_CLEAR(clear_module_state->__pyx_n_s_microseconds);
  Py_CLEAR(clear_module_state->__pyx_n_u_microseconds);
  Py_CLEAR(clear_module_state->__pyx_n_u_millisecond);
  Py_CLEAR(clear_module_state->__pyx_n_u_milliseconds);
  Py_CLEAR(clear_module_state->__pyx_n_u_min);
  Py_CLEAR(clear_module_state->__pyx_n_s_min_day_of_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_minute);
  Py_CLEAR(clear_module_state->__pyx_n_u_minute);
  Py_CLEAR(clear_module_state->__pyx_n_s_minutes);
  Py_CLEAR(clear_module_state->__pyx_n_u_minutes);
  Py_CLEAR(clear_module_state->__pyx_n_s_mod_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_modby);
  Py_CLEAR(clear_module_state->__pyx_n_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_moff);
  Py_CLEAR(clear_module_state->__pyx_n_s_month);
  Py_CLEAR(clear_module_state->__pyx_n_u_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_month_roll);
  Py_CLEAR(clear_module_state->__pyx_n_s_months);
  Py_CLEAR(clear_module_state->__pyx_n_u_months);
  Py_CLEAR(clear_module_state->__pyx_n_s_months_since);
  Py_CLEAR(clear_module_state->__pyx_n_s_months_to_roll);
  Py_CLEAR(clear_module_state->__pyx_n_s_mro_entries);
  Py_CLEAR(clear_module_state->__pyx_n_u_ms);
  Py_CLEAR(clear_module_state->__pyx_n_s_mstart);
  Py_CLEAR(clear_module_state->__pyx_n_s_mts);
  Py_CLEAR(clear_module_state->__pyx_n_s_mul);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_u_n);
  Py_CLEAR(clear_module_state->__pyx_kp_u_n_argument_must_be_an_integer_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_nadj);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_nano);
  Py_CLEAR(clear_module_state->__pyx_n_s_nanos);
  Py_CLEAR(clear_module_state->__pyx_n_s_nanos_inc);
  Py_CLEAR(clear_module_state->__pyx_n_s_nanosecond);
  Py_CLEAR(clear_module_state->__pyx_n_u_nanosecond);
  Py_CLEAR(clear_module_state->__pyx_n_s_nanoseconds);
  Py_CLEAR(clear_module_state->__pyx_n_u_nanoseconds);
  Py_CLEAR(clear_module_state->__pyx_n_s_nb_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndim);
  Py_CLEAR(clear_module_state->__pyx_n_u_nearest);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_new_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_bday);
  Py_CLEAR(clear_module_state->__pyx_n_u_next_bday);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_higher_resolution);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_opening_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_next_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_nint);
  Py_CLEAR(clear_module_state->__pyx_n_s_norm);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalize);
  Py_CLEAR(clear_module_state->__pyx_n_u_normalize);
  Py_CLEAR(clear_module_state->__pyx_n_s_normalize_i8_timestamps);
  Py_CLEAR(clear_module_state->__pyx_kp_u_not_able_to_be_applied_vectoriz);
  Py_CLEAR(clear_module_state->__pyx_n_s_np);
  Py_CLEAR(clear_module_state->__pyx_n_s_np_dt);
  Py_CLEAR(clear_module_state->__pyx_n_s_np_incr_dt);
  Py_CLEAR(clear_module_state->__pyx_kp_s_np_ndarray);
  Py_CLEAR(clear_module_state->__pyx_n_u_ns);
  Py_CLEAR(clear_module_state->__pyx_n_s_num_nano);
  Py_CLEAR(clear_module_state->__pyx_n_s_num_qtrs);
  Py_CLEAR(clear_module_state->__pyx_kp_u_number_of_starting_time_and_endi);
  Py_CLEAR(clear_module_state->__pyx_n_s_numpy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_off_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset);
  Py_CLEAR(clear_module_state->__pyx_n_u_offset);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_offset_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_offset_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset_map);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_offset_str_locals_get_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_op);
  Py_CLEAR(clear_module_state->__pyx_n_s_opattern);
  Py_CLEAR(clear_module_state->__pyx_n_s_other);
  Py_CLEAR(clear_module_state->__pyx_n_s_otherDay);
  Py_CLEAR(clear_module_state->__pyx_n_s_out);
  Py_CLEAR(clear_module_state->__pyx_n_s_outputName);
  Py_CLEAR(clear_module_state->__pyx_n_s_output_name);
  Py_CLEAR(clear_module_state->__pyx_n_u_output_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas__libs_properties);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas__libs_tslibs_ccalendar);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas__libs_tslibs_offsets);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pandas__libs_tslibs_offsets_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_params);
  Py_CLEAR(clear_module_state->__pyx_n_s_params_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_parse_suffix);
  Py_CLEAR(clear_module_state->__pyx_kp_u_pass_as_a_string_instead);
  Py_CLEAR(clear_module_state->__pyx_n_s_period_dtype_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pop);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix_mapping);
  Py_CLEAR(clear_module_state->__pyx_n_s_prepare);
  Py_CLEAR(clear_module_state->__pyx_n_s_prev_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_prev_opening_time);
  Py_CLEAR(clear_module_state->__pyx_n_s_prev_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_prev_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_BaseOffset);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_RelativeDeltaOffs);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_qlen);
  Py_CLEAR(clear_module_state->__pyx_n_s_qtr_len);
  Py_CLEAR(clear_module_state->__pyx_n_s_qtr_lens);
  Py_CLEAR(clear_module_state->__pyx_n_s_qtr_with_extra_week);
  Py_CLEAR(clear_module_state->__pyx_n_u_qtr_with_extra_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_qtrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_qualname);
  Py_CLEAR(clear_module_state->__pyx_n_s_r);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_re);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce___locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_relativedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_relativedelta_fast);
  Py_CLEAR(clear_module_state->__pyx_n_s_relativedelta_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_s_rem_nano);
  Py_CLEAR(clear_module_state->__pyx_n_s_remain);
  Py_CLEAR(clear_module_state->__pyx_n_s_replace);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr_attrs);
  Py_CLEAR(clear_module_state->__pyx_n_s_repr_attrs_locals_genexpr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_requires_a_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_res);
  Py_CLEAR(clear_module_state->__pyx_n_s_res_val);
  Py_CLEAR(clear_module_state->__pyx_n_s_reso);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_result2);
  Py_CLEAR(clear_module_state->__pyx_n_s_ret);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_reversed);
  Py_CLEAR(clear_module_state->__pyx_n_s_roll);
  Py_CLEAR(clear_module_state->__pyx_n_s_roll_convention);
  Py_CLEAR(clear_module_state->__pyx_n_s_roll_func);
  Py_CLEAR(clear_module_state->__pyx_n_s_roll_qtrday);
  Py_CLEAR(clear_module_state->__pyx_n_s_rollback);
  Py_CLEAR(clear_module_state->__pyx_n_s_rollback_to_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_rollforward);
  Py_CLEAR(clear_module_state->__pyx_n_s_rtruediv);
  Py_CLEAR(clear_module_state->__pyx_n_s_rule_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_u_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_second);
  Py_CLEAR(clear_module_state->__pyx_n_u_second);
  Py_CLEAR(clear_module_state->__pyx_n_s_seconds);
  Py_CLEAR(clear_module_state->__pyx_n_u_seconds);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_n_s_send);
  Py_CLEAR(clear_module_state->__pyx_kp_u_separator_must_be_spaces);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_setattr);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_shift_days);
  Py_CLEAR(clear_module_state->__pyx_n_s_shift_month);
  Py_CLEAR(clear_module_state->__pyx_n_s_shift_months);
  Py_CLEAR(clear_module_state->__pyx_n_s_shifted);
  Py_CLEAR(clear_module_state->__pyx_n_s_sign);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_skip_bd);
  Py_CLEAR(clear_module_state->__pyx_n_s_span);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_st);
  Py_CLEAR(clear_module_state->__pyx_n_s_stamp);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_u_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_startingMonth);
  Py_CLEAR(clear_module_state->__pyx_n_u_startingMonth);
  Py_CLEAR(clear_module_state->__pyx_n_s_startingMonth_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_startswith);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_staticmethod);
  Py_CLEAR(clear_module_state->__pyx_n_s_str);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_strptime);
  Py_CLEAR(clear_module_state->__pyx_n_s_subclasscheck);
  Py_CLEAR(clear_module_state->__pyx_n_s_suffix);
  Py_CLEAR(clear_module_state->__pyx_n_s_sum);
  Py_CLEAR(clear_module_state->__pyx_n_s_super);
  Py_CLEAR(clear_module_state->__pyx_n_s_target_date);
  Py_CLEAR(clear_module_state->__pyx_n_s_td);
  Py_CLEAR(clear_module_state->__pyx_n_s_td64);
  Py_CLEAR(clear_module_state->__pyx_n_s_td64_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_td_nano);
  Py_CLEAR(clear_module_state->__pyx_n_s_tdelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_kp_u_the_add_operation_between);
  Py_CLEAR(clear_module_state->__pyx_n_s_throw);
  Py_CLEAR(clear_module_state->__pyx_n_s_time);
  Py_CLEAR(clear_module_state->__pyx_kp_u_time_data_must_be_specified_only);
  Py_CLEAR(clear_module_state->__pyx_kp_u_time_data_must_be_string_or_date);
  Py_CLEAR(clear_module_state->__pyx_kp_u_time_data_must_match_H_M_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_timedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_timedelta64);
  Py_CLEAR(clear_module_state->__pyx_n_s_timedelta_kwds);
  Py_CLEAR(clear_module_state->__pyx_n_s_timedeltas);
  Py_CLEAR(clear_module_state->__pyx_n_s_timestamps);
  Py_CLEAR(clear_module_state->__pyx_n_s_tm_hour);
  Py_CLEAR(clear_module_state->__pyx_n_s_tm_min);
  Py_CLEAR(clear_module_state->__pyx_kp_u_to);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_day);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_u_to_offset_does_not_support_tuple);
  Py_CLEAR(clear_module_state->__pyx_kp_u_to_offset_line_4102);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_pydatetime);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_pytimedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_tolist);
  Py_CLEAR(clear_module_state->__pyx_n_s_total_seconds);
  Py_CLEAR(clear_module_state->__pyx_n_s_truediv);
  Py_CLEAR(clear_module_state->__pyx_n_s_ts);
  Py_CLEAR(clear_module_state->__pyx_n_s_tup);
  Py_CLEAR(clear_module_state->__pyx_n_s_tz);
  Py_CLEAR(clear_module_state->__pyx_n_s_tz_localize);
  Py_CLEAR(clear_module_state->__pyx_n_s_tzinfo);
  Py_CLEAR(clear_module_state->__pyx_n_u_tzinfo);
  Py_CLEAR(clear_module_state->__pyx_n_u_undefined);
  Py_CLEAR(clear_module_state->__pyx_n_s_unit);
  Py_CLEAR(clear_module_state->__pyx_n_s_until);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_upper);
  Py_CLEAR(clear_module_state->__pyx_n_u_us);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_relativedelta);
  Py_CLEAR(clear_module_state->__pyx_n_u_use_relativedelta);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_val);
  Py_CLEAR(clear_module_state->__pyx_n_s_validate_n);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_value_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_variation);
  Py_CLEAR(clear_module_state->__pyx_n_u_variation);
  Py_CLEAR(clear_module_state->__pyx_n_s_varion_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_vectorized);
  Py_CLEAR(clear_module_state->__pyx_n_s_view);
  Py_CLEAR(clear_module_state->__pyx_n_s_wday);
  Py_CLEAR(clear_module_state->__pyx_n_s_week);
  Py_CLEAR(clear_module_state->__pyx_n_u_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_weekday);
  Py_CLEAR(clear_module_state->__pyx_n_u_weekday);
  Py_CLEAR(clear_module_state->__pyx_n_s_weekday_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_weekday_to_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_weekmask);
  Py_CLEAR(clear_module_state->__pyx_n_u_weekmask);
  Py_CLEAR(clear_module_state->__pyx_n_s_weeks);
  Py_CLEAR(clear_module_state->__pyx_n_u_weeks);
  Py_CLEAR(clear_module_state->__pyx_n_s_weeks_in_year);
  Py_CLEAR(clear_module_state->__pyx_kp_u_will_overflow);
  Py_CLEAR(clear_module_state->__pyx_n_s_wkday_diff);
  Py_CLEAR(clear_module_state->__pyx_n_s_wrapper);
  Py_CLEAR(clear_module_state->__pyx_n_s_year);
  Py_CLEAR(clear_module_state->__pyx_n_u_year);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_year_has_extra_week);
  Py_CLEAR(clear_module_state->__pyx_n_s_years);
  Py_CLEAR(clear_module_state->__pyx_n_u_years);
  Py_CLEAR(clear_module_state->__pyx_n_s_zero);
  Py_CLEAR(clear_module_state->__pyx_n_s_zip);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_4);
  Py_CLEAR(clear_module_state->__pyx_int_5);
  Py_CLEAR(clear_module_state->__pyx_int_6);
  Py_CLEAR(clear_module_state->__pyx_int_7);
  Py_CLEAR(clear_module_state->__pyx_int_12);
  Py_CLEAR(clear_module_state->__pyx_int_13);
  Py_CLEAR(clear_module_state->__pyx_int_14);
  Py_CLEAR(clear_module_state->__pyx_int_15);
  Py_CLEAR(clear_module_state->__pyx_int_27);
  Py_CLEAR(clear_module_state->__pyx_int_52);
  Py_CLEAR(clear_module_state->__pyx_int_53);
  Py_CLEAR(clear_module_state->__pyx_int_60);
  Py_CLEAR(clear_module_state->__pyx_int_1000);
  Py_CLEAR(clear_module_state->__pyx_int_2014);
  Py_CLEAR(clear_module_state->__pyx_int_3600);
  Py_CLEAR(clear_module_state->__pyx_int_86400);
  Py_CLEAR(clear_module_state->__pyx_int_1000000);
  Py_CLEAR(clear_module_state->__pyx_int_10844460);
  Py_CLEAR(clear_module_state->__pyx_int_171034093);
  Py_CLEAR(clear_module_state->__pyx_int_213572416);
  Py_CLEAR(clear_module_state->__pyx_int_1000000000);
  Py_CLEAR(clear_module_state->__pyx_int_60000000000);
  Py_CLEAR(clear_module_state->__pyx_int_3600000000000);
  Py_CLEAR(clear_module_state->__pyx_int_0x4e94914f0000);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_k__33);
  Py_CLEAR(clear_module_state->__pyx_k__40);
  Py_CLEAR(clear_module_state->__pyx_k__56);
  Py_CLEAR(clear_module_state->__pyx_k__57);
  Py_CLEAR(clear_module_state->__pyx_k__58);
  Py_CLEAR(clear_module_state->__pyx_tuple_);
  Py_CLEAR(clear_module_state->__pyx_tuple__2);
  Py_CLEAR(clear_module_state->__pyx_tuple__3);
  Py_CLEAR(clear_module_state->__pyx_tuple__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__7);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_slice__53);
  Py_CLEAR(clear_module_state->__pyx_slice__60);
  Py_CLEAR(clear_module_state->__pyx_slice__61);
  Py_CLEAR(clear_module_state->__pyx_slice__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__12);
  Py_CLEAR(clear_module_state->__pyx_tuple__14);
  Py_CLEAR(clear_module_state->__pyx_tuple__22);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__25);
  Py_CLEAR(clear_module_state->__pyx_tuple__26);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__28);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__30);
  Py_CLEAR(clear_module_state->__pyx_tuple__31);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__42);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__44);
  Py_CLEAR(clear_module_state->__pyx_tuple__45);
  Py_CLEAR(clear_module_state->__pyx_tuple__48);
  Py_CLEAR(clear_module_state->__pyx_tuple__49);
  Py_CLEAR(clear_module_state->__pyx_tuple__50);
  Py_CLEAR(clear_module_state->__pyx_tuple__51);
  Py_CLEAR(clear_module_state->__pyx_tuple__52);
  Py_CLEAR(clear_module_state->__pyx_tuple__54);
  Py_CLEAR(clear_module_state->__pyx_tuple__55);
  Py_CLEAR(clear_module_state->__pyx_tuple__59);
  Py_CLEAR(clear_module_state->__pyx_tuple__63);
  Py_CLEAR(clear_module_state->__pyx_tuple__65);
  Py_CLEAR(clear_module_state->__pyx_tuple__66);
  Py_CLEAR(clear_module_state->__pyx_tuple__68);
  Py_CLEAR(clear_module_state->__pyx_tuple__70);
  Py_CLEAR(clear_module_state->__pyx_tuple__73);
  Py_CLEAR(clear_module_state->__pyx_tuple__74);
  Py_CLEAR(clear_module_state->__pyx_tuple__75);
  Py_CLEAR(clear_module_state->__pyx_tuple__77);
  Py_CLEAR(clear_module_state->__pyx_tuple__79);
  Py_CLEAR(clear_module_state->__pyx_tuple__81);
  Py_CLEAR(clear_module_state->__pyx_tuple__84);
  Py_CLEAR(clear_module_state->__pyx_tuple__86);
  Py_CLEAR(clear_module_state->__pyx_tuple__88);
  Py_CLEAR(clear_module_state->__pyx_tuple__91);
  Py_CLEAR(clear_module_state->__pyx_tuple__93);
  Py_CLEAR(clear_module_state->__pyx_tuple__95);
  Py_CLEAR(clear_module_state->__pyx_tuple__97);
  Py_CLEAR(clear_module_state->__pyx_codeobj__6);
  Py_CLEAR(clear_module_state->__pyx_codeobj__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__108);
  Py_CLEAR(clear_module_state->__pyx_tuple__110);
  Py_CLEAR(clear_module_state->__pyx_tuple__112);
  Py_CLEAR(clear_module_state->__pyx_tuple__114);
  Py_CLEAR(clear_module_state->__pyx_tuple__115);
  Py_CLEAR(clear_module_state->__pyx_tuple__123);
  Py_CLEAR(clear_module_state->__pyx_tuple__127);
  Py_CLEAR(clear_module_state->__pyx_tuple__129);
  Py_CLEAR(clear_module_state->__pyx_tuple__134);
  Py_CLEAR(clear_module_state->__pyx_tuple__137);
  Py_CLEAR(clear_module_state->__pyx_tuple__139);
  Py_CLEAR(clear_module_state->__pyx_tuple__141);
  Py_CLEAR(clear_module_state->__pyx_tuple__145);
  Py_CLEAR(clear_module_state->__pyx_tuple__147);
  Py_CLEAR(clear_module_state->__pyx_tuple__149);
  Py_CLEAR(clear_module_state->__pyx_tuple__153);
  Py_CLEAR(clear_module_state->__pyx_tuple__155);
  Py_CLEAR(clear_module_state->__pyx_tuple__157);
  Py_CLEAR(clear_module_state->__pyx_tuple__159);
  Py_CLEAR(clear_module_state->__pyx_tuple__161);
  Py_CLEAR(clear_module_state->__pyx_tuple__166);
  Py_CLEAR(clear_module_state->__pyx_tuple__169);
  Py_CLEAR(clear_module_state->__pyx_tuple__171);
  Py_CLEAR(clear_module_state->__pyx_tuple__175);
  Py_CLEAR(clear_module_state->__pyx_tuple__179);
  Py_CLEAR(clear_module_state->__pyx_tuple__181);
  Py_CLEAR(clear_module_state->__pyx_tuple__186);
  Py_CLEAR(clear_module_state->__pyx_tuple__188);
  Py_CLEAR(clear_module_state->__pyx_tuple__192);
  Py_CLEAR(clear_module_state->__pyx_tuple__198);
  Py_CLEAR(clear_module_state->__pyx_tuple__200);
  Py_CLEAR(clear_module_state->__pyx_tuple__202);
  Py_CLEAR(clear_module_state->__pyx_tuple__207);
  Py_CLEAR(clear_module_state->__pyx_tuple__209);
  Py_CLEAR(clear_module_state->__pyx_tuple__212);
  Py_CLEAR(clear_module_state->__pyx_tuple__215);
  Py_CLEAR(clear_module_state->__pyx_tuple__217);
  Py_CLEAR(clear_module_state->__pyx_tuple__220);
  Py_CLEAR(clear_module_state->__pyx_tuple__226);
  Py_CLEAR(clear_module_state->__pyx_tuple__228);
  Py_CLEAR(clear_module_state->__pyx_tuple__230);
  Py_CLEAR(clear_module_state->__pyx_tuple__232);
  Py_CLEAR(clear_module_state->__pyx_tuple__234);
  Py_CLEAR(clear_module_state->__pyx_tuple__236);
  Py_CLEAR(clear_module_state->__pyx_tuple__240);
  Py_CLEAR(clear_module_state->__pyx_tuple__242);
  Py_CLEAR(clear_module_state->__pyx_tuple__244);
  Py_CLEAR(clear_module_state->__pyx_tuple__246);
  Py_CLEAR(clear_module_state->__pyx_tuple__248);
  Py_CLEAR(clear_module_state->__pyx_tuple__252);
  Py_CLEAR(clear_module_state->__pyx_tuple__256);
  Py_CLEAR(clear_module_state->__pyx_tuple__258);
  Py_CLEAR(clear_module_state->__pyx_tuple__260);
  Py_CLEAR(clear_module_state->__pyx_tuple__262);
  Py_CLEAR(clear_module_state->__pyx_tuple__264);
  Py_CLEAR(clear_module_state->__pyx_tuple__266);
  Py_CLEAR(clear_module_state->__pyx_tuple__268);
  Py_CLEAR(clear_module_state->__pyx_tuple__269);
  Py_CLEAR(clear_module_state->__pyx_tuple__271);
  Py_CLEAR(clear_module_state->__pyx_tuple__273);
  Py_CLEAR(clear_module_state->__pyx_tuple__275);
  Py_CLEAR(clear_module_state->__pyx_tuple__277);
  Py_CLEAR(clear_module_state->__pyx_tuple__279);
  Py_CLEAR(clear_module_state->__pyx_tuple__281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__35);
  Py_CLEAR(clear_module_state->__pyx_codeobj__69);
  Py_CLEAR(clear_module_state->__pyx_codeobj__71);
  Py_CLEAR(clear_module_state->__pyx_codeobj__72);
  Py_CLEAR(clear_module_state->__pyx_codeobj__76);
  Py_CLEAR(clear_module_state->__pyx_codeobj__78);
  Py_CLEAR(clear_module_state->__pyx_codeobj__80);
  Py_CLEAR(clear_module_state->__pyx_codeobj__82);
  Py_CLEAR(clear_module_state->__pyx_codeobj__83);
  Py_CLEAR(clear_module_state->__pyx_codeobj__85);
  Py_CLEAR(clear_module_state->__pyx_codeobj__87);
  Py_CLEAR(clear_module_state->__pyx_codeobj__89);
  Py_CLEAR(clear_module_state->__pyx_codeobj__90);
  Py_CLEAR(clear_module_state->__pyx_codeobj__92);
  Py_CLEAR(clear_module_state->__pyx_codeobj__94);
  Py_CLEAR(clear_module_state->__pyx_codeobj__96);
  Py_CLEAR(clear_module_state->__pyx_codeobj__98);
  Py_CLEAR(clear_module_state->__pyx_codeobj__99);
  Py_CLEAR(clear_module_state->__pyx_codeobj__100);
  Py_CLEAR(clear_module_state->__pyx_codeobj__102);
  Py_CLEAR(clear_module_state->__pyx_codeobj__103);
  Py_CLEAR(clear_module_state->__pyx_codeobj__104);
  Py_CLEAR(clear_module_state->__pyx_codeobj__105);
  Py_CLEAR(clear_module_state->__pyx_codeobj__106);
  Py_CLEAR(clear_module_state->__pyx_codeobj__107);
  Py_CLEAR(clear_module_state->__pyx_codeobj__109);
  Py_CLEAR(clear_module_state->__pyx_codeobj__111);
  Py_CLEAR(clear_module_state->__pyx_codeobj__113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__117);
  Py_CLEAR(clear_module_state->__pyx_codeobj__118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__119);
  Py_CLEAR(clear_module_state->__pyx_codeobj__120);
  Py_CLEAR(clear_module_state->__pyx_codeobj__121);
  Py_CLEAR(clear_module_state->__pyx_codeobj__122);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__125);
  Py_CLEAR(clear_module_state->__pyx_codeobj__126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__128);
  Py_CLEAR(clear_module_state->__pyx_codeobj__130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__131);
  Py_CLEAR(clear_module_state->__pyx_codeobj__132);
  Py_CLEAR(clear_module_state->__pyx_codeobj__133);
  Py_CLEAR(clear_module_state->__pyx_codeobj__135);
  Py_CLEAR(clear_module_state->__pyx_codeobj__136);
  Py_CLEAR(clear_module_state->__pyx_codeobj__138);
  Py_CLEAR(clear_module_state->__pyx_codeobj__140);
  Py_CLEAR(clear_module_state->__pyx_codeobj__142);
  Py_CLEAR(clear_module_state->__pyx_codeobj__143);
  Py_CLEAR(clear_module_state->__pyx_codeobj__144);
  Py_CLEAR(clear_module_state->__pyx_codeobj__146);
  Py_CLEAR(clear_module_state->__pyx_codeobj__148);
  Py_CLEAR(clear_module_state->__pyx_codeobj__150);
  Py_CLEAR(clear_module_state->__pyx_codeobj__151);
  Py_CLEAR(clear_module_state->__pyx_codeobj__152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__156);
  Py_CLEAR(clear_module_state->__pyx_codeobj__158);
  Py_CLEAR(clear_module_state->__pyx_codeobj__160);
  Py_CLEAR(clear_module_state->__pyx_codeobj__162);
  Py_CLEAR(clear_module_state->__pyx_codeobj__163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__165);
  Py_CLEAR(clear_module_state->__pyx_codeobj__167);
  Py_CLEAR(clear_module_state->__pyx_codeobj__168);
  Py_CLEAR(clear_module_state->__pyx_codeobj__170);
  Py_CLEAR(clear_module_state->__pyx_codeobj__172);
  Py_CLEAR(clear_module_state->__pyx_codeobj__173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__177);
  Py_CLEAR(clear_module_state->__pyx_codeobj__178);
  Py_CLEAR(clear_module_state->__pyx_codeobj__180);
  Py_CLEAR(clear_module_state->__pyx_codeobj__182);
  Py_CLEAR(clear_module_state->__pyx_codeobj__183);
  Py_CLEAR(clear_module_state->__pyx_codeobj__184);
  Py_CLEAR(clear_module_state->__pyx_codeobj__185);
  Py_CLEAR(clear_module_state->__pyx_codeobj__187);
  Py_CLEAR(clear_module_state->__pyx_codeobj__189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__190);
  Py_CLEAR(clear_module_state->__pyx_codeobj__191);
  Py_CLEAR(clear_module_state->__pyx_codeobj__193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__194);
  Py_CLEAR(clear_module_state->__pyx_codeobj__195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__196);
  Py_CLEAR(clear_module_state->__pyx_codeobj__197);
  Py_CLEAR(clear_module_state->__pyx_codeobj__199);
  Py_CLEAR(clear_module_state->__pyx_codeobj__201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__203);
  Py_CLEAR(clear_module_state->__pyx_codeobj__204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__206);
  Py_CLEAR(clear_module_state->__pyx_codeobj__208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__211);
  Py_CLEAR(clear_module_state->__pyx_codeobj__213);
  Py_CLEAR(clear_module_state->__pyx_codeobj__214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__218);
  Py_CLEAR(clear_module_state->__pyx_codeobj__219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__221);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__227);
  Py_CLEAR(clear_module_state->__pyx_codeobj__229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__241);
  Py_CLEAR(clear_module_state->__pyx_codeobj__243);
  Py_CLEAR(clear_module_state->__pyx_codeobj__245);
  Py_CLEAR(clear_module_state->__pyx_codeobj__247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__250);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__254);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__265);
  Py_CLEAR(clear_module_state->__pyx_codeobj__267);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__274);
  Py_CLEAR(clear_module_state->__pyx_codeobj__276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__283);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_dtype);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flatiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_broadcast);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ndarray);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_generic);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_number);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_integer);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_inexact);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_floating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flexible);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_character);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ufunc);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_02d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_09_00);
  Py_VISIT(traverse_module_state->__pyx_kp_u_17_00);
  Py_VISIT(traverse_module_state->__pyx_n_u_A);
  Py_VISIT(traverse_module_state->__pyx_n_u_AS);
  Py_VISIT(traverse_module_state->__pyx_kp_u_AS_JAN);
  Py_VISIT(traverse_module_state->__pyx_kp_u_A_DEC);
  Py_VISIT(traverse_module_state->__pyx_n_s_ApplyTypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_AssertionError);
  Py_VISIT(traverse_module_state->__pyx_n_s_AttributeError);
  Py_VISIT(traverse_module_state->__pyx_n_u_B);
  Py_VISIT(traverse_module_state->__pyx_n_u_BA);
  Py_VISIT(traverse_module_state->__pyx_n_u_BAS);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BAS_JAN);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BA_DEC);
  Py_VISIT(traverse_module_state->__pyx_n_s_BDay);
  Py_VISIT(traverse_module_state->__pyx_n_u_BH);
  Py_VISIT(traverse_module_state->__pyx_n_u_BM);
  Py_VISIT(traverse_module_state->__pyx_n_u_BMS);
  Py_VISIT(traverse_module_state->__pyx_n_s_BMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_BQ);
  Py_VISIT(traverse_module_state->__pyx_n_u_BQS);
  Py_VISIT(traverse_module_state->__pyx_n_s_BQuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BQuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_BY);
  Py_VISIT(traverse_module_state->__pyx_n_u_BYS);
  Py_VISIT(traverse_module_state->__pyx_n_s_BYearBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BYearEnd);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Bad_freq_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset___getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__get_offset_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__offset_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__params);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__repr_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset__validate_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_copy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_copy_line_532);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_freqstr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_freqstr_line_607);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_anchored_line_790);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_month_end);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_month_end_line_820);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_month_start);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_month_start_line_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_on_offset_line_696);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_quarter_end);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_quarter_end_line_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_quarter_start);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_quarter_start_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_year_end);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_year_end_line_872);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_is_year_start);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_is_year_start_line_85);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_kwds___get___line_449);
  Py_VISIT(traverse_module_state->__pyx_kp_u_BaseOffset_name___get___line_584);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_rollback);
  Py_VISIT(traverse_module_state->__pyx_n_s_BaseOffset_rollforward);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay__offset_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessDay_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__get_business_hours);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__get_closing_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__next_opening_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__prev_opening_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour__repr_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour_next_bday);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour_rollback);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessHour_rollforward);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMixin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMixin___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMixin__init_custom);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMixin__repr_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_BusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_BusinessQuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_n_u_BusinessQuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_BusinessYearBegin);
  Py_VISIT(traverse_module_state->__pyx_n_u_BusinessYearEnd);
  Py_VISIT(traverse_module_state->__pyx_n_u_C);
  Py_VISIT(traverse_module_state->__pyx_n_u_CBH);
  Py_VISIT(traverse_module_state->__pyx_n_u_CBM);
  Py_VISIT(traverse_module_state->__pyx_n_u_CBMS);
  Py_VISIT(traverse_module_state->__pyx_n_s_CBMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_CBMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_CDay);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_add);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_subtract_datetime_from_of);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Could_not_convert_to_integer_off);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessDay___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessDay__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessDay_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessHour);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonth);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonth__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonth_cbday_roll);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonth_m_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_CustomBusinessMonth_month_roll);
  Py_VISIT(traverse_module_state->__pyx_n_u_D);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_DateOffset___setattr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_DateOffset_objects_are_immutable);
  Py_VISIT(traverse_module_state->__pyx_kp_u_DateOffset_subclass);
  Py_VISIT(traverse_module_state->__pyx_kp_u_DateOffset_with_relativedelta_ke);
  Py_VISIT(traverse_module_state->__pyx_n_s_Day);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Day_must_be_0_day_6_got);
  Py_VISIT(traverse_module_state->__pyx_n_s_Easter);
  Py_VISIT(traverse_module_state->__pyx_n_s_Easter___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_Easter__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_Easter_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Mixin);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Mixin___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Mixin__get_suffix_prefix);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Mixin_get_rule_code_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Mixin_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter__offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter__rollback_to_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter_get_weeks);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253Quarter_year_has_extra_wee);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253__parse_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253_get_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_FY5253_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_u_H);
  Py_VISIT(traverse_module_state->__pyx_kp_u_H_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_Hour);
  Py_VISIT(traverse_module_state->__pyx_n_s_INVALID_FREQ_ERR_MSG);
  Py_VISIT(traverse_module_state->__pyx_n_s_ImportError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_argument_s_or_bad_combin);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_frequency_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_u_L);
  Py_VISIT(traverse_module_state->__pyx_n_u_LWOM);
  Py_VISIT(traverse_module_state->__pyx_n_s_LastWeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_n_s_LastWeekOfMonth___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_LastWeekOfMonth__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_LastWeekOfMonth__get_offset_day);
  Py_VISIT(traverse_module_state->__pyx_n_u_M);
  Py_VISIT(traverse_module_state->__pyx_n_s_MONTH_ALIASES);
  Py_VISIT(traverse_module_state->__pyx_n_s_MONTH_TO_CAL_NUM);
  Py_VISIT(traverse_module_state->__pyx_n_u_MS);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Metaclass_that_allows_us_to_pre);
  Py_VISIT(traverse_module_state->__pyx_n_s_Micro);
  Py_VISIT(traverse_module_state->__pyx_n_s_Milli);
  Py_VISIT(traverse_module_state->__pyx_n_u_Min);
  Py_VISIT(traverse_module_state->__pyx_n_s_Minute);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Mon_Tue_Wed_Thu_Fri);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_MonthOffset_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Month_must_go_from_1_to_12);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Must_include_at_least_1_end_time);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Must_include_at_least_1_start_ti);
  Py_VISIT(traverse_module_state->__pyx_n_u_N);
  Py_VISIT(traverse_module_state->__pyx_kp_u_N_cannot_be_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_Nano);
  Py_VISIT(traverse_module_state->__pyx_kp_u_None);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotImplemented);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotImplementedError);
  Py_VISIT(traverse_module_state->__pyx_n_s_OffsetMeta);
  Py_VISIT(traverse_module_state->__pyx_n_s_OffsetMeta___instancecheck);
  Py_VISIT(traverse_module_state->__pyx_n_s_OffsetMeta___subclasscheck);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Only_know_how_to_combine_busines);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Only_know_how_to_combine_trading);
  Py_VISIT(traverse_module_state->__pyx_n_s_OverflowError);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Prefix);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Prefix_not_defined);
  Py_VISIT(traverse_module_state->__pyx_n_u_Q);
  Py_VISIT(traverse_module_state->__pyx_n_u_QS);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Q_DEC);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_n_s_QuarterOffset_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_u_RE);
  Py_VISIT(traverse_module_state->__pyx_n_u_REQ);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset___getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset___reduce_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset___setstate_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_RelativeDeltaOffset_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_DateOffset_object_from_s);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_a_copy_of_the_frequency);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_a_dict_of_extra_paramete);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_a_string_representing_th);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_a_string_representing_th_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_an_integer_of_the_total);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_6);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_a_timest_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Return_boolean_whether_the_freq);
  Py_VISIT(traverse_module_state->__pyx_n_s_RuntimeError);
  Py_VISIT(traverse_module_state->__pyx_n_u_S);
  Py_VISIT(traverse_module_state->__pyx_n_u_SM);
  Py_VISIT(traverse_module_state->__pyx_n_u_SMS);
  Py_VISIT(traverse_module_state->__pyx_n_s_Second);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthBegin_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthEnd_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_SemiMonthOffset__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_SingleConstructorOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_SingleConstructorOffset___reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_SingleConstructorOffset__from_na);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Standard_kind_of_date_increment);
  Py_VISIT(traverse_module_state->__pyx_n_u_T);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick__next_higher_resolution);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick__repr_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_n_s_Tick_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Tick_nanos___get___line_953);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Tick_offset_with_normalize_True);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Time_zones_are_not_available_fro);
  Py_VISIT(traverse_module_state->__pyx_n_s_Timedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_Timestamp);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_u_U);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unable_to_parse_varion_code);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unexpected_key__offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Unhandled_type);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Using_DateOffset_to_replace_mill);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_u_W);
  Py_VISIT(traverse_module_state->__pyx_n_u_WOM);
  Py_VISIT(traverse_module_state->__pyx_kp_u_W_SUN);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonth);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonthMixin);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonthMixin__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonthMixin_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonth___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonth__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_WeekOfMonth__get_offset_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_n_s_Week_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Week_must_be_0_week_3_got);
  Py_VISIT(traverse_module_state->__pyx_n_u_Y);
  Py_VISIT(traverse_module_state->__pyx_n_u_YS);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearBegin);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearEnd);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset__apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset__apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset__from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset__get_offset_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_YearOffset_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_u__13);
  Py_VISIT(traverse_module_state->__pyx_kp_u__15);
  Py_VISIT(traverse_module_state->__pyx_kp_u__16);
  Py_VISIT(traverse_module_state->__pyx_kp_u__17);
  Py_VISIT(traverse_module_state->__pyx_kp_u__18);
  Py_VISIT(traverse_module_state->__pyx_kp_u__19);
  Py_VISIT(traverse_module_state->__pyx_kp_u__20);
  Py_VISIT(traverse_module_state->__pyx_kp_u__21);
  Py_VISIT(traverse_module_state->__pyx_n_s__284);
  Py_VISIT(traverse_module_state->__pyx_kp_u__37);
  Py_VISIT(traverse_module_state->__pyx_kp_u__38);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_kp_u__46);
  Py_VISIT(traverse_module_state->__pyx_kp_u__47);
  Py_VISIT(traverse_module_state->__pyx_n_s__67);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_add);
  Py_VISIT(traverse_module_state->__pyx_n_s_adjust_dst);
  Py_VISIT(traverse_module_state->__pyx_n_s_all_paras);
  Py_VISIT(traverse_module_state->__pyx_n_s_anchor);
  Py_VISIT(traverse_module_state->__pyx_n_s_anchor_dom);
  Py_VISIT(traverse_module_state->__pyx_kp_u_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_array_wraps);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_array_wraps_locals_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_wrapper_core);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_wraps);
  Py_VISIT(traverse_module_state->__pyx_n_s_apply_wraps_locals_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_argsort);
  Py_VISIT(traverse_module_state->__pyx_n_s_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_array_priority);
  Py_VISIT(traverse_module_state->__pyx_n_s_as_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_asarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_astype);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_attr);
  Py_VISIT(traverse_module_state->__pyx_n_s_attributes);
  Py_VISIT(traverse_module_state->__pyx_n_s_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_b);
  Py_VISIT(traverse_module_state->__pyx_n_u_backward);
  Py_VISIT(traverse_module_state->__pyx_n_s_bd);
  Py_VISIT(traverse_module_state->__pyx_n_s_bhour);
  Py_VISIT(traverse_module_state->__pyx_n_s_bhour_remain);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_busday_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_busdaycal);
  Py_VISIT(traverse_module_state->__pyx_n_s_busdaycalendar);
  Py_VISIT(traverse_module_state->__pyx_n_u_business_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_business_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_businesshours);
  Py_VISIT(traverse_module_state->__pyx_n_u_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache_readonly);
  Py_VISIT(traverse_module_state->__pyx_n_s_calendar);
  Py_VISIT(traverse_module_state->__pyx_n_u_calendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_cbday);
  Py_VISIT(traverse_module_state->__pyx_n_s_cbday_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_s_cbday_roll);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_cls);
  Py_VISIT(traverse_module_state->__pyx_n_s_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_combine);
  Py_VISIT(traverse_module_state->__pyx_n_s_compare);
  Py_VISIT(traverse_module_state->__pyx_n_s_compare_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_compare_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_compile);
  Py_VISIT(traverse_module_state->__pyx_n_s_copy);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_creso);
  Py_VISIT(traverse_module_state->__pyx_n_s_cur_month_offset_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_cur_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_current);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_easter);
  Py_VISIT(traverse_module_state->__pyx_n_s_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z);
  Py_VISIT(traverse_module_state->__pyx_n_s_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_date_in);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_datetime64);
  Py_VISIT(traverse_module_state->__pyx_kp_u_datetime64_D);
  Py_VISIT(traverse_module_state->__pyx_n_s_dateutil_easter);
  Py_VISIT(traverse_module_state->__pyx_n_s_dateutil_relativedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_day);
  Py_VISIT(traverse_module_state->__pyx_n_u_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_day64);
  Py_VISIT(traverse_module_state->__pyx_kp_u_day_must_be_None_start_end_busin);
  Py_VISIT(traverse_module_state->__pyx_n_s_day_of_month);
  Py_VISIT(traverse_module_state->__pyx_n_u_day_of_month);
  Py_VISIT(traverse_module_state->__pyx_kp_u_day_of_month_27_got);
  Py_VISIT(traverse_module_state->__pyx_kp_u_day_of_month_must_be);
  Py_VISIT(traverse_module_state->__pyx_n_s_day_opt);
  Py_VISIT(traverse_module_state->__pyx_n_s_day_opt_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_days);
  Py_VISIT(traverse_module_state->__pyx_n_u_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_days_forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_days_in_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_default_day_of_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_default_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_default_starting_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta);
  Py_VISIT(traverse_module_state->__pyx_n_s_delta_to_tick);
  Py_VISIT(traverse_module_state->__pyx_n_s_determine_offset_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_u_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_dim);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_doc);
  Py_VISIT(traverse_module_state->__pyx_kp_u_does_not_have_a_vectorized_impl);
  Py_VISIT(traverse_module_state->__pyx_n_s_dont_uppercase);
  Py_VISIT(traverse_module_state->__pyx_n_s_dt);
  Py_VISIT(traverse_module_state->__pyx_n_s_dt64other);
  Py_VISIT(traverse_module_state->__pyx_n_s_dt_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtarr);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtindex);
  Py_VISIT(traverse_module_state->__pyx_n_s_dts);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtstart);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_dy);
  Py_VISIT(traverse_module_state->__pyx_n_s_earliest_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_easter);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_endswith);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_err);
  Py_VISIT(traverse_module_state->__pyx_n_s_exclude);
  Py_VISIT(traverse_module_state->__pyx_n_s_fabs);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_u_forward);
  Py_VISIT(traverse_module_state->__pyx_n_s_freq);
  Py_VISIT(traverse_module_state->__pyx_n_s_freqstr);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_from_name_starting_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_fstr);
  Py_VISIT(traverse_module_state->__pyx_n_s_func);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_ge);
  Py_VISIT(traverse_module_state->__pyx_n_s_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_business_hours_by_sec);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_closing_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_offset_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_rule_code_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_suffix_prefix);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_weeks);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_gt);
  Py_VISIT(traverse_module_state->__pyx_n_u_h);
  Py_VISIT(traverse_module_state->__pyx_n_s_holidays);
  Py_VISIT(traverse_module_state->__pyx_n_u_holidays);
  Py_VISIT(traverse_module_state->__pyx_n_s_hour);
  Py_VISIT(traverse_module_state->__pyx_n_u_hour);
  Py_VISIT(traverse_module_state->__pyx_n_s_hours);
  Py_VISIT(traverse_module_state->__pyx_n_u_hours);
  Py_VISIT(traverse_module_state->__pyx_n_s_hrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_u_i8);
  Py_VISIT(traverse_module_state->__pyx_n_s_i8other);
  Py_VISIT(traverse_module_state->__pyx_kp_u_implemented_by_subclasses);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_u_inc);
  Py_VISIT(traverse_module_state->__pyx_n_s_inc_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_init);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_custom);
  Py_VISIT(traverse_module_state->__pyx_n_s_init_subclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_instancecheck);
  Py_VISIT(traverse_module_state->__pyx_n_s_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_int_to_weekday);
  Py_VISIT(traverse_module_state->__pyx_kp_u_invalid_starting_and_ending_time);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_a_non_fixed_frequency);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_anchored);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_busday);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_month_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_month_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_month_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_month_start);
  Py_VISIT(traverse_module_state->__pyx_kp_u_is_not_a_valid_variation);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_on_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_on_offset_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_quarter_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_quarter_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_quarter_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_quarter_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_same_sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_year_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_is_year_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_isclose);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_isspace);
  Py_VISIT(traverse_module_state->__pyx_n_s_issubset);
  Py_VISIT(traverse_module_state->__pyx_n_s_items);
  Py_VISIT(traverse_module_state->__pyx_n_s_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_klass);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwd);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_u_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_u_last);
  Py_VISIT(traverse_module_state->__pyx_kp_u_last_element_must_be_blank);
  Py_VISIT(traverse_module_state->__pyx_n_s_latest_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_le);
  Py_VISIT(traverse_module_state->__pyx_n_s_lite_rule_alias);
  Py_VISIT(traverse_module_state->__pyx_n_s_lower);
  Py_VISIT(traverse_module_state->__pyx_n_s_lt);
  Py_VISIT(traverse_module_state->__pyx_n_u_m);
  Py_VISIT(traverse_module_state->__pyx_n_s_m_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_mend);
  Py_VISIT(traverse_module_state->__pyx_n_s_metaclass);
  Py_VISIT(traverse_module_state->__pyx_n_s_mi);
  Py_VISIT(traverse_module_state->__pyx_n_s_microsecond);
  Py_VISIT(traverse_module_state->__pyx_n_u_microsecond);
  Py_VISIT(traverse_module_state->__pyx_n_s_microseconds);
  Py_VISIT(traverse_module_state->__pyx_n_u_microseconds);
  Py_VISIT(traverse_module_state->__pyx_n_u_millisecond);
  Py_VISIT(traverse_module_state->__pyx_n_u_milliseconds);
  Py_VISIT(traverse_module_state->__pyx_n_u_min);
  Py_VISIT(traverse_module_state->__pyx_n_s_min_day_of_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_minute);
  Py_VISIT(traverse_module_state->__pyx_n_u_minute);
  Py_VISIT(traverse_module_state->__pyx_n_s_minutes);
  Py_VISIT(traverse_module_state->__pyx_n_u_minutes);
  Py_VISIT(traverse_module_state->__pyx_n_s_mod_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_modby);
  Py_VISIT(traverse_module_state->__pyx_n_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_moff);
  Py_VISIT(traverse_module_state->__pyx_n_s_month);
  Py_VISIT(traverse_module_state->__pyx_n_u_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_month_roll);
  Py_VISIT(traverse_module_state->__pyx_n_s_months);
  Py_VISIT(traverse_module_state->__pyx_n_u_months);
  Py_VISIT(traverse_module_state->__pyx_n_s_months_since);
  Py_VISIT(traverse_module_state->__pyx_n_s_months_to_roll);
  Py_VISIT(traverse_module_state->__pyx_n_s_mro_entries);
  Py_VISIT(traverse_module_state->__pyx_n_u_ms);
  Py_VISIT(traverse_module_state->__pyx_n_s_mstart);
  Py_VISIT(traverse_module_state->__pyx_n_s_mts);
  Py_VISIT(traverse_module_state->__pyx_n_s_mul);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_u_n);
  Py_VISIT(traverse_module_state->__pyx_kp_u_n_argument_must_be_an_integer_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_nadj);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_nano);
  Py_VISIT(traverse_module_state->__pyx_n_s_nanos);
  Py_VISIT(traverse_module_state->__pyx_n_s_nanos_inc);
  Py_VISIT(traverse_module_state->__pyx_n_s_nanosecond);
  Py_VISIT(traverse_module_state->__pyx_n_u_nanosecond);
  Py_VISIT(traverse_module_state->__pyx_n_s_nanoseconds);
  Py_VISIT(traverse_module_state->__pyx_n_u_nanoseconds);
  Py_VISIT(traverse_module_state->__pyx_n_s_nb_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndim);
  Py_VISIT(traverse_module_state->__pyx_n_u_nearest);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_new_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_bday);
  Py_VISIT(traverse_module_state->__pyx_n_u_next_bday);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_higher_resolution);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_opening_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_next_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_nint);
  Py_VISIT(traverse_module_state->__pyx_n_s_norm);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalize);
  Py_VISIT(traverse_module_state->__pyx_n_u_normalize);
  Py_VISIT(traverse_module_state->__pyx_n_s_normalize_i8_timestamps);
  Py_VISIT(traverse_module_state->__pyx_kp_u_not_able_to_be_applied_vectoriz);
  Py_VISIT(traverse_module_state->__pyx_n_s_np);
  Py_VISIT(traverse_module_state->__pyx_n_s_np_dt);
  Py_VISIT(traverse_module_state->__pyx_n_s_np_incr_dt);
  Py_VISIT(traverse_module_state->__pyx_kp_s_np_ndarray);
  Py_VISIT(traverse_module_state->__pyx_n_u_ns);
  Py_VISIT(traverse_module_state->__pyx_n_s_num_nano);
  Py_VISIT(traverse_module_state->__pyx_n_s_num_qtrs);
  Py_VISIT(traverse_module_state->__pyx_kp_u_number_of_starting_time_and_endi);
  Py_VISIT(traverse_module_state->__pyx_n_s_numpy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_off_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset);
  Py_VISIT(traverse_module_state->__pyx_n_u_offset);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_offset_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_offset_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset_map);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_offset_str_locals_get_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_op);
  Py_VISIT(traverse_module_state->__pyx_n_s_opattern);
  Py_VISIT(traverse_module_state->__pyx_n_s_other);
  Py_VISIT(traverse_module_state->__pyx_n_s_otherDay);
  Py_VISIT(traverse_module_state->__pyx_n_s_out);
  Py_VISIT(traverse_module_state->__pyx_n_s_outputName);
  Py_VISIT(traverse_module_state->__pyx_n_s_output_name);
  Py_VISIT(traverse_module_state->__pyx_n_u_output_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas__libs_properties);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas__libs_tslibs_ccalendar);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas__libs_tslibs_offsets);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pandas__libs_tslibs_offsets_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_params);
  Py_VISIT(traverse_module_state->__pyx_n_s_params_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_parse_suffix);
  Py_VISIT(traverse_module_state->__pyx_kp_u_pass_as_a_string_instead);
  Py_VISIT(traverse_module_state->__pyx_n_s_period_dtype_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pop);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix_mapping);
  Py_VISIT(traverse_module_state->__pyx_n_s_prepare);
  Py_VISIT(traverse_module_state->__pyx_n_s_prev_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_prev_opening_time);
  Py_VISIT(traverse_module_state->__pyx_n_s_prev_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_prev_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_BaseOffset);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_RelativeDeltaOffs);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_qlen);
  Py_VISIT(traverse_module_state->__pyx_n_s_qtr_len);
  Py_VISIT(traverse_module_state->__pyx_n_s_qtr_lens);
  Py_VISIT(traverse_module_state->__pyx_n_s_qtr_with_extra_week);
  Py_VISIT(traverse_module_state->__pyx_n_u_qtr_with_extra_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_qtrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_qualname);
  Py_VISIT(traverse_module_state->__pyx_n_s_r);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_re);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce___locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_relativedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_relativedelta_fast);
  Py_VISIT(traverse_module_state->__pyx_n_s_relativedelta_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_s_rem_nano);
  Py_VISIT(traverse_module_state->__pyx_n_s_remain);
  Py_VISIT(traverse_module_state->__pyx_n_s_replace);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr_attrs);
  Py_VISIT(traverse_module_state->__pyx_n_s_repr_attrs_locals_genexpr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_requires_a_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_res);
  Py_VISIT(traverse_module_state->__pyx_n_s_res_val);
  Py_VISIT(traverse_module_state->__pyx_n_s_reso);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_result2);
  Py_VISIT(traverse_module_state->__pyx_n_s_ret);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_reversed);
  Py_VISIT(traverse_module_state->__pyx_n_s_roll);
  Py_VISIT(traverse_module_state->__pyx_n_s_roll_convention);
  Py_VISIT(traverse_module_state->__pyx_n_s_roll_func);
  Py_VISIT(traverse_module_state->__pyx_n_s_roll_qtrday);
  Py_VISIT(traverse_module_state->__pyx_n_s_rollback);
  Py_VISIT(traverse_module_state->__pyx_n_s_rollback_to_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_rollforward);
  Py_VISIT(traverse_module_state->__pyx_n_s_rtruediv);
  Py_VISIT(traverse_module_state->__pyx_n_s_rule_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_u_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_second);
  Py_VISIT(traverse_module_state->__pyx_n_u_second);
  Py_VISIT(traverse_module_state->__pyx_n_s_seconds);
  Py_VISIT(traverse_module_state->__pyx_n_u_seconds);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_n_s_send);
  Py_VISIT(traverse_module_state->__pyx_kp_u_separator_must_be_spaces);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_setattr);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_shift_days);
  Py_VISIT(traverse_module_state->__pyx_n_s_shift_month);
  Py_VISIT(traverse_module_state->__pyx_n_s_shift_months);
  Py_VISIT(traverse_module_state->__pyx_n_s_shifted);
  Py_VISIT(traverse_module_state->__pyx_n_s_sign);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_skip_bd);
  Py_VISIT(traverse_module_state->__pyx_n_s_span);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_st);
  Py_VISIT(traverse_module_state->__pyx_n_s_stamp);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_u_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_startingMonth);
  Py_VISIT(traverse_module_state->__pyx_n_u_startingMonth);
  Py_VISIT(traverse_module_state->__pyx_n_s_startingMonth_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_startswith);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_staticmethod);
  Py_VISIT(traverse_module_state->__pyx_n_s_str);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_strptime);
  Py_VISIT(traverse_module_state->__pyx_n_s_subclasscheck);
  Py_VISIT(traverse_module_state->__pyx_n_s_suffix);
  Py_VISIT(traverse_module_state->__pyx_n_s_sum);
  Py_VISIT(traverse_module_state->__pyx_n_s_super);
  Py_VISIT(traverse_module_state->__pyx_n_s_target_date);
  Py_VISIT(traverse_module_state->__pyx_n_s_td);
  Py_VISIT(traverse_module_state->__pyx_n_s_td64);
  Py_VISIT(traverse_module_state->__pyx_n_s_td64_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_td_nano);
  Py_VISIT(traverse_module_state->__pyx_n_s_tdelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_kp_u_the_add_operation_between);
  Py_VISIT(traverse_module_state->__pyx_n_s_throw);
  Py_VISIT(traverse_module_state->__pyx_n_s_time);
  Py_VISIT(traverse_module_state->__pyx_kp_u_time_data_must_be_specified_only);
  Py_VISIT(traverse_module_state->__pyx_kp_u_time_data_must_be_string_or_date);
  Py_VISIT(traverse_module_state->__pyx_kp_u_time_data_must_match_H_M_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_timedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_timedelta64);
  Py_VISIT(traverse_module_state->__pyx_n_s_timedelta_kwds);
  Py_VISIT(traverse_module_state->__pyx_n_s_timedeltas);
  Py_VISIT(traverse_module_state->__pyx_n_s_timestamps);
  Py_VISIT(traverse_module_state->__pyx_n_s_tm_hour);
  Py_VISIT(traverse_module_state->__pyx_n_s_tm_min);
  Py_VISIT(traverse_module_state->__pyx_kp_u_to);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_day);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_u_to_offset_does_not_support_tuple);
  Py_VISIT(traverse_module_state->__pyx_kp_u_to_offset_line_4102);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_pydatetime);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_pytimedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_tolist);
  Py_VISIT(traverse_module_state->__pyx_n_s_total_seconds);
  Py_VISIT(traverse_module_state->__pyx_n_s_truediv);
  Py_VISIT(traverse_module_state->__pyx_n_s_ts);
  Py_VISIT(traverse_module_state->__pyx_n_s_tup);
  Py_VISIT(traverse_module_state->__pyx_n_s_tz);
  Py_VISIT(traverse_module_state->__pyx_n_s_tz_localize);
  Py_VISIT(traverse_module_state->__pyx_n_s_tzinfo);
  Py_VISIT(traverse_module_state->__pyx_n_u_tzinfo);
  Py_VISIT(traverse_module_state->__pyx_n_u_undefined);
  Py_VISIT(traverse_module_state->__pyx_n_s_unit);
  Py_VISIT(traverse_module_state->__pyx_n_s_until);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_upper);
  Py_VISIT(traverse_module_state->__pyx_n_u_us);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_relativedelta);
  Py_VISIT(traverse_module_state->__pyx_n_u_use_relativedelta);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_val);
  Py_VISIT(traverse_module_state->__pyx_n_s_validate_n);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_value_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_variation);
  Py_VISIT(traverse_module_state->__pyx_n_u_variation);
  Py_VISIT(traverse_module_state->__pyx_n_s_varion_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_vectorized);
  Py_VISIT(traverse_module_state->__pyx_n_s_view);
  Py_VISIT(traverse_module_state->__pyx_n_s_wday);
  Py_VISIT(traverse_module_state->__pyx_n_s_week);
  Py_VISIT(traverse_module_state->__pyx_n_u_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_weekday);
  Py_VISIT(traverse_module_state->__pyx_n_u_weekday);
  Py_VISIT(traverse_module_state->__pyx_n_s_weekday_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_weekday_to_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_weekmask);
  Py_VISIT(traverse_module_state->__pyx_n_u_weekmask);
  Py_VISIT(traverse_module_state->__pyx_n_s_weeks);
  Py_VISIT(traverse_module_state->__pyx_n_u_weeks);
  Py_VISIT(traverse_module_state->__pyx_n_s_weeks_in_year);
  Py_VISIT(traverse_module_state->__pyx_kp_u_will_overflow);
  Py_VISIT(traverse_module_state->__pyx_n_s_wkday_diff);
  Py_VISIT(traverse_module_state->__pyx_n_s_wrapper);
  Py_VISIT(traverse_module_state->__pyx_n_s_year);
  Py_VISIT(traverse_module_state->__pyx_n_u_year);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_year_has_extra_week);
  Py_VISIT(traverse_module_state->__pyx_n_s_years);
  Py_VISIT(traverse_module_state->__pyx_n_u_years);
  Py_VISIT(traverse_module_state->__pyx_n_s_zero);
  Py_VISIT(traverse_module_state->__pyx_n_s_zip);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_4);
  Py_VISIT(traverse_module_state->__pyx_int_5);
  Py_VISIT(traverse_module_state->__pyx_int_6);
  Py_VISIT(traverse_module_state->__pyx_int_7);
  Py_VISIT(traverse_module_state->__pyx_int_12);
  Py_VISIT(traverse_module_state->__pyx_int_13);
  Py_VISIT(traverse_module_state->__pyx_int_14);
  Py_VISIT(traverse_module_state->__pyx_int_15);
  Py_VISIT(traverse_module_state->__pyx_int_27);
  Py_VISIT(traverse_module_state->__pyx_int_52);
  Py_VISIT(traverse_module_state->__pyx_int_53);
  Py_VISIT(traverse_module_state->__pyx_int_60);
  Py_VISIT(traverse_module_state->__pyx_int_1000);
  Py_VISIT(traverse_module_state->__pyx_int_2014);
  Py_VISIT(traverse_module_state->__pyx_int_3600);
  Py_VISIT(traverse_module_state->__pyx_int_86400);
  Py_VISIT(traverse_module_state->__pyx_int_1000000);
  Py_VISIT(traverse_module_state->__pyx_int_10844460);
  Py_VISIT(traverse_module_state->__pyx_int_171034093);
  Py_VISIT(traverse_module_state->__pyx_int_213572416);
  Py_VISIT(traverse_module_state->__pyx_int_1000000000);
  Py_VISIT(traverse_module_state->__pyx_int_60000000000);
  Py_VISIT(traverse_module_state->__pyx_int_3600000000000);
  Py_VISIT(traverse_module_state->__pyx_int_0x4e94914f0000);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_k__33);
  Py_VISIT(traverse_module_state->__pyx_k__40);
  Py_VISIT(traverse_module_state->__pyx_k__56);
  Py_VISIT(traverse_module_state->__pyx_k__57);
  Py_VISIT(traverse_module_state->__pyx_k__58);
  Py_VISIT(traverse_module_state->__pyx_tuple_);
  Py_VISIT(traverse_module_state->__pyx_tuple__2);
  Py_VISIT(traverse_module_state->__pyx_tuple__3);
  Py_VISIT(traverse_module_state->__pyx_tuple__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__7);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_slice__53);
  Py_VISIT(traverse_module_state->__pyx_slice__60);
  Py_VISIT(traverse_module_state->__pyx_slice__61);
  Py_VISIT(traverse_module_state->__pyx_slice__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__12);
  Py_VISIT(traverse_module_state->__pyx_tuple__14);
  Py_VISIT(traverse_module_state->__pyx_tuple__22);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__25);
  Py_VISIT(traverse_module_state->__pyx_tuple__26);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__28);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__30);
  Py_VISIT(traverse_module_state->__pyx_tuple__31);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__42);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__44);
  Py_VISIT(traverse_module_state->__pyx_tuple__45);
  Py_VISIT(traverse_module_state->__pyx_tuple__48);
  Py_VISIT(traverse_module_state->__pyx_tuple__49);
  Py_VISIT(traverse_module_state->__pyx_tuple__50);
  Py_VISIT(traverse_module_state->__pyx_tuple__51);
  Py_VISIT(traverse_module_state->__pyx_tuple__52);
  Py_VISIT(traverse_module_state->__pyx_tuple__54);
  Py_VISIT(traverse_module_state->__pyx_tuple__55);
  Py_VISIT(traverse_module_state->__pyx_tuple__59);
  Py_VISIT(traverse_module_state->__pyx_tuple__63);
  Py_VISIT(traverse_module_state->__pyx_tuple__65);
  Py_VISIT(traverse_module_state->__pyx_tuple__66);
  Py_VISIT(traverse_module_state->__pyx_tuple__68);
  Py_VISIT(traverse_module_state->__pyx_tuple__70);
  Py_VISIT(traverse_module_state->__pyx_tuple__73);
  Py_VISIT(traverse_module_state->__pyx_tuple__74);
  Py_VISIT(traverse_module_state->__pyx_tuple__75);
  Py_VISIT(traverse_module_state->__pyx_tuple__77);
  Py_VISIT(traverse_module_state->__pyx_tuple__79);
  Py_VISIT(traverse_module_state->__pyx_tuple__81);
  Py_VISIT(traverse_module_state->__pyx_tuple__84);
  Py_VISIT(traverse_module_state->__pyx_tuple__86);
  Py_VISIT(traverse_module_state->__pyx_tuple__88);
  Py_VISIT(traverse_module_state->__pyx_tuple__91);
  Py_VISIT(traverse_module_state->__pyx_tuple__93);
  Py_VISIT(traverse_module_state->__pyx_tuple__95);
  Py_VISIT(traverse_module_state->__pyx_tuple__97);
  Py_VISIT(traverse_module_state->__pyx_codeobj__6);
  Py_VISIT(traverse_module_state->__pyx_codeobj__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__108);
  Py_VISIT(traverse_module_state->__pyx_tuple__110);
  Py_VISIT(traverse_module_state->__pyx_tuple__112);
  Py_VISIT(traverse_module_state->__pyx_tuple__114);
  Py_VISIT(traverse_module_state->__pyx_tuple__115);
  Py_VISIT(traverse_module_state->__pyx_tuple__123);
  Py_VISIT(traverse_module_state->__pyx_tuple__127);
  Py_VISIT(traverse_module_state->__pyx_tuple__129);
  Py_VISIT(traverse_module_state->__pyx_tuple__134);
  Py_VISIT(traverse_module_state->__pyx_tuple__137);
  Py_VISIT(traverse_module_state->__pyx_tuple__139);
  Py_VISIT(traverse_module_state->__pyx_tuple__141);
  Py_VISIT(traverse_module_state->__pyx_tuple__145);
  Py_VISIT(traverse_module_state->__pyx_tuple__147);
  Py_VISIT(traverse_module_state->__pyx_tuple__149);
  Py_VISIT(traverse_module_state->__pyx_tuple__153);
  Py_VISIT(traverse_module_state->__pyx_tuple__155);
  Py_VISIT(traverse_module_state->__pyx_tuple__157);
  Py_VISIT(traverse_module_state->__pyx_tuple__159);
  Py_VISIT(traverse_module_state->__pyx_tuple__161);
  Py_VISIT(traverse_module_state->__pyx_tuple__166);
  Py_VISIT(traverse_module_state->__pyx_tuple__169);
  Py_VISIT(traverse_module_state->__pyx_tuple__171);
  Py_VISIT(traverse_module_state->__pyx_tuple__175);
  Py_VISIT(traverse_module_state->__pyx_tuple__179);
  Py_VISIT(traverse_module_state->__pyx_tuple__181);
  Py_VISIT(traverse_module_state->__pyx_tuple__186);
  Py_VISIT(traverse_module_state->__pyx_tuple__188);
  Py_VISIT(traverse_module_state->__pyx_tuple__192);
  Py_VISIT(traverse_module_state->__pyx_tuple__198);
  Py_VISIT(traverse_module_state->__pyx_tuple__200);
  Py_VISIT(traverse_module_state->__pyx_tuple__202);
  Py_VISIT(traverse_module_state->__pyx_tuple__207);
  Py_VISIT(traverse_module_state->__pyx_tuple__209);
  Py_VISIT(traverse_module_state->__pyx_tuple__212);
  Py_VISIT(traverse_module_state->__pyx_tuple__215);
  Py_VISIT(traverse_module_state->__pyx_tuple__217);
  Py_VISIT(traverse_module_state->__pyx_tuple__220);
  Py_VISIT(traverse_module_state->__pyx_tuple__226);
  Py_VISIT(traverse_module_state->__pyx_tuple__228);
  Py_VISIT(traverse_module_state->__pyx_tuple__230);
  Py_VISIT(traverse_module_state->__pyx_tuple__232);
  Py_VISIT(traverse_module_state->__pyx_tuple__234);
  Py_VISIT(traverse_module_state->__pyx_tuple__236);
  Py_VISIT(traverse_module_state->__pyx_tuple__240);
  Py_VISIT(traverse_module_state->__pyx_tuple__242);
  Py_VISIT(traverse_module_state->__pyx_tuple__244);
  Py_VISIT(traverse_module_state->__pyx_tuple__246);
  Py_VISIT(traverse_module_state->__pyx_tuple__248);
  Py_VISIT(traverse_module_state->__pyx_tuple__252);
  Py_VISIT(traverse_module_state->__pyx_tuple__256);
  Py_VISIT(traverse_module_state->__pyx_tuple__258);
  Py_VISIT(traverse_module_state->__pyx_tuple__260);
  Py_VISIT(traverse_module_state->__pyx_tuple__262);
  Py_VISIT(traverse_module_state->__pyx_tuple__264);
  Py_VISIT(traverse_module_state->__pyx_tuple__266);
  Py_VISIT(traverse_module_state->__pyx_tuple__268);
  Py_VISIT(traverse_module_state->__pyx_tuple__269);
  Py_VISIT(traverse_module_state->__pyx_tuple__271);
  Py_VISIT(traverse_module_state->__pyx_tuple__273);
  Py_VISIT(traverse_module_state->__pyx_tuple__275);
  Py_VISIT(traverse_module_state->__pyx_tuple__277);
  Py_VISIT(traverse_module_state->__pyx_tuple__279);
  Py_VISIT(traverse_module_state->__pyx_tuple__281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__35);
  Py_VISIT(traverse_module_state->__pyx_codeobj__69);
  Py_VISIT(traverse_module_state->__pyx_codeobj__71);
  Py_VISIT(traverse_module_state->__pyx_codeobj__72);
  Py_VISIT(traverse_module_state->__pyx_codeobj__76);
  Py_VISIT(traverse_module_state->__pyx_codeobj__78);
  Py_VISIT(traverse_module_state->__pyx_codeobj__80);
  Py_VISIT(traverse_module_state->__pyx_codeobj__82);
  Py_VISIT(traverse_module_state->__pyx_codeobj__83);
  Py_VISIT(traverse_module_state->__pyx_codeobj__85);
  Py_VISIT(traverse_module_state->__pyx_codeobj__87);
  Py_VISIT(traverse_module_state->__pyx_codeobj__89);
  Py_VISIT(traverse_module_state->__pyx_codeobj__90);
  Py_VISIT(traverse_module_state->__pyx_codeobj__92);
  Py_VISIT(traverse_module_state->__pyx_codeobj__94);
  Py_VISIT(traverse_module_state->__pyx_codeobj__96);
  Py_VISIT(traverse_module_state->__pyx_codeobj__98);
  Py_VISIT(traverse_module_state->__pyx_codeobj__99);
  Py_VISIT(traverse_module_state->__pyx_codeobj__100);
  Py_VISIT(traverse_module_state->__pyx_codeobj__102);
  Py_VISIT(traverse_module_state->__pyx_codeobj__103);
  Py_VISIT(traverse_module_state->__pyx_codeobj__104);
  Py_VISIT(traverse_module_state->__pyx_codeobj__105);
  Py_VISIT(traverse_module_state->__pyx_codeobj__106);
  Py_VISIT(traverse_module_state->__pyx_codeobj__107);
  Py_VISIT(traverse_module_state->__pyx_codeobj__109);
  Py_VISIT(traverse_module_state->__pyx_codeobj__111);
  Py_VISIT(traverse_module_state->__pyx_codeobj__113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__117);
  Py_VISIT(traverse_module_state->__pyx_codeobj__118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__119);
  Py_VISIT(traverse_module_state->__pyx_codeobj__120);
  Py_VISIT(traverse_module_state->__pyx_codeobj__121);
  Py_VISIT(traverse_module_state->__pyx_codeobj__122);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__125);
  Py_VISIT(traverse_module_state->__pyx_codeobj__126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__128);
  Py_VISIT(traverse_module_state->__pyx_codeobj__130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__131);
  Py_VISIT(traverse_module_state->__pyx_codeobj__132);
  Py_VISIT(traverse_module_state->__pyx_codeobj__133);
  Py_VISIT(traverse_module_state->__pyx_codeobj__135);
  Py_VISIT(traverse_module_state->__pyx_codeobj__136);
  Py_VISIT(traverse_module_state->__pyx_codeobj__138);
  Py_VISIT(traverse_module_state->__pyx_codeobj__140);
  Py_VISIT(traverse_module_state->__pyx_codeobj__142);
  Py_VISIT(traverse_module_state->__pyx_codeobj__143);
  Py_VISIT(traverse_module_state->__pyx_codeobj__144);
  Py_VISIT(traverse_module_state->__pyx_codeobj__146);
  Py_VISIT(traverse_module_state->__pyx_codeobj__148);
  Py_VISIT(traverse_module_state->__pyx_codeobj__150);
  Py_VISIT(traverse_module_state->__pyx_codeobj__151);
  Py_VISIT(traverse_module_state->__pyx_codeobj__152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__156);
  Py_VISIT(traverse_module_state->__pyx_codeobj__158);
  Py_VISIT(traverse_module_state->__pyx_codeobj__160);
  Py_VISIT(traverse_module_state->__pyx_codeobj__162);
  Py_VISIT(traverse_module_state->__pyx_codeobj__163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__165);
  Py_VISIT(traverse_module_state->__pyx_codeobj__167);
  Py_VISIT(traverse_module_state->__pyx_codeobj__168);
  Py_VISIT(traverse_module_state->__pyx_codeobj__170);
  Py_VISIT(traverse_module_state->__pyx_codeobj__172);
  Py_VISIT(traverse_module_state->__pyx_codeobj__173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__177);
  Py_VISIT(traverse_module_state->__pyx_codeobj__178);
  Py_VISIT(traverse_module_state->__pyx_codeobj__180);
  Py_VISIT(traverse_module_state->__pyx_codeobj__182);
  Py_VISIT(traverse_module_state->__pyx_codeobj__183);
  Py_VISIT(traverse_module_state->__pyx_codeobj__184);
  Py_VISIT(traverse_module_state->__pyx_codeobj__185);
  Py_VISIT(traverse_module_state->__pyx_codeobj__187);
  Py_VISIT(traverse_module_state->__pyx_codeobj__189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__190);
  Py_VISIT(traverse_module_state->__pyx_codeobj__191);
  Py_VISIT(traverse_module_state->__pyx_codeobj__193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__194);
  Py_VISIT(traverse_module_state->__pyx_codeobj__195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__196);
  Py_VISIT(traverse_module_state->__pyx_codeobj__197);
  Py_VISIT(traverse_module_state->__pyx_codeobj__199);
  Py_VISIT(traverse_module_state->__pyx_codeobj__201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__203);
  Py_VISIT(traverse_module_state->__pyx_codeobj__204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__206);
  Py_VISIT(traverse_module_state->__pyx_codeobj__208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__211);
  Py_VISIT(traverse_module_state->__pyx_codeobj__213);
  Py_VISIT(traverse_module_state->__pyx_codeobj__214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__218);
  Py_VISIT(traverse_module_state->__pyx_codeobj__219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__221);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__227);
  Py_VISIT(traverse_module_state->__pyx_codeobj__229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__241);
  Py_VISIT(traverse_module_state->__pyx_codeobj__243);
  Py_VISIT(traverse_module_state->__pyx_codeobj__245);
  Py_VISIT(traverse_module_state->__pyx_codeobj__247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__250);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__254);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__265);
  Py_VISIT(traverse_module_state->__pyx_codeobj__267);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__274);
  Py_VISIT(traverse_module_state->__pyx_codeobj__276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__283);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_5numpy_dtype __pyx_mstate_global->__pyx_ptype_5numpy_dtype
#define __pyx_ptype_5numpy_flatiter __pyx_mstate_global->__pyx_ptype_5numpy_flatiter
#define __pyx_ptype_5numpy_broadcast __pyx_mstate_global->__pyx_ptype_5numpy_broadcast
#define __pyx_ptype_5numpy_ndarray __pyx_mstate_global->__pyx_ptype_5numpy_ndarray
#define __pyx_ptype_5numpy_generic __pyx_mstate_global->__pyx_ptype_5numpy_generic
#define __pyx_ptype_5numpy_number __pyx_mstate_global->__pyx_ptype_5numpy_number
#define __pyx_ptype_5numpy_integer __pyx_mstate_global->__pyx_ptype_5numpy_integer
#define __pyx_ptype_5numpy_signedinteger __pyx_mstate_global->__pyx_ptype_5numpy_signedinteger
#define __pyx_ptype_5numpy_unsignedinteger __pyx_mstate_global->__pyx_ptype_5numpy_unsignedinteger
#define __pyx_ptype_5numpy_inexact __pyx_mstate_global->__pyx_ptype_5numpy_inexact
#define __pyx_ptype_5numpy_floating __pyx_mstate_global->__pyx_ptype_5numpy_floating
#define __pyx_ptype_5numpy_complexfloating __pyx_mstate_global->__pyx_ptype_5numpy_complexfloating
#define __pyx_ptype_5numpy_flexible __pyx_mstate_global->__pyx_ptype_5numpy_flexible
#define __pyx_ptype_5numpy_character __pyx_mstate_global->__pyx_ptype_5numpy_character
#define __pyx_ptype_5numpy_ufunc __pyx_mstate_global->__pyx_ptype_5numpy_ufunc
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_8datetime_date __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_date
#define __pyx_ptype_7cpython_8datetime_time __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_time
#define __pyx_ptype_7cpython_8datetime_datetime __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_datetime
#define __pyx_ptype_7cpython_8datetime_timedelta __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_timedelta
#define __pyx_ptype_7cpython_8datetime_tzinfo __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_tzinfo
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Day __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Second __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Week __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253 __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply
#define __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr __pyx_mstate_global->__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr
#endif
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253 __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply
#define __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr
#define __pyx_kp_u_02d __pyx_mstate_global->__pyx_kp_u_02d
#define __pyx_kp_u_09_00 __pyx_mstate_global->__pyx_kp_u_09_00
#define __pyx_kp_u_17_00 __pyx_mstate_global->__pyx_kp_u_17_00
#define __pyx_n_u_A __pyx_mstate_global->__pyx_n_u_A
#define __pyx_n_u_AS __pyx_mstate_global->__pyx_n_u_AS
#define __pyx_kp_u_AS_JAN __pyx_mstate_global->__pyx_kp_u_AS_JAN
#define __pyx_kp_u_A_DEC __pyx_mstate_global->__pyx_kp_u_A_DEC
#define __pyx_n_s_ApplyTypeError __pyx_mstate_global->__pyx_n_s_ApplyTypeError
#define __pyx_n_s_AssertionError __pyx_mstate_global->__pyx_n_s_AssertionError
#define __pyx_n_s_AttributeError __pyx_mstate_global->__pyx_n_s_AttributeError
#define __pyx_n_u_B __pyx_mstate_global->__pyx_n_u_B
#define __pyx_n_u_BA __pyx_mstate_global->__pyx_n_u_BA
#define __pyx_n_u_BAS __pyx_mstate_global->__pyx_n_u_BAS
#define __pyx_kp_u_BAS_JAN __pyx_mstate_global->__pyx_kp_u_BAS_JAN
#define __pyx_kp_u_BA_DEC __pyx_mstate_global->__pyx_kp_u_BA_DEC
#define __pyx_n_s_BDay __pyx_mstate_global->__pyx_n_s_BDay
#define __pyx_n_u_BH __pyx_mstate_global->__pyx_n_u_BH
#define __pyx_n_u_BM __pyx_mstate_global->__pyx_n_u_BM
#define __pyx_n_u_BMS __pyx_mstate_global->__pyx_n_u_BMS
#define __pyx_n_s_BMonthBegin __pyx_mstate_global->__pyx_n_s_BMonthBegin
#define __pyx_n_s_BMonthEnd __pyx_mstate_global->__pyx_n_s_BMonthEnd
#define __pyx_n_u_BQ __pyx_mstate_global->__pyx_n_u_BQ
#define __pyx_n_u_BQS __pyx_mstate_global->__pyx_n_u_BQS
#define __pyx_n_s_BQuarterBegin __pyx_mstate_global->__pyx_n_s_BQuarterBegin
#define __pyx_n_s_BQuarterEnd __pyx_mstate_global->__pyx_n_s_BQuarterEnd
#define __pyx_n_u_BY __pyx_mstate_global->__pyx_n_u_BY
#define __pyx_n_u_BYS __pyx_mstate_global->__pyx_n_u_BYS
#define __pyx_n_s_BYearBegin __pyx_mstate_global->__pyx_n_s_BYearBegin
#define __pyx_n_s_BYearEnd __pyx_mstate_global->__pyx_n_s_BYearEnd
#define __pyx_kp_u_Bad_freq_suffix __pyx_mstate_global->__pyx_kp_u_Bad_freq_suffix
#define __pyx_n_s_BaseOffset __pyx_mstate_global->__pyx_n_s_BaseOffset
#define __pyx_n_s_BaseOffset___getstate __pyx_mstate_global->__pyx_n_s_BaseOffset___getstate
#define __pyx_n_s_BaseOffset___reduce_cython __pyx_mstate_global->__pyx_n_s_BaseOffset___reduce_cython
#define __pyx_n_s_BaseOffset___setstate __pyx_mstate_global->__pyx_n_s_BaseOffset___setstate
#define __pyx_n_s_BaseOffset___setstate_cython __pyx_mstate_global->__pyx_n_s_BaseOffset___setstate_cython
#define __pyx_n_s_BaseOffset__apply __pyx_mstate_global->__pyx_n_s_BaseOffset__apply
#define __pyx_n_s_BaseOffset__apply_array __pyx_mstate_global->__pyx_n_s_BaseOffset__apply_array
#define __pyx_n_s_BaseOffset__get_offset_day __pyx_mstate_global->__pyx_n_s_BaseOffset__get_offset_day
#define __pyx_n_s_BaseOffset__offset_str __pyx_mstate_global->__pyx_n_s_BaseOffset__offset_str
#define __pyx_n_s_BaseOffset__params __pyx_mstate_global->__pyx_n_s_BaseOffset__params
#define __pyx_n_s_BaseOffset__repr_attrs __pyx_mstate_global->__pyx_n_s_BaseOffset__repr_attrs
#define __pyx_n_s_BaseOffset__validate_n __pyx_mstate_global->__pyx_n_s_BaseOffset__validate_n
#define __pyx_n_s_BaseOffset_copy __pyx_mstate_global->__pyx_n_s_BaseOffset_copy
#define __pyx_kp_u_BaseOffset_copy_line_532 __pyx_mstate_global->__pyx_kp_u_BaseOffset_copy_line_532
#define __pyx_n_s_BaseOffset_freqstr __pyx_mstate_global->__pyx_n_s_BaseOffset_freqstr
#define __pyx_kp_u_BaseOffset_freqstr_line_607 __pyx_mstate_global->__pyx_kp_u_BaseOffset_freqstr_line_607
#define __pyx_n_s_BaseOffset_is_anchored __pyx_mstate_global->__pyx_n_s_BaseOffset_is_anchored
#define __pyx_kp_u_BaseOffset_is_anchored_line_790 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_anchored_line_790
#define __pyx_n_s_BaseOffset_is_month_end __pyx_mstate_global->__pyx_n_s_BaseOffset_is_month_end
#define __pyx_kp_u_BaseOffset_is_month_end_line_820 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_month_end_line_820
#define __pyx_n_s_BaseOffset_is_month_start __pyx_mstate_global->__pyx_n_s_BaseOffset_is_month_start
#define __pyx_kp_u_BaseOffset_is_month_start_line_8 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_month_start_line_8
#define __pyx_n_s_BaseOffset_is_on_offset __pyx_mstate_global->__pyx_n_s_BaseOffset_is_on_offset
#define __pyx_kp_u_BaseOffset_is_on_offset_line_696 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_on_offset_line_696
#define __pyx_n_s_BaseOffset_is_quarter_end __pyx_mstate_global->__pyx_n_s_BaseOffset_is_quarter_end
#define __pyx_kp_u_BaseOffset_is_quarter_end_line_8 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_quarter_end_line_8
#define __pyx_n_s_BaseOffset_is_quarter_start __pyx_mstate_global->__pyx_n_s_BaseOffset_is_quarter_start
#define __pyx_kp_u_BaseOffset_is_quarter_start_line __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_quarter_start_line
#define __pyx_n_s_BaseOffset_is_year_end __pyx_mstate_global->__pyx_n_s_BaseOffset_is_year_end
#define __pyx_kp_u_BaseOffset_is_year_end_line_872 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_year_end_line_872
#define __pyx_n_s_BaseOffset_is_year_start __pyx_mstate_global->__pyx_n_s_BaseOffset_is_year_start
#define __pyx_kp_u_BaseOffset_is_year_start_line_85 __pyx_mstate_global->__pyx_kp_u_BaseOffset_is_year_start_line_85
#define __pyx_kp_u_BaseOffset_kwds___get___line_449 __pyx_mstate_global->__pyx_kp_u_BaseOffset_kwds___get___line_449
#define __pyx_kp_u_BaseOffset_name___get___line_584 __pyx_mstate_global->__pyx_kp_u_BaseOffset_name___get___line_584
#define __pyx_n_s_BaseOffset_rollback __pyx_mstate_global->__pyx_n_s_BaseOffset_rollback
#define __pyx_n_s_BaseOffset_rollforward __pyx_mstate_global->__pyx_n_s_BaseOffset_rollforward
#define __pyx_n_s_BusinessDay __pyx_mstate_global->__pyx_n_s_BusinessDay
#define __pyx_n_s_BusinessDay___setstate __pyx_mstate_global->__pyx_n_s_BusinessDay___setstate
#define __pyx_n_s_BusinessDay__apply __pyx_mstate_global->__pyx_n_s_BusinessDay__apply
#define __pyx_n_s_BusinessDay__apply_array __pyx_mstate_global->__pyx_n_s_BusinessDay__apply_array
#define __pyx_n_s_BusinessDay__offset_str __pyx_mstate_global->__pyx_n_s_BusinessDay__offset_str
#define __pyx_n_s_BusinessDay_is_on_offset __pyx_mstate_global->__pyx_n_s_BusinessDay_is_on_offset
#define __pyx_n_s_BusinessHour __pyx_mstate_global->__pyx_n_s_BusinessHour
#define __pyx_n_s_BusinessHour___setstate __pyx_mstate_global->__pyx_n_s_BusinessHour___setstate
#define __pyx_n_s_BusinessHour__apply __pyx_mstate_global->__pyx_n_s_BusinessHour__apply
#define __pyx_n_s_BusinessHour__get_business_hours __pyx_mstate_global->__pyx_n_s_BusinessHour__get_business_hours
#define __pyx_n_s_BusinessHour__get_closing_time __pyx_mstate_global->__pyx_n_s_BusinessHour__get_closing_time
#define __pyx_n_s_BusinessHour__is_on_offset __pyx_mstate_global->__pyx_n_s_BusinessHour__is_on_offset
#define __pyx_n_s_BusinessHour__next_opening_time __pyx_mstate_global->__pyx_n_s_BusinessHour__next_opening_time
#define __pyx_n_s_BusinessHour__prev_opening_time __pyx_mstate_global->__pyx_n_s_BusinessHour__prev_opening_time
#define __pyx_n_s_BusinessHour__repr_attrs __pyx_mstate_global->__pyx_n_s_BusinessHour__repr_attrs
#define __pyx_n_s_BusinessHour_is_on_offset __pyx_mstate_global->__pyx_n_s_BusinessHour_is_on_offset
#define __pyx_n_s_BusinessHour_next_bday __pyx_mstate_global->__pyx_n_s_BusinessHour_next_bday
#define __pyx_n_s_BusinessHour_rollback __pyx_mstate_global->__pyx_n_s_BusinessHour_rollback
#define __pyx_n_s_BusinessHour_rollforward __pyx_mstate_global->__pyx_n_s_BusinessHour_rollforward
#define __pyx_n_s_BusinessMixin __pyx_mstate_global->__pyx_n_s_BusinessMixin
#define __pyx_n_s_BusinessMixin___setstate __pyx_mstate_global->__pyx_n_s_BusinessMixin___setstate
#define __pyx_n_s_BusinessMixin__init_custom __pyx_mstate_global->__pyx_n_s_BusinessMixin__init_custom
#define __pyx_n_s_BusinessMixin__repr_attrs __pyx_mstate_global->__pyx_n_s_BusinessMixin__repr_attrs
#define __pyx_n_s_BusinessMonthBegin __pyx_mstate_global->__pyx_n_s_BusinessMonthBegin
#define __pyx_n_s_BusinessMonthEnd __pyx_mstate_global->__pyx_n_s_BusinessMonthEnd
#define __pyx_n_u_BusinessQuarterBegin __pyx_mstate_global->__pyx_n_u_BusinessQuarterBegin
#define __pyx_n_u_BusinessQuarterEnd __pyx_mstate_global->__pyx_n_u_BusinessQuarterEnd
#define __pyx_n_u_BusinessYearBegin __pyx_mstate_global->__pyx_n_u_BusinessYearBegin
#define __pyx_n_u_BusinessYearEnd __pyx_mstate_global->__pyx_n_u_BusinessYearEnd
#define __pyx_n_u_C __pyx_mstate_global->__pyx_n_u_C
#define __pyx_n_u_CBH __pyx_mstate_global->__pyx_n_u_CBH
#define __pyx_n_u_CBM __pyx_mstate_global->__pyx_n_u_CBM
#define __pyx_n_u_CBMS __pyx_mstate_global->__pyx_n_u_CBMS
#define __pyx_n_s_CBMonthBegin __pyx_mstate_global->__pyx_n_s_CBMonthBegin
#define __pyx_n_s_CBMonthEnd __pyx_mstate_global->__pyx_n_s_CBMonthEnd
#define __pyx_n_s_CDay __pyx_mstate_global->__pyx_n_s_CDay
#define __pyx_kp_u_Cannot_add __pyx_mstate_global->__pyx_kp_u_Cannot_add
#define __pyx_kp_u_Cannot_subtract_datetime_from_of __pyx_mstate_global->__pyx_kp_u_Cannot_subtract_datetime_from_of
#define __pyx_kp_u_Could_not_convert_to_integer_off __pyx_mstate_global->__pyx_kp_u_Could_not_convert_to_integer_off
#define __pyx_n_s_CustomBusinessDay __pyx_mstate_global->__pyx_n_s_CustomBusinessDay
#define __pyx_n_s_CustomBusinessDay___setstate __pyx_mstate_global->__pyx_n_s_CustomBusinessDay___setstate
#define __pyx_n_s_CustomBusinessDay__apply __pyx_mstate_global->__pyx_n_s_CustomBusinessDay__apply
#define __pyx_n_s_CustomBusinessDay_is_on_offset __pyx_mstate_global->__pyx_n_s_CustomBusinessDay_is_on_offset
#define __pyx_n_s_CustomBusinessHour __pyx_mstate_global->__pyx_n_s_CustomBusinessHour
#define __pyx_n_s_CustomBusinessMonth __pyx_mstate_global->__pyx_n_s_CustomBusinessMonth
#define __pyx_n_s_CustomBusinessMonthBegin __pyx_mstate_global->__pyx_n_s_CustomBusinessMonthBegin
#define __pyx_n_s_CustomBusinessMonthEnd __pyx_mstate_global->__pyx_n_s_CustomBusinessMonthEnd
#define __pyx_n_s_CustomBusinessMonth__apply __pyx_mstate_global->__pyx_n_s_CustomBusinessMonth__apply
#define __pyx_n_s_CustomBusinessMonth_cbday_roll __pyx_mstate_global->__pyx_n_s_CustomBusinessMonth_cbday_roll
#define __pyx_n_s_CustomBusinessMonth_m_offset __pyx_mstate_global->__pyx_n_s_CustomBusinessMonth_m_offset
#define __pyx_n_s_CustomBusinessMonth_month_roll __pyx_mstate_global->__pyx_n_s_CustomBusinessMonth_month_roll
#define __pyx_n_u_D __pyx_mstate_global->__pyx_n_u_D
#define __pyx_n_s_DateOffset __pyx_mstate_global->__pyx_n_s_DateOffset
#define __pyx_n_s_DateOffset___setattr __pyx_mstate_global->__pyx_n_s_DateOffset___setattr
#define __pyx_kp_u_DateOffset_objects_are_immutable __pyx_mstate_global->__pyx_kp_u_DateOffset_objects_are_immutable
#define __pyx_kp_u_DateOffset_subclass __pyx_mstate_global->__pyx_kp_u_DateOffset_subclass
#define __pyx_kp_u_DateOffset_with_relativedelta_ke __pyx_mstate_global->__pyx_kp_u_DateOffset_with_relativedelta_ke
#define __pyx_n_s_Day __pyx_mstate_global->__pyx_n_s_Day
#define __pyx_kp_u_Day_must_be_0_day_6_got __pyx_mstate_global->__pyx_kp_u_Day_must_be_0_day_6_got
#define __pyx_n_s_Easter __pyx_mstate_global->__pyx_n_s_Easter
#define __pyx_n_s_Easter___setstate __pyx_mstate_global->__pyx_n_s_Easter___setstate
#define __pyx_n_s_Easter__apply __pyx_mstate_global->__pyx_n_s_Easter__apply
#define __pyx_n_s_Easter_is_on_offset __pyx_mstate_global->__pyx_n_s_Easter_is_on_offset
#define __pyx_n_s_FY5253 __pyx_mstate_global->__pyx_n_s_FY5253
#define __pyx_n_s_FY5253Mixin __pyx_mstate_global->__pyx_n_s_FY5253Mixin
#define __pyx_n_s_FY5253Mixin___setstate __pyx_mstate_global->__pyx_n_s_FY5253Mixin___setstate
#define __pyx_n_s_FY5253Mixin__get_suffix_prefix __pyx_mstate_global->__pyx_n_s_FY5253Mixin__get_suffix_prefix
#define __pyx_n_s_FY5253Mixin_get_rule_code_suffix __pyx_mstate_global->__pyx_n_s_FY5253Mixin_get_rule_code_suffix
#define __pyx_n_s_FY5253Mixin_is_anchored __pyx_mstate_global->__pyx_n_s_FY5253Mixin_is_anchored
#define __pyx_n_s_FY5253Quarter __pyx_mstate_global->__pyx_n_s_FY5253Quarter
#define __pyx_n_s_FY5253Quarter___setstate __pyx_mstate_global->__pyx_n_s_FY5253Quarter___setstate
#define __pyx_n_s_FY5253Quarter__apply __pyx_mstate_global->__pyx_n_s_FY5253Quarter__apply
#define __pyx_n_s_FY5253Quarter__from_name __pyx_mstate_global->__pyx_n_s_FY5253Quarter__from_name
#define __pyx_n_s_FY5253Quarter__offset __pyx_mstate_global->__pyx_n_s_FY5253Quarter__offset
#define __pyx_n_s_FY5253Quarter__rollback_to_year __pyx_mstate_global->__pyx_n_s_FY5253Quarter__rollback_to_year
#define __pyx_n_s_FY5253Quarter_get_weeks __pyx_mstate_global->__pyx_n_s_FY5253Quarter_get_weeks
#define __pyx_n_s_FY5253Quarter_is_on_offset __pyx_mstate_global->__pyx_n_s_FY5253Quarter_is_on_offset
#define __pyx_n_s_FY5253Quarter_year_has_extra_wee __pyx_mstate_global->__pyx_n_s_FY5253Quarter_year_has_extra_wee
#define __pyx_n_s_FY5253__apply __pyx_mstate_global->__pyx_n_s_FY5253__apply
#define __pyx_n_s_FY5253__from_name __pyx_mstate_global->__pyx_n_s_FY5253__from_name
#define __pyx_n_s_FY5253__parse_suffix __pyx_mstate_global->__pyx_n_s_FY5253__parse_suffix
#define __pyx_n_s_FY5253_get_year_end __pyx_mstate_global->__pyx_n_s_FY5253_get_year_end
#define __pyx_n_s_FY5253_is_on_offset __pyx_mstate_global->__pyx_n_s_FY5253_is_on_offset
#define __pyx_n_u_H __pyx_mstate_global->__pyx_n_u_H
#define __pyx_kp_u_H_M __pyx_mstate_global->__pyx_kp_u_H_M
#define __pyx_n_s_Hour __pyx_mstate_global->__pyx_n_s_Hour
#define __pyx_n_s_INVALID_FREQ_ERR_MSG __pyx_mstate_global->__pyx_n_s_INVALID_FREQ_ERR_MSG
#define __pyx_n_s_ImportError __pyx_mstate_global->__pyx_n_s_ImportError
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_kp_u_Invalid_argument_s_or_bad_combin __pyx_mstate_global->__pyx_kp_u_Invalid_argument_s_or_bad_combin
#define __pyx_kp_u_Invalid_frequency_0 __pyx_mstate_global->__pyx_kp_u_Invalid_frequency_0
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_u_L __pyx_mstate_global->__pyx_n_u_L
#define __pyx_n_u_LWOM __pyx_mstate_global->__pyx_n_u_LWOM
#define __pyx_n_s_LastWeekOfMonth __pyx_mstate_global->__pyx_n_s_LastWeekOfMonth
#define __pyx_n_s_LastWeekOfMonth___setstate __pyx_mstate_global->__pyx_n_s_LastWeekOfMonth___setstate
#define __pyx_n_s_LastWeekOfMonth__from_name __pyx_mstate_global->__pyx_n_s_LastWeekOfMonth__from_name
#define __pyx_n_s_LastWeekOfMonth__get_offset_day __pyx_mstate_global->__pyx_n_s_LastWeekOfMonth__get_offset_day
#define __pyx_n_u_M __pyx_mstate_global->__pyx_n_u_M
#define __pyx_n_s_MONTH_ALIASES __pyx_mstate_global->__pyx_n_s_MONTH_ALIASES
#define __pyx_n_s_MONTH_TO_CAL_NUM __pyx_mstate_global->__pyx_n_s_MONTH_TO_CAL_NUM
#define __pyx_n_u_MS __pyx_mstate_global->__pyx_n_u_MS
#define __pyx_kp_s_Metaclass_that_allows_us_to_pre __pyx_mstate_global->__pyx_kp_s_Metaclass_that_allows_us_to_pre
#define __pyx_n_s_Micro __pyx_mstate_global->__pyx_n_s_Micro
#define __pyx_n_s_Milli __pyx_mstate_global->__pyx_n_s_Milli
#define __pyx_n_u_Min __pyx_mstate_global->__pyx_n_u_Min
#define __pyx_n_s_Minute __pyx_mstate_global->__pyx_n_s_Minute
#define __pyx_kp_u_Mon_Tue_Wed_Thu_Fri __pyx_mstate_global->__pyx_kp_u_Mon_Tue_Wed_Thu_Fri
#define __pyx_n_s_MonthBegin __pyx_mstate_global->__pyx_n_s_MonthBegin
#define __pyx_n_s_MonthEnd __pyx_mstate_global->__pyx_n_s_MonthEnd
#define __pyx_n_s_MonthOffset __pyx_mstate_global->__pyx_n_s_MonthOffset
#define __pyx_n_s_MonthOffset___setstate __pyx_mstate_global->__pyx_n_s_MonthOffset___setstate
#define __pyx_n_s_MonthOffset__apply __pyx_mstate_global->__pyx_n_s_MonthOffset__apply
#define __pyx_n_s_MonthOffset__apply_array __pyx_mstate_global->__pyx_n_s_MonthOffset__apply_array
#define __pyx_n_s_MonthOffset_is_on_offset __pyx_mstate_global->__pyx_n_s_MonthOffset_is_on_offset
#define __pyx_kp_u_Month_must_go_from_1_to_12 __pyx_mstate_global->__pyx_kp_u_Month_must_go_from_1_to_12
#define __pyx_kp_u_Must_include_at_least_1_end_time __pyx_mstate_global->__pyx_kp_u_Must_include_at_least_1_end_time
#define __pyx_kp_u_Must_include_at_least_1_start_ti __pyx_mstate_global->__pyx_kp_u_Must_include_at_least_1_start_ti
#define __pyx_n_u_N __pyx_mstate_global->__pyx_n_u_N
#define __pyx_kp_u_N_cannot_be_0 __pyx_mstate_global->__pyx_kp_u_N_cannot_be_0
#define __pyx_n_s_Nano __pyx_mstate_global->__pyx_n_s_Nano
#define __pyx_kp_u_None __pyx_mstate_global->__pyx_kp_u_None
#define __pyx_n_s_NotImplemented __pyx_mstate_global->__pyx_n_s_NotImplemented
#define __pyx_n_s_NotImplementedError __pyx_mstate_global->__pyx_n_s_NotImplementedError
#define __pyx_n_s_OffsetMeta __pyx_mstate_global->__pyx_n_s_OffsetMeta
#define __pyx_n_s_OffsetMeta___instancecheck __pyx_mstate_global->__pyx_n_s_OffsetMeta___instancecheck
#define __pyx_n_s_OffsetMeta___subclasscheck __pyx_mstate_global->__pyx_n_s_OffsetMeta___subclasscheck
#define __pyx_kp_u_Only_know_how_to_combine_busines __pyx_mstate_global->__pyx_kp_u_Only_know_how_to_combine_busines
#define __pyx_kp_u_Only_know_how_to_combine_trading __pyx_mstate_global->__pyx_kp_u_Only_know_how_to_combine_trading
#define __pyx_n_s_OverflowError __pyx_mstate_global->__pyx_n_s_OverflowError
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_kp_u_Prefix __pyx_mstate_global->__pyx_kp_u_Prefix
#define __pyx_kp_u_Prefix_not_defined __pyx_mstate_global->__pyx_kp_u_Prefix_not_defined
#define __pyx_n_u_Q __pyx_mstate_global->__pyx_n_u_Q
#define __pyx_n_u_QS __pyx_mstate_global->__pyx_n_u_QS
#define __pyx_kp_u_Q_DEC __pyx_mstate_global->__pyx_kp_u_Q_DEC
#define __pyx_n_s_QuarterBegin __pyx_mstate_global->__pyx_n_s_QuarterBegin
#define __pyx_n_s_QuarterEnd __pyx_mstate_global->__pyx_n_s_QuarterEnd
#define __pyx_n_s_QuarterOffset __pyx_mstate_global->__pyx_n_s_QuarterOffset
#define __pyx_n_s_QuarterOffset___setstate __pyx_mstate_global->__pyx_n_s_QuarterOffset___setstate
#define __pyx_n_s_QuarterOffset__apply __pyx_mstate_global->__pyx_n_s_QuarterOffset__apply
#define __pyx_n_s_QuarterOffset__apply_array __pyx_mstate_global->__pyx_n_s_QuarterOffset__apply_array
#define __pyx_n_s_QuarterOffset__from_name __pyx_mstate_global->__pyx_n_s_QuarterOffset__from_name
#define __pyx_n_s_QuarterOffset_is_anchored __pyx_mstate_global->__pyx_n_s_QuarterOffset_is_anchored
#define __pyx_n_s_QuarterOffset_is_on_offset __pyx_mstate_global->__pyx_n_s_QuarterOffset_is_on_offset
#define __pyx_n_u_RE __pyx_mstate_global->__pyx_n_u_RE
#define __pyx_n_u_REQ __pyx_mstate_global->__pyx_n_u_REQ
#define __pyx_n_s_RelativeDeltaOffset __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset
#define __pyx_n_s_RelativeDeltaOffset___getstate __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset___getstate
#define __pyx_n_s_RelativeDeltaOffset___reduce_cyt __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset___reduce_cyt
#define __pyx_n_s_RelativeDeltaOffset___setstate __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset___setstate
#define __pyx_n_s_RelativeDeltaOffset___setstate_c __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset___setstate_c
#define __pyx_n_s_RelativeDeltaOffset__apply __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset__apply
#define __pyx_n_s_RelativeDeltaOffset__apply_array __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset__apply_array
#define __pyx_n_s_RelativeDeltaOffset_is_on_offset __pyx_mstate_global->__pyx_n_s_RelativeDeltaOffset_is_on_offset
#define __pyx_kp_u_Return_DateOffset_object_from_s __pyx_mstate_global->__pyx_kp_u_Return_DateOffset_object_from_s
#define __pyx_kp_u_Return_a_copy_of_the_frequency __pyx_mstate_global->__pyx_kp_u_Return_a_copy_of_the_frequency
#define __pyx_kp_u_Return_a_dict_of_extra_paramete __pyx_mstate_global->__pyx_kp_u_Return_a_dict_of_extra_paramete
#define __pyx_kp_u_Return_a_string_representing_th __pyx_mstate_global->__pyx_kp_u_Return_a_string_representing_th
#define __pyx_kp_u_Return_a_string_representing_th_2 __pyx_mstate_global->__pyx_kp_u_Return_a_string_representing_th_2
#define __pyx_kp_u_Return_an_integer_of_the_total __pyx_mstate_global->__pyx_kp_u_Return_an_integer_of_the_total
#define __pyx_kp_u_Return_boolean_whether_a_timest __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest
#define __pyx_kp_u_Return_boolean_whether_a_timest_2 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_2
#define __pyx_kp_u_Return_boolean_whether_a_timest_3 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_3
#define __pyx_kp_u_Return_boolean_whether_a_timest_4 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_4
#define __pyx_kp_u_Return_boolean_whether_a_timest_5 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_5
#define __pyx_kp_u_Return_boolean_whether_a_timest_6 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_6
#define __pyx_kp_u_Return_boolean_whether_a_timest_7 __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_a_timest_7
#define __pyx_kp_u_Return_boolean_whether_the_freq __pyx_mstate_global->__pyx_kp_u_Return_boolean_whether_the_freq
#define __pyx_n_s_RuntimeError __pyx_mstate_global->__pyx_n_s_RuntimeError
#define __pyx_n_u_S __pyx_mstate_global->__pyx_n_u_S
#define __pyx_n_u_SM __pyx_mstate_global->__pyx_n_u_SM
#define __pyx_n_u_SMS __pyx_mstate_global->__pyx_n_u_SMS
#define __pyx_n_s_Second __pyx_mstate_global->__pyx_n_s_Second
#define __pyx_n_s_SemiMonthBegin __pyx_mstate_global->__pyx_n_s_SemiMonthBegin
#define __pyx_n_s_SemiMonthBegin_is_on_offset __pyx_mstate_global->__pyx_n_s_SemiMonthBegin_is_on_offset
#define __pyx_n_s_SemiMonthEnd __pyx_mstate_global->__pyx_n_s_SemiMonthEnd
#define __pyx_n_s_SemiMonthEnd_is_on_offset __pyx_mstate_global->__pyx_n_s_SemiMonthEnd_is_on_offset
#define __pyx_n_s_SemiMonthOffset __pyx_mstate_global->__pyx_n_s_SemiMonthOffset
#define __pyx_n_s_SemiMonthOffset___setstate __pyx_mstate_global->__pyx_n_s_SemiMonthOffset___setstate
#define __pyx_n_s_SemiMonthOffset__apply __pyx_mstate_global->__pyx_n_s_SemiMonthOffset__apply
#define __pyx_n_s_SemiMonthOffset__apply_array __pyx_mstate_global->__pyx_n_s_SemiMonthOffset__apply_array
#define __pyx_n_s_SemiMonthOffset__from_name __pyx_mstate_global->__pyx_n_s_SemiMonthOffset__from_name
#define __pyx_n_s_SingleConstructorOffset __pyx_mstate_global->__pyx_n_s_SingleConstructorOffset
#define __pyx_n_s_SingleConstructorOffset___reduce __pyx_mstate_global->__pyx_n_s_SingleConstructorOffset___reduce
#define __pyx_n_s_SingleConstructorOffset__from_na __pyx_mstate_global->__pyx_n_s_SingleConstructorOffset__from_na
#define __pyx_kp_s_Standard_kind_of_date_increment __pyx_mstate_global->__pyx_kp_s_Standard_kind_of_date_increment
#define __pyx_n_u_T __pyx_mstate_global->__pyx_n_u_T
#define __pyx_n_s_Tick __pyx_mstate_global->__pyx_n_s_Tick
#define __pyx_n_s_Tick___setstate __pyx_mstate_global->__pyx_n_s_Tick___setstate
#define __pyx_n_s_Tick__apply __pyx_mstate_global->__pyx_n_s_Tick__apply
#define __pyx_n_s_Tick__next_higher_resolution __pyx_mstate_global->__pyx_n_s_Tick__next_higher_resolution
#define __pyx_n_s_Tick__repr_attrs __pyx_mstate_global->__pyx_n_s_Tick__repr_attrs
#define __pyx_n_s_Tick_is_anchored __pyx_mstate_global->__pyx_n_s_Tick_is_anchored
#define __pyx_n_s_Tick_is_on_offset __pyx_mstate_global->__pyx_n_s_Tick_is_on_offset
#define __pyx_kp_u_Tick_nanos___get___line_953 __pyx_mstate_global->__pyx_kp_u_Tick_nanos___get___line_953
#define __pyx_kp_u_Tick_offset_with_normalize_True __pyx_mstate_global->__pyx_kp_u_Tick_offset_with_normalize_True
#define __pyx_kp_u_Time_zones_are_not_available_fro __pyx_mstate_global->__pyx_kp_u_Time_zones_are_not_available_fro
#define __pyx_n_s_Timedelta __pyx_mstate_global->__pyx_n_s_Timedelta
#define __pyx_n_s_Timestamp __pyx_mstate_global->__pyx_n_s_Timestamp
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_u_U __pyx_mstate_global->__pyx_n_u_U
#define __pyx_kp_u_Unable_to_parse_varion_code __pyx_mstate_global->__pyx_kp_u_Unable_to_parse_varion_code
#define __pyx_kp_u_Unexpected_key__offset __pyx_mstate_global->__pyx_kp_u_Unexpected_key__offset
#define __pyx_kp_u_Unhandled_type __pyx_mstate_global->__pyx_kp_u_Unhandled_type
#define __pyx_kp_u_Using_DateOffset_to_replace_mill __pyx_mstate_global->__pyx_kp_u_Using_DateOffset_to_replace_mill
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_u_W __pyx_mstate_global->__pyx_n_u_W
#define __pyx_n_u_WOM __pyx_mstate_global->__pyx_n_u_WOM
#define __pyx_kp_u_W_SUN __pyx_mstate_global->__pyx_kp_u_W_SUN
#define __pyx_n_s_Week __pyx_mstate_global->__pyx_n_s_Week
#define __pyx_n_s_WeekOfMonth __pyx_mstate_global->__pyx_n_s_WeekOfMonth
#define __pyx_n_s_WeekOfMonthMixin __pyx_mstate_global->__pyx_n_s_WeekOfMonthMixin
#define __pyx_n_s_WeekOfMonthMixin__apply __pyx_mstate_global->__pyx_n_s_WeekOfMonthMixin__apply
#define __pyx_n_s_WeekOfMonthMixin_is_on_offset __pyx_mstate_global->__pyx_n_s_WeekOfMonthMixin_is_on_offset
#define __pyx_n_s_WeekOfMonth___setstate __pyx_mstate_global->__pyx_n_s_WeekOfMonth___setstate
#define __pyx_n_s_WeekOfMonth__from_name __pyx_mstate_global->__pyx_n_s_WeekOfMonth__from_name
#define __pyx_n_s_WeekOfMonth__get_offset_day __pyx_mstate_global->__pyx_n_s_WeekOfMonth__get_offset_day
#define __pyx_n_s_Week___setstate __pyx_mstate_global->__pyx_n_s_Week___setstate
#define __pyx_n_s_Week__apply __pyx_mstate_global->__pyx_n_s_Week__apply
#define __pyx_n_s_Week__apply_array __pyx_mstate_global->__pyx_n_s_Week__apply_array
#define __pyx_n_s_Week__from_name __pyx_mstate_global->__pyx_n_s_Week__from_name
#define __pyx_n_s_Week_is_anchored __pyx_mstate_global->__pyx_n_s_Week_is_anchored
#define __pyx_n_s_Week_is_on_offset __pyx_mstate_global->__pyx_n_s_Week_is_on_offset
#define __pyx_kp_u_Week_must_be_0_week_3_got __pyx_mstate_global->__pyx_kp_u_Week_must_be_0_week_3_got
#define __pyx_n_u_Y __pyx_mstate_global->__pyx_n_u_Y
#define __pyx_n_u_YS __pyx_mstate_global->__pyx_n_u_YS
#define __pyx_n_s_YearBegin __pyx_mstate_global->__pyx_n_s_YearBegin
#define __pyx_n_s_YearEnd __pyx_mstate_global->__pyx_n_s_YearEnd
#define __pyx_n_s_YearOffset __pyx_mstate_global->__pyx_n_s_YearOffset
#define __pyx_n_s_YearOffset___setstate __pyx_mstate_global->__pyx_n_s_YearOffset___setstate
#define __pyx_n_s_YearOffset__apply __pyx_mstate_global->__pyx_n_s_YearOffset__apply
#define __pyx_n_s_YearOffset__apply_array __pyx_mstate_global->__pyx_n_s_YearOffset__apply_array
#define __pyx_n_s_YearOffset__from_name __pyx_mstate_global->__pyx_n_s_YearOffset__from_name
#define __pyx_n_s_YearOffset__get_offset_day __pyx_mstate_global->__pyx_n_s_YearOffset__get_offset_day
#define __pyx_n_s_YearOffset_is_on_offset __pyx_mstate_global->__pyx_n_s_YearOffset_is_on_offset
#define __pyx_n_u__13 __pyx_mstate_global->__pyx_n_u__13
#define __pyx_kp_u__15 __pyx_mstate_global->__pyx_kp_u__15
#define __pyx_kp_u__16 __pyx_mstate_global->__pyx_kp_u__16
#define __pyx_kp_u__17 __pyx_mstate_global->__pyx_kp_u__17
#define __pyx_kp_u__18 __pyx_mstate_global->__pyx_kp_u__18
#define __pyx_kp_u__19 __pyx_mstate_global->__pyx_kp_u__19
#define __pyx_kp_u__20 __pyx_mstate_global->__pyx_kp_u__20
#define __pyx_kp_u__21 __pyx_mstate_global->__pyx_kp_u__21
#define __pyx_n_s__284 __pyx_mstate_global->__pyx_n_s__284
#define __pyx_kp_u__37 __pyx_mstate_global->__pyx_kp_u__37
#define __pyx_kp_u__38 __pyx_mstate_global->__pyx_kp_u__38
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_kp_u__46 __pyx_mstate_global->__pyx_kp_u__46
#define __pyx_kp_u__47 __pyx_mstate_global->__pyx_kp_u__47
#define __pyx_n_s__67 __pyx_mstate_global->__pyx_n_s__67
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_n_s_add __pyx_mstate_global->__pyx_n_s_add
#define __pyx_n_s_adjust_dst __pyx_mstate_global->__pyx_n_s_adjust_dst
#define __pyx_n_s_all_paras __pyx_mstate_global->__pyx_n_s_all_paras
#define __pyx_n_s_anchor __pyx_mstate_global->__pyx_n_s_anchor
#define __pyx_n_s_anchor_dom __pyx_mstate_global->__pyx_n_s_anchor_dom
#define __pyx_kp_u_and __pyx_mstate_global->__pyx_kp_u_and
#define __pyx_n_s_apply __pyx_mstate_global->__pyx_n_s_apply
#define __pyx_n_s_apply_array __pyx_mstate_global->__pyx_n_s_apply_array
#define __pyx_n_s_apply_array_wraps __pyx_mstate_global->__pyx_n_s_apply_array_wraps
#define __pyx_n_s_apply_array_wraps_locals_wrapper __pyx_mstate_global->__pyx_n_s_apply_array_wraps_locals_wrapper
#define __pyx_n_s_apply_locals_genexpr __pyx_mstate_global->__pyx_n_s_apply_locals_genexpr
#define __pyx_n_s_apply_wrapper_core __pyx_mstate_global->__pyx_n_s_apply_wrapper_core
#define __pyx_n_s_apply_wraps __pyx_mstate_global->__pyx_n_s_apply_wraps
#define __pyx_n_s_apply_wraps_locals_wrapper __pyx_mstate_global->__pyx_n_s_apply_wraps_locals_wrapper
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_argsort __pyx_mstate_global->__pyx_n_s_argsort
#define __pyx_n_s_array __pyx_mstate_global->__pyx_n_s_array
#define __pyx_n_s_array_priority __pyx_mstate_global->__pyx_n_s_array_priority
#define __pyx_n_s_as_unit __pyx_mstate_global->__pyx_n_s_as_unit
#define __pyx_n_s_asarray __pyx_mstate_global->__pyx_n_s_asarray
#define __pyx_n_s_astype __pyx_mstate_global->__pyx_n_s_astype
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_attr __pyx_mstate_global->__pyx_n_s_attr
#define __pyx_n_s_attributes __pyx_mstate_global->__pyx_n_s_attributes
#define __pyx_n_s_attrs __pyx_mstate_global->__pyx_n_s_attrs
#define __pyx_n_s_b __pyx_mstate_global->__pyx_n_s_b
#define __pyx_n_u_backward __pyx_mstate_global->__pyx_n_u_backward
#define __pyx_n_s_bd __pyx_mstate_global->__pyx_n_s_bd
#define __pyx_n_s_bhour __pyx_mstate_global->__pyx_n_s_bhour
#define __pyx_n_s_bhour_remain __pyx_mstate_global->__pyx_n_s_bhour_remain
#define __pyx_n_s_bool __pyx_mstate_global->__pyx_n_s_bool
#define __pyx_n_s_busday_offset __pyx_mstate_global->__pyx_n_s_busday_offset
#define __pyx_n_s_busdaycal __pyx_mstate_global->__pyx_n_s_busdaycal
#define __pyx_n_s_busdaycalendar __pyx_mstate_global->__pyx_n_s_busdaycalendar
#define __pyx_n_u_business_end __pyx_mstate_global->__pyx_n_u_business_end
#define __pyx_n_u_business_start __pyx_mstate_global->__pyx_n_u_business_start
#define __pyx_n_s_businesshours __pyx_mstate_global->__pyx_n_s_businesshours
#define __pyx_n_u_cache __pyx_mstate_global->__pyx_n_u_cache
#define __pyx_n_s_cache_readonly __pyx_mstate_global->__pyx_n_s_cache_readonly
#define __pyx_n_s_calendar __pyx_mstate_global->__pyx_n_s_calendar
#define __pyx_n_u_calendar __pyx_mstate_global->__pyx_n_u_calendar
#define __pyx_n_s_cbday __pyx_mstate_global->__pyx_n_s_cbday
#define __pyx_n_s_cbday_kwds __pyx_mstate_global->__pyx_n_s_cbday_kwds
#define __pyx_n_s_cbday_roll __pyx_mstate_global->__pyx_n_s_cbday_roll
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_cls __pyx_mstate_global->__pyx_n_s_cls
#define __pyx_n_s_code __pyx_mstate_global->__pyx_n_s_code
#define __pyx_n_s_combine __pyx_mstate_global->__pyx_n_s_combine
#define __pyx_n_s_compare __pyx_mstate_global->__pyx_n_s_compare
#define __pyx_n_s_compare_date __pyx_mstate_global->__pyx_n_s_compare_date
#define __pyx_n_s_compare_day __pyx_mstate_global->__pyx_n_s_compare_day
#define __pyx_n_s_compile __pyx_mstate_global->__pyx_n_s_compile
#define __pyx_n_s_copy __pyx_mstate_global->__pyx_n_s_copy
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_creso __pyx_mstate_global->__pyx_n_s_creso
#define __pyx_n_s_cur_month_offset_date __pyx_mstate_global->__pyx_n_s_cur_month_offset_date
#define __pyx_n_s_cur_year __pyx_mstate_global->__pyx_n_s_cur_year
#define __pyx_n_s_current __pyx_mstate_global->__pyx_n_s_current
#define __pyx_n_s_current_easter __pyx_mstate_global->__pyx_n_s_current_easter
#define __pyx_n_s_d __pyx_mstate_global->__pyx_n_s_d
#define __pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z __pyx_mstate_global->__pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z
#define __pyx_n_s_date __pyx_mstate_global->__pyx_n_s_date
#define __pyx_n_s_date_in __pyx_mstate_global->__pyx_n_s_date_in
#define __pyx_n_s_datetime __pyx_mstate_global->__pyx_n_s_datetime
#define __pyx_n_s_datetime64 __pyx_mstate_global->__pyx_n_s_datetime64
#define __pyx_kp_u_datetime64_D __pyx_mstate_global->__pyx_kp_u_datetime64_D
#define __pyx_n_s_dateutil_easter __pyx_mstate_global->__pyx_n_s_dateutil_easter
#define __pyx_n_s_dateutil_relativedelta __pyx_mstate_global->__pyx_n_s_dateutil_relativedelta
#define __pyx_n_s_day __pyx_mstate_global->__pyx_n_s_day
#define __pyx_n_u_day __pyx_mstate_global->__pyx_n_u_day
#define __pyx_n_s_day64 __pyx_mstate_global->__pyx_n_s_day64
#define __pyx_kp_u_day_must_be_None_start_end_busin __pyx_mstate_global->__pyx_kp_u_day_must_be_None_start_end_busin
#define __pyx_n_s_day_of_month __pyx_mstate_global->__pyx_n_s_day_of_month
#define __pyx_n_u_day_of_month __pyx_mstate_global->__pyx_n_u_day_of_month
#define __pyx_kp_u_day_of_month_27_got __pyx_mstate_global->__pyx_kp_u_day_of_month_27_got
#define __pyx_kp_u_day_of_month_must_be __pyx_mstate_global->__pyx_kp_u_day_of_month_must_be
#define __pyx_n_s_day_opt __pyx_mstate_global->__pyx_n_s_day_opt
#define __pyx_n_s_day_opt_2 __pyx_mstate_global->__pyx_n_s_day_opt_2
#define __pyx_n_s_days __pyx_mstate_global->__pyx_n_s_days
#define __pyx_n_u_days __pyx_mstate_global->__pyx_n_u_days
#define __pyx_n_s_days_forward __pyx_mstate_global->__pyx_n_s_days_forward
#define __pyx_n_s_days_in_month __pyx_mstate_global->__pyx_n_s_days_in_month
#define __pyx_n_s_default_day_of_month __pyx_mstate_global->__pyx_n_s_default_day_of_month
#define __pyx_n_s_default_month __pyx_mstate_global->__pyx_n_s_default_month
#define __pyx_n_s_default_starting_month __pyx_mstate_global->__pyx_n_s_default_starting_month
#define __pyx_n_s_delta __pyx_mstate_global->__pyx_n_s_delta
#define __pyx_n_s_delta_to_tick __pyx_mstate_global->__pyx_n_s_delta_to_tick
#define __pyx_n_s_determine_offset_locals_genexpr __pyx_mstate_global->__pyx_n_s_determine_offset_locals_genexpr
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_u_dict __pyx_mstate_global->__pyx_n_u_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_n_s_dim __pyx_mstate_global->__pyx_n_s_dim
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_doc __pyx_mstate_global->__pyx_n_s_doc
#define __pyx_kp_u_does_not_have_a_vectorized_impl __pyx_mstate_global->__pyx_kp_u_does_not_have_a_vectorized_impl
#define __pyx_n_s_dont_uppercase __pyx_mstate_global->__pyx_n_s_dont_uppercase
#define __pyx_n_s_dt __pyx_mstate_global->__pyx_n_s_dt
#define __pyx_n_s_dt64other __pyx_mstate_global->__pyx_n_s_dt64other
#define __pyx_n_s_dt_date __pyx_mstate_global->__pyx_n_s_dt_date
#define __pyx_n_s_dtarr __pyx_mstate_global->__pyx_n_s_dtarr
#define __pyx_n_s_dtindex __pyx_mstate_global->__pyx_n_s_dtindex
#define __pyx_n_s_dts __pyx_mstate_global->__pyx_n_s_dts
#define __pyx_n_s_dtstart __pyx_mstate_global->__pyx_n_s_dtstart
#define __pyx_n_s_dtype __pyx_mstate_global->__pyx_n_s_dtype
#define __pyx_n_s_dy __pyx_mstate_global->__pyx_n_s_dy
#define __pyx_n_s_earliest_start __pyx_mstate_global->__pyx_n_s_earliest_start
#define __pyx_n_s_easter __pyx_mstate_global->__pyx_n_s_easter
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_end __pyx_mstate_global->__pyx_n_s_end
#define __pyx_n_u_end __pyx_mstate_global->__pyx_n_u_end
#define __pyx_n_s_endswith __pyx_mstate_global->__pyx_n_s_endswith
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_err __pyx_mstate_global->__pyx_n_s_err
#define __pyx_n_s_exclude __pyx_mstate_global->__pyx_n_s_exclude
#define __pyx_n_s_fabs __pyx_mstate_global->__pyx_n_s_fabs
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_u_forward __pyx_mstate_global->__pyx_n_u_forward
#define __pyx_n_s_freq __pyx_mstate_global->__pyx_n_s_freq
#define __pyx_n_s_freqstr __pyx_mstate_global->__pyx_n_s_freqstr
#define __pyx_n_s_from_name __pyx_mstate_global->__pyx_n_s_from_name
#define __pyx_n_s_from_name_starting_month __pyx_mstate_global->__pyx_n_s_from_name_starting_month
#define __pyx_n_s_fstr __pyx_mstate_global->__pyx_n_s_fstr
#define __pyx_n_s_func __pyx_mstate_global->__pyx_n_s_func
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_ge __pyx_mstate_global->__pyx_n_s_ge
#define __pyx_n_s_genexpr __pyx_mstate_global->__pyx_n_s_genexpr
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_get_2 __pyx_mstate_global->__pyx_n_s_get_2
#define __pyx_n_s_get_business_hours_by_sec __pyx_mstate_global->__pyx_n_s_get_business_hours_by_sec
#define __pyx_n_s_get_closing_time __pyx_mstate_global->__pyx_n_s_get_closing_time
#define __pyx_n_s_get_offset __pyx_mstate_global->__pyx_n_s_get_offset
#define __pyx_n_s_get_offset_day __pyx_mstate_global->__pyx_n_s_get_offset_day
#define __pyx_n_s_get_rule_code_suffix __pyx_mstate_global->__pyx_n_s_get_rule_code_suffix
#define __pyx_n_s_get_str __pyx_mstate_global->__pyx_n_s_get_str
#define __pyx_n_s_get_suffix_prefix __pyx_mstate_global->__pyx_n_s_get_suffix_prefix
#define __pyx_n_s_get_weeks __pyx_mstate_global->__pyx_n_s_get_weeks
#define __pyx_n_s_get_year_end __pyx_mstate_global->__pyx_n_s_get_year_end
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_gt __pyx_mstate_global->__pyx_n_s_gt
#define __pyx_n_u_h __pyx_mstate_global->__pyx_n_u_h
#define __pyx_n_s_holidays __pyx_mstate_global->__pyx_n_s_holidays
#define __pyx_n_u_holidays __pyx_mstate_global->__pyx_n_u_holidays
#define __pyx_n_s_hour __pyx_mstate_global->__pyx_n_s_hour
#define __pyx_n_u_hour __pyx_mstate_global->__pyx_n_u_hour
#define __pyx_n_s_hours __pyx_mstate_global->__pyx_n_s_hours
#define __pyx_n_u_hours __pyx_mstate_global->__pyx_n_u_hours
#define __pyx_n_s_hrs __pyx_mstate_global->__pyx_n_s_hrs
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_u_i8 __pyx_mstate_global->__pyx_n_u_i8
#define __pyx_n_s_i8other __pyx_mstate_global->__pyx_n_s_i8other
#define __pyx_kp_u_implemented_by_subclasses __pyx_mstate_global->__pyx_kp_u_implemented_by_subclasses
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_u_inc __pyx_mstate_global->__pyx_n_u_inc
#define __pyx_n_s_inc_2 __pyx_mstate_global->__pyx_n_s_inc_2
#define __pyx_n_s_init __pyx_mstate_global->__pyx_n_s_init
#define __pyx_n_s_init_custom __pyx_mstate_global->__pyx_n_s_init_custom
#define __pyx_n_s_init_subclass __pyx_mstate_global->__pyx_n_s_init_subclass
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_instancecheck __pyx_mstate_global->__pyx_n_s_instancecheck
#define __pyx_n_s_int __pyx_mstate_global->__pyx_n_s_int
#define __pyx_n_s_int_to_weekday __pyx_mstate_global->__pyx_n_s_int_to_weekday
#define __pyx_kp_u_invalid_starting_and_ending_time __pyx_mstate_global->__pyx_kp_u_invalid_starting_and_ending_time
#define __pyx_kp_u_is_a_non_fixed_frequency __pyx_mstate_global->__pyx_kp_u_is_a_non_fixed_frequency
#define __pyx_n_s_is_anchored __pyx_mstate_global->__pyx_n_s_is_anchored
#define __pyx_n_s_is_busday __pyx_mstate_global->__pyx_n_s_is_busday
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_month_end __pyx_mstate_global->__pyx_n_s_is_month_end
#define __pyx_n_u_is_month_end __pyx_mstate_global->__pyx_n_u_is_month_end
#define __pyx_n_s_is_month_start __pyx_mstate_global->__pyx_n_s_is_month_start
#define __pyx_n_u_is_month_start __pyx_mstate_global->__pyx_n_u_is_month_start
#define __pyx_kp_u_is_not_a_valid_variation __pyx_mstate_global->__pyx_kp_u_is_not_a_valid_variation
#define __pyx_n_s_is_on_offset __pyx_mstate_global->__pyx_n_s_is_on_offset
#define __pyx_n_s_is_on_offset_2 __pyx_mstate_global->__pyx_n_s_is_on_offset_2
#define __pyx_n_s_is_quarter_end __pyx_mstate_global->__pyx_n_s_is_quarter_end
#define __pyx_n_u_is_quarter_end __pyx_mstate_global->__pyx_n_u_is_quarter_end
#define __pyx_n_s_is_quarter_start __pyx_mstate_global->__pyx_n_s_is_quarter_start
#define __pyx_n_u_is_quarter_start __pyx_mstate_global->__pyx_n_u_is_quarter_start
#define __pyx_n_s_is_same_sign __pyx_mstate_global->__pyx_n_s_is_same_sign
#define __pyx_n_s_is_start __pyx_mstate_global->__pyx_n_s_is_start
#define __pyx_n_s_is_year_end __pyx_mstate_global->__pyx_n_s_is_year_end
#define __pyx_n_u_is_year_end __pyx_mstate_global->__pyx_n_u_is_year_end
#define __pyx_n_s_is_year_start __pyx_mstate_global->__pyx_n_s_is_year_start
#define __pyx_n_u_is_year_start __pyx_mstate_global->__pyx_n_u_is_year_start
#define __pyx_n_s_isclose __pyx_mstate_global->__pyx_n_s_isclose
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_isspace __pyx_mstate_global->__pyx_n_s_isspace
#define __pyx_n_s_issubset __pyx_mstate_global->__pyx_n_s_issubset
#define __pyx_n_s_items __pyx_mstate_global->__pyx_n_s_items
#define __pyx_n_s_k __pyx_mstate_global->__pyx_n_s_k
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_klass __pyx_mstate_global->__pyx_n_s_klass
#define __pyx_n_s_kwargs __pyx_mstate_global->__pyx_n_s_kwargs
#define __pyx_n_s_kwd __pyx_mstate_global->__pyx_n_s_kwd
#define __pyx_n_s_kwds __pyx_mstate_global->__pyx_n_s_kwds
#define __pyx_n_u_kwds __pyx_mstate_global->__pyx_n_u_kwds
#define __pyx_n_u_last __pyx_mstate_global->__pyx_n_u_last
#define __pyx_kp_u_last_element_must_be_blank __pyx_mstate_global->__pyx_kp_u_last_element_must_be_blank
#define __pyx_n_s_latest_start __pyx_mstate_global->__pyx_n_s_latest_start
#define __pyx_n_s_le __pyx_mstate_global->__pyx_n_s_le
#define __pyx_n_s_lite_rule_alias __pyx_mstate_global->__pyx_n_s_lite_rule_alias
#define __pyx_n_s_lower __pyx_mstate_global->__pyx_n_s_lower
#define __pyx_n_s_lt __pyx_mstate_global->__pyx_n_s_lt
#define __pyx_n_u_m __pyx_mstate_global->__pyx_n_u_m
#define __pyx_n_s_m_offset __pyx_mstate_global->__pyx_n_s_m_offset
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_mend __pyx_mstate_global->__pyx_n_s_mend
#define __pyx_n_s_metaclass __pyx_mstate_global->__pyx_n_s_metaclass
#define __pyx_n_s_mi __pyx_mstate_global->__pyx_n_s_mi
#define __pyx_n_s_microsecond __pyx_mstate_global->__pyx_n_s_microsecond
#define __pyx_n_u_microsecond __pyx_mstate_global->__pyx_n_u_microsecond
#define __pyx_n_s_microseconds __pyx_mstate_global->__pyx_n_s_microseconds
#define __pyx_n_u_microseconds __pyx_mstate_global->__pyx_n_u_microseconds
#define __pyx_n_u_millisecond __pyx_mstate_global->__pyx_n_u_millisecond
#define __pyx_n_u_milliseconds __pyx_mstate_global->__pyx_n_u_milliseconds
#define __pyx_n_u_min __pyx_mstate_global->__pyx_n_u_min
#define __pyx_n_s_min_day_of_month __pyx_mstate_global->__pyx_n_s_min_day_of_month
#define __pyx_n_s_minute __pyx_mstate_global->__pyx_n_s_minute
#define __pyx_n_u_minute __pyx_mstate_global->__pyx_n_u_minute
#define __pyx_n_s_minutes __pyx_mstate_global->__pyx_n_s_minutes
#define __pyx_n_u_minutes __pyx_mstate_global->__pyx_n_u_minutes
#define __pyx_n_s_mod_month __pyx_mstate_global->__pyx_n_s_mod_month
#define __pyx_n_s_modby __pyx_mstate_global->__pyx_n_s_modby
#define __pyx_n_s_module __pyx_mstate_global->__pyx_n_s_module
#define __pyx_n_s_moff __pyx_mstate_global->__pyx_n_s_moff
#define __pyx_n_s_month __pyx_mstate_global->__pyx_n_s_month
#define __pyx_n_u_month __pyx_mstate_global->__pyx_n_u_month
#define __pyx_n_s_month_roll __pyx_mstate_global->__pyx_n_s_month_roll
#define __pyx_n_s_months __pyx_mstate_global->__pyx_n_s_months
#define __pyx_n_u_months __pyx_mstate_global->__pyx_n_u_months
#define __pyx_n_s_months_since __pyx_mstate_global->__pyx_n_s_months_since
#define __pyx_n_s_months_to_roll __pyx_mstate_global->__pyx_n_s_months_to_roll
#define __pyx_n_s_mro_entries __pyx_mstate_global->__pyx_n_s_mro_entries
#define __pyx_n_u_ms __pyx_mstate_global->__pyx_n_u_ms
#define __pyx_n_s_mstart __pyx_mstate_global->__pyx_n_s_mstart
#define __pyx_n_s_mts __pyx_mstate_global->__pyx_n_s_mts
#define __pyx_n_s_mul __pyx_mstate_global->__pyx_n_s_mul
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_u_n __pyx_mstate_global->__pyx_n_u_n
#define __pyx_kp_u_n_argument_must_be_an_integer_g __pyx_mstate_global->__pyx_kp_u_n_argument_must_be_an_integer_g
#define __pyx_n_s_nadj __pyx_mstate_global->__pyx_n_s_nadj
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_u_name_2 __pyx_mstate_global->__pyx_n_u_name_2
#define __pyx_n_s_nano __pyx_mstate_global->__pyx_n_s_nano
#define __pyx_n_s_nanos __pyx_mstate_global->__pyx_n_s_nanos
#define __pyx_n_s_nanos_inc __pyx_mstate_global->__pyx_n_s_nanos_inc
#define __pyx_n_s_nanosecond __pyx_mstate_global->__pyx_n_s_nanosecond
#define __pyx_n_u_nanosecond __pyx_mstate_global->__pyx_n_u_nanosecond
#define __pyx_n_s_nanoseconds __pyx_mstate_global->__pyx_n_s_nanoseconds
#define __pyx_n_u_nanoseconds __pyx_mstate_global->__pyx_n_u_nanoseconds
#define __pyx_n_s_nb_offset __pyx_mstate_global->__pyx_n_s_nb_offset
#define __pyx_n_s_ndarray __pyx_mstate_global->__pyx_n_s_ndarray
#define __pyx_n_s_ndim __pyx_mstate_global->__pyx_n_s_ndim
#define __pyx_n_u_nearest __pyx_mstate_global->__pyx_n_u_nearest
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_new_2 __pyx_mstate_global->__pyx_n_s_new_2
#define __pyx_n_s_next_bday __pyx_mstate_global->__pyx_n_s_next_bday
#define __pyx_n_u_next_bday __pyx_mstate_global->__pyx_n_u_next_bday
#define __pyx_n_s_next_higher_resolution __pyx_mstate_global->__pyx_n_s_next_higher_resolution
#define __pyx_n_s_next_opening_time __pyx_mstate_global->__pyx_n_s_next_opening_time
#define __pyx_n_s_next_year __pyx_mstate_global->__pyx_n_s_next_year
#define __pyx_n_s_next_year_end __pyx_mstate_global->__pyx_n_s_next_year_end
#define __pyx_n_s_nint __pyx_mstate_global->__pyx_n_s_nint
#define __pyx_n_s_norm __pyx_mstate_global->__pyx_n_s_norm
#define __pyx_n_s_normalize __pyx_mstate_global->__pyx_n_s_normalize
#define __pyx_n_u_normalize __pyx_mstate_global->__pyx_n_u_normalize
#define __pyx_n_s_normalize_i8_timestamps __pyx_mstate_global->__pyx_n_s_normalize_i8_timestamps
#define __pyx_kp_u_not_able_to_be_applied_vectoriz __pyx_mstate_global->__pyx_kp_u_not_able_to_be_applied_vectoriz
#define __pyx_n_s_np __pyx_mstate_global->__pyx_n_s_np
#define __pyx_n_s_np_dt __pyx_mstate_global->__pyx_n_s_np_dt
#define __pyx_n_s_np_incr_dt __pyx_mstate_global->__pyx_n_s_np_incr_dt
#define __pyx_kp_s_np_ndarray __pyx_mstate_global->__pyx_kp_s_np_ndarray
#define __pyx_n_u_ns __pyx_mstate_global->__pyx_n_u_ns
#define __pyx_n_s_num_nano __pyx_mstate_global->__pyx_n_s_num_nano
#define __pyx_n_s_num_qtrs __pyx_mstate_global->__pyx_n_s_num_qtrs
#define __pyx_kp_u_number_of_starting_time_and_endi __pyx_mstate_global->__pyx_kp_u_number_of_starting_time_and_endi
#define __pyx_n_s_numpy __pyx_mstate_global->__pyx_n_s_numpy
#define __pyx_kp_u_numpy_core_multiarray_failed_to __pyx_mstate_global->__pyx_kp_u_numpy_core_multiarray_failed_to
#define __pyx_kp_u_numpy_core_umath_failed_to_impor __pyx_mstate_global->__pyx_kp_u_numpy_core_umath_failed_to_impor
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_off_str __pyx_mstate_global->__pyx_n_s_off_str
#define __pyx_n_s_offset __pyx_mstate_global->__pyx_n_s_offset
#define __pyx_n_u_offset __pyx_mstate_global->__pyx_n_u_offset
#define __pyx_n_s_offset_2 __pyx_mstate_global->__pyx_n_s_offset_2
#define __pyx_n_u_offset_2 __pyx_mstate_global->__pyx_n_u_offset_2
#define __pyx_kp_u_offset_3 __pyx_mstate_global->__pyx_kp_u_offset_3
#define __pyx_n_s_offset_map __pyx_mstate_global->__pyx_n_s_offset_map
#define __pyx_n_s_offset_str __pyx_mstate_global->__pyx_n_s_offset_str
#define __pyx_n_s_offset_str_locals_get_str __pyx_mstate_global->__pyx_n_s_offset_str_locals_get_str
#define __pyx_n_s_op __pyx_mstate_global->__pyx_n_s_op
#define __pyx_n_s_opattern __pyx_mstate_global->__pyx_n_s_opattern
#define __pyx_n_s_other __pyx_mstate_global->__pyx_n_s_other
#define __pyx_n_s_otherDay __pyx_mstate_global->__pyx_n_s_otherDay
#define __pyx_n_s_out __pyx_mstate_global->__pyx_n_s_out
#define __pyx_n_s_outputName __pyx_mstate_global->__pyx_n_s_outputName
#define __pyx_n_s_output_name __pyx_mstate_global->__pyx_n_s_output_name
#define __pyx_n_u_output_name __pyx_mstate_global->__pyx_n_u_output_name
#define __pyx_n_s_pandas__libs_properties __pyx_mstate_global->__pyx_n_s_pandas__libs_properties
#define __pyx_n_s_pandas__libs_tslibs_ccalendar __pyx_mstate_global->__pyx_n_s_pandas__libs_tslibs_ccalendar
#define __pyx_n_s_pandas__libs_tslibs_offsets __pyx_mstate_global->__pyx_n_s_pandas__libs_tslibs_offsets
#define __pyx_kp_s_pandas__libs_tslibs_offsets_pyx __pyx_mstate_global->__pyx_kp_s_pandas__libs_tslibs_offsets_pyx
#define __pyx_n_s_params __pyx_mstate_global->__pyx_n_s_params
#define __pyx_n_s_params_2 __pyx_mstate_global->__pyx_n_s_params_2
#define __pyx_n_s_parse_suffix __pyx_mstate_global->__pyx_n_s_parse_suffix
#define __pyx_kp_u_pass_as_a_string_instead __pyx_mstate_global->__pyx_kp_u_pass_as_a_string_instead
#define __pyx_n_s_period_dtype_code __pyx_mstate_global->__pyx_n_s_period_dtype_code
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_pop __pyx_mstate_global->__pyx_n_s_pop
#define __pyx_n_s_prefix __pyx_mstate_global->__pyx_n_s_prefix
#define __pyx_n_s_prefix_2 __pyx_mstate_global->__pyx_n_s_prefix_2
#define __pyx_n_s_prefix_mapping __pyx_mstate_global->__pyx_n_s_prefix_mapping
#define __pyx_n_s_prepare __pyx_mstate_global->__pyx_n_s_prepare
#define __pyx_n_s_prev_open __pyx_mstate_global->__pyx_n_s_prev_open
#define __pyx_n_s_prev_opening_time __pyx_mstate_global->__pyx_n_s_prev_opening_time
#define __pyx_n_s_prev_year __pyx_mstate_global->__pyx_n_s_prev_year
#define __pyx_n_s_prev_year_end __pyx_mstate_global->__pyx_n_s_prev_year_end
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_BaseOffset __pyx_mstate_global->__pyx_n_s_pyx_unpickle_BaseOffset
#define __pyx_n_s_pyx_unpickle_RelativeDeltaOffs __pyx_mstate_global->__pyx_n_s_pyx_unpickle_RelativeDeltaOffs
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_qlen __pyx_mstate_global->__pyx_n_s_qlen
#define __pyx_n_s_qtr_len __pyx_mstate_global->__pyx_n_s_qtr_len
#define __pyx_n_s_qtr_lens __pyx_mstate_global->__pyx_n_s_qtr_lens
#define __pyx_n_s_qtr_with_extra_week __pyx_mstate_global->__pyx_n_s_qtr_with_extra_week
#define __pyx_n_u_qtr_with_extra_week __pyx_mstate_global->__pyx_n_u_qtr_with_extra_week
#define __pyx_n_s_qtrs __pyx_mstate_global->__pyx_n_s_qtrs
#define __pyx_n_s_qualname __pyx_mstate_global->__pyx_n_s_qualname
#define __pyx_n_s_r __pyx_mstate_global->__pyx_n_s_r
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_re __pyx_mstate_global->__pyx_n_s_re
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce___locals_genexpr __pyx_mstate_global->__pyx_n_s_reduce___locals_genexpr
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_relativedelta __pyx_mstate_global->__pyx_n_s_relativedelta
#define __pyx_n_s_relativedelta_fast __pyx_mstate_global->__pyx_n_s_relativedelta_fast
#define __pyx_n_s_relativedelta_kwds __pyx_mstate_global->__pyx_n_s_relativedelta_kwds
#define __pyx_n_s_rem_nano __pyx_mstate_global->__pyx_n_s_rem_nano
#define __pyx_n_s_remain __pyx_mstate_global->__pyx_n_s_remain
#define __pyx_n_s_replace __pyx_mstate_global->__pyx_n_s_replace
#define __pyx_n_s_repr_attrs __pyx_mstate_global->__pyx_n_s_repr_attrs
#define __pyx_n_s_repr_attrs_locals_genexpr __pyx_mstate_global->__pyx_n_s_repr_attrs_locals_genexpr
#define __pyx_kp_u_requires_a_suffix __pyx_mstate_global->__pyx_kp_u_requires_a_suffix
#define __pyx_n_s_res __pyx_mstate_global->__pyx_n_s_res
#define __pyx_n_s_res_val __pyx_mstate_global->__pyx_n_s_res_val
#define __pyx_n_s_reso __pyx_mstate_global->__pyx_n_s_reso
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_result2 __pyx_mstate_global->__pyx_n_s_result2
#define __pyx_n_s_ret __pyx_mstate_global->__pyx_n_s_ret
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_reversed __pyx_mstate_global->__pyx_n_s_reversed
#define __pyx_n_s_roll __pyx_mstate_global->__pyx_n_s_roll
#define __pyx_n_s_roll_convention __pyx_mstate_global->__pyx_n_s_roll_convention
#define __pyx_n_s_roll_func __pyx_mstate_global->__pyx_n_s_roll_func
#define __pyx_n_s_roll_qtrday __pyx_mstate_global->__pyx_n_s_roll_qtrday
#define __pyx_n_s_rollback __pyx_mstate_global->__pyx_n_s_rollback
#define __pyx_n_s_rollback_to_year __pyx_mstate_global->__pyx_n_s_rollback_to_year
#define __pyx_n_s_rollforward __pyx_mstate_global->__pyx_n_s_rollforward
#define __pyx_n_s_rtruediv __pyx_mstate_global->__pyx_n_s_rtruediv
#define __pyx_n_s_rule_code __pyx_mstate_global->__pyx_n_s_rule_code
#define __pyx_n_s_s __pyx_mstate_global->__pyx_n_s_s
#define __pyx_n_u_s __pyx_mstate_global->__pyx_n_u_s
#define __pyx_n_s_second __pyx_mstate_global->__pyx_n_s_second
#define __pyx_n_u_second __pyx_mstate_global->__pyx_n_u_second
#define __pyx_n_s_seconds __pyx_mstate_global->__pyx_n_s_seconds
#define __pyx_n_u_seconds __pyx_mstate_global->__pyx_n_u_seconds
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_n_s_send __pyx_mstate_global->__pyx_n_s_send
#define __pyx_kp_u_separator_must_be_spaces __pyx_mstate_global->__pyx_kp_u_separator_must_be_spaces
#define __pyx_n_s_set_name __pyx_mstate_global->__pyx_n_s_set_name
#define __pyx_n_s_setattr __pyx_mstate_global->__pyx_n_s_setattr
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_shift_days __pyx_mstate_global->__pyx_n_s_shift_days
#define __pyx_n_s_shift_month __pyx_mstate_global->__pyx_n_s_shift_month
#define __pyx_n_s_shift_months __pyx_mstate_global->__pyx_n_s_shift_months
#define __pyx_n_s_shifted __pyx_mstate_global->__pyx_n_s_shifted
#define __pyx_n_s_sign __pyx_mstate_global->__pyx_n_s_sign
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_s_skip_bd __pyx_mstate_global->__pyx_n_s_skip_bd
#define __pyx_n_s_span __pyx_mstate_global->__pyx_n_s_span
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_st __pyx_mstate_global->__pyx_n_s_st
#define __pyx_n_s_stamp __pyx_mstate_global->__pyx_n_s_stamp
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_u_start __pyx_mstate_global->__pyx_n_u_start
#define __pyx_n_s_startingMonth __pyx_mstate_global->__pyx_n_s_startingMonth
#define __pyx_n_u_startingMonth __pyx_mstate_global->__pyx_n_u_startingMonth
#define __pyx_n_s_startingMonth_code __pyx_mstate_global->__pyx_n_s_startingMonth_code
#define __pyx_n_s_startswith __pyx_mstate_global->__pyx_n_s_startswith
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_staticmethod __pyx_mstate_global->__pyx_n_s_staticmethod
#define __pyx_n_s_str __pyx_mstate_global->__pyx_n_s_str
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_strptime __pyx_mstate_global->__pyx_n_s_strptime
#define __pyx_n_s_subclasscheck __pyx_mstate_global->__pyx_n_s_subclasscheck
#define __pyx_n_s_suffix __pyx_mstate_global->__pyx_n_s_suffix
#define __pyx_n_s_sum __pyx_mstate_global->__pyx_n_s_sum
#define __pyx_n_s_super __pyx_mstate_global->__pyx_n_s_super
#define __pyx_n_s_target_date __pyx_mstate_global->__pyx_n_s_target_date
#define __pyx_n_s_td __pyx_mstate_global->__pyx_n_s_td
#define __pyx_n_s_td64 __pyx_mstate_global->__pyx_n_s_td64
#define __pyx_n_s_td64_unit __pyx_mstate_global->__pyx_n_s_td64_unit
#define __pyx_n_s_td_nano __pyx_mstate_global->__pyx_n_s_td_nano
#define __pyx_n_s_tdelta __pyx_mstate_global->__pyx_n_s_tdelta
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_kp_u_the_add_operation_between __pyx_mstate_global->__pyx_kp_u_the_add_operation_between
#define __pyx_n_s_throw __pyx_mstate_global->__pyx_n_s_throw
#define __pyx_n_s_time __pyx_mstate_global->__pyx_n_s_time
#define __pyx_kp_u_time_data_must_be_specified_only __pyx_mstate_global->__pyx_kp_u_time_data_must_be_specified_only
#define __pyx_kp_u_time_data_must_be_string_or_date __pyx_mstate_global->__pyx_kp_u_time_data_must_be_string_or_date
#define __pyx_kp_u_time_data_must_match_H_M_format __pyx_mstate_global->__pyx_kp_u_time_data_must_match_H_M_format
#define __pyx_n_s_timedelta __pyx_mstate_global->__pyx_n_s_timedelta
#define __pyx_n_s_timedelta64 __pyx_mstate_global->__pyx_n_s_timedelta64
#define __pyx_n_s_timedelta_kwds __pyx_mstate_global->__pyx_n_s_timedelta_kwds
#define __pyx_n_s_timedeltas __pyx_mstate_global->__pyx_n_s_timedeltas
#define __pyx_n_s_timestamps __pyx_mstate_global->__pyx_n_s_timestamps
#define __pyx_n_s_tm_hour __pyx_mstate_global->__pyx_n_s_tm_hour
#define __pyx_n_s_tm_min __pyx_mstate_global->__pyx_n_s_tm_min
#define __pyx_kp_u_to __pyx_mstate_global->__pyx_kp_u_to
#define __pyx_n_s_to_day __pyx_mstate_global->__pyx_n_s_to_day
#define __pyx_n_s_to_offset __pyx_mstate_global->__pyx_n_s_to_offset
#define __pyx_kp_u_to_offset_does_not_support_tuple __pyx_mstate_global->__pyx_kp_u_to_offset_does_not_support_tuple
#define __pyx_kp_u_to_offset_line_4102 __pyx_mstate_global->__pyx_kp_u_to_offset_line_4102
#define __pyx_n_s_to_pydatetime __pyx_mstate_global->__pyx_n_s_to_pydatetime
#define __pyx_n_s_to_pytimedelta __pyx_mstate_global->__pyx_n_s_to_pytimedelta
#define __pyx_n_s_tolist __pyx_mstate_global->__pyx_n_s_tolist
#define __pyx_n_s_total_seconds __pyx_mstate_global->__pyx_n_s_total_seconds
#define __pyx_n_s_truediv __pyx_mstate_global->__pyx_n_s_truediv
#define __pyx_n_s_ts __pyx_mstate_global->__pyx_n_s_ts
#define __pyx_n_s_tup __pyx_mstate_global->__pyx_n_s_tup
#define __pyx_n_s_tz __pyx_mstate_global->__pyx_n_s_tz
#define __pyx_n_s_tz_localize __pyx_mstate_global->__pyx_n_s_tz_localize
#define __pyx_n_s_tzinfo __pyx_mstate_global->__pyx_n_s_tzinfo
#define __pyx_n_u_tzinfo __pyx_mstate_global->__pyx_n_u_tzinfo
#define __pyx_n_u_undefined __pyx_mstate_global->__pyx_n_u_undefined
#define __pyx_n_s_unit __pyx_mstate_global->__pyx_n_s_unit
#define __pyx_n_s_until __pyx_mstate_global->__pyx_n_s_until
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_upper __pyx_mstate_global->__pyx_n_s_upper
#define __pyx_n_u_us __pyx_mstate_global->__pyx_n_u_us
#define __pyx_n_s_use_relativedelta __pyx_mstate_global->__pyx_n_s_use_relativedelta
#define __pyx_n_u_use_relativedelta __pyx_mstate_global->__pyx_n_u_use_relativedelta
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_val __pyx_mstate_global->__pyx_n_s_val
#define __pyx_n_s_validate_n __pyx_mstate_global->__pyx_n_s_validate_n
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_n_s_value_2 __pyx_mstate_global->__pyx_n_s_value_2
#define __pyx_n_s_variation __pyx_mstate_global->__pyx_n_s_variation
#define __pyx_n_u_variation __pyx_mstate_global->__pyx_n_u_variation
#define __pyx_n_s_varion_code __pyx_mstate_global->__pyx_n_s_varion_code
#define __pyx_n_s_vectorized __pyx_mstate_global->__pyx_n_s_vectorized
#define __pyx_n_s_view __pyx_mstate_global->__pyx_n_s_view
#define __pyx_n_s_wday __pyx_mstate_global->__pyx_n_s_wday
#define __pyx_n_s_week __pyx_mstate_global->__pyx_n_s_week
#define __pyx_n_u_week __pyx_mstate_global->__pyx_n_u_week
#define __pyx_n_s_weekday __pyx_mstate_global->__pyx_n_s_weekday
#define __pyx_n_u_weekday __pyx_mstate_global->__pyx_n_u_weekday
#define __pyx_n_s_weekday_code __pyx_mstate_global->__pyx_n_s_weekday_code
#define __pyx_n_s_weekday_to_int __pyx_mstate_global->__pyx_n_s_weekday_to_int
#define __pyx_n_s_weekmask __pyx_mstate_global->__pyx_n_s_weekmask
#define __pyx_n_u_weekmask __pyx_mstate_global->__pyx_n_u_weekmask
#define __pyx_n_s_weeks __pyx_mstate_global->__pyx_n_s_weeks
#define __pyx_n_u_weeks __pyx_mstate_global->__pyx_n_u_weeks
#define __pyx_n_s_weeks_in_year __pyx_mstate_global->__pyx_n_s_weeks_in_year
#define __pyx_kp_u_will_overflow __pyx_mstate_global->__pyx_kp_u_will_overflow
#define __pyx_n_s_wkday_diff __pyx_mstate_global->__pyx_n_s_wkday_diff
#define __pyx_n_s_wrapper __pyx_mstate_global->__pyx_n_s_wrapper
#define __pyx_n_s_year __pyx_mstate_global->__pyx_n_s_year
#define __pyx_n_u_year __pyx_mstate_global->__pyx_n_u_year
#define __pyx_n_s_year_end __pyx_mstate_global->__pyx_n_s_year_end
#define __pyx_n_s_year_has_extra_week __pyx_mstate_global->__pyx_n_s_year_has_extra_week
#define __pyx_n_s_years __pyx_mstate_global->__pyx_n_s_years
#define __pyx_n_u_years __pyx_mstate_global->__pyx_n_u_years
#define __pyx_n_s_zero __pyx_mstate_global->__pyx_n_s_zero
#define __pyx_n_s_zip __pyx_mstate_global->__pyx_n_s_zip
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_4 __pyx_mstate_global->__pyx_int_4
#define __pyx_int_5 __pyx_mstate_global->__pyx_int_5
#define __pyx_int_6 __pyx_mstate_global->__pyx_int_6
#define __pyx_int_7 __pyx_mstate_global->__pyx_int_7
#define __pyx_int_12 __pyx_mstate_global->__pyx_int_12
#define __pyx_int_13 __pyx_mstate_global->__pyx_int_13
#define __pyx_int_14 __pyx_mstate_global->__pyx_int_14
#define __pyx_int_15 __pyx_mstate_global->__pyx_int_15
#define __pyx_int_27 __pyx_mstate_global->__pyx_int_27
#define __pyx_int_52 __pyx_mstate_global->__pyx_int_52
#define __pyx_int_53 __pyx_mstate_global->__pyx_int_53
#define __pyx_int_60 __pyx_mstate_global->__pyx_int_60
#define __pyx_int_1000 __pyx_mstate_global->__pyx_int_1000
#define __pyx_int_2014 __pyx_mstate_global->__pyx_int_2014
#define __pyx_int_3600 __pyx_mstate_global->__pyx_int_3600
#define __pyx_int_86400 __pyx_mstate_global->__pyx_int_86400
#define __pyx_int_1000000 __pyx_mstate_global->__pyx_int_1000000
#define __pyx_int_10844460 __pyx_mstate_global->__pyx_int_10844460
#define __pyx_int_171034093 __pyx_mstate_global->__pyx_int_171034093
#define __pyx_int_213572416 __pyx_mstate_global->__pyx_int_213572416
#define __pyx_int_1000000000 __pyx_mstate_global->__pyx_int_1000000000
#define __pyx_int_60000000000 __pyx_mstate_global->__pyx_int_60000000000
#define __pyx_int_3600000000000 __pyx_mstate_global->__pyx_int_3600000000000
#define __pyx_int_0x4e94914f0000 __pyx_mstate_global->__pyx_int_0x4e94914f0000
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_k__33 __pyx_mstate_global->__pyx_k__33
#define __pyx_k__39 __pyx_mstate_global->__pyx_k__39
#define __pyx_k__40 __pyx_mstate_global->__pyx_k__40
#define __pyx_k__56 __pyx_mstate_global->__pyx_k__56
#define __pyx_k__57 __pyx_mstate_global->__pyx_k__57
#define __pyx_k__58 __pyx_mstate_global->__pyx_k__58
#define __pyx_k__64 __pyx_mstate_global->__pyx_k__64
#define __pyx_tuple_ __pyx_mstate_global->__pyx_tuple_
#define __pyx_tuple__2 __pyx_mstate_global->__pyx_tuple__2
#define __pyx_tuple__3 __pyx_mstate_global->__pyx_tuple__3
#define __pyx_tuple__5 __pyx_mstate_global->__pyx_tuple__5
#define __pyx_tuple__7 __pyx_mstate_global->__pyx_tuple__7
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_slice__53 __pyx_mstate_global->__pyx_slice__53
#define __pyx_slice__60 __pyx_mstate_global->__pyx_slice__60
#define __pyx_slice__61 __pyx_mstate_global->__pyx_slice__61
#define __pyx_slice__62 __pyx_mstate_global->__pyx_slice__62
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__12 __pyx_mstate_global->__pyx_tuple__12
#define __pyx_tuple__14 __pyx_mstate_global->__pyx_tuple__14
#define __pyx_tuple__22 __pyx_mstate_global->__pyx_tuple__22
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__25 __pyx_mstate_global->__pyx_tuple__25
#define __pyx_tuple__26 __pyx_mstate_global->__pyx_tuple__26
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__28 __pyx_mstate_global->__pyx_tuple__28
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__30 __pyx_mstate_global->__pyx_tuple__30
#define __pyx_tuple__31 __pyx_mstate_global->__pyx_tuple__31
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__42 __pyx_mstate_global->__pyx_tuple__42
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__44 __pyx_mstate_global->__pyx_tuple__44
#define __pyx_tuple__45 __pyx_mstate_global->__pyx_tuple__45
#define __pyx_tuple__48 __pyx_mstate_global->__pyx_tuple__48
#define __pyx_tuple__49 __pyx_mstate_global->__pyx_tuple__49
#define __pyx_tuple__50 __pyx_mstate_global->__pyx_tuple__50
#define __pyx_tuple__51 __pyx_mstate_global->__pyx_tuple__51
#define __pyx_tuple__52 __pyx_mstate_global->__pyx_tuple__52
#define __pyx_tuple__54 __pyx_mstate_global->__pyx_tuple__54
#define __pyx_tuple__55 __pyx_mstate_global->__pyx_tuple__55
#define __pyx_tuple__59 __pyx_mstate_global->__pyx_tuple__59
#define __pyx_tuple__63 __pyx_mstate_global->__pyx_tuple__63
#define __pyx_tuple__65 __pyx_mstate_global->__pyx_tuple__65
#define __pyx_tuple__66 __pyx_mstate_global->__pyx_tuple__66
#define __pyx_tuple__68 __pyx_mstate_global->__pyx_tuple__68
#define __pyx_tuple__70 __pyx_mstate_global->__pyx_tuple__70
#define __pyx_tuple__73 __pyx_mstate_global->__pyx_tuple__73
#define __pyx_tuple__74 __pyx_mstate_global->__pyx_tuple__74
#define __pyx_tuple__75 __pyx_mstate_global->__pyx_tuple__75
#define __pyx_tuple__77 __pyx_mstate_global->__pyx_tuple__77
#define __pyx_tuple__79 __pyx_mstate_global->__pyx_tuple__79
#define __pyx_tuple__81 __pyx_mstate_global->__pyx_tuple__81
#define __pyx_tuple__84 __pyx_mstate_global->__pyx_tuple__84
#define __pyx_tuple__86 __pyx_mstate_global->__pyx_tuple__86
#define __pyx_tuple__88 __pyx_mstate_global->__pyx_tuple__88
#define __pyx_tuple__91 __pyx_mstate_global->__pyx_tuple__91
#define __pyx_tuple__93 __pyx_mstate_global->__pyx_tuple__93
#define __pyx_tuple__95 __pyx_mstate_global->__pyx_tuple__95
#define __pyx_tuple__97 __pyx_mstate_global->__pyx_tuple__97
#define __pyx_codeobj__6 __pyx_mstate_global->__pyx_codeobj__6
#define __pyx_codeobj__8 __pyx_mstate_global->__pyx_codeobj__8
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__108 __pyx_mstate_global->__pyx_tuple__108
#define __pyx_tuple__110 __pyx_mstate_global->__pyx_tuple__110
#define __pyx_tuple__112 __pyx_mstate_global->__pyx_tuple__112
#define __pyx_tuple__114 __pyx_mstate_global->__pyx_tuple__114
#define __pyx_tuple__115 __pyx_mstate_global->__pyx_tuple__115
#define __pyx_tuple__123 __pyx_mstate_global->__pyx_tuple__123
#define __pyx_tuple__127 __pyx_mstate_global->__pyx_tuple__127
#define __pyx_tuple__129 __pyx_mstate_global->__pyx_tuple__129
#define __pyx_tuple__134 __pyx_mstate_global->__pyx_tuple__134
#define __pyx_tuple__137 __pyx_mstate_global->__pyx_tuple__137
#define __pyx_tuple__139 __pyx_mstate_global->__pyx_tuple__139
#define __pyx_tuple__141 __pyx_mstate_global->__pyx_tuple__141
#define __pyx_tuple__145 __pyx_mstate_global->__pyx_tuple__145
#define __pyx_tuple__147 __pyx_mstate_global->__pyx_tuple__147
#define __pyx_tuple__149 __pyx_mstate_global->__pyx_tuple__149
#define __pyx_tuple__153 __pyx_mstate_global->__pyx_tuple__153
#define __pyx_tuple__155 __pyx_mstate_global->__pyx_tuple__155
#define __pyx_tuple__157 __pyx_mstate_global->__pyx_tuple__157
#define __pyx_tuple__159 __pyx_mstate_global->__pyx_tuple__159
#define __pyx_tuple__161 __pyx_mstate_global->__pyx_tuple__161
#define __pyx_tuple__166 __pyx_mstate_global->__pyx_tuple__166
#define __pyx_tuple__169 __pyx_mstate_global->__pyx_tuple__169
#define __pyx_tuple__171 __pyx_mstate_global->__pyx_tuple__171
#define __pyx_tuple__175 __pyx_mstate_global->__pyx_tuple__175
#define __pyx_tuple__179 __pyx_mstate_global->__pyx_tuple__179
#define __pyx_tuple__181 __pyx_mstate_global->__pyx_tuple__181
#define __pyx_tuple__186 __pyx_mstate_global->__pyx_tuple__186
#define __pyx_tuple__188 __pyx_mstate_global->__pyx_tuple__188
#define __pyx_tuple__192 __pyx_mstate_global->__pyx_tuple__192
#define __pyx_tuple__198 __pyx_mstate_global->__pyx_tuple__198
#define __pyx_tuple__200 __pyx_mstate_global->__pyx_tuple__200
#define __pyx_tuple__202 __pyx_mstate_global->__pyx_tuple__202
#define __pyx_tuple__207 __pyx_mstate_global->__pyx_tuple__207
#define __pyx_tuple__209 __pyx_mstate_global->__pyx_tuple__209
#define __pyx_tuple__212 __pyx_mstate_global->__pyx_tuple__212
#define __pyx_tuple__215 __pyx_mstate_global->__pyx_tuple__215
#define __pyx_tuple__217 __pyx_mstate_global->__pyx_tuple__217
#define __pyx_tuple__220 __pyx_mstate_global->__pyx_tuple__220
#define __pyx_tuple__226 __pyx_mstate_global->__pyx_tuple__226
#define __pyx_tuple__228 __pyx_mstate_global->__pyx_tuple__228
#define __pyx_tuple__230 __pyx_mstate_global->__pyx_tuple__230
#define __pyx_tuple__232 __pyx_mstate_global->__pyx_tuple__232
#define __pyx_tuple__234 __pyx_mstate_global->__pyx_tuple__234
#define __pyx_tuple__236 __pyx_mstate_global->__pyx_tuple__236
#define __pyx_tuple__240 __pyx_mstate_global->__pyx_tuple__240
#define __pyx_tuple__242 __pyx_mstate_global->__pyx_tuple__242
#define __pyx_tuple__244 __pyx_mstate_global->__pyx_tuple__244
#define __pyx_tuple__246 __pyx_mstate_global->__pyx_tuple__246
#define __pyx_tuple__248 __pyx_mstate_global->__pyx_tuple__248
#define __pyx_tuple__252 __pyx_mstate_global->__pyx_tuple__252
#define __pyx_tuple__256 __pyx_mstate_global->__pyx_tuple__256
#define __pyx_tuple__258 __pyx_mstate_global->__pyx_tuple__258
#define __pyx_tuple__260 __pyx_mstate_global->__pyx_tuple__260
#define __pyx_tuple__262 __pyx_mstate_global->__pyx_tuple__262
#define __pyx_tuple__264 __pyx_mstate_global->__pyx_tuple__264
#define __pyx_tuple__266 __pyx_mstate_global->__pyx_tuple__266
#define __pyx_tuple__268 __pyx_mstate_global->__pyx_tuple__268
#define __pyx_tuple__269 __pyx_mstate_global->__pyx_tuple__269
#define __pyx_tuple__271 __pyx_mstate_global->__pyx_tuple__271
#define __pyx_tuple__273 __pyx_mstate_global->__pyx_tuple__273
#define __pyx_tuple__275 __pyx_mstate_global->__pyx_tuple__275
#define __pyx_tuple__277 __pyx_mstate_global->__pyx_tuple__277
#define __pyx_tuple__279 __pyx_mstate_global->__pyx_tuple__279
#define __pyx_tuple__281 __pyx_mstate_global->__pyx_tuple__281
#define __pyx_codeobj__35 __pyx_mstate_global->__pyx_codeobj__35
#define __pyx_codeobj__69 __pyx_mstate_global->__pyx_codeobj__69
#define __pyx_codeobj__71 __pyx_mstate_global->__pyx_codeobj__71
#define __pyx_codeobj__72 __pyx_mstate_global->__pyx_codeobj__72
#define __pyx_codeobj__76 __pyx_mstate_global->__pyx_codeobj__76
#define __pyx_codeobj__78 __pyx_mstate_global->__pyx_codeobj__78
#define __pyx_codeobj__80 __pyx_mstate_global->__pyx_codeobj__80
#define __pyx_codeobj__82 __pyx_mstate_global->__pyx_codeobj__82
#define __pyx_codeobj__83 __pyx_mstate_global->__pyx_codeobj__83
#define __pyx_codeobj__85 __pyx_mstate_global->__pyx_codeobj__85
#define __pyx_codeobj__87 __pyx_mstate_global->__pyx_codeobj__87
#define __pyx_codeobj__89 __pyx_mstate_global->__pyx_codeobj__89
#define __pyx_codeobj__90 __pyx_mstate_global->__pyx_codeobj__90
#define __pyx_codeobj__92 __pyx_mstate_global->__pyx_codeobj__92
#define __pyx_codeobj__94 __pyx_mstate_global->__pyx_codeobj__94
#define __pyx_codeobj__96 __pyx_mstate_global->__pyx_codeobj__96
#define __pyx_codeobj__98 __pyx_mstate_global->__pyx_codeobj__98
#define __pyx_codeobj__99 __pyx_mstate_global->__pyx_codeobj__99
#define __pyx_codeobj__100 __pyx_mstate_global->__pyx_codeobj__100
#define __pyx_codeobj__102 __pyx_mstate_global->__pyx_codeobj__102
#define __pyx_codeobj__103 __pyx_mstate_global->__pyx_codeobj__103
#define __pyx_codeobj__104 __pyx_mstate_global->__pyx_codeobj__104
#define __pyx_codeobj__105 __pyx_mstate_global->__pyx_codeobj__105
#define __pyx_codeobj__106 __pyx_mstate_global->__pyx_codeobj__106
#define __pyx_codeobj__107 __pyx_mstate_global->__pyx_codeobj__107
#define __pyx_codeobj__109 __pyx_mstate_global->__pyx_codeobj__109
#define __pyx_codeobj__111 __pyx_mstate_global->__pyx_codeobj__111
#define __pyx_codeobj__113 __pyx_mstate_global->__pyx_codeobj__113
#define __pyx_codeobj__116 __pyx_mstate_global->__pyx_codeobj__116
#define __pyx_codeobj__117 __pyx_mstate_global->__pyx_codeobj__117
#define __pyx_codeobj__118 __pyx_mstate_global->__pyx_codeobj__118
#define __pyx_codeobj__119 __pyx_mstate_global->__pyx_codeobj__119
#define __pyx_codeobj__120 __pyx_mstate_global->__pyx_codeobj__120
#define __pyx_codeobj__121 __pyx_mstate_global->__pyx_codeobj__121
#define __pyx_codeobj__122 __pyx_mstate_global->__pyx_codeobj__122
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__125 __pyx_mstate_global->__pyx_codeobj__125
#define __pyx_codeobj__126 __pyx_mstate_global->__pyx_codeobj__126
#define __pyx_codeobj__128 __pyx_mstate_global->__pyx_codeobj__128
#define __pyx_codeobj__130 __pyx_mstate_global->__pyx_codeobj__130
#define __pyx_codeobj__131 __pyx_mstate_global->__pyx_codeobj__131
#define __pyx_codeobj__132 __pyx_mstate_global->__pyx_codeobj__132
#define __pyx_codeobj__133 __pyx_mstate_global->__pyx_codeobj__133
#define __pyx_codeobj__135 __pyx_mstate_global->__pyx_codeobj__135
#define __pyx_codeobj__136 __pyx_mstate_global->__pyx_codeobj__136
#define __pyx_codeobj__138 __pyx_mstate_global->__pyx_codeobj__138
#define __pyx_codeobj__140 __pyx_mstate_global->__pyx_codeobj__140
#define __pyx_codeobj__142 __pyx_mstate_global->__pyx_codeobj__142
#define __pyx_codeobj__143 __pyx_mstate_global->__pyx_codeobj__143
#define __pyx_codeobj__144 __pyx_mstate_global->__pyx_codeobj__144
#define __pyx_codeobj__146 __pyx_mstate_global->__pyx_codeobj__146
#define __pyx_codeobj__148 __pyx_mstate_global->__pyx_codeobj__148
#define __pyx_codeobj__150 __pyx_mstate_global->__pyx_codeobj__150
#define __pyx_codeobj__151 __pyx_mstate_global->__pyx_codeobj__151
#define __pyx_codeobj__152 __pyx_mstate_global->__pyx_codeobj__152
#define __pyx_codeobj__154 __pyx_mstate_global->__pyx_codeobj__154
#define __pyx_codeobj__156 __pyx_mstate_global->__pyx_codeobj__156
#define __pyx_codeobj__158 __pyx_mstate_global->__pyx_codeobj__158
#define __pyx_codeobj__160 __pyx_mstate_global->__pyx_codeobj__160
#define __pyx_codeobj__162 __pyx_mstate_global->__pyx_codeobj__162
#define __pyx_codeobj__163 __pyx_mstate_global->__pyx_codeobj__163
#define __pyx_codeobj__164 __pyx_mstate_global->__pyx_codeobj__164
#define __pyx_codeobj__165 __pyx_mstate_global->__pyx_codeobj__165
#define __pyx_codeobj__167 __pyx_mstate_global->__pyx_codeobj__167
#define __pyx_codeobj__168 __pyx_mstate_global->__pyx_codeobj__168
#define __pyx_codeobj__170 __pyx_mstate_global->__pyx_codeobj__170
#define __pyx_codeobj__172 __pyx_mstate_global->__pyx_codeobj__172
#define __pyx_codeobj__173 __pyx_mstate_global->__pyx_codeobj__173
#define __pyx_codeobj__174 __pyx_mstate_global->__pyx_codeobj__174
#define __pyx_codeobj__176 __pyx_mstate_global->__pyx_codeobj__176
#define __pyx_codeobj__177 __pyx_mstate_global->__pyx_codeobj__177
#define __pyx_codeobj__178 __pyx_mstate_global->__pyx_codeobj__178
#define __pyx_codeobj__180 __pyx_mstate_global->__pyx_codeobj__180
#define __pyx_codeobj__182 __pyx_mstate_global->__pyx_codeobj__182
#define __pyx_codeobj__183 __pyx_mstate_global->__pyx_codeobj__183
#define __pyx_codeobj__184 __pyx_mstate_global->__pyx_codeobj__184
#define __pyx_codeobj__185 __pyx_mstate_global->__pyx_codeobj__185
#define __pyx_codeobj__187 __pyx_mstate_global->__pyx_codeobj__187
#define __pyx_codeobj__189 __pyx_mstate_global->__pyx_codeobj__189
#define __pyx_codeobj__190 __pyx_mstate_global->__pyx_codeobj__190
#define __pyx_codeobj__191 __pyx_mstate_global->__pyx_codeobj__191
#define __pyx_codeobj__193 __pyx_mstate_global->__pyx_codeobj__193
#define __pyx_codeobj__194 __pyx_mstate_global->__pyx_codeobj__194
#define __pyx_codeobj__195 __pyx_mstate_global->__pyx_codeobj__195
#define __pyx_codeobj__196 __pyx_mstate_global->__pyx_codeobj__196
#define __pyx_codeobj__197 __pyx_mstate_global->__pyx_codeobj__197
#define __pyx_codeobj__199 __pyx_mstate_global->__pyx_codeobj__199
#define __pyx_codeobj__201 __pyx_mstate_global->__pyx_codeobj__201
#define __pyx_codeobj__203 __pyx_mstate_global->__pyx_codeobj__203
#define __pyx_codeobj__204 __pyx_mstate_global->__pyx_codeobj__204
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__206 __pyx_mstate_global->__pyx_codeobj__206
#define __pyx_codeobj__208 __pyx_mstate_global->__pyx_codeobj__208
#define __pyx_codeobj__210 __pyx_mstate_global->__pyx_codeobj__210
#define __pyx_codeobj__211 __pyx_mstate_global->__pyx_codeobj__211
#define __pyx_codeobj__213 __pyx_mstate_global->__pyx_codeobj__213
#define __pyx_codeobj__214 __pyx_mstate_global->__pyx_codeobj__214
#define __pyx_codeobj__216 __pyx_mstate_global->__pyx_codeobj__216
#define __pyx_codeobj__218 __pyx_mstate_global->__pyx_codeobj__218
#define __pyx_codeobj__219 __pyx_mstate_global->__pyx_codeobj__219
#define __pyx_codeobj__221 __pyx_mstate_global->__pyx_codeobj__221
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__223 __pyx_mstate_global->__pyx_codeobj__223
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__225 __pyx_mstate_global->__pyx_codeobj__225
#define __pyx_codeobj__227 __pyx_mstate_global->__pyx_codeobj__227
#define __pyx_codeobj__229 __pyx_mstate_global->__pyx_codeobj__229
#define __pyx_codeobj__231 __pyx_mstate_global->__pyx_codeobj__231
#define __pyx_codeobj__233 __pyx_mstate_global->__pyx_codeobj__233
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__237 __pyx_mstate_global->__pyx_codeobj__237
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__241 __pyx_mstate_global->__pyx_codeobj__241
#define __pyx_codeobj__243 __pyx_mstate_global->__pyx_codeobj__243
#define __pyx_codeobj__245 __pyx_mstate_global->__pyx_codeobj__245
#define __pyx_codeobj__247 __pyx_mstate_global->__pyx_codeobj__247
#define __pyx_codeobj__249 __pyx_mstate_global->__pyx_codeobj__249
#define __pyx_codeobj__250 __pyx_mstate_global->__pyx_codeobj__250
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__254 __pyx_mstate_global->__pyx_codeobj__254
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__259 __pyx_mstate_global->__pyx_codeobj__259
#define __pyx_codeobj__261 __pyx_mstate_global->__pyx_codeobj__261
#define __pyx_codeobj__263 __pyx_mstate_global->__pyx_codeobj__263
#define __pyx_codeobj__265 __pyx_mstate_global->__pyx_codeobj__265
#define __pyx_codeobj__267 __pyx_mstate_global->__pyx_codeobj__267
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__274 __pyx_mstate_global->__pyx_codeobj__274
#define __pyx_codeobj__276 __pyx_mstate_global->__pyx_codeobj__276
#define __pyx_codeobj__278 __pyx_mstate_global->__pyx_codeobj__278
#define __pyx_codeobj__280 __pyx_mstate_global->__pyx_codeobj__280
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__283 __pyx_mstate_global->__pyx_codeobj__283
/* #### Code section: module_code ### */

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self) {
  PyObject *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":248
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 *             return PyArray_BASE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_BASE(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self) {
  PyArray_Descr *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyArray_Descr *__pyx_t_1;
  __Pyx_RefNannySetupContext("descr", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":254
 *             """Returns an owned reference to the dtype of the array.
 *             """
 *             return <dtype>PyArray_DESCR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyArray_DESCR(__pyx_v_self);
  __Pyx_INCREF((PyObject *)((PyArray_Descr *)__pyx_t_1));
  __pyx_r = ((PyArray_Descr *)__pyx_t_1);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":260
 *             """Returns the number of dimensions in the array.
 *             """
 *             return PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_NDIM(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":268
 *             Can return NULL for 0-dimensional arrays.
 *             """
 *             return PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_DIMS(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":275
 *             The number of elements matches the number of dimensions of the array (ndim).
 *             """
 *             return PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_STRIDES(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":281
 *             """Returns the total size (in number of elements) of the array.
 *             """
 *             return PyArray_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_SIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self) {
  char *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":290
 *             of `PyArray_DATA()` instead, which returns a 'void*'.
 *             """
 *             return PyArray_BYTES(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef unsigned char      npy_bool
 */
  __pyx_r = PyArray_BYTES(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":783
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":786
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = PyDataType_HASSUBARRAY(__pyx_v_d);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":790
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":792
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":968
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":969
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":970
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_t_1 = PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(1, 970, __pyx_L1_error)

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":968
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("numpy.set_array_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":972
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":973
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":974
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = (__pyx_v_base == NULL);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":975
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":974
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":976
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":972
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":980
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":982
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 982, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":983
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 983, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":984
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 984, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 984, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":980
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":986
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":988
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 988, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":989
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 989, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":990
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 990, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 990, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":986
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":992
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":994
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 994, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":995
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 995, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":996
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 996, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(1, 996, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":992
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":999
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1011
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":999
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1014
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1026
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1014
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1036
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1039
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1043
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1039
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1046
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1050
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1046
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":72
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":73
 *         @property
 *         cdef inline int year(self):
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":72
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":76
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":77
 *         @property
 *         cdef inline int month(self):
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":76
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":80
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":81
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 */
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":80
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":85
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":86
 *         @property
 *         cdef inline int hour(self):
 *             return PyDateTime_TIME_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":85
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":89
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":90
 *         @property
 *         cdef inline int minute(self):
 *             return PyDateTime_TIME_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":89
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":93
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":94
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_TIME_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":93
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":97
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":98
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_TIME_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":97
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":101
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 1);

  /* "cpython/datetime.pxd":102
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":101
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":105
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":107
 *         cdef inline int fold(self):
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 */
  __pyx_r = PyDateTime_TIME_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":105
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":111
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":112
 *         @property
 *         cdef inline int year(self):
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":111
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property
 *         cdef inline int year(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_YEAR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":115
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":116
 *         @property
 *         cdef inline int month(self):
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":115
 * 
 *         @property
 *         cdef inline int month(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_MONTH(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":119
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":120
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":119
 * 
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_GET_DAY(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":123
 * 
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":124
 *         @property
 *         cdef inline int hour(self):
 *             return PyDateTime_DATE_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":123
 * 
 *         @property
 *         cdef inline int hour(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":127
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":128
 *         @property
 *         cdef inline int minute(self):
 *             return PyDateTime_DATE_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":127
 * 
 *         @property
 *         cdef inline int minute(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":131
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":132
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_DATE_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":131
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":135
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":136
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_DATE_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":135
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":139
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 1);

  /* "cpython/datetime.pxd":140
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":139
 * 
 *         @property
 *         cdef inline object tzinfo(self):             # <<<<<<<<<<<<<<
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":143
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":145
 *         cdef inline int fold(self):
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 */
  __pyx_r = PyDateTime_DATE_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":143
 * 
 *         @property
 *         cdef inline int fold(self):             # <<<<<<<<<<<<<<
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":149
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":150
 *         @property
 *         cdef inline int day(self):
 *             return PyDateTime_DELTA_GET_DAYS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":149
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property
 *         cdef inline int day(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":153
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":154
 *         @property
 *         cdef inline int second(self):
 *             return PyDateTime_DELTA_GET_SECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":153
 * 
 *         @property
 *         cdef inline int second(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":157
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "cpython/datetime.pxd":158
 *         @property
 *         cdef inline int microsecond(self):
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.tzinfo[object PyDateTime_TZInfo]:
 */
  __pyx_r = PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":157
 * 
 *         @property
 *         cdef inline int microsecond(self):             # <<<<<<<<<<<<<<
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":282
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {

  /* "cpython/datetime.pxd":283
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
 */
  (void)(PyDateTime_IMPORT);

  /* "cpython/datetime.pxd":282
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime():             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
 */

  /* function exit code */
}

/* "cpython/datetime.pxd":287
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 1);

  /* "cpython/datetime.pxd":288
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Date *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":287
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */

static CYTHON_INLINE PyDateTime_Time *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_time_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_Time *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "cpython/datetime.pxd":293
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_TimeWithFold(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_time))))) __PYX_ERR(2, 293, __pyx_L1_error)
  __pyx_r = ((PyDateTime_Time *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":292
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_datetime_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "cpython/datetime.pxd":298
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_DateTimeWithFold(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":297
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":302
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

static CYTHON_INLINE PyDateTime_Delta *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyDateTime_Delta *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 1);

  /* "cpython/datetime.pxd":303
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Delta *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":302
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timezone_new(PyObject *__pyx_v_offset, struct __pyx_opt_args_7cpython_8datetime_timezone_new *__pyx_optional_args) {
  PyObject *__pyx_v_name = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timezone_new", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_name = __pyx_optional_args->name;
    }
  }

  /* "cpython/datetime.pxd":307
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 */
  __pyx_t_1 = (PY_VERSION_HEX < 0x030700b1);
  if (unlikely(__pyx_t_1)) {

    /* "cpython/datetime.pxd":308
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 308, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 308, __pyx_L1_error)

    /* "cpython/datetime.pxd":307
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 */
  }

  /* "cpython/datetime.pxd":309
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DB API constructor.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (__pyx_v_name != Py_None);
  if (__pyx_t_1) {
    __pyx_t_3 = ((PyObject *)__pyx_v_name);
  } else {
    __pyx_t_3 = NULL;
  }
  __pyx_t_2 = __Pyx_TimeZone_FromOffsetAndName(__pyx_v_offset, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":306
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.timezone_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_from_timestamp(PyObject *__pyx_v_timestamp, struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp *__pyx_optional_args) {
  PyObject *__pyx_v_tz = ((PyObject *)Py_None);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_from_timestamp", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_tz = __pyx_optional_args->tz;
    }
  }

  /* "cpython/datetime.pxd":313
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);

  /* "cpython/datetime.pxd":314
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DB API constructor.
 */
  __pyx_t_2 = (__pyx_v_tz != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp)) __PYX_ERR(2, 314, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_tz);
    __Pyx_GIVEREF(__pyx_v_tz);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_tz)) __PYX_ERR(2, 314, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp)) __PYX_ERR(2, 314, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "cpython/datetime.pxd":313
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
 */
  __pyx_t_3 = ((PyObject *)PyDateTimeAPI->DateTime_FromTimestamp(((PyObject *)PyDateTimeAPI->DateTimeType), __pyx_t_1, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":312
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.datetime.datetime_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":317
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
 */

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_from_timestamp(PyObject *__pyx_v_timestamp) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_from_timestamp", 1);

  /* "cpython/datetime.pxd":318
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_timestamp);
  __Pyx_GIVEREF(__pyx_v_timestamp);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_timestamp)) __PYX_ERR(2, 318, __pyx_L1_error);
  __pyx_t_2 = ((PyObject *)PyDateTimeAPI->Date_FromTimestamp(((PyObject *)PyDateTimeAPI->DateType), __pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_Date *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":317
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.date_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":326
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_get_utc(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_utc", 1);

  /* "cpython/datetime.pxd":327
 * # Get UTC singleton
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC
 */
  __pyx_t_1 = (PY_VERSION_HEX < 0x030700b1);
  if (unlikely(__pyx_t_1)) {

    /* "cpython/datetime.pxd":328
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return <object>__Pyx_TimeZone_UTC
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 328, __pyx_L1_error)

    /* "cpython/datetime.pxd":327
 * # Get UTC singleton
 * cdef inline object get_utc():
 *     if PY_VERSION_HEX < 0x030700b1:             # <<<<<<<<<<<<<<
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC
 */
  }

  /* "cpython/datetime.pxd":329
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 *     return <object>__Pyx_TimeZone_UTC             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of time
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__Pyx_TimeZone_UTC));
  __pyx_r = ((PyObject *)__Pyx_TimeZone_UTC);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":326
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.get_utc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":332
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 1);

  /* "cpython/datetime.pxd":333
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":332
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":336
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 1);

  /* "cpython/datetime.pxd":337
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":336
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cpython/datetime.pxd":340
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":341
 * # Get year of date
 * cdef inline int date_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":340
 * 
 * # Get year of date
 * cdef inline int date_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":344
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":345
 * # Get month of date
 * cdef inline int date_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":344
 * 
 * # Get month of date
 * cdef inline int date_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":348
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":349
 * # Get day of date
 * cdef inline int date_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":348
 * 
 * # Get day of date
 * cdef inline int date_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":352
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":353
 * # Get year of datetime
 * cdef inline int datetime_year(object o):
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
 */
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":352
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":356
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":357
 * # Get month of datetime
 * cdef inline int datetime_month(object o):
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
 */
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":356
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":360
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":361
 * # Get day of datetime
 * cdef inline int datetime_day(object o):
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
 */
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":360
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":364
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":365
 * # Get hour of time
 * cdef inline int time_hour(object o):
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
 */
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":364
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":368
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":369
 * # Get minute of time
 * cdef inline int time_minute(object o):
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
 */
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":368
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":372
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":373
 * # Get second of time
 * cdef inline int time_second(object o):
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
 */
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":372
 * 
 * # Get second of time
 * cdef inline int time_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":376
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":377
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of time
 */
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":376
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":380
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_fold(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":382
 * cdef inline int time_fold(object o):
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
 */
  __pyx_r = PyDateTime_TIME_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":380
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":385
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":386
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":385
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":389
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":390
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":389
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":393
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":394
 * # Get second of datetime
 * cdef inline int datetime_second(object o):
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":393
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":397
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":398
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of datetime
 */
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":397
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o):             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":401
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_fold(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":403
 * cdef inline int datetime_fold(object o):
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
 */
  __pyx_r = PyDateTime_DATE_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "cpython/datetime.pxd":401
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o):             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":406
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":407
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):
 *     return (<PyDateTime_Delta*>o).days             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->days;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":406
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).days
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":410
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":411
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):
 *     return (<PyDateTime_Delta*>o).seconds             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->seconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":410
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).seconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":414
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 */

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "cpython/datetime.pxd":415
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):
 *     return (<PyDateTime_Delta*>o).microseconds             # <<<<<<<<<<<<<<
 * 
 * cdef inline double total_seconds(timedelta obj):
 */
  __pyx_r = ((PyDateTime_Delta *)__pyx_v_o)->microseconds;
  goto __pyx_L0;

  /* "cpython/datetime.pxd":414
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o):             # <<<<<<<<<<<<<<
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "cpython/datetime.pxd":417
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 * cdef inline double total_seconds(timedelta obj):             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
 */

static CYTHON_INLINE double __pyx_f_7cpython_8datetime_total_seconds(PyDateTime_Delta *__pyx_v_obj) {
  double __pyx_v_days;
  double __pyx_v_seconds;
  double __pyx_v_micros;
  double __pyx_r;

  /* "cpython/datetime.pxd":423
 *     cdef:
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)             # <<<<<<<<<<<<<<
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 */
  __pyx_v_days = ((double)PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_obj)));

  /* "cpython/datetime.pxd":424
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)             # <<<<<<<<<<<<<<
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
 */
  __pyx_v_seconds = ((double)PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_obj)));

  /* "cpython/datetime.pxd":425
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)             # <<<<<<<<<<<<<<
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
 */
  __pyx_v_micros = ((double)PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_obj)));

  /* "cpython/datetime.pxd":426
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((((__pyx_v_days * 24.0) * 3600.0) + __pyx_v_seconds) + (__pyx_v_micros / 1000000.0));
  goto __pyx_L0;

  /* "cpython/datetime.pxd":417
 *     return (<PyDateTime_Delta*>o).microseconds
 * 
 * cdef inline double total_seconds(timedelta obj):             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":46
 * 
 * 
 * cdef inline int64_t get_nat():             # <<<<<<<<<<<<<<
 *     return NPY_MIN_INT64
 * 
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_6pandas_5_libs_6tslibs_4util_get_nat(void) {
  __pyx_t_5numpy_int64_t __pyx_r;

  /* "util.pxd":47
 * 
 * cdef inline int64_t get_nat():
 *     return NPY_MIN_INT64             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = NPY_MIN_INT64;
  goto __pyx_L0;

  /* "util.pxd":46
 * 
 * 
 * cdef inline int64_t get_nat():             # <<<<<<<<<<<<<<
 *     return NPY_MIN_INT64
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":53
 * # Type Checking
 * 
 * cdef inline bint is_integer_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "util.pxd":71
 *     This counts np.timedelta64 objects as integers.
 *     """
 *     return (not PyBool_Check(obj) and PyArray_IsIntegerScalar(obj)             # <<<<<<<<<<<<<<
 *             and not is_timedelta64_object(obj))
 * 
 */
  __pyx_t_2 = (!PyBool_Check(__pyx_v_obj));
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "util.pxd":72
 *     """
 *     return (not PyBool_Check(obj) and PyArray_IsIntegerScalar(obj)
 *             and not is_timedelta64_object(obj))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyArray_IsIntegerScalar(__pyx_v_obj);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(3, 72, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":53
 * # Type Checking
 * 
 * cdef inline bint is_integer_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_integer_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":75
 * 
 * 
 * cdef inline bint is_float_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (float, np.float_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "util.pxd":87
 *     is_float : bool
 *     """
 *     return (PyFloat_Check(obj) or             # <<<<<<<<<<<<<<
 *             (PyObject_TypeCheck(obj, &PyFloatingArrType_Type)))
 * 
 */
  __pyx_t_2 = PyFloat_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "util.pxd":88
 *     """
 *     return (PyFloat_Check(obj) or
 *             (PyObject_TypeCheck(obj, &PyFloatingArrType_Type)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyFloatingArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":75
 * 
 * 
 * cdef inline bint is_float_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (float, np.float_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":91
 * 
 * 
 * cdef inline bint is_complex_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (complex, np.complex_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "util.pxd":103
 *     is_complex : bool
 *     """
 *     return (PyComplex_Check(obj) or             # <<<<<<<<<<<<<<
 *             PyObject_TypeCheck(obj, &PyComplexFloatingArrType_Type))
 * 
 */
  __pyx_t_2 = PyComplex_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "util.pxd":104
 *     """
 *     return (PyComplex_Check(obj) or
 *             PyObject_TypeCheck(obj, &PyComplexFloatingArrType_Type))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyComplexFloatingArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":91
 * 
 * 
 * cdef inline bint is_complex_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (complex, np.complex_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":107
 * 
 * 
 * cdef inline bint is_bool_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (bool, np.bool_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "util.pxd":119
 *     is_bool : bool
 *     """
 *     return (PyBool_Check(obj) or             # <<<<<<<<<<<<<<
 *             PyObject_TypeCheck(obj, &PyBoolArrType_Type))
 * 
 */
  __pyx_t_2 = PyBool_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "util.pxd":120
 *     """
 *     return (PyBool_Check(obj) or
 *             PyObject_TypeCheck(obj, &PyBoolArrType_Type))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyBoolArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":107
 * 
 * 
 * cdef inline bint is_bool_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (bool, np.bool_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":123
 * 
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)
 * 
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_real_number_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "util.pxd":124
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(3, 124, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(3, 124, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(3, 124, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":123
 * 
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_real_number_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":127
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "util.pxd":139
 *     is_timedelta64 : bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "util.pxd":127
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":142
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "util.pxd":154
 *     is_datetime64 : bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "util.pxd":142
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":157
 * 
 * 
 * cdef inline bint is_array(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.ndarray)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_array(PyObject *__pyx_v_val) {
  int __pyx_r;

  /* "util.pxd":169
 *     is_ndarray : bool
 *     """
 *     return PyArray_Check(val)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyArray_Check(__pyx_v_val);
  goto __pyx_L0;

  /* "util.pxd":157
 * 
 * 
 * cdef inline bint is_array(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.ndarray)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":172
 * 
 * 
 * cdef inline bint is_nan(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Check if val is a Not-A-Number float or complex, including
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_nan(PyObject *__pyx_v_val) {
  __pyx_t_5numpy_float64_t __pyx_v_fval;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_float64_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_nan", 1);

  /* "util.pxd":186
 *     """
 *     cdef float64_t fval
 *     if is_float_object(val):             # <<<<<<<<<<<<<<
 *         fval = val
 *         return fval != fval
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(__pyx_v_val); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(3, 186, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "util.pxd":187
 *     cdef float64_t fval
 *     if is_float_object(val):
 *         fval = val             # <<<<<<<<<<<<<<
 *         return fval != fval
 *     return is_complex_object(val) and val != val
 */
    __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_val); if (unlikely((__pyx_t_2 == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(3, 187, __pyx_L1_error)
    __pyx_v_fval = __pyx_t_2;

    /* "util.pxd":188
 *     if is_float_object(val):
 *         fval = val
 *         return fval != fval             # <<<<<<<<<<<<<<
 *     return is_complex_object(val) and val != val
 * 
 */
    __pyx_r = (__pyx_v_fval != __pyx_v_fval);
    goto __pyx_L0;

    /* "util.pxd":186
 *     """
 *     cdef float64_t fval
 *     if is_float_object(val):             # <<<<<<<<<<<<<<
 *         fval = val
 *         return fval != fval
 */
  }

  /* "util.pxd":189
 *         fval = val
 *         return fval != fval
 *     return is_complex_object(val) and val != val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(__pyx_v_val); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(3, 189, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_val, __pyx_v_val, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 189, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(3, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":172
 * 
 * 
 * cdef inline bint is_nan(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Check if val is a Not-A-Number float or complex, including
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_nan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "util.pxd":192
 * 
 * 
 * cdef inline const char* get_c_string_buf_and_size(str py_string,             # <<<<<<<<<<<<<<
 *                                                   Py_ssize_t *length) except NULL:
 *     """
 */

static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(PyObject *__pyx_v_py_string, Py_ssize_t *__pyx_v_length) {
  char const *__pyx_r;
  char const *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "util.pxd":212
 *     buf : const char*
 *     """
 *     return PyUnicode_AsUTF8AndSize(py_string, length)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyUnicode_AsUTF8AndSize(__pyx_v_py_string, __pyx_v_length); if (unlikely(__pyx_t_1 == ((char const *)NULL))) __PYX_ERR(3, 212, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":192
 * 
 * 
 * cdef inline const char* get_c_string_buf_and_size(str py_string,             # <<<<<<<<<<<<<<
 *                                                   Py_ssize_t *length) except NULL:
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.util.get_c_string_buf_and_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":215
 * 
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:             # <<<<<<<<<<<<<<
 *     return get_c_string_buf_and_size(py_string, NULL)
 * 
 */

static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(PyObject *__pyx_v_py_string) {
  char const *__pyx_r;
  char const *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "util.pxd":216
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:
 *     return get_c_string_buf_and_size(py_string, NULL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(__pyx_v_py_string, NULL); if (unlikely(__pyx_t_1 == ((char const *)NULL))) __PYX_ERR(3, 216, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "util.pxd":215
 * 
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:             # <<<<<<<<<<<<<<
 *     return get_c_string_buf_and_size(py_string, NULL)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.util.get_c_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "util.pxd":219
 * 
 * 
 * cdef inline bytes string_encode_locale(str py_string):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)
 */

static CYTHON_INLINE PyObject *__pyx_f_6pandas_5_libs_6tslibs_4util_string_encode_locale(PyObject *__pyx_v_py_string) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("string_encode_locale", 1);

  /* "util.pxd":221
 * cdef inline bytes string_encode_locale(str py_string):
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_EncodeLocale(__pyx_v_py_string, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyBytes_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_1))) __PYX_ERR(3, 221, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "util.pxd":219
 * 
 * 
 * cdef inline bytes string_encode_locale(str py_string):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.string_encode_locale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "util.pxd":224
 * 
 * 
 * cdef inline object char_to_string_locale(const char* data):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)
 */

static CYTHON_INLINE PyObject *__pyx_f_6pandas_5_libs_6tslibs_4util_char_to_string_locale(char const *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("char_to_string_locale", 1);

  /* "util.pxd":226
 * cdef inline object char_to_string_locale(const char* data):
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_DecodeLocale(__pyx_v_data, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "util.pxd":224
 * 
 * 
 * cdef inline object char_to_string_locale(const char* data):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.char_to_string_locale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":85
 * # Misc Helpers
 * 
 * cdef bint is_offset_object(object obj):             # <<<<<<<<<<<<<<
 *     return isinstance(obj, BaseOffset)
 * 
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_is_offset_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":86
 * 
 * cdef bint is_offset_object(object obj):
 *     return isinstance(obj, BaseOffset)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":85
 * # Misc Helpers
 * 
 * cdef bint is_offset_object(object obj):             # <<<<<<<<<<<<<<
 *     return isinstance(obj, BaseOffset)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":89
 * 
 * 
 * cdef bint is_tick_object(object obj):             # <<<<<<<<<<<<<<
 *     return isinstance(obj, Tick)
 * 
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_is_tick_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":90
 * 
 * cdef bint is_tick_object(object obj):
 *     return isinstance(obj, Tick)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":89
 * 
 * 
 * cdef bint is_tick_object(object obj):             # <<<<<<<<<<<<<<
 *     return isinstance(obj, Tick)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":93
 * 
 * 
 * cdef datetime _as_datetime(datetime obj):             # <<<<<<<<<<<<<<
 *     if isinstance(obj, _Timestamp):
 *         return obj.to_pydatetime()
 */

static PyDateTime_DateTime *__pyx_f_6pandas_5_libs_6tslibs_7offsets__as_datetime(PyDateTime_DateTime *__pyx_v_obj) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_as_datetime", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":94
 * 
 * cdef datetime _as_datetime(datetime obj):
 *     if isinstance(obj, _Timestamp):             # <<<<<<<<<<<<<<
 *         return obj.to_pydatetime()
 *     return obj
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_obj), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":95
 * cdef datetime _as_datetime(datetime obj):
 *     if isinstance(obj, _Timestamp):
 *         return obj.to_pydatetime()             # <<<<<<<<<<<<<<
 *     return obj
 * 
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_obj), __pyx_n_s_to_pydatetime); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 95, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":94
 * 
 * cdef datetime _as_datetime(datetime obj):
 *     if isinstance(obj, _Timestamp):             # <<<<<<<<<<<<<<
 *         return obj.to_pydatetime()
 *     return obj
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":96
 *     if isinstance(obj, _Timestamp):
 *         return obj.to_pydatetime()
 *     return obj             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":93
 * 
 * 
 * cdef datetime _as_datetime(datetime obj):             # <<<<<<<<<<<<<<
 *     if isinstance(obj, _Timestamp):
 *         return obj.to_pydatetime()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._as_datetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":99
 * 
 * 
 * cdef bint _is_normalized(datetime dt):             # <<<<<<<<<<<<<<
 *     if dt.hour != 0 or dt.minute != 0 or dt.second != 0 or dt.microsecond != 0:
 *         # Regardless of whether dt is datetime vs Timestamp
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(PyDateTime_DateTime *__pyx_v_dt) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_normalized", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":100
 * 
 * cdef bint _is_normalized(datetime dt):
 *     if dt.hour != 0 or dt.minute != 0 or dt.second != 0 or dt.microsecond != 0:             # <<<<<<<<<<<<<<
 *         # Regardless of whether dt is datetime vs Timestamp
 *         return False
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_6second_second(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 100, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":102
 *     if dt.hour != 0 or dt.minute != 0 or dt.second != 0 or dt.microsecond != 0:
 *         # Regardless of whether dt is datetime vs Timestamp
 *         return False             # <<<<<<<<<<<<<<
 *     if isinstance(dt, _Timestamp):
 *         return dt.nanosecond == 0
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":100
 * 
 * cdef bint _is_normalized(datetime dt):
 *     if dt.hour != 0 or dt.minute != 0 or dt.second != 0 or dt.microsecond != 0:             # <<<<<<<<<<<<<<
 *         # Regardless of whether dt is datetime vs Timestamp
 *         return False
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":103
 *         # Regardless of whether dt is datetime vs Timestamp
 *         return False
 *     if isinstance(dt, _Timestamp):             # <<<<<<<<<<<<<<
 *         return dt.nanosecond == 0
 *     return True
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_dt), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":104
 *         return False
 *     if isinstance(dt, _Timestamp):
 *         return dt.nanosecond == 0             # <<<<<<<<<<<<<<
 *     return True
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_nanosecond); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_t_4, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 104, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 104, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_1;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":103
 *         # Regardless of whether dt is datetime vs Timestamp
 *         return False
 *     if isinstance(dt, _Timestamp):             # <<<<<<<<<<<<<<
 *         return dt.nanosecond == 0
 *     return True
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":105
 *     if isinstance(dt, _Timestamp):
 *         return dt.nanosecond == 0
 *     return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":99
 * 
 * 
 * cdef bint _is_normalized(datetime dt):             # <<<<<<<<<<<<<<
 *     if dt.hour != 0 or dt.minute != 0 or dt.second != 0 or dt.microsecond != 0:
 *         # Regardless of whether dt is datetime vs Timestamp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._is_normalized", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":108
 * 
 * 
 * def apply_wrapper_core(func, self, other) -> ndarray:             # <<<<<<<<<<<<<<
 *     result = func(self, other)
 *     result = np.asarray(result)
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_1apply_wrapper_core(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_1apply_wrapper_core = {"apply_wrapper_core", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_1apply_wrapper_core, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_1apply_wrapper_core(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply_wrapper_core (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 108, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 108, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("apply_wrapper_core", 1, 3, 3, 1); __PYX_ERR(0, 108, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 108, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("apply_wrapper_core", 1, 3, 3, 2); __PYX_ERR(0, 108, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "apply_wrapper_core") < 0)) __PYX_ERR(0, 108, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_func = values[0];
    __pyx_v_self = values[1];
    __pyx_v_other = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("apply_wrapper_core", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 108, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wrapper_core", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_apply_wrapper_core(__pyx_self, __pyx_v_func, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_apply_wrapper_core(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_normalize_i8_timestamps = NULL;
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  NPY_DATETIMEUNIT __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_wrapper_core", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":109
 * 
 * def apply_wrapper_core(func, self, other) -> ndarray:
 *     result = func(self, other)             # <<<<<<<<<<<<<<
 *     result = np.asarray(result)
 * 
 */
  __Pyx_INCREF(__pyx_v_func);
  __pyx_t_2 = __pyx_v_func; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_self, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":110
 * def apply_wrapper_core(func, self, other) -> ndarray:
 *     result = func(self, other)
 *     result = np.asarray(result)             # <<<<<<<<<<<<<<
 * 
 *     if self.normalize:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_result};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":112
 *     result = np.asarray(result)
 * 
 *     if self.normalize:             # <<<<<<<<<<<<<<
 *         # TODO: Avoid circular/runtime import
 *         from .vectorized import normalize_i8_timestamps
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_normalize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":114
 *     if self.normalize:
 *         # TODO: Avoid circular/runtime import
 *         from .vectorized import normalize_i8_timestamps             # <<<<<<<<<<<<<<
 *         reso = get_unit_from_dtype(other.dtype)
 *         result = normalize_i8_timestamps(result.view("i8"), None, reso=reso)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_normalize_i8_timestamps);
    __Pyx_GIVEREF(__pyx_n_s_normalize_i8_timestamps);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_normalize_i8_timestamps)) __PYX_ERR(0, 114, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_vectorized, __pyx_t_1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_normalize_i8_timestamps); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_normalize_i8_timestamps = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":115
 *         # TODO: Avoid circular/runtime import
 *         from .vectorized import normalize_i8_timestamps
 *         reso = get_unit_from_dtype(other.dtype)             # <<<<<<<<<<<<<<
 *         result = normalize_i8_timestamps(result.view("i8"), None, reso=reso)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 115, __pyx_L1_error)
    __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_3)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_reso = __pyx_t_6;

    /* "pandas/_libs/tslibs/offsets.pyx":116
 *         from .vectorized import normalize_i8_timestamps
 *         reso = get_unit_from_dtype(other.dtype)
 *         result = normalize_i8_timestamps(result.view("i8"), None, reso=reso)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_view); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_i8};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 116, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(0, 116, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(__pyx_v_reso); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_reso, __pyx_t_2) < 0) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_normalize_i8_timestamps, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":112
 *     result = np.asarray(result)
 * 
 *     if self.normalize:             # <<<<<<<<<<<<<<
 *         # TODO: Avoid circular/runtime import
 *         from .vectorized import normalize_i8_timestamps
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":118
 *         result = normalize_i8_timestamps(result.view("i8"), None, reso=reso)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_result) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_result, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = ((PyArrayObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":108
 * 
 * 
 * def apply_wrapper_core(func, self, other) -> ndarray:             # <<<<<<<<<<<<<<
 *     result = func(self, other)
 *     result = np.asarray(result)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wrapper_core", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_normalize_i8_timestamps);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_3apply_array_wraps(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_3apply_array_wraps = {"apply_array_wraps", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_3apply_array_wraps, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_3apply_array_wraps(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_func = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply_array_wraps (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 121, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "apply_array_wraps") < 0)) __PYX_ERR(0, 121, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_func = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("apply_array_wraps", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 121, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_array_wraps", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_2apply_array_wraps(__pyx_self, __pyx_v_func);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":124
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 *     def wrapper(self, other) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_1wrapper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_1wrapper = {"wrapper", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_1wrapper, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_1wrapper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrapper (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 124, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 124, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("wrapper", 1, 2, 2, 1); __PYX_ERR(0, 124, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "wrapper") < 0)) __PYX_ERR(0, 124, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wrapper", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 124, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_array_wraps.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_wrapper(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_wrapper(PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *__pyx_cur_scope;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *__pyx_outer_scope;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrapper", 1);
  __pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "pandas/_libs/tslibs/offsets.pyx":126
 *     def wrapper(self, other) -> np.ndarray:
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wrapper_core); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 126, __pyx_L1_error) }
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_func, __pyx_v_self, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":127
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":124
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 *     def wrapper(self, other) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_array_wraps.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_2apply_array_wraps(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *__pyx_cur_scope;
  PyObject *__pyx_v_wrapper = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_array_wraps", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 121, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);

  /* "pandas/_libs/tslibs/offsets.pyx":124
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 *     def wrapper(self, other) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(0, 124, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17apply_array_wraps_1wrapper, 0, __pyx_n_s_apply_array_wraps_locals_wrapper, ((PyObject*)__pyx_cur_scope), __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_wrapper = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":130
 * 
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 *     wrapper.__name__ = func.__name__             # <<<<<<<<<<<<<<
 *     wrapper.__doc__ = func.__doc__
 *     return wrapper
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_func, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_name, __pyx_t_2) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":131
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 *     wrapper.__name__ = func.__name__
 *     wrapper.__doc__ = func.__doc__             # <<<<<<<<<<<<<<
 *     return wrapper
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_func, __pyx_n_s_doc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_doc, __pyx_t_2) < 0) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":132
 *     wrapper.__name__ = func.__name__
 *     wrapper.__doc__ = func.__doc__
 *     return wrapper             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrapper);
  __pyx_r = __pyx_v_wrapper;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_array_wraps", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_5apply_wraps(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_5apply_wraps = {"apply_wraps", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_5apply_wraps, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_5apply_wraps(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_func = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("apply_wraps (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_func,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_func)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 135, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "apply_wraps") < 0)) __PYX_ERR(0, 135, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_func = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("apply_wraps", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 135, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wraps", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4apply_wraps(__pyx_self, __pyx_v_func);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":139
 *     # not play nicely with cython class methods
 * 
 *     def wrapper(self, other):             # <<<<<<<<<<<<<<
 * 
 *         if other is NaT:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_1wrapper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_1wrapper = {"wrapper", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_1wrapper, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_1wrapper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrapper (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 139, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 139, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("wrapper", 1, 2, 2, 1); __PYX_ERR(0, 139, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "wrapper") < 0)) __PYX_ERR(0, 139, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_other = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wrapper", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 139, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wraps.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_wrapper(__pyx_self, __pyx_v_self, __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_wrapper(PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *__pyx_cur_scope;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *__pyx_outer_scope;
  PyObject *__pyx_v_tz = NULL;
  PyObject *__pyx_v_nano = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_result2 = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrapper", 0);
  __pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_INCREF(__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":141
 *     def wrapper(self, other):
 * 
 *         if other is NaT:             # <<<<<<<<<<<<<<
 *             return NaT
 *         elif (
 */
  __pyx_t_1 = (__pyx_v_other == ((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT));
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":142
 * 
 *         if other is NaT:
 *             return NaT             # <<<<<<<<<<<<<<
 *         elif (
 *             isinstance(other, BaseOffset)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT);
    __pyx_r = ((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT);
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":141
 *     def wrapper(self, other):
 * 
 *         if other is NaT:             # <<<<<<<<<<<<<<
 *             return NaT
 *         elif (
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":144
 *             return NaT
 *         elif (
 *             isinstance(other, BaseOffset)             # <<<<<<<<<<<<<<
 *             or PyDelta_Check(other)
 *             or util.is_timedelta64_object(other)
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":145
 *         elif (
 *             isinstance(other, BaseOffset)
 *             or PyDelta_Check(other)             # <<<<<<<<<<<<<<
 *             or util.is_timedelta64_object(other)
 *         ):
 */
  __pyx_t_2 = PyDelta_Check(__pyx_v_other);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":146
 *             isinstance(other, BaseOffset)
 *             or PyDelta_Check(other)
 *             or util.is_timedelta64_object(other)             # <<<<<<<<<<<<<<
 *         ):
 *             # timedelta path
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 146, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;

  /* "pandas/_libs/tslibs/offsets.pyx":143
 *         if other is NaT:
 *             return NaT
 *         elif (             # <<<<<<<<<<<<<<
 *             isinstance(other, BaseOffset)
 *             or PyDelta_Check(other)
 */
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":149
 *         ):
 *             # timedelta path
 *             return func(self, other)             # <<<<<<<<<<<<<<
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 *             # PyDate_Check includes date, datetime
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 149, __pyx_L1_error) }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
    __pyx_t_4 = __pyx_cur_scope->__pyx_v_func; __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_self, __pyx_v_other};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":143
 *         if other is NaT:
 *             return NaT
 *         elif (             # <<<<<<<<<<<<<<
 *             isinstance(other, BaseOffset)
 *             or PyDelta_Check(other)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":150
 *             # timedelta path
 *             return func(self, other)
 *         elif is_datetime64_object(other) or PyDate_Check(other):             # <<<<<<<<<<<<<<
 *             # PyDate_Check includes date, datetime
 *             other = Timestamp(other)
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_datetime64_object(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 150, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = PyDate_Check(__pyx_v_other);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;
  if (likely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":152
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 *             # PyDate_Check includes date, datetime
 *             other = Timestamp(other)             # <<<<<<<<<<<<<<
 *         else:
 *             # This will end up returning NotImplemented back in __add__
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":150
 *             # timedelta path
 *             return func(self, other)
 *         elif is_datetime64_object(other) or PyDate_Check(other):             # <<<<<<<<<<<<<<
 *             # PyDate_Check includes date, datetime
 *             other = Timestamp(other)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":155
 *         else:
 *             # This will end up returning NotImplemented back in __add__
 *             raise ApplyTypeError             # <<<<<<<<<<<<<<
 * 
 *         tz = other.tzinfo
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 155, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":157
 *             raise ApplyTypeError
 * 
 *         tz = other.tzinfo             # <<<<<<<<<<<<<<
 *         nano = other.nanosecond
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_tzinfo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_tz = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":158
 * 
 *         tz = other.tzinfo
 *         nano = other.nanosecond             # <<<<<<<<<<<<<<
 * 
 *         if self._adjust_dst:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_nanosecond); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_nano = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":160
 *         nano = other.nanosecond
 * 
 *         if self._adjust_dst:             # <<<<<<<<<<<<<<
 *             other = other.tz_localize(None)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adjust_dst); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":161
 * 
 *         if self._adjust_dst:
 *             other = other.tz_localize(None)             # <<<<<<<<<<<<<<
 * 
 *         result = func(self, other)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, Py_None};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":160
 *         nano = other.nanosecond
 * 
 *         if self._adjust_dst:             # <<<<<<<<<<<<<<
 *             other = other.tz_localize(None)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":163
 *             other = other.tz_localize(None)
 * 
 *         result = func(self, other)             # <<<<<<<<<<<<<<
 * 
 *         result2 = Timestamp(result).as_unit(other.unit)
 */
  if (unlikely(!__pyx_cur_scope->__pyx_v_func)) { __Pyx_RaiseClosureNameError("func"); __PYX_ERR(0, 163, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_func; __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_self, __pyx_v_other};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":165
 *         result = func(self, other)
 * 
 *         result2 = Timestamp(result).as_unit(other.unit)             # <<<<<<<<<<<<<<
 *         if result == result2:
 *             # i.e. the conversion is non-lossy, not the case for e.g.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_result};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_as_unit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_unit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_4};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_result2 = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":166
 * 
 *         result2 = Timestamp(result).as_unit(other.unit)
 *         if result == result2:             # <<<<<<<<<<<<<<
 *             # i.e. the conversion is non-lossy, not the case for e.g.
 *             #  test_milliseconds_combination
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_result, __pyx_v_result2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 166, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":169
 *             # i.e. the conversion is non-lossy, not the case for e.g.
 *             #  test_milliseconds_combination
 *             result = result2             # <<<<<<<<<<<<<<
 * 
 *         if self._adjust_dst:
 */
    __Pyx_INCREF(__pyx_v_result2);
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_v_result2);

    /* "pandas/_libs/tslibs/offsets.pyx":166
 * 
 *         result2 = Timestamp(result).as_unit(other.unit)
 *         if result == result2:             # <<<<<<<<<<<<<<
 *             # i.e. the conversion is non-lossy, not the case for e.g.
 *             #  test_milliseconds_combination
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":171
 *             result = result2
 * 
 *         if self._adjust_dst:             # <<<<<<<<<<<<<<
 *             result = result.tz_localize(tz)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_adjust_dst); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 171, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":172
 * 
 *         if self._adjust_dst:
 *             result = result.tz_localize(tz)             # <<<<<<<<<<<<<<
 * 
 *         if self.normalize:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_tz};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":171
 *             result = result2
 * 
 *         if self._adjust_dst:             # <<<<<<<<<<<<<<
 *             result = result.tz_localize(tz)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":174
 *             result = result.tz_localize(tz)
 * 
 *         if self.normalize:             # <<<<<<<<<<<<<<
 *             result = result.normalize()
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":175
 * 
 *         if self.normalize:
 *             result = result.normalize()             # <<<<<<<<<<<<<<
 * 
 *         # If the offset object does not have a nanoseconds component,
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_normalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 175, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 175, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":174
 *             result = result.tz_localize(tz)
 * 
 *         if self.normalize:             # <<<<<<<<<<<<<<
 *             result = result.normalize()
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":179
 *         # If the offset object does not have a nanoseconds component,
 *         # the result's nanosecond component may be lost.
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):             # <<<<<<<<<<<<<<
 *             if result.nanosecond != nano:
 *                 if result.tz is not None:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = (!__pyx_t_2);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_nano, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 179, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L14_bool_binop_done;
  }
  __pyx_t_8 = __Pyx_HasAttr(__pyx_v_self, __pyx_n_u_nanoseconds); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 179, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_8);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L14_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":180
 *         # the result's nanosecond component may be lost.
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):
 *             if result.nanosecond != nano:             # <<<<<<<<<<<<<<
 *                 if result.tz is not None:
 *                     # convert to UTC
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_nanosecond); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_v_nano, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":181
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):
 *             if result.nanosecond != nano:
 *                 if result.tz is not None:             # <<<<<<<<<<<<<<
 *                     # convert to UTC
 *                     res = result.tz_localize(None)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_tz); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 181, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = (__pyx_t_5 != Py_None);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "pandas/_libs/tslibs/offsets.pyx":183
 *                 if result.tz is not None:
 *                     # convert to UTC
 *                     res = result.tz_localize(None)             # <<<<<<<<<<<<<<
 *                 else:
 *                     res = result
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 183, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, Py_None};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 183, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_v_res = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":181
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):
 *             if result.nanosecond != nano:
 *                 if result.tz is not None:             # <<<<<<<<<<<<<<
 *                     # convert to UTC
 *                     res = result.tz_localize(None)
 */
        goto __pyx_L18;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":185
 *                     res = result.tz_localize(None)
 *                 else:
 *                     res = result             # <<<<<<<<<<<<<<
 *                 value = res.as_unit("ns")._value
 *                 result = Timestamp(value + nano)
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_v_result);
        __pyx_v_res = __pyx_v_result;
      }
      __pyx_L18:;

      /* "pandas/_libs/tslibs/offsets.pyx":186
 *                 else:
 *                     res = result
 *                 value = res.as_unit("ns")._value             # <<<<<<<<<<<<<<
 *                 result = Timestamp(value + nano)
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_as_unit); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_ns};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 186, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_value = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":187
 *                     res = result
 *                 value = res.as_unit("ns")._value
 *                 result = Timestamp(value + nano)             # <<<<<<<<<<<<<<
 * 
 *         if tz is not None and result.tzinfo is None:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PyNumber_Add(__pyx_v_value, __pyx_v_nano); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 187, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 187, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":180
 *         # the result's nanosecond component may be lost.
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):
 *             if result.nanosecond != nano:             # <<<<<<<<<<<<<<
 *                 if result.tz is not None:
 *                     # convert to UTC
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":179
 *         # If the offset object does not have a nanoseconds component,
 *         # the result's nanosecond component may be lost.
 *         if not self.normalize and nano != 0 and not hasattr(self, "nanoseconds"):             # <<<<<<<<<<<<<<
 *             if result.nanosecond != nano:
 *                 if result.tz is not None:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":189
 *                 result = Timestamp(value + nano)
 * 
 *         if tz is not None and result.tzinfo is None:             # <<<<<<<<<<<<<<
 *             result = result.tz_localize(tz)
 * 
 */
  __pyx_t_2 = (__pyx_v_tz != Py_None);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_tzinfo); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 == Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":190
 * 
 *         if tz is not None and result.tzinfo is None:
 *             result = result.tz_localize(tz)             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_tz};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":189
 *                 result = Timestamp(value + nano)
 * 
 *         if tz is not None and result.tzinfo is None:             # <<<<<<<<<<<<<<
 *             result = result.tz_localize(tz)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":192
 *             result = result.tz_localize(tz)
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":139
 *     # not play nicely with cython class methods
 * 
 *     def wrapper(self, other):             # <<<<<<<<<<<<<<
 * 
 *         if other is NaT:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wraps.wrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tz);
  __Pyx_XDECREF(__pyx_v_nano);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_result2);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4apply_wraps(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_func) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *__pyx_cur_scope;
  PyObject *__pyx_v_wrapper = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("apply_wraps", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 135, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_func = __pyx_v_func;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_func);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_func);

  /* "pandas/_libs/tslibs/offsets.pyx":139
 *     # not play nicely with cython class methods
 * 
 *     def wrapper(self, other):             # <<<<<<<<<<<<<<
 * 
 *         if other is NaT:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11apply_wraps_1wrapper, 0, __pyx_n_s_apply_wraps_locals_wrapper, ((PyObject*)__pyx_cur_scope), __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrapper = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":195
 * 
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 *     wrapper.__name__ = func.__name__             # <<<<<<<<<<<<<<
 *     wrapper.__doc__ = func.__doc__
 *     return wrapper
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_func, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_name, __pyx_t_1) < 0) __PYX_ERR(0, 195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":196
 *     # do @functools.wraps(func) manually since it doesn't work on cdef funcs
 *     wrapper.__name__ = func.__name__
 *     wrapper.__doc__ = func.__doc__             # <<<<<<<<<<<<<<
 *     return wrapper
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_func, __pyx_n_s_doc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_wrapper, __pyx_n_s_doc, __pyx_t_1) < 0) __PYX_ERR(0, 196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":197
 *     wrapper.__name__ = func.__name__
 *     wrapper.__doc__ = func.__doc__
 *     return wrapper             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrapper);
  __pyx_r = __pyx_v_wrapper;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.apply_wraps", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":200
 * 
 * 
 * cdef _wrap_timedelta_result(result):             # <<<<<<<<<<<<<<
 *     """
 *     Tick operations dispatch to their Timedelta counterparts.  Wrap the result
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__wrap_timedelta_result(PyObject *__pyx_v_result) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_wrap_timedelta_result", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":213
 *     object
 *     """
 *     if PyDelta_Check(result):             # <<<<<<<<<<<<<<
 *         # convert Timedelta back to a Tick
 *         return delta_to_tick(result)
 */
  __pyx_t_1 = PyDelta_Check(__pyx_v_result);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":215
 *     if PyDelta_Check(result):
 *         # convert Timedelta back to a Tick
 *         return delta_to_tick(result)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_delta_to_tick); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_result};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":213
 *     object
 *     """
 *     if PyDelta_Check(result):             # <<<<<<<<<<<<<<
 *         # convert Timedelta back to a Tick
 *         return delta_to_tick(result)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":217
 *         return delta_to_tick(result)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * # ---------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":200
 * 
 * 
 * cdef _wrap_timedelta_result(result):             # <<<<<<<<<<<<<<
 *     """
 *     Tick operations dispatch to their Timedelta counterparts.  Wrap the result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._wrap_timedelta_result", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":223
 * 
 * 
 * cdef _get_calendar(weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *     """
 *     Generate busdaycalendar
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__get_calendar(PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar) {
  PyObject *__pyx_v_kwargs = NULL;
  PyObject *__pyx_v_busdaycalendar = NULL;
  PyObject *__pyx_7genexpr__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_calendar", 0);
  __Pyx_INCREF(__pyx_v_holidays);

  /* "pandas/_libs/tslibs/offsets.pyx":227
 *     Generate busdaycalendar
 *     """
 *     if isinstance(calendar, np.busdaycalendar):             # <<<<<<<<<<<<<<
 *         if not holidays:
 *             holidays = tuple(calendar.holidays)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_busdaycalendar); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_calendar, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":228
 *     """
 *     if isinstance(calendar, np.busdaycalendar):
 *         if not holidays:             # <<<<<<<<<<<<<<
 *             holidays = tuple(calendar.holidays)
 *         elif not isinstance(holidays, tuple):
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_holidays); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 228, __pyx_L1_error)
    __pyx_t_4 = (!__pyx_t_3);
    if (__pyx_t_4) {

      /* "pandas/_libs/tslibs/offsets.pyx":229
 *     if isinstance(calendar, np.busdaycalendar):
 *         if not holidays:
 *             holidays = tuple(calendar.holidays)             # <<<<<<<<<<<<<<
 *         elif not isinstance(holidays, tuple):
 *             holidays = tuple(holidays)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_calendar, __pyx_n_s_holidays); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":228
 *     """
 *     if isinstance(calendar, np.busdaycalendar):
 *         if not holidays:             # <<<<<<<<<<<<<<
 *             holidays = tuple(calendar.holidays)
 *         elif not isinstance(holidays, tuple):
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":230
 *         if not holidays:
 *             holidays = tuple(calendar.holidays)
 *         elif not isinstance(holidays, tuple):             # <<<<<<<<<<<<<<
 *             holidays = tuple(holidays)
 *         else:
 */
    __pyx_t_4 = PyTuple_Check(__pyx_v_holidays); 
    __pyx_t_3 = (!__pyx_t_4);
    if (__pyx_t_3) {

      /* "pandas/_libs/tslibs/offsets.pyx":231
 *             holidays = tuple(calendar.holidays)
 *         elif not isinstance(holidays, tuple):
 *             holidays = tuple(holidays)             # <<<<<<<<<<<<<<
 *         else:
 *             # trust that calendar.holidays and holidays are
 */
      __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_v_holidays); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":230
 *         if not holidays:
 *             holidays = tuple(calendar.holidays)
 *         elif not isinstance(holidays, tuple):             # <<<<<<<<<<<<<<
 *             holidays = tuple(holidays)
 *         else:
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":235
 *             # trust that calendar.holidays and holidays are
 *             # consistent
 *             pass             # <<<<<<<<<<<<<<
 *         return calendar, holidays
 * 
 */
    /*else*/ {
    }
    __pyx_L4:;

    /* "pandas/_libs/tslibs/offsets.pyx":236
 *             # consistent
 *             pass
 *         return calendar, holidays             # <<<<<<<<<<<<<<
 * 
 *     if holidays is None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_calendar);
    __Pyx_GIVEREF(__pyx_v_calendar);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_calendar)) __PYX_ERR(0, 236, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_holidays);
    __Pyx_GIVEREF(__pyx_v_holidays);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_holidays)) __PYX_ERR(0, 236, __pyx_L1_error);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":227
 *     Generate busdaycalendar
 *     """
 *     if isinstance(calendar, np.busdaycalendar):             # <<<<<<<<<<<<<<
 *         if not holidays:
 *             holidays = tuple(calendar.holidays)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":238
 *         return calendar, holidays
 * 
 *     if holidays is None:             # <<<<<<<<<<<<<<
 *         holidays = []
 *     try:
 */
  __pyx_t_3 = (__pyx_v_holidays == Py_None);
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":239
 * 
 *     if holidays is None:
 *         holidays = []             # <<<<<<<<<<<<<<
 *     try:
 *         holidays = holidays + calendar.holidays().tolist()
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":238
 *         return calendar, holidays
 * 
 *     if holidays is None:             # <<<<<<<<<<<<<<
 *         holidays = []
 *     try:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":240
 *     if holidays is None:
 *         holidays = []
 *     try:             # <<<<<<<<<<<<<<
 *         holidays = holidays + calendar.holidays().tolist()
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":241
 *         holidays = []
 *     try:
 *         holidays = holidays + calendar.holidays().tolist()             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         pass
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_calendar, __pyx_n_s_holidays); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tolist); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = PyNumber_Add(__pyx_v_holidays, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 241, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":240
 *     if holidays is None:
 *         holidays = []
 *     try:             # <<<<<<<<<<<<<<
 *         holidays = holidays + calendar.holidays().tolist()
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":242
 *     try:
 *         holidays = holidays + calendar.holidays().tolist()
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         pass
 *     holidays = [_to_dt64D(dt) for dt in holidays]
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_10) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":240
 *     if holidays is None:
 *         holidays = []
 *     try:             # <<<<<<<<<<<<<<
 *         holidays = holidays + calendar.holidays().tolist()
 *     except AttributeError:
 */
    __pyx_L8_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L11_try_end:;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":244
 *     except AttributeError:
 *         pass
 *     holidays = [_to_dt64D(dt) for dt in holidays]             # <<<<<<<<<<<<<<
 *     holidays = tuple(sorted(holidays))
 * 
 */
  { /* enter inner scope */
    __pyx_t_8 = PyList_New(0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 244, __pyx_L14_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (likely(PyList_CheckExact(__pyx_v_holidays)) || PyTuple_CheckExact(__pyx_v_holidays)) {
      __pyx_t_1 = __pyx_v_holidays; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_11 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_holidays); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 244, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 244, __pyx_L14_error)
    }
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 244, __pyx_L14_error)
            #endif
            if (__pyx_t_11 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_2); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 244, __pyx_L14_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 244, __pyx_L14_error)
            #endif
            if (__pyx_t_11 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_2); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 244, __pyx_L14_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_12(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 244, __pyx_L14_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_7genexpr__pyx_v_dt, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__to_dt64D(__pyx_7genexpr__pyx_v_dt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 244, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_8, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 244, __pyx_L14_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_dt); __pyx_7genexpr__pyx_v_dt = 0;
    goto __pyx_L18_exit_scope;
    __pyx_L14_error:;
    __Pyx_XDECREF(__pyx_7genexpr__pyx_v_dt); __pyx_7genexpr__pyx_v_dt = 0;
    goto __pyx_L1_error;
    __pyx_L18_exit_scope:;
  } /* exit inner scope */
  __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_8);
  __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":245
 *         pass
 *     holidays = [_to_dt64D(dt) for dt in holidays]
 *     holidays = tuple(sorted(holidays))             # <<<<<<<<<<<<<<
 * 
 *     kwargs = {"weekmask": weekmask}
 */
  __pyx_t_1 = PySequence_List(__pyx_v_holidays); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_13 = PyList_Sort(__pyx_t_8); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 245, __pyx_L1_error)
  __pyx_t_1 = PyList_AsTuple(((PyObject*)__pyx_t_8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":247
 *     holidays = tuple(sorted(holidays))
 * 
 *     kwargs = {"weekmask": weekmask}             # <<<<<<<<<<<<<<
 *     if holidays:
 *         kwargs["holidays"] = holidays
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_weekmask, __pyx_v_weekmask) < 0) __PYX_ERR(0, 247, __pyx_L1_error)
  __pyx_v_kwargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":248
 * 
 *     kwargs = {"weekmask": weekmask}
 *     if holidays:             # <<<<<<<<<<<<<<
 *         kwargs["holidays"] = holidays
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_holidays); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 248, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":249
 *     kwargs = {"weekmask": weekmask}
 *     if holidays:
 *         kwargs["holidays"] = holidays             # <<<<<<<<<<<<<<
 * 
 *     busdaycalendar = np.busdaycalendar(**kwargs)
 */
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_u_holidays, __pyx_v_holidays) < 0))) __PYX_ERR(0, 249, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":248
 * 
 *     kwargs = {"weekmask": weekmask}
 *     if holidays:             # <<<<<<<<<<<<<<
 *         kwargs["holidays"] = holidays
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":251
 *         kwargs["holidays"] = holidays
 * 
 *     busdaycalendar = np.busdaycalendar(**kwargs)             # <<<<<<<<<<<<<<
 *     return busdaycalendar, holidays
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_busdaycalendar); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_busdaycalendar = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":252
 * 
 *     busdaycalendar = np.busdaycalendar(**kwargs)
 *     return busdaycalendar, holidays             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_busdaycalendar);
  __Pyx_GIVEREF(__pyx_v_busdaycalendar);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_busdaycalendar)) __PYX_ERR(0, 252, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_holidays);
  __Pyx_GIVEREF(__pyx_v_holidays);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_holidays)) __PYX_ERR(0, 252, __pyx_L1_error);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":223
 * 
 * 
 * cdef _get_calendar(weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *     """
 *     Generate busdaycalendar
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._get_calendar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XDECREF(__pyx_v_busdaycalendar);
  __Pyx_XDECREF(__pyx_7genexpr__pyx_v_dt);
  __Pyx_XDECREF(__pyx_v_holidays);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":255
 * 
 * 
 * cdef _to_dt64D(dt):             # <<<<<<<<<<<<<<
 *     # Currently
 *     # > np.datetime64(dt.datetime(2013,5,1),dtype='datetime64[D]')
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__to_dt64D(PyObject *__pyx_v_dt) {
  PyObject *__pyx_v_naive = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_to_dt64D", 0);
  __Pyx_INCREF(__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":260
 *     # numpy.datetime64('2013-05-01T02:00:00.000000+0200')
 *     # Thus astype is needed to cast datetime to datetime64[D]
 *     if getattr(dt, "tzinfo", None) is not None:             # <<<<<<<<<<<<<<
 *         # Get the nanosecond timestamp,
 *         #  equiv `Timestamp(dt).value` or `dt.timestamp() * 10**9`
 */
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_dt, __pyx_n_u_tzinfo, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":265
 *         # The `naive` must be the `dt` naive wall time
 *         #  instead of the naive absolute time (GH#49441)
 *         naive = dt.replace(tzinfo=None)             # <<<<<<<<<<<<<<
 *         dt = np.datetime64(naive, "D")
 *     else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_tzinfo, Py_None) < 0) __PYX_ERR(0, 265, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 265, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_naive = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":266
 *         #  instead of the naive absolute time (GH#49441)
 *         naive = dt.replace(tzinfo=None)
 *         dt = np.datetime64(naive, "D")             # <<<<<<<<<<<<<<
 *     else:
 *         dt = np.datetime64(dt)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_datetime64); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_naive, __pyx_n_u_D};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":260
 *     # numpy.datetime64('2013-05-01T02:00:00.000000+0200')
 *     # Thus astype is needed to cast datetime to datetime64[D]
 *     if getattr(dt, "tzinfo", None) is not None:             # <<<<<<<<<<<<<<
 *         # Get the nanosecond timestamp,
 *         #  equiv `Timestamp(dt).value` or `dt.timestamp() * 10**9`
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":268
 *         dt = np.datetime64(naive, "D")
 *     else:
 *         dt = np.datetime64(dt)             # <<<<<<<<<<<<<<
 *     if dt.dtype.name != "datetime64[D]":
 *         dt = dt.astype("datetime64[D]")
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_datetime64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_dt};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 268, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_4);
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":269
 *     else:
 *         dt = np.datetime64(dt)
 *     if dt.dtype.name != "datetime64[D]":             # <<<<<<<<<<<<<<
 *         dt = dt.astype("datetime64[D]")
 *     return dt
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_datetime64_D, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":270
 *         dt = np.datetime64(dt)
 *     if dt.dtype.name != "datetime64[D]":
 *         dt = dt.astype("datetime64[D]")             # <<<<<<<<<<<<<<
 *     return dt
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt, __pyx_n_s_astype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 270, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_kp_u_datetime64_D};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":269
 *     else:
 *         dt = np.datetime64(dt)
 *     if dt.dtype.name != "datetime64[D]":             # <<<<<<<<<<<<<<
 *         dt = dt.astype("datetime64[D]")
 *     return dt
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":271
 *     if dt.dtype.name != "datetime64[D]":
 *         dt = dt.astype("datetime64[D]")
 *     return dt             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_dt);
  __pyx_r = __pyx_v_dt;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":255
 * 
 * 
 * cdef _to_dt64D(dt):             # <<<<<<<<<<<<<<
 *     # Currently
 *     # > np.datetime64(dt.datetime(2013,5,1),dtype='datetime64[D]')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._to_dt64D", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_naive);
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":278
 * 
 * 
 * cdef _validate_business_time(t_input):             # <<<<<<<<<<<<<<
 *     if isinstance(t_input, str):
 *         try:
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__validate_business_time(PyObject *__pyx_v_t_input) {
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_validate_business_time", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":279
 * 
 * cdef _validate_business_time(t_input):
 *     if isinstance(t_input, str):             # <<<<<<<<<<<<<<
 *         try:
 *             t = time.strptime(t_input, "%H:%M")
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_t_input); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":280
 * cdef _validate_business_time(t_input):
 *     if isinstance(t_input, str):
 *         try:             # <<<<<<<<<<<<<<
 *             t = time.strptime(t_input, "%H:%M")
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":281
 *     if isinstance(t_input, str):
 *         try:
 *             t = time.strptime(t_input, "%H:%M")             # <<<<<<<<<<<<<<
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 *         except ValueError:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 281, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strptime); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 281, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        __pyx_t_8 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_8 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_v_t_input, __pyx_kp_u_H_M};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 281, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_v_t = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":282
 *         try:
 *             t = time.strptime(t_input, "%H:%M")
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             raise ValueError("time data must match '%H:%M' format")
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_tm_hour); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_hour, __pyx_t_7) < 0) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_t, __pyx_n_s_tm_min); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_minute, __pyx_t_7) < 0) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_time), __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 282, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_r = __pyx_t_7;
        __pyx_t_7 = 0;
        goto __pyx_L8_try_return;

        /* "pandas/_libs/tslibs/offsets.pyx":280
 * cdef _validate_business_time(t_input):
 *     if isinstance(t_input, str):
 *         try:             # <<<<<<<<<<<<<<
 *             t = time.strptime(t_input, "%H:%M")
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 */
      }
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":283
 *             t = time.strptime(t_input, "%H:%M")
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             raise ValueError("time data must match '%H:%M' format")
 *     elif isinstance(t_input, dt_time):
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_8) {
        __Pyx_AddTraceback("pandas._libs.tslibs.offsets._validate_business_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 283, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "pandas/_libs/tslibs/offsets.pyx":284
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 *         except ValueError:
 *             raise ValueError("time data must match '%H:%M' format")             # <<<<<<<<<<<<<<
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:
 */
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 284, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_Raise(__pyx_t_9, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __PYX_ERR(0, 284, __pyx_L6_except_error)
      }
      goto __pyx_L6_except_error;

      /* "pandas/_libs/tslibs/offsets.pyx":280
 * cdef _validate_business_time(t_input):
 *     if isinstance(t_input, str):
 *         try:             # <<<<<<<<<<<<<<
 *             t = time.strptime(t_input, "%H:%M")
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L8_try_return:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L0;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":279
 * 
 * cdef _validate_business_time(t_input):
 *     if isinstance(t_input, str):             # <<<<<<<<<<<<<<
 *         try:
 *             t = time.strptime(t_input, "%H:%M")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":285
 *         except ValueError:
 *             raise ValueError("time data must match '%H:%M' format")
 *     elif isinstance(t_input, dt_time):             # <<<<<<<<<<<<<<
 *         if t_input.second != 0 or t_input.microsecond != 0:
 *             raise ValueError(
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_t_input, __pyx_ptype_7cpython_8datetime_time); 
  if (likely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":286
 *             raise ValueError("time data must match '%H:%M' format")
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "time data must be specified only with hour and minute")
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_t_input, __pyx_n_s_second); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_6, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!__pyx_t_10) {
    } else {
      __pyx_t_1 = __pyx_t_10;
      goto __pyx_L13_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_t_input, __pyx_n_s_microsecond); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_6, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_1 = __pyx_t_10;
    __pyx_L13_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "pandas/_libs/tslibs/offsets.pyx":287
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "time data must be specified only with hour and minute")
 *         return t_input
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(0, 287, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":286
 *             raise ValueError("time data must match '%H:%M' format")
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "time data must be specified only with hour and minute")
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":289
 *             raise ValueError(
 *                 "time data must be specified only with hour and minute")
 *         return t_input             # <<<<<<<<<<<<<<
 *     else:
 *         raise ValueError("time data must be string or datetime.time")
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_t_input);
    __pyx_r = __pyx_v_t_input;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":285
 *         except ValueError:
 *             raise ValueError("time data must match '%H:%M' format")
 *     elif isinstance(t_input, dt_time):             # <<<<<<<<<<<<<<
 *         if t_input.second != 0 or t_input.microsecond != 0:
 *             raise ValueError(
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":291
 *         return t_input
 *     else:
 *         raise ValueError("time data must be string or datetime.time")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 291, __pyx_L1_error)
  }

  /* "pandas/_libs/tslibs/offsets.pyx":278
 * 
 * 
 * cdef _validate_business_time(t_input):             # <<<<<<<<<<<<<<
 *     if isinstance(t_input, str):
 *         try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._validate_business_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":320
 * 
 *     # nanos are handled by apply_wraps
 *     if all(k in nanos for k in kwds):             # <<<<<<<<<<<<<<
 *         return timedelta(days=0), False
 * 
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 320, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_2generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_determine_offset_locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._determine_offset.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 320, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 320, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 320, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 320, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_nanos)) { __Pyx_RaiseClosureNameError("nanos"); __PYX_ERR(0, 320, __pyx_L1_error) }
    if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_nanos == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 320, __pyx_L1_error)
    }
    __pyx_t_5 = (__Pyx_PySet_ContainsTF(__pyx_cur_scope->__pyx_v_k, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_nanos, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
    __pyx_t_6 = (!__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_5generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":337
 *     }
 * 
 *     if all(k in kwds_use_timedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         # Sub-daily offset - use timedelta (tz-aware)
 *         # This also handles "milliseconds" (plur): see GH 49897
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_3genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 337, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_5generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_determine_offset_locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._determine_offset.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_5generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 337, __pyx_L1_error)
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 337, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 1, ((PyObject *)NULL), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, NULL, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_timedelta)) { __Pyx_RaiseClosureNameError("kwds_use_timedelta"); __PYX_ERR(0, 337, __pyx_L1_error) }
    if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_timedelta == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 337, __pyx_L1_error)
    }
    __pyx_t_7 = (__Pyx_PySet_ContainsTF(__pyx_cur_scope->__pyx_v_k, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_timedelta, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 337, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_7);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_8generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":347
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         return relativedelta(**kwds_no_nanos), True
 * 
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_6genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 347, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_8generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_determine_offset_locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._determine_offset.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_8generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 347, __pyx_L1_error)
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 347, __pyx_L1_error) }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_genexpr_arg_0, 1, ((PyObject *)NULL), (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_6 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, NULL, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_6 == 0)) break;
    if (unlikely(__pyx_t_6 == -1)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_relativedelta)) { __Pyx_RaiseClosureNameError("kwds_use_relativedelta"); __PYX_ERR(0, 347, __pyx_L1_error) }
    if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_relativedelta == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 347, __pyx_L1_error)
    }
    __pyx_t_7 = (__Pyx_PySet_ContainsTF(__pyx_cur_scope->__pyx_v_k, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_kwds_use_relativedelta, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 347, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_7);
    if (__pyx_t_8) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":304
 * 
 * 
 * cdef _determine_offset(kwds):             # <<<<<<<<<<<<<<
 *     if not kwds:
 *         # GH 45643/45890: (historically) defaults to 1 day
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyObject *__pyx_v_kwds) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *__pyx_cur_scope;
  PyObject *__pyx_v_kwds_no_nanos = NULL;
  PyObject *__pyx_v_micro = NULL;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_2generator = 0;
  PyObject *__pyx_8genexpr2__pyx_v_k = NULL;
  PyObject *__pyx_8genexpr2__pyx_v_v = NULL;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_5generator1 = 0;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_8generator2 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_determine_offset", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 304, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }

  /* "pandas/_libs/tslibs/offsets.pyx":305
 * 
 * cdef _determine_offset(kwds):
 *     if not kwds:             # <<<<<<<<<<<<<<
 *         # GH 45643/45890: (historically) defaults to 1 day
 *         return timedelta(days=1), False
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_kwds); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 305, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":307
 *     if not kwds:
 *         # GH 45643/45890: (historically) defaults to 1 day
 *         return timedelta(days=1), False             # <<<<<<<<<<<<<<
 * 
 *     if "millisecond" in kwds:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_days, __pyx_int_1) < 0) __PYX_ERR(0, 307, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, Py_False)) __PYX_ERR(0, 307, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":305
 * 
 * cdef _determine_offset(kwds):
 *     if not kwds:             # <<<<<<<<<<<<<<
 *         # GH 45643/45890: (historically) defaults to 1 day
 *         return timedelta(days=1), False
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":309
 *         return timedelta(days=1), False
 * 
 *     if "millisecond" in kwds:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError(
 *             "Using DateOffset to replace `millisecond` component in "
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_millisecond, __pyx_v_kwds, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 309, __pyx_L1_error)
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/tslibs/offsets.pyx":310
 * 
 *     if "millisecond" in kwds:
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             "Using DateOffset to replace `millisecond` component in "
 *             "datetime object is not supported. Use "
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 310, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":309
 *         return timedelta(days=1), False
 * 
 *     if "millisecond" in kwds:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError(
 *             "Using DateOffset to replace `millisecond` component in "
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":317
 *         )
 * 
 *     nanos = {"nanosecond", "nanoseconds"}             # <<<<<<<<<<<<<<
 * 
 *     # nanos are handled by apply_wraps
 */
  __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PySet_Add(__pyx_t_3, __pyx_n_u_nanosecond) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_nanoseconds) < 0) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_nanos = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":320
 * 
 *     # nanos are handled by apply_wraps
 *     if all(k in nanos for k in kwds):             # <<<<<<<<<<<<<<
 *         return timedelta(days=0), False
 * 
 */
  __pyx_t_3 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_kwds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":321
 *     # nanos are handled by apply_wraps
 *     if all(k in nanos for k in kwds):
 *         return timedelta(days=0), False             # <<<<<<<<<<<<<<
 * 
 *     kwds_no_nanos = {k: v for k, v in kwds.items() if k not in nanos}
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_days, __pyx_int_0) < 0) __PYX_ERR(0, 321, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, Py_False)) __PYX_ERR(0, 321, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":320
 * 
 *     # nanos are handled by apply_wraps
 *     if all(k in nanos for k in kwds):             # <<<<<<<<<<<<<<
 *         return timedelta(days=0), False
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":323
 *         return timedelta(days=0), False
 * 
 *     kwds_no_nanos = {k: v for k, v in kwds.items() if k not in nanos}             # <<<<<<<<<<<<<<
 * 
 *     kwds_use_relativedelta = {
 */
  { /* enter inner scope */
    __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 323, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_kwds == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 323, __pyx_L8_error)
    }
    __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_kwds, 0, __pyx_n_s_items, (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 323, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_8;
    __pyx_t_8 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_6, &__pyx_t_5, &__pyx_t_8, &__pyx_t_9, NULL, __pyx_t_7);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 323, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_k, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_8genexpr2__pyx_v_v, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_2 = (__Pyx_PySet_ContainsTF(__pyx_8genexpr2__pyx_v_k, __pyx_cur_scope->__pyx_v_nanos, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 323, __pyx_L8_error)
      if (__pyx_t_2) {
        if (unlikely(PyDict_SetItem(__pyx_t_4, (PyObject*)__pyx_8genexpr2__pyx_v_k, (PyObject*)__pyx_8genexpr2__pyx_v_v))) __PYX_ERR(0, 323, __pyx_L8_error)
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_k); __pyx_8genexpr2__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v); __pyx_8genexpr2__pyx_v_v = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_k); __pyx_8genexpr2__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v); __pyx_8genexpr2__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __pyx_v_kwds_no_nanos = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":326
 * 
 *     kwds_use_relativedelta = {
 *         "year", "month", "day", "hour", "minute",             # <<<<<<<<<<<<<<
 *         "second", "microsecond", "weekday", "years", "months", "weeks", "days",
 *         "hours", "minutes", "seconds", "microseconds"
 */
  __pyx_t_4 = PySet_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PySet_Add(__pyx_t_4, __pyx_n_u_year) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_month) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_day) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_hour) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_minute) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_second) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_microsecond) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_weekday) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_years) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_months) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_weeks) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_days) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_hours) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_minutes) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_seconds) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_microseconds) < 0) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_kwds_use_relativedelta = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":334
 *     # because (historically) timedelta is used only for sub-daily.
 *     kwds_use_timedelta = {
 *         "seconds", "microseconds", "milliseconds", "minutes", "hours",             # <<<<<<<<<<<<<<
 *     }
 * 
 */
  __pyx_t_4 = PySet_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PySet_Add(__pyx_t_4, __pyx_n_u_seconds) < 0) __PYX_ERR(0, 334, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_microseconds) < 0) __PYX_ERR(0, 334, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_milliseconds) < 0) __PYX_ERR(0, 334, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_minutes) < 0) __PYX_ERR(0, 334, __pyx_L1_error)
  if (PySet_Add(__pyx_t_4, __pyx_n_u_hours) < 0) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_kwds_use_timedelta = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":337
 *     }
 * 
 *     if all(k in kwds_use_timedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         # Sub-daily offset - use timedelta (tz-aware)
 *         # This also handles "milliseconds" (plur): see GH 49897
 */
  __pyx_t_4 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_3genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_kwds_no_nanos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 337, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":340
 *         # Sub-daily offset - use timedelta (tz-aware)
 *         # This also handles "milliseconds" (plur): see GH 49897
 *         return timedelta(**kwds_no_nanos), False             # <<<<<<<<<<<<<<
 * 
 *     # convert milliseconds to microseconds, so relativedelta can parse it
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyDict_Copy(__pyx_v_kwds_no_nanos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 340, __pyx_L1_error);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, Py_False)) __PYX_ERR(0, 340, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":337
 *     }
 * 
 *     if all(k in kwds_use_timedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         # Sub-daily offset - use timedelta (tz-aware)
 *         # This also handles "milliseconds" (plur): see GH 49897
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":343
 * 
 *     # convert milliseconds to microseconds, so relativedelta can parse it
 *     if "milliseconds" in kwds_no_nanos:             # <<<<<<<<<<<<<<
 *         micro = kwds_no_nanos.pop("milliseconds") * 1000
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 */
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_n_u_milliseconds, __pyx_v_kwds_no_nanos, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 343, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":344
 *     # convert milliseconds to microseconds, so relativedelta can parse it
 *     if "milliseconds" in kwds_no_nanos:
 *         micro = kwds_no_nanos.pop("milliseconds") * 1000             # <<<<<<<<<<<<<<
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 * 
 */
    __pyx_t_3 = __Pyx_PyDict_Pop(__pyx_v_kwds_no_nanos, __pyx_n_u_milliseconds, ((PyObject *)NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_MultiplyObjC(__pyx_t_3, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_micro = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":345
 *     if "milliseconds" in kwds_no_nanos:
 *         micro = kwds_no_nanos.pop("milliseconds") * 1000
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro             # <<<<<<<<<<<<<<
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):
 */
    __pyx_t_4 = __Pyx_PyDict_GetItemDefault(__pyx_v_kwds_no_nanos, __pyx_n_u_microseconds, __pyx_int_0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Add(__pyx_t_4, __pyx_v_micro); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_kwds_no_nanos, __pyx_n_u_microseconds, __pyx_t_3) < 0))) __PYX_ERR(0, 345, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":343
 * 
 *     # convert milliseconds to microseconds, so relativedelta can parse it
 *     if "milliseconds" in kwds_no_nanos:             # <<<<<<<<<<<<<<
 *         micro = kwds_no_nanos.pop("milliseconds") * 1000
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":347
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         return relativedelta(**kwds_no_nanos), True
 * 
 */
  __pyx_t_3 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_6genexpr(((PyObject*)__pyx_cur_scope), __pyx_v_kwds_no_nanos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":348
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):
 *         return relativedelta(**kwds_no_nanos), True             # <<<<<<<<<<<<<<
 * 
 *     raise ValueError(
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_relativedelta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyDict_Copy(__pyx_v_kwds_no_nanos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9)) __PYX_ERR(0, 348, __pyx_L1_error);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, Py_True)) __PYX_ERR(0, 348, __pyx_L1_error);
    __pyx_t_9 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":347
 *         kwds_no_nanos["microseconds"] = kwds_no_nanos.get("microseconds", 0) + micro
 * 
 *     if all(k in kwds_use_relativedelta for k in kwds_no_nanos):             # <<<<<<<<<<<<<<
 *         return relativedelta(**kwds_no_nanos), True
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":351
 * 
 *     raise ValueError(
 *         f"Invalid argument/s or bad combination of arguments: {list(kwds.keys())}"             # <<<<<<<<<<<<<<
 *     )
 * 
 */
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_kwds, __pyx_n_s_keys); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_t_9 = __Pyx_PySequence_ListKeepNew(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_9, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_argument_s_or_bad_combin, __pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":350
 *         return relativedelta(**kwds_no_nanos), True
 * 
 *     raise ValueError(             # <<<<<<<<<<<<<<
 *         f"Invalid argument/s or bad combination of arguments: {list(kwds.keys())}"
 *     )
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 350, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":304
 * 
 * 
 * cdef _determine_offset(kwds):             # <<<<<<<<<<<<<<
 *     if not kwds:
 *         # GH 45643/45890: (historically) defaults to 1 day
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._determine_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwds_no_nanos);
  __Pyx_XDECREF(__pyx_v_micro);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_2generator);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_k);
  __Pyx_XDECREF(__pyx_8genexpr2__pyx_v_v);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_5generator1);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_17_determine_offset_8generator2);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":398
 *     #    dict _cache
 * 
 *     def __init__(self, n=1, normalize=False):             # <<<<<<<<<<<<<<
 *         n = self._validate_n(n)
 *         self.n = n
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 398, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 398, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 398, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 398, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_n);

  /* "pandas/_libs/tslibs/offsets.pyx":399
 * 
 *     def __init__(self, n=1, normalize=False):
 *         n = self._validate_n(n)             # <<<<<<<<<<<<<<
 *         self.n = n
 *         self.normalize = normalize
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_validate_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 399, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":400
 *     def __init__(self, n=1, normalize=False):
 *         n = self._validate_n(n)
 *         self.n = n             # <<<<<<<<<<<<<<
 *         self.normalize = normalize
 *         self._cache = {}
 */
  __pyx_t_5 = __Pyx_PyInt_As_npy_int64(__pyx_v_n); if (unlikely((__pyx_t_5 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 400, __pyx_L1_error)
  __pyx_v_self->n = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":401
 *         n = self._validate_n(n)
 *         self.n = n
 *         self.normalize = normalize             # <<<<<<<<<<<<<<
 *         self._cache = {}
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_normalize); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 401, __pyx_L1_error)
  __pyx_v_self->normalize = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":402
 *         self.n = n
 *         self.normalize = normalize
 *         self._cache = {}             # <<<<<<<<<<<<<<
 * 
 *     def __eq__(self, other) -> bool:
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_cache);
  __Pyx_DECREF(__pyx_v_self->_cache);
  __pyx_v_self->_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":398
 *     #    dict _cache
 * 
 *     def __init__(self, n=1, normalize=False):             # <<<<<<<<<<<<<<
 *         n = self._validate_n(n)
 *         self.n = n
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":404
 *         self._cache = {}
 * 
 *     def __eq__(self, other) -> bool:             # <<<<<<<<<<<<<<
 *         if isinstance(other, str):
 *             try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_3__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_2__eq__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_2__eq__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":405
 * 
 *     def __eq__(self, other) -> bool:
 *         if isinstance(other, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # GH#23524 if to_offset fails, we are dealing with an
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_other); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":406
 *     def __eq__(self, other) -> bool:
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":409
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 *                 other = to_offset(other)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 # e.g. "infer"
 */
        __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset(__pyx_v_other, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 409, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":406
 *     def __eq__(self, other) -> bool:
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":410
 *                 #  incomparable type so == is False and != is True
 *                 other = to_offset(other)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 # e.g. "infer"
 *                 return False
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 410, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);

        /* "pandas/_libs/tslibs/offsets.pyx":412
 *             except ValueError:
 *                 # e.g. "infer"
 *                 return False             # <<<<<<<<<<<<<<
 *         try:
 *             return self._params == other._params
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "pandas/_libs/tslibs/offsets.pyx":406
 *     def __eq__(self, other) -> bool:
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":405
 * 
 *     def __eq__(self, other) -> bool:
 *         if isinstance(other, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # GH#23524 if to_offset fails, we are dealing with an
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":413
 *                 # e.g. "infer"
 *                 return False
 *         try:             # <<<<<<<<<<<<<<
 *             return self._params == other._params
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":414
 *                 return False
 *         try:
 *             return self._params == other._params             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             # other is not a DateOffset object
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_params); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 414, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_params); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 414, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_8, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 414, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L16_try_return;

      /* "pandas/_libs/tslibs/offsets.pyx":413
 *                 # e.g. "infer"
 *                 return False
 *         try:             # <<<<<<<<<<<<<<
 *             return self._params == other._params
 *         except AttributeError:
 */
    }
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":415
 *         try:
 *             return self._params == other._params
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             # other is not a DateOffset object
 *             return False
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 415, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "pandas/_libs/tslibs/offsets.pyx":417
 *         except AttributeError:
 *             # other is not a DateOffset object
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L15_except_return;
    }
    goto __pyx_L14_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":413
 *                 # e.g. "infer"
 *                 return False
 *         try:             # <<<<<<<<<<<<<<
 *             return self._params == other._params
 *         except AttributeError:
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_3, __pyx_t_2);
    goto __pyx_L1_error;
    __pyx_L16_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_3, __pyx_t_2);
    goto __pyx_L0;
    __pyx_L15_except_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_3, __pyx_t_2);
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":404
 *         self._cache = {}
 * 
 *     def __eq__(self, other) -> bool:             # <<<<<<<<<<<<<<
 *         if isinstance(other, str):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":419
 *             return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not self == other
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4__ne__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4__ne__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ne__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":420
 * 
 *     def __ne__(self, other):
 *         return not self == other             # <<<<<<<<<<<<<<
 * 
 *     def __hash__(self) -> int:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self), __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 420, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 420, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":419
 *             return False
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not self == other
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":422
 *         return not self == other
 * 
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash(self._params)
 * 
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7__hash__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6__hash__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6__hash__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_hash_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":423
 * 
 *     def __hash__(self) -> int:
 *         return hash(self._params)             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Hash(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_hash_t)-1))) __PYX_ERR(0, 423, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":422
 *         return not self == other
 * 
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash(self._params)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":425
 *         return hash(self._params)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _params(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params, "\n        Returns a tuple containing all of the attributes needed to evaluate\n        equality between two DateOffset objects.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params = {"_params", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_params (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_params", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_params", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_v_all_paras = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_exclude = NULL;
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_8genexpr5__pyx_v_k = NULL;
  PyObject *__pyx_8genexpr5__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_params", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":431
 *         equality between two DateOffset objects.
 *         """
 *         d = getattr(self, "__dict__", {})             # <<<<<<<<<<<<<<
 *         all_paras = d.copy()
 *         all_paras["n"] = self.n
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_u_dict, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_d = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":432
 *         """
 *         d = getattr(self, "__dict__", {})
 *         all_paras = d.copy()             # <<<<<<<<<<<<<<
 *         all_paras["n"] = self.n
 *         all_paras["normalize"] = self.normalize
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_d, __pyx_n_s_copy); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_all_paras = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":433
 *         d = getattr(self, "__dict__", {})
 *         all_paras = d.copy()
 *         all_paras["n"] = self.n             # <<<<<<<<<<<<<<
 *         all_paras["normalize"] = self.normalize
 *         for attr in self._attributes:
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_v_all_paras, __pyx_n_u_n, __pyx_t_2) < 0))) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":434
 *         all_paras = d.copy()
 *         all_paras["n"] = self.n
 *         all_paras["normalize"] = self.normalize             # <<<<<<<<<<<<<<
 *         for attr in self._attributes:
 *             if hasattr(self, attr) and attr not in d:
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely((PyObject_SetItem(__pyx_v_all_paras, __pyx_n_u_normalize, __pyx_t_2) < 0))) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":435
 *         all_paras["n"] = self.n
 *         all_paras["normalize"] = self.normalize
 *         for attr in self._attributes:             # <<<<<<<<<<<<<<
 *             if hasattr(self, attr) and attr not in d:
 *                 # cython attributes are not in __dict__
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 435, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 435, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 435, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 435, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 435, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 435, __pyx_L1_error)
        #else
        __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 435, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 435, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":436
 *         all_paras["normalize"] = self.normalize
 *         for attr in self._attributes:
 *             if hasattr(self, attr) and attr not in d:             # <<<<<<<<<<<<<<
 *                 # cython attributes are not in __dict__
 *                 all_paras[attr] = getattr(self, attr)
 */
    __pyx_t_8 = __Pyx_HasAttr(((PyObject *)__pyx_v_self), __pyx_v_attr); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 436, __pyx_L1_error)
    if (__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_v_attr, __pyx_v_d, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 436, __pyx_L1_error)
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":438
 *             if hasattr(self, attr) and attr not in d:
 *                 # cython attributes are not in __dict__
 *                 all_paras[attr] = getattr(self, attr)             # <<<<<<<<<<<<<<
 * 
 *         if "holidays" in all_paras and not all_paras["holidays"]:
 */
      __pyx_t_2 = __Pyx_GetAttr(((PyObject *)__pyx_v_self), __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (unlikely((PyObject_SetItem(__pyx_v_all_paras, __pyx_v_attr, __pyx_t_2) < 0))) __PYX_ERR(0, 438, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":436
 *         all_paras["normalize"] = self.normalize
 *         for attr in self._attributes:
 *             if hasattr(self, attr) and attr not in d:             # <<<<<<<<<<<<<<
 *                 # cython attributes are not in __dict__
 *                 all_paras[attr] = getattr(self, attr)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":435
 *         all_paras["n"] = self.n
 *         all_paras["normalize"] = self.normalize
 *         for attr in self._attributes:             # <<<<<<<<<<<<<<
 *             if hasattr(self, attr) and attr not in d:
 *                 # cython attributes are not in __dict__
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":440
 *                 all_paras[attr] = getattr(self, attr)
 * 
 *         if "holidays" in all_paras and not all_paras["holidays"]:             # <<<<<<<<<<<<<<
 *             all_paras.pop("holidays")
 *         exclude = ["kwds", "name", "calendar"]
 */
  __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_holidays, __pyx_v_all_paras, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 440, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_all_paras, __pyx_n_u_holidays); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = (!__pyx_t_8);
  __pyx_t_7 = __pyx_t_9;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":441
 * 
 *         if "holidays" in all_paras and not all_paras["holidays"]:
 *             all_paras.pop("holidays")             # <<<<<<<<<<<<<<
 *         exclude = ["kwds", "name", "calendar"]
 *         attrs = [(k, v) for k, v in all_paras.items()
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_all_paras, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_holidays};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":440
 *                 all_paras[attr] = getattr(self, attr)
 * 
 *         if "holidays" in all_paras and not all_paras["holidays"]:             # <<<<<<<<<<<<<<
 *             all_paras.pop("holidays")
 *         exclude = ["kwds", "name", "calendar"]
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":442
 *         if "holidays" in all_paras and not all_paras["holidays"]:
 *             all_paras.pop("holidays")
 *         exclude = ["kwds", "name", "calendar"]             # <<<<<<<<<<<<<<
 *         attrs = [(k, v) for k, v in all_paras.items()
 *                  if (k not in exclude) and (k[0] != "_")]
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_u_kwds);
  __Pyx_GIVEREF(__pyx_n_u_kwds);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_u_kwds)) __PYX_ERR(0, 442, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_name_2);
  __Pyx_GIVEREF(__pyx_n_u_name_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_name_2)) __PYX_ERR(0, 442, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_calendar);
  __Pyx_GIVEREF(__pyx_n_u_calendar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_u_calendar)) __PYX_ERR(0, 442, __pyx_L1_error);
  __pyx_v_exclude = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":443
 *             all_paras.pop("holidays")
 *         exclude = ["kwds", "name", "calendar"]
 *         attrs = [(k, v) for k, v in all_paras.items()             # <<<<<<<<<<<<<<
 *                  if (k not in exclude) and (k[0] != "_")]
 *         attrs = sorted(set(attrs))
 */
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 443, __pyx_L14_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_all_paras == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
      __PYX_ERR(0, 443, __pyx_L14_error)
    }
    __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_all_paras, 0, __pyx_n_s_items, (&__pyx_t_10), (&__pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 443, __pyx_L14_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
    while (1) {
      __pyx_t_12 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_10, &__pyx_t_5, &__pyx_t_3, &__pyx_t_11, NULL, __pyx_t_4);
      if (unlikely(__pyx_t_12 == 0)) break;
      if (unlikely(__pyx_t_12 == -1)) __PYX_ERR(0, 443, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_k, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_8genexpr5__pyx_v_v, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":444
 *         exclude = ["kwds", "name", "calendar"]
 *         attrs = [(k, v) for k, v in all_paras.items()
 *                  if (k not in exclude) and (k[0] != "_")]             # <<<<<<<<<<<<<<
 *         attrs = sorted(set(attrs))
 *         params = tuple([str(type(self))] + attrs)
 */
      __pyx_t_9 = (__Pyx_PySequence_ContainsTF(__pyx_8genexpr5__pyx_v_k, __pyx_v_exclude, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 444, __pyx_L14_error)
      if (__pyx_t_9) {
      } else {
        __pyx_t_7 = __pyx_t_9;
        goto __pyx_L18_bool_binop_done;
      }
      __pyx_t_11 = __Pyx_GetItemInt(__pyx_8genexpr5__pyx_v_k, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 444, __pyx_L14_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_11, __pyx_n_u__13, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 444, __pyx_L14_error)
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_7 = __pyx_t_9;
      __pyx_L18_bool_binop_done:;
      if (__pyx_t_7) {

        /* "pandas/_libs/tslibs/offsets.pyx":443
 *             all_paras.pop("holidays")
 *         exclude = ["kwds", "name", "calendar"]
 *         attrs = [(k, v) for k, v in all_paras.items()             # <<<<<<<<<<<<<<
 *                  if (k not in exclude) and (k[0] != "_")]
 *         attrs = sorted(set(attrs))
 */
        __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 443, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_8genexpr5__pyx_v_k);
        __Pyx_GIVEREF(__pyx_8genexpr5__pyx_v_k);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_8genexpr5__pyx_v_k)) __PYX_ERR(0, 443, __pyx_L14_error);
        __Pyx_INCREF(__pyx_8genexpr5__pyx_v_v);
        __Pyx_GIVEREF(__pyx_8genexpr5__pyx_v_v);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_8genexpr5__pyx_v_v)) __PYX_ERR(0, 443, __pyx_L14_error);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_11))) __PYX_ERR(0, 443, __pyx_L14_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":444
 *         exclude = ["kwds", "name", "calendar"]
 *         attrs = [(k, v) for k, v in all_paras.items()
 *                  if (k not in exclude) and (k[0] != "_")]             # <<<<<<<<<<<<<<
 *         attrs = sorted(set(attrs))
 *         params = tuple([str(type(self))] + attrs)
 */
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_k); __pyx_8genexpr5__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v); __pyx_8genexpr5__pyx_v_v = 0;
    goto __pyx_L20_exit_scope;
    __pyx_L14_error:;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_k); __pyx_8genexpr5__pyx_v_k = 0;
    __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v); __pyx_8genexpr5__pyx_v_v = 0;
    goto __pyx_L1_error;
    __pyx_L20_exit_scope:;
  } /* exit inner scope */
  __pyx_v_attrs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":445
 *         attrs = [(k, v) for k, v in all_paras.items()
 *                  if (k not in exclude) and (k[0] != "_")]
 *         attrs = sorted(set(attrs))             # <<<<<<<<<<<<<<
 *         params = tuple([str(type(self))] + attrs)
 *         return params
 */
  __pyx_t_2 = PySet_New(__pyx_v_attrs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_11 = PySequence_List(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = ((PyObject*)__pyx_t_11);
  __pyx_t_11 = 0;
  __pyx_t_13 = PyList_Sort(__pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_DECREF_SET(__pyx_v_attrs, ((PyObject*)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":446
 *                  if (k not in exclude) and (k[0] != "_")]
 *         attrs = sorted(set(attrs))
 *         params = tuple([str(type(self))] + attrs)             # <<<<<<<<<<<<<<
 *         return params
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Str(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_11 = PyList_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_11, 0, __pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_t_11, __pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_params = ((PyObject*)__pyx_t_11);
  __pyx_t_11 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":447
 *         attrs = sorted(set(attrs))
 *         params = tuple([str(type(self))] + attrs)
 *         return params             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_params);
  __pyx_r = __pyx_v_params;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":425
 *         return hash(self._params)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _params(self):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._params", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_all_paras);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_exclude);
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_k);
  __Pyx_XDECREF(__pyx_8genexpr5__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":449
 *         return params
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def kwds(self) -> dict:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_kwds = NULL;
  PyObject *__pyx_8genexpr6__pyx_v_name = NULL;
  PyObject *__pyx_8genexpr7__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":466
 *         """
 *         # for backwards-compatibility
 *         kwds = {name: getattr(self, name, None) for name in self._attributes             # <<<<<<<<<<<<<<
 *                 if name not in ["n", "normalize"]}
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 */
  { /* enter inner scope */
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_5 = NULL;
    } else {
      __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 466, __pyx_L5_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_5)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 466, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 466, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 466, __pyx_L5_error)
            #endif
            if (__pyx_t_4 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 466, __pyx_L5_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_5(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 466, __pyx_L5_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_8genexpr6__pyx_v_name, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":467
 *         # for backwards-compatibility
 *         kwds = {name: getattr(self, name, None) for name in self._attributes
 *                 if name not in ["n", "normalize"]}             # <<<<<<<<<<<<<<
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 * 
 */
      __Pyx_INCREF(__pyx_8genexpr6__pyx_v_name);
      __pyx_t_2 = __pyx_8genexpr6__pyx_v_name;
      __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_n, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 467, __pyx_L5_error)
      if (__pyx_t_7) {
      } else {
        __pyx_t_6 = __pyx_t_7;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_normalize, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 467, __pyx_L5_error)
      __pyx_t_6 = __pyx_t_7;
      __pyx_L9_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_t_6;
      if (__pyx_t_7) {

        /* "pandas/_libs/tslibs/offsets.pyx":466
 *         """
 *         # for backwards-compatibility
 *         kwds = {name: getattr(self, name, None) for name in self._attributes             # <<<<<<<<<<<<<<
 *                 if name not in ["n", "normalize"]}
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 */
        __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_8genexpr6__pyx_v_name, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(PyDict_SetItem(__pyx_t_1, (PyObject*)__pyx_8genexpr6__pyx_v_name, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 466, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":467
 *         # for backwards-compatibility
 *         kwds = {name: getattr(self, name, None) for name in self._attributes
 *                 if name not in ["n", "normalize"]}             # <<<<<<<<<<<<<<
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 * 
 */
      }

      /* "pandas/_libs/tslibs/offsets.pyx":466
 *         """
 *         # for backwards-compatibility
 *         kwds = {name: getattr(self, name, None) for name in self._attributes             # <<<<<<<<<<<<<<
 *                 if name not in ["n", "normalize"]}
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_name); __pyx_8genexpr6__pyx_v_name = 0;
    goto __pyx_L12_exit_scope;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_name); __pyx_8genexpr6__pyx_v_name = 0;
    goto __pyx_L1_error;
    __pyx_L12_exit_scope:;
  } /* exit inner scope */
  __pyx_v_kwds = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":468
 *         kwds = {name: getattr(self, name, None) for name in self._attributes
 *                 if name not in ["n", "normalize"]}
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_kwds, 1, ((PyObject *)NULL), (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L15_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_2;
    __pyx_t_2 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_3, __pyx_t_8, &__pyx_t_4, &__pyx_t_2, NULL, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(0, 468, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_8genexpr7__pyx_v_name, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_kwds, __pyx_8genexpr7__pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L15_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = (__pyx_t_2 != Py_None);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_7) {
        __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_kwds, __pyx_8genexpr7__pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(PyDict_SetItem(__pyx_t_1, (PyObject*)__pyx_8genexpr7__pyx_v_name, (PyObject*)__pyx_t_2))) __PYX_ERR(0, 468, __pyx_L15_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_name); __pyx_8genexpr7__pyx_v_name = 0;
    goto __pyx_L19_exit_scope;
    __pyx_L15_error:;
    __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_name); __pyx_8genexpr7__pyx_v_name = 0;
    goto __pyx_L1_error;
    __pyx_L19_exit_scope:;
  } /* exit inner scope */
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":449
 *         return params
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def kwds(self) -> dict:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.kwds.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwds);
  __Pyx_XDECREF(__pyx_8genexpr6__pyx_v_name);
  __Pyx_XDECREF(__pyx_8genexpr7__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":470
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":476
 *         attributes equal.
 *         """
 *         return type(self)(n=1, normalize=self.normalize, **self.kwds)             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_n, __pyx_int_1) < 0) __PYX_ERR(0, 476, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_3) < 0) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 476, __pyx_L1_error)
  }
  if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_t_2) < 0) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":470
 *         return {name: kwds[name] for name in kwds if kwds[name] is not None}
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.base.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":478
 *         return type(self)(n=1, normalize=self.normalize, **self.kwds)
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, BaseOffset):
 *             # cython semantics; this is __radd__
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_11__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_11__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_10__add__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_10__add__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_8genexpr8__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":479
 * 
 *     def __add__(self, other):
 *         if not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":482
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 *             return other.__add__(self)             # <<<<<<<<<<<<<<
 * 
 *         elif util.is_array(other) and other.dtype == object:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_add); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 482, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":479
 * 
 *     def __add__(self, other):
 *         if not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":484
 *             return other.__add__(self)
 * 
 *         elif util.is_array(other) and other.dtype == object:             # <<<<<<<<<<<<<<
 *             return np.array([self + x for x in other])
 * 
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_array(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 484, __pyx_L1_error)
  if (__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_builtin_object, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_1;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":485
 * 
 *         elif util.is_array(other) and other.dtype == object:
 *             return np.array([self + x for x in other])             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 485, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    { /* enter inner scope */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 485, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_v_other)) || PyTuple_CheckExact(__pyx_v_other)) {
        __pyx_t_7 = __pyx_v_other; __Pyx_INCREF(__pyx_t_7);
        __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_other); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 485, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 485, __pyx_L8_error)
      }
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_7))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 485, __pyx_L8_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_10 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_8); __Pyx_INCREF(__pyx_t_10); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 485, __pyx_L8_error)
            #else
            __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 485, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_10);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 485, __pyx_L8_error)
              #endif
              if (__pyx_t_8 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_8); __Pyx_INCREF(__pyx_t_10); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 485, __pyx_L8_error)
            #else
            __pyx_t_10 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 485, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_10);
            #endif
          }
        } else {
          __pyx_t_10 = __pyx_t_9(__pyx_t_7);
          if (unlikely(!__pyx_t_10)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 485, __pyx_L8_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_10);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr8__pyx_v_x, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_10 = PyNumber_Add(((PyObject *)__pyx_v_self), __pyx_8genexpr8__pyx_v_x); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 485, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_10))) __PYX_ERR(0, 485, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_x); __pyx_8genexpr8__pyx_v_x = 0;
      goto __pyx_L12_exit_scope;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_x); __pyx_8genexpr8__pyx_v_x = 0;
      goto __pyx_L1_error;
      __pyx_L12_exit_scope:;
    } /* exit inner scope */
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 485, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":484
 *             return other.__add__(self)
 * 
 *         elif util.is_array(other) and other.dtype == object:             # <<<<<<<<<<<<<<
 *             return np.array([self + x for x in other])
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":487
 *             return np.array([self + x for x in other])
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":488
 * 
 *         try:
 *             return self._apply(other)             # <<<<<<<<<<<<<<
 *         except ApplyTypeError:
 *             return NotImplemented
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 488, __pyx_L13_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 488, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L17_try_return;

      /* "pandas/_libs/tslibs/offsets.pyx":487
 *             return np.array([self + x for x in other])
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
    }
    __pyx_L13_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":489
 *         try:
 *             return self._apply(other)
 *         except ApplyTypeError:             # <<<<<<<<<<<<<<
 *             return NotImplemented
 * 
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 489, __pyx_L15_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_3);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_3 = 0;
    if (__pyx_t_6) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(0, 489, __pyx_L15_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "pandas/_libs/tslibs/offsets.pyx":490
 *             return self._apply(other)
 *         except ApplyTypeError:
 *             return NotImplemented             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_builtin_NotImplemented);
      __pyx_r = __pyx_builtin_NotImplemented;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L16_except_return;
    }
    goto __pyx_L15_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":487
 *             return np.array([self + x for x in other])
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
    __pyx_L15_except_error:;
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    goto __pyx_L1_error;
    __pyx_L17_try_return:;
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    goto __pyx_L0;
    __pyx_L16_except_return:;
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":478
 *         return type(self)(n=1, normalize=self.normalize, **self.kwds)
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, BaseOffset):
 *             # cython semantics; this is __radd__
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_8genexpr8__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":492
 *             return NotImplemented
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__add__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_13__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_13__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_12__radd__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_12__radd__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__radd__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":493
 * 
 *     def __radd__(self, other):
 *         return self.__add__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __sub__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":492
 *             return NotImplemented
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__add__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":495
 *         return self.__add__(other)
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_15__sub__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_15__sub__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sub__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_14__sub__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_14__sub__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sub__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":496
 * 
 *     def __sub__(self, other):
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):
 */
  __pyx_t_1 = PyDateTime_Check(__pyx_v_other);
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":497
 *     def __sub__(self, other):
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")             # <<<<<<<<<<<<<<
 *         elif type(other) == type(self):
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 497, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 497, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":496
 * 
 *     def __sub__(self, other):
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":498
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):             # <<<<<<<<<<<<<<
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 *                               **self.kwds)
 */
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)Py_TYPE(__pyx_v_other)), ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 498, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":499
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):
 *             return type(self)(self.n - other.n, normalize=self.normalize,             # <<<<<<<<<<<<<<
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Subtract(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 499, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_5) < 0) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":500
 *         elif type(other) == type(self):
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 *                               **self.kwds)             # <<<<<<<<<<<<<<
 *         elif not isinstance(self, BaseOffset):
 *             # TODO(cython3): remove, this moved to __rsub__
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 500, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_4, __pyx_t_2) < 0) __PYX_ERR(0, 500, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":499
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):
 *             return type(self)(self.n - other.n, normalize=self.normalize,             # <<<<<<<<<<<<<<
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":498
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")
 *         elif type(other) == type(self):             # <<<<<<<<<<<<<<
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 *                               **self.kwds)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":501
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # TODO(cython3): remove, this moved to __rsub__
 *             # cython semantics, this is __rsub__
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  __pyx_t_6 = (!__pyx_t_1);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":504
 *             # TODO(cython3): remove, this moved to __rsub__
 *             # cython semantics, this is __rsub__
 *             return (-other).__add__(self)             # <<<<<<<<<<<<<<
 *         else:
 *             # e.g. PeriodIndex
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyNumber_Negative(__pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_add); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 504, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":501
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # TODO(cython3): remove, this moved to __rsub__
 *             # cython semantics, this is __rsub__
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":507
 *         else:
 *             # e.g. PeriodIndex
 *             return NotImplemented             # <<<<<<<<<<<<<<
 * 
 *     def __rsub__(self, other):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_NotImplemented);
    __pyx_r = __pyx_builtin_NotImplemented;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":495
 *         return self.__add__(other)
 * 
 *     def __sub__(self, other):             # <<<<<<<<<<<<<<
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__sub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":509
 *             return NotImplemented
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         return (-self).__add__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_17__rsub__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_17__rsub__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rsub__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_16__rsub__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_16__rsub__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rsub__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":510
 * 
 *     def __rsub__(self, other):
 *         return (-self).__add__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __mul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyNumber_Negative(((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_add); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":509
 *             return NotImplemented
 * 
 *     def __rsub__(self, other):             # <<<<<<<<<<<<<<
 *         return (-self).__add__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__rsub__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":512
 *         return (-self).__add__(other)
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         if util.is_array(other):
 *             return np.array([self * x for x in other])
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_19__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_19__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_18__mul__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_18__mul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_8genexpr9__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mul__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":513
 * 
 *     def __mul__(self, other):
 *         if util.is_array(other):             # <<<<<<<<<<<<<<
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_array(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 513, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":514
 *     def __mul__(self, other):
 *         if util.is_array(other):
 *             return np.array([self * x for x in other])             # <<<<<<<<<<<<<<
 *         elif is_integer_object(other):
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    { /* enter inner scope */
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_v_other)) || PyTuple_CheckExact(__pyx_v_other)) {
        __pyx_t_5 = __pyx_v_other; __Pyx_INCREF(__pyx_t_5);
        __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_other); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 514, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 514, __pyx_L6_error)
      }
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L6_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_8 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 514, __pyx_L6_error)
            #else
            __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 514, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_8);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_5);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 514, __pyx_L6_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 514, __pyx_L6_error)
            #else
            __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 514, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_8);
            #endif
          }
        } else {
          __pyx_t_8 = __pyx_t_7(__pyx_t_5);
          if (unlikely(!__pyx_t_8)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 514, __pyx_L6_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_XDECREF_SET(__pyx_8genexpr9__pyx_v_x, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_Multiply(((PyObject *)__pyx_v_self), __pyx_8genexpr9__pyx_v_x); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 514, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_8))) __PYX_ERR(0, 514, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_x); __pyx_8genexpr9__pyx_v_x = 0;
      goto __pyx_L10_exit_scope;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_x); __pyx_8genexpr9__pyx_v_x = 0;
      goto __pyx_L1_error;
      __pyx_L10_exit_scope:;
    } /* exit inner scope */
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":513
 * 
 *     def __mul__(self, other):
 *         if util.is_array(other):             # <<<<<<<<<<<<<<
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":515
 *         if util.is_array(other):
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):             # <<<<<<<<<<<<<<
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 *                               **self.kwds)
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 515, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":516
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):
 *             return type(self)(n=other * self.n, normalize=self.normalize,             # <<<<<<<<<<<<<<
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Multiply(__pyx_v_other, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_n, __pyx_t_5) < 0) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_normalize, __pyx_t_5) < 0) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":517
 *         elif is_integer_object(other):
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 *                               **self.kwds)             # <<<<<<<<<<<<<<
 *         elif not isinstance(self, BaseOffset):
 *             # TODO(cython3): remove this, this moved to __rmul__
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_t_4 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 517, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_2, __pyx_t_4) < 0) __PYX_ERR(0, 517, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":516
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):
 *             return type(self)(n=other * self.n, normalize=self.normalize,             # <<<<<<<<<<<<<<
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):
 */
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":515
 *         if util.is_array(other):
 *             return np.array([self * x for x in other])
 *         elif is_integer_object(other):             # <<<<<<<<<<<<<<
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 *                               **self.kwds)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":518
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # TODO(cython3): remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  __pyx_t_10 = (!__pyx_t_1);
  if (__pyx_t_10) {

    /* "pandas/_libs/tslibs/offsets.pyx":521
 *             # TODO(cython3): remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 *             return other.__mul__(self)             # <<<<<<<<<<<<<<
 *         return NotImplemented
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 521, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":518
 *             return type(self)(n=other * self.n, normalize=self.normalize,
 *                               **self.kwds)
 *         elif not isinstance(self, BaseOffset):             # <<<<<<<<<<<<<<
 *             # TODO(cython3): remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":522
 *             # cython semantics, this is __rmul__
 *             return other.__mul__(self)
 *         return NotImplemented             # <<<<<<<<<<<<<<
 * 
 *     def __rmul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_builtin_NotImplemented);
  __pyx_r = __pyx_builtin_NotImplemented;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":512
 *         return (-self).__add__(other)
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         if util.is_array(other):
 *             return np.array([self * x for x in other])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_8genexpr9__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":524
 *         return NotImplemented
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_21__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_21__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_20__rmul__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_20__rmul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rmul__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":525
 * 
 *     def __rmul__(self, other):
 *         return self.__mul__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __neg__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":524
 *         return NotImplemented
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":527
 *         return self.__mul__(other)
 * 
 *     def __neg__(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_23__neg__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_23__neg__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__neg__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_22__neg__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_22__neg__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__neg__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":530
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 *         return self * -1             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Multiply(((PyObject *)__pyx_v_self), __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":527
 *         return self.__mul__(other)
 * 
 *     def __neg__(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__neg__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":532
 *         return self * -1
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy, "\n        Return a copy of the frequency.\n\n        Examples\n        --------\n        >>> freq = pd.DateOffset(1)\n        >>> freq_copy = freq.copy()\n        >>> freq is freq_copy\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy = {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":545
 *         False
 *         """
 *         return self * 1             # <<<<<<<<<<<<<<
 * 
 *     # ------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Multiply(((PyObject *)__pyx_v_self), __pyx_int_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":532
 *         return self * -1
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":550
 *     # Name and Rendering Methods
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         # _output_name used by B(Year|Quarter)(End|Begin) to
 *         #  expand "B" -> "Business"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_26__repr__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_26__repr__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_class_name = NULL;
  PyObject *__pyx_v_plural = NULL;
  PyObject *__pyx_v_n_str = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":553
 *         # _output_name used by B(Year|Quarter)(End|Begin) to
 *         #  expand "B" -> "Business"
 *         class_name = getattr(self, "_output_name", type(self).__name__)             # <<<<<<<<<<<<<<
 * 
 *         if abs(self.n) != 1:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_u_output_name, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_class_name = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":555
 *         class_name = getattr(self, "_output_name", type(self).__name__)
 * 
 *         if abs(self.n) != 1:             # <<<<<<<<<<<<<<
 *             plural = "s"
 *         else:
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyNumber_Absolute(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (__Pyx_PyInt_BoolNeObjC(__pyx_t_1, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 555, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":556
 * 
 *         if abs(self.n) != 1:
 *             plural = "s"             # <<<<<<<<<<<<<<
 *         else:
 *             plural = ""
 */
    __Pyx_INCREF(__pyx_n_u_s);
    __pyx_v_plural = __pyx_n_u_s;

    /* "pandas/_libs/tslibs/offsets.pyx":555
 *         class_name = getattr(self, "_output_name", type(self).__name__)
 * 
 *         if abs(self.n) != 1:             # <<<<<<<<<<<<<<
 *             plural = "s"
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":558
 *             plural = "s"
 *         else:
 *             plural = ""             # <<<<<<<<<<<<<<
 * 
 *         n_str = ""
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_kp_u__15);
    __pyx_v_plural = __pyx_kp_u__15;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":560
 *             plural = ""
 * 
 *         n_str = ""             # <<<<<<<<<<<<<<
 *         if self.n != 1:
 *             n_str = f"{self.n} * "
 */
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_v_n_str = __pyx_kp_u__15;

  /* "pandas/_libs/tslibs/offsets.pyx":561
 * 
 *         n_str = ""
 *         if self.n != 1:             # <<<<<<<<<<<<<<
 *             n_str = f"{self.n} * "
 * 
 */
  __pyx_t_3 = (__pyx_v_self->n != 1);
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":562
 *         n_str = ""
 *         if self.n != 1:
 *             n_str = f"{self.n} * "             # <<<<<<<<<<<<<<
 * 
 *         out = f"<{n_str}{class_name}{plural}{self._repr_attrs()}>"
 */
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_2, __pyx_kp_u__16); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_n_str, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":561
 * 
 *         n_str = ""
 *         if self.n != 1:             # <<<<<<<<<<<<<<
 *             n_str = f"{self.n} * "
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":564
 *             n_str = f"{self.n} * "
 * 
 *         out = f"<{n_str}{class_name}{plural}{self._repr_attrs()}>"             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
  __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = 0;
  __pyx_t_5 = 127;
  __Pyx_INCREF(__pyx_kp_u__17);
  __pyx_t_4 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__17);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__17);
  __Pyx_INCREF(__pyx_v_n_str);
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_n_str) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_n_str) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_v_n_str);
  __Pyx_GIVEREF(__pyx_v_n_str);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_n_str);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_class_name, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_v_plural);
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_plural) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_v_plural) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_v_plural);
  __Pyx_GIVEREF(__pyx_v_plural);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_plural);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_repr_attrs); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 0+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_5;
  __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u__18);
  __pyx_t_4 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__18);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_kp_u__18);
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 6, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_out = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":565
 * 
 *         out = f"<{n_str}{class_name}{plural}{self._repr_attrs()}>"
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def _repr_attrs(self) -> str:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":550
 *     # Name and Rendering Methods
 * 
 *     def __repr__(self) -> str:             # <<<<<<<<<<<<<<
 *         # _output_name used by B(Year|Quarter)(End|Begin) to
 *         #  expand "B" -> "Business"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_class_name);
  __Pyx_XDECREF(__pyx_v_plural);
  __Pyx_XDECREF(__pyx_v_n_str);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":567
 *         return out
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs = {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_attrs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_attrs", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_attrs", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_28_repr_attrs(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_28_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_exclude = NULL;
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_v_attr = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr_attrs", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":568
 * 
 *     def _repr_attrs(self) -> str:
 *         exclude = {"n", "inc", "normalize"}             # <<<<<<<<<<<<<<
 *         attrs = []
 *         for attr in sorted(self._attributes):
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PySet_Add(__pyx_t_1, __pyx_n_u_n) < 0) __PYX_ERR(0, 568, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_inc) < 0) __PYX_ERR(0, 568, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_normalize) < 0) __PYX_ERR(0, 568, __pyx_L1_error)
  __pyx_v_exclude = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":569
 *     def _repr_attrs(self) -> str:
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []             # <<<<<<<<<<<<<<
 *         for attr in sorted(self._attributes):
 *             # _attributes instead of __dict__ because cython attrs are not in __dict__
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_attrs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":570
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 *         for attr in sorted(self._attributes):             # <<<<<<<<<<<<<<
 *             # _attributes instead of __dict__ because cython attrs are not in __dict__
 *             if attr.startswith("_") or attr == "kwds" or not hasattr(self, attr):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_attributes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PySequence_List(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_4 = PyList_Sort(__pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 570, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 570, __pyx_L1_error)
      #endif
      if (__pyx_t_5 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(0, 570, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_attr, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":572
 *         for attr in sorted(self._attributes):
 *             # _attributes instead of __dict__ because cython attrs are not in __dict__
 *             if attr.startswith("_") or attr == "kwds" or not hasattr(self, attr):             # <<<<<<<<<<<<<<
 *                 # DateOffset may not have some of these attributes
 *                 continue
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_attr, __pyx_n_s_startswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u__13};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 572, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_9) {
    } else {
      __pyx_t_6 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_attr, __pyx_n_u_kwds, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 572, __pyx_L1_error)
    if (!__pyx_t_9) {
    } else {
      __pyx_t_6 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_9 = __Pyx_HasAttr(((PyObject *)__pyx_v_self), __pyx_v_attr); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 572, __pyx_L1_error)
    __pyx_t_10 = (!__pyx_t_9);
    __pyx_t_6 = __pyx_t_10;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":574
 *             if attr.startswith("_") or attr == "kwds" or not hasattr(self, attr):
 *                 # DateOffset may not have some of these attributes
 *                 continue             # <<<<<<<<<<<<<<
 *             elif attr not in exclude:
 *                 value = getattr(self, attr)
 */
      goto __pyx_L3_continue;

      /* "pandas/_libs/tslibs/offsets.pyx":572
 *         for attr in sorted(self._attributes):
 *             # _attributes instead of __dict__ because cython attrs are not in __dict__
 *             if attr.startswith("_") or attr == "kwds" or not hasattr(self, attr):             # <<<<<<<<<<<<<<
 *                 # DateOffset may not have some of these attributes
 *                 continue
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":575
 *                 # DateOffset may not have some of these attributes
 *                 continue
 *             elif attr not in exclude:             # <<<<<<<<<<<<<<
 *                 value = getattr(self, attr)
 *                 attrs.append(f"{attr}={value}")
 */
    __pyx_t_6 = (__Pyx_PySet_ContainsTF(__pyx_v_attr, __pyx_v_exclude, Py_NE)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 575, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":576
 *                 continue
 *             elif attr not in exclude:
 *                 value = getattr(self, attr)             # <<<<<<<<<<<<<<
 *                 attrs.append(f"{attr}={value}")
 * 
 */
      __pyx_t_1 = __Pyx_GetAttr(((PyObject *)__pyx_v_self), __pyx_v_attr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":577
 *             elif attr not in exclude:
 *                 value = getattr(self, attr)
 *                 attrs.append(f"{attr}={value}")             # <<<<<<<<<<<<<<
 * 
 *         out = ""
 */
      __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = 0;
      __pyx_t_12 = 127;
      __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_attr, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_12;
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_INCREF(__pyx_kp_u__19);
      __pyx_t_11 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__19);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__19);
      __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_value, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_12;
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_attrs, __pyx_t_2); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":575
 *                 # DateOffset may not have some of these attributes
 *                 continue
 *             elif attr not in exclude:             # <<<<<<<<<<<<<<
 *                 value = getattr(self, attr)
 *                 attrs.append(f"{attr}={value}")
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":570
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 *         for attr in sorted(self._attributes):             # <<<<<<<<<<<<<<
 *             # _attributes instead of __dict__ because cython attrs are not in __dict__
 *             if attr.startswith("_") or attr == "kwds" or not hasattr(self, attr):
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":579
 *                 attrs.append(f"{attr}={value}")
 * 
 *         out = ""             # <<<<<<<<<<<<<<
 *         if attrs:
 *             out += ": " + ", ".join(attrs)
 */
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_v_out = __pyx_kp_u__15;

  /* "pandas/_libs/tslibs/offsets.pyx":580
 * 
 *         out = ""
 *         if attrs:             # <<<<<<<<<<<<<<
 *             out += ": " + ", ".join(attrs)
 *         return out
 */
  __pyx_t_6 = (PyList_GET_SIZE(__pyx_v_attrs) != 0);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":581
 *         out = ""
 *         if attrs:
 *             out += ": " + ", ".join(attrs)             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
    __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__21, __pyx_v_attrs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__20, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_ConcatInPlace(__pyx_v_out, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":580
 * 
 *         out = ""
 *         if attrs:             # <<<<<<<<<<<<<<
 *             out += ": " + ", ".join(attrs)
 *         return out
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":582
 *         if attrs:
 *             out += ": " + ", ".join(attrs)
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":567
 *         return out
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._repr_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exclude);
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_v_attr);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":584
 *         return out
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def name(self) -> str:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":597
 *         'H'
 *         """
 *         return self.rule_code             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rule_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":584
 *         return out
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def name(self) -> str:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.name.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":599
 *         return self.rule_code
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def _prefix(self) -> str:
 *         raise NotImplementedError("Prefix not defined")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix___get__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":601
 *     @property
 *     def _prefix(self) -> str:
 *         raise NotImplementedError("Prefix not defined")             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 601, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":599
 *         return self.rule_code
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def _prefix(self) -> str:
 *         raise NotImplementedError("Prefix not defined")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._prefix.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":603
 *         raise NotImplementedError("Prefix not defined")
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         return self._prefix
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":605
 *     @property
 *     def rule_code(self) -> str:
 *         return self._prefix             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":603
 *         raise NotImplementedError("Prefix not defined")
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         return self._prefix
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":607
 *         return self._prefix
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def freqstr(self) -> str:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr, "\n        Return a string representing the frequency.\n\n        Examples\n        --------\n        >>> pd.DateOffset(5).freqstr\n        '<5 * DateOffsets>'\n\n        >>> pd.offsets.BusinessHour(2).freqstr\n        '2BH'\n\n        >>> pd.offsets.Nano().freqstr\n        'N'\n\n        >>> pd.offsets.Nano(-3).freqstr\n        '-3N'\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr = {"freqstr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("freqstr (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("freqstr", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "freqstr", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_code = NULL;
  PyObject *__pyx_v_fstr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("freqstr", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":626
 *         '-3N'
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             code = self.rule_code
 *         except NotImplementedError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":627
 *         """
 *         try:
 *             code = self.rule_code             # <<<<<<<<<<<<<<
 *         except NotImplementedError:
 *             return str(repr(self))
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rule_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 627, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_code = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":626
 *         '-3N'
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             code = self.rule_code
 *         except NotImplementedError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":628
 *         try:
 *             code = self.rule_code
 *         except NotImplementedError:             # <<<<<<<<<<<<<<
 *             return str(repr(self))
 * 
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_NotImplementedError);
    if (__pyx_t_5) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.freqstr", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 628, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "pandas/_libs/tslibs/offsets.pyx":629
 *             code = self.rule_code
 *         except NotImplementedError:
 *             return str(repr(self))             # <<<<<<<<<<<<<<
 * 
 *         if self.n != 1:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_8 = PyObject_Repr(((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 629, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_Str(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 629, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = ((PyObject*)__pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":626
 *         '-3N'
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             code = self.rule_code
 *         except NotImplementedError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":631
 *             return str(repr(self))
 * 
 *         if self.n != 1:             # <<<<<<<<<<<<<<
 *             fstr = f"{self.n}{code}"
 *         else:
 */
  __pyx_t_10 = (__pyx_v_self->n != 1);
  if (__pyx_t_10) {

    /* "pandas/_libs/tslibs/offsets.pyx":632
 * 
 *         if self.n != 1:
 *             fstr = f"{self.n}{code}"             # <<<<<<<<<<<<<<
 *         else:
 *             fstr = code
 */
    __pyx_t_7 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_code, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_fstr = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":631
 *             return str(repr(self))
 * 
 *         if self.n != 1:             # <<<<<<<<<<<<<<
 *             fstr = f"{self.n}{code}"
 *         else:
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":634
 *             fstr = f"{self.n}{code}"
 *         else:
 *             fstr = code             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_code);
    __pyx_v_fstr = __pyx_v_code;
  }
  __pyx_L11:;

  /* "pandas/_libs/tslibs/offsets.pyx":636
 *             fstr = code
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._offset:
 *                 fstr += self._offset_str()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":637
 * 
 *         try:
 *             if self._offset:             # <<<<<<<<<<<<<<
 *                 fstr += self._offset_str()
 *         except AttributeError:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 637, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_10) {

        /* "pandas/_libs/tslibs/offsets.pyx":638
 *         try:
 *             if self._offset:
 *                 fstr += self._offset_str()             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             # TODO: standardize `_offset` vs `offset` naming convention
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 638, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 638, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_fstr, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 638, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_fstr, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":637
 * 
 *         try:
 *             if self._offset:             # <<<<<<<<<<<<<<
 *                 fstr += self._offset_str()
 *         except AttributeError:
 */
      }

      /* "pandas/_libs/tslibs/offsets.pyx":636
 *             fstr = code
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._offset:
 *                 fstr += self._offset_str()
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":639
 *             if self._offset:
 *                 fstr += self._offset_str()
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             # TODO: standardize `_offset` vs `offset` naming convention
 *             pass
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_5) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L13_exception_handled;
    }
    goto __pyx_L14_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":636
 *             fstr = code
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._offset:
 *                 fstr += self._offset_str()
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L13_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L17_try_end:;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":643
 *             pass
 * 
 *         return fstr             # <<<<<<<<<<<<<<
 * 
 *     def _offset_str(self) -> str:
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_fstr))||((__pyx_v_fstr) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_fstr))) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_fstr);
  __pyx_r = ((PyObject*)__pyx_v_fstr);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":607
 *         return self._prefix
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def freqstr(self) -> str:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.freqstr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_code);
  __Pyx_XDECREF(__pyx_v_fstr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":645
 *         return fstr
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str = {"_offset_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_offset_str (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_offset_str", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_offset_str", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_32_offset_str(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_32_offset_str(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_offset_str", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":646
 * 
 *     def _offset_str(self) -> str:
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     # ------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_r = __pyx_kp_u__15;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":645
 *         return fstr
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":650
 *     # ------------------------------------------------------------------
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("implemented by subclasses")
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 650, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 650, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 650, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_34_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_34_apply(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":651
 * 
 *     def _apply(self, other):
 *         raise NotImplementedError("implemented by subclasses")             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 651, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":650
 *     # ------------------------------------------------------------------
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("implemented by subclasses")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":653
 *         raise NotImplementedError("implemented by subclasses")
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 653, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 653, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 653, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_36_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_36_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_dtarr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":656
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(
 *             f"DateOffset subclass {type(self).__name__} "             # <<<<<<<<<<<<<<
 *             "does not have a vectorized implementation"
 *         )
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_DateOffset_subclass);
  __pyx_t_2 += 20;
  __Pyx_GIVEREF(__pyx_kp_u_DateOffset_subclass);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_DateOffset_subclass);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_does_not_have_a_vectorized_impl);
  __pyx_t_2 += 42;
  __Pyx_GIVEREF(__pyx_kp_u_does_not_have_a_vectorized_impl);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_does_not_have_a_vectorized_impl);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":655
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             f"DateOffset subclass {type(self).__name__} "
 *             "does not have a vectorized implementation"
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_NotImplementedError, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 655, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":653
 *         raise NotImplementedError("implemented by subclasses")
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":660
 *         )
 * 
 *     def rollback(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date backward to next offset only if not on offset.
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback, "\n        Roll provided date backward to next offset only if not on offset.\n\n        Returns\n        -------\n        TimeStamp\n            Rolled timestamp if not on offset, otherwise unchanged timestamp.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback = {"rollback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rollback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 660, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "rollback") < 0)) __PYX_ERR(0, 660, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rollback", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 660, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.rollback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rollback", 0);
  __Pyx_INCREF(__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":669
 *             Rolled timestamp if not on offset, otherwise unchanged timestamp.
 *         """
 *         dt = Timestamp(dt)             # <<<<<<<<<<<<<<
 *         if not self.is_on_offset(dt):
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_dt};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":670
 *         """
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_dt};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":671
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)             # <<<<<<<<<<<<<<
 *         return dt
 * 
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_3) < 0) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 671, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_t_2) < 0) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_tuple__24, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Subtract(__pyx_v_dt, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":670
 *         """
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":672
 *         if not self.is_on_offset(dt):
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt             # <<<<<<<<<<<<<<
 * 
 *     def rollforward(self, dt) -> datetime:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_dt) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dt, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_dt);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_dt);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":660
 *         )
 * 
 *     def rollback(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date backward to next offset only if not on offset.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.rollback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":674
 *         return dt
 * 
 *     def rollforward(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date forward to next offset only if not on offset.
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward, "\n        Roll provided date forward to next offset only if not on offset.\n\n        Returns\n        -------\n        TimeStamp\n            Rolled timestamp if not on offset, otherwise unchanged timestamp.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward = {"rollforward", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rollforward (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 674, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "rollforward") < 0)) __PYX_ERR(0, 674, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rollforward", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 674, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.rollforward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_dt) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rollforward", 0);
  __Pyx_INCREF(__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":683
 *             Rolled timestamp if not on offset, otherwise unchanged timestamp.
 *         """
 *         dt = Timestamp(dt)             # <<<<<<<<<<<<<<
 *         if not self.is_on_offset(dt):
 *             dt = dt + type(self)(1, normalize=self.normalize, **self.kwds)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_dt};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":684
 *         """
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             dt = dt + type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_dt};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":685
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):
 *             dt = dt + type(self)(1, normalize=self.normalize, **self.kwds)             # <<<<<<<<<<<<<<
 *         return dt
 * 
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_3) < 0) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
      __PYX_ERR(0, 685, __pyx_L1_error)
    }
    if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_t_2) < 0) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_tuple__24, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_v_dt, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":684
 *         """
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             dt = dt + type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":686
 *         if not self.is_on_offset(dt):
 *             dt = dt + type(self)(1, normalize=self.normalize, **self.kwds)
 *         return dt             # <<<<<<<<<<<<<<
 * 
 *     def _get_offset_day(self, other: datetime) -> int:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_dt) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dt, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_dt);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_dt);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":674
 *         return dt
 * 
 *     def rollforward(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date forward to next offset only if not on offset.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.rollforward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":688
 *         return dt
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # subclass must implement `_day_opt`; calling from the base class
 *         # will implicitly assume day_opt = "business_end", see get_day_of_month.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day = {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_offset_day (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 688, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_offset_day") < 0)) __PYX_ERR(0, 688, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_offset_day", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 688, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_42_get_offset_day(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_42_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  npy_datetimestruct __pyx_v_dts;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_offset_day", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":693
 *         cdef:
 *             npy_datetimestruct dts
 *         pydate_to_dtstruct(other, &dts)             # <<<<<<<<<<<<<<
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 */
  if (!(likely(__Pyx_TypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_date)))) __PYX_ERR(0, 693, __pyx_L1_error)
  __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dtstruct(((PyDateTime_Date *)__pyx_v_other), (&__pyx_v_dts)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 693, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":694
 *             npy_datetimestruct dts
 *         pydate_to_dtstruct(other, &dts)
 *         return get_day_of_month(&dts, self._day_opt)             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 694, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month((&__pyx_v_dts), ((PyObject*)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_1)) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_1))) __PYX_ERR(0, 694, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":688
 *         return dt
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # subclass must implement `_day_opt`; calling from the base class
 *         # will implicitly assume day_opt = "business_end", see get_day_of_month.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":696
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp intersects with this frequency.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset, "\n        Return boolean whether a timestamp intersects with this frequency.\n\n        Parameters\n        ----------\n        dt : datetime.datetime\n            Timestamp to check intersections with frequency.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Day(1)\n        >>> freq.is_on_offset(ts)\n        True\n\n        >>> ts = pd.Timestamp(2022, 8, 6)\n        >>> ts.day_name()\n        'Saturday'\n        >>> freq = pd.offsets.BusinessDay(1)\n        >>> freq.is_on_offset(ts)\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 696, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 696, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 696, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 696, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyDateTime_DateTime *__pyx_v_a = NULL;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":719
 *         False
 *         """
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  if (__pyx_v_self->normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 719, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":720
 *         """
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         # Default (slow) method for determining if some date is a member of the
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":719
 *         False
 *         """
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":725
 *         # date range generated by this offset. Subclasses may have this
 *         # re-implemented in a nicer way.
 *         a = dt             # <<<<<<<<<<<<<<
 *         b = (dt + self) - self
 *         return a == b
 */
  __Pyx_INCREF((PyObject *)__pyx_v_dt);
  __pyx_v_a = __pyx_v_dt;

  /* "pandas/_libs/tslibs/offsets.pyx":726
 *         # re-implemented in a nicer way.
 *         a = dt
 *         b = (dt + self) - self             # <<<<<<<<<<<<<<
 *         return a == b
 * 
 */
  __pyx_t_4 = PyNumber_Add(((PyObject *)__pyx_v_dt), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Subtract(__pyx_t_4, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_b = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":727
 *         a = dt
 *         b = (dt + self) - self
 *         return a == b             # <<<<<<<<<<<<<<
 * 
 *     # ------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyObject_RichCompare(((PyObject *)__pyx_v_a), __pyx_v_b, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 727, __pyx_L1_error)
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":696
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp intersects with this frequency.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_a);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":733
 *     # Staticmethod so we can call from Tick.__init__, will be unnecessary
 *     #  once BaseOffset is a cdef class and is inherited by Tick
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _validate_n(n) -> int:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n, "\n        Require that `n` be an integer.\n\n        Parameters\n        ----------\n        n : int\n\n        Returns\n        -------\n        nint : int\n\n        Raises\n        ------\n        TypeError if `int(n)` raises\n        ValueError if n != int(n)\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n = {"_validate_n", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n(CYTHON_UNUSED PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_n = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_validate_n (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 733, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_validate_n") < 0)) __PYX_ERR(0, 733, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_n = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_validate_n", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 733, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._validate_n", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n(__pyx_v_n);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n(PyObject *__pyx_v_n) {
  PyObject *__pyx_v_nint = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_validate_n", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":751
 *         ValueError if n != int(n)
 *         """
 *         if util.is_timedelta64_object(n):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(__pyx_v_n); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 751, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":752
 *         """
 *         if util.is_timedelta64_object(n):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")             # <<<<<<<<<<<<<<
 *         try:
 *             nint = int(n)
 */
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_n)), __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_n_argument_must_be_an_integer_g, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 752, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":751
 *         ValueError if n != int(n)
 *         """
 *         if util.is_timedelta64_object(n):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":753
 *         if util.is_timedelta64_object(n):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:             # <<<<<<<<<<<<<<
 *             nint = int(n)
 *         except (ValueError, TypeError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":754
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:
 *             nint = int(n)             # <<<<<<<<<<<<<<
 *         except (ValueError, TypeError):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 */
      __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 754, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_nint = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":753
 *         if util.is_timedelta64_object(n):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:             # <<<<<<<<<<<<<<
 *             nint = int(n)
 *         except (ValueError, TypeError):
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":755
 *         try:
 *             nint = int(n)
 *         except (ValueError, TypeError):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         if n != nint:
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._validate_n", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_8) < 0) __PYX_ERR(0, 755, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "pandas/_libs/tslibs/offsets.pyx":756
 *             nint = int(n)
 *         except (ValueError, TypeError):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")             # <<<<<<<<<<<<<<
 *         if n != nint:
 *             raise ValueError(f"`n` argument must be an integer, got {n}")
 */
      __pyx_t_9 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_n)), __pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 756, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_kp_u_n_argument_must_be_an_integer_g, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 756, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 756, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(0, 756, __pyx_L6_except_error)
    }
    goto __pyx_L6_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":753
 *         if util.is_timedelta64_object(n):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         try:             # <<<<<<<<<<<<<<
 *             nint = int(n)
 *         except (ValueError, TypeError):
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":757
 *         except (ValueError, TypeError):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         if n != nint:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"`n` argument must be an integer, got {n}")
 *         return nint
 */
  __pyx_t_8 = PyObject_RichCompare(__pyx_v_n, __pyx_v_nint, Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 757, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 757, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":758
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         if n != nint:
 *             raise ValueError(f"`n` argument must be an integer, got {n}")             # <<<<<<<<<<<<<<
 *         return nint
 * 
 */
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_n, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_n_argument_must_be_an_integer_g, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 758, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":757
 *         except (ValueError, TypeError):
 *             raise TypeError(f"`n` argument must be an integer, got {type(n)}")
 *         if n != nint:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"`n` argument must be an integer, got {n}")
 *         return nint
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":759
 *         if n != nint:
 *             raise ValueError(f"`n` argument must be an integer, got {n}")
 *         return nint             # <<<<<<<<<<<<<<
 * 
 *     def __setstate__(self, state):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_v_nint))||((__pyx_v_nint) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_v_nint))) __PYX_ERR(0, 759, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_nint);
  __pyx_r = ((PyObject*)__pyx_v_nint);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":733
 *     # Staticmethod so we can call from Tick.__init__, will be unnecessary
 *     #  once BaseOffset is a cdef class and is inherited by Tick
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _validate_n(n) -> int:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset._validate_n", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nint);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":761
 *         return nint
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__, "\n        Reconstruct an instance from a pickled state\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 761, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 761, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 761, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":765
 *         Reconstruct an instance from a pickled state
 *         """
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self._cache = state.pop("_cache", {})
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_5 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 765, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->n = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":766
 *         """
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self._cache = state.pop("_cache", {})
 *         # At this point we expect state to be empty
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 766, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->normalize = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":767
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self._cache = state.pop("_cache", {})             # <<<<<<<<<<<<<<
 *         # At this point we expect state to be empty
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_n_u_cache, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 767, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_cache);
  __Pyx_DECREF(__pyx_v_self->_cache);
  __pyx_v_self->_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":761
 *         return nint
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":770
 *         # At this point we expect state to be empty
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__, "\n        Return a pickleable state\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__ = {"__getstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__getstate__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__getstate__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getstate__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":774
 *         Return a pickleable state
 *         """
 *         state = {}             # <<<<<<<<<<<<<<
 *         state["n"] = self.n
 *         state["normalize"] = self.normalize
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":775
 *         """
 *         state = {}
 *         state["n"] = self.n             # <<<<<<<<<<<<<<
 *         state["normalize"] = self.normalize
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_state, __pyx_n_u_n, __pyx_t_1) < 0))) __PYX_ERR(0, 775, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":776
 *         state = {}
 *         state["n"] = self.n
 *         state["normalize"] = self.normalize             # <<<<<<<<<<<<<<
 * 
 *         # we don't want to actually pickle the calendar object
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyDict_SetItem(__pyx_v_state, __pyx_n_u_normalize, __pyx_t_1) < 0))) __PYX_ERR(0, 776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":780
 *         # we don't want to actually pickle the calendar object
 *         # as its a np.busyday; we recreate on deserialization
 *         state.pop("calendar", None)             # <<<<<<<<<<<<<<
 *         if "kwds" in state:
 *             state["kwds"].pop("calendar", None)
 */
  __pyx_t_1 = __Pyx_PyDict_Pop(__pyx_v_state, __pyx_n_u_calendar, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":781
 *         # as its a np.busyday; we recreate on deserialization
 *         state.pop("calendar", None)
 *         if "kwds" in state:             # <<<<<<<<<<<<<<
 *             state["kwds"].pop("calendar", None)
 * 
 */
  __pyx_t_2 = (__Pyx_PyDict_ContainsTF(__pyx_n_u_kwds, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 781, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":782
 *         state.pop("calendar", None)
 *         if "kwds" in state:
 *             state["kwds"].pop("calendar", None)             # <<<<<<<<<<<<<<
 * 
 *         return state
 */
    __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_state, __pyx_n_u_kwds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":781
 *         # as its a np.busyday; we recreate on deserialization
 *         state.pop("calendar", None)
 *         if "kwds" in state:             # <<<<<<<<<<<<<<
 *             state["kwds"].pop("calendar", None)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":784
 *             state["kwds"].pop("calendar", None)
 * 
 *         return state             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_state);
  __pyx_r = __pyx_v_state;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":770
 *         # At this point we expect state to be empty
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":786
 *         return state
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nanos(self):
 *         raise ValueError(f"{self} is a non-fixed frequency")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":788
 *     @property
 *     def nanos(self):
 *         raise ValueError(f"{self} is a non-fixed frequency")             # <<<<<<<<<<<<<<
 * 
 *     def is_anchored(self) -> bool:
 */
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(((PyObject *)__pyx_v_self), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_1, __pyx_kp_u_is_a_non_fixed_frequency); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 788, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":786
 *         return state
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nanos(self):
 *         raise ValueError(f"{self} is a non-fixed frequency")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.nanos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":790
 *         raise ValueError(f"{self} is a non-fixed frequency")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         # TODO: Does this make sense for the general case?  It would help
 *         # if there were a canonical docstring for what is_anchored means.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored, "\n        Return boolean whether the frequency is a unit frequency (n=1).\n\n        Examples\n        --------\n        >>> pd.DateOffset().is_anchored()\n        True\n        >>> pd.DateOffset(2).is_anchored()\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored = {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_anchored", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_anchored", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_anchored", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":803
 *         False
 *         """
 *         return self.n == 1             # <<<<<<<<<<<<<<
 * 
 *     # ------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong((__pyx_v_self->n == 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":790
 *         raise ValueError(f"{self} is a non-fixed frequency")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         # TODO: Does this make sense for the general case?  It would help
 *         # if there were a canonical docstring for what is_anchored means.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_anchored", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":807
 *     # ------------------------------------------------------------------
 * 
 *     def is_month_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month start.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start, "\n        Return boolean whether a timestamp occurs on the month start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_month_start(ts)\n        True\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start = {"is_month_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_month_start (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 807, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_month_start") < 0)) __PYX_ERR(0, 807, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_month_start", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 807, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_month_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 807, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_month_start", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":818
 *         True
 *         """
 *         return ts._get_start_end_field("is_month_start", self)             # <<<<<<<<<<<<<<
 * 
 *     def is_month_end(self, _Timestamp ts):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_month_start, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 818, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":807
 *     # ------------------------------------------------------------------
 * 
 *     def is_month_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month start.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_month_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":820
 *         return ts._get_start_end_field("is_month_start", self)
 * 
 *     def is_month_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month end.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end, "\n        Return boolean whether a timestamp occurs on the month end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_month_end(ts)\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end = {"is_month_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_month_end (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 820, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_month_end") < 0)) __PYX_ERR(0, 820, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_month_end", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 820, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_month_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 820, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_month_end", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":831
 *         False
 *         """
 *         return ts._get_start_end_field("is_month_end", self)             # <<<<<<<<<<<<<<
 * 
 *     def is_quarter_start(self, _Timestamp ts):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_month_end, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 831, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":820
 *         return ts._get_start_end_field("is_month_start", self)
 * 
 *     def is_month_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month end.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_month_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":833
 *         return ts._get_start_end_field("is_month_end", self)
 * 
 *     def is_quarter_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter start.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start, "\n        Return boolean whether a timestamp occurs on the quarter start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_quarter_start(ts)\n        True\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start = {"is_quarter_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_quarter_start (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 833, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_quarter_start") < 0)) __PYX_ERR(0, 833, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_quarter_start", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 833, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_quarter_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 833, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_quarter_start", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":844
 *         True
 *         """
 *         return ts._get_start_end_field("is_quarter_start", self)             # <<<<<<<<<<<<<<
 * 
 *     def is_quarter_end(self, _Timestamp ts):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_quarter_start, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 844, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 844, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":833
 *         return ts._get_start_end_field("is_month_end", self)
 * 
 *     def is_quarter_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter start.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_quarter_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":846
 *         return ts._get_start_end_field("is_quarter_start", self)
 * 
 *     def is_quarter_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter end.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end, "\n        Return boolean whether a timestamp occurs on the quarter end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_quarter_end(ts)\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end = {"is_quarter_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_quarter_end (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 846, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_quarter_end") < 0)) __PYX_ERR(0, 846, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_quarter_end", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 846, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_quarter_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 846, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_quarter_end", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":857
 *         False
 *         """
 *         return ts._get_start_end_field("is_quarter_end", self)             # <<<<<<<<<<<<<<
 * 
 *     def is_year_start(self, _Timestamp ts):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_quarter_end, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 857, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 857, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":846
 *         return ts._get_start_end_field("is_quarter_start", self)
 * 
 *     def is_quarter_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter end.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_quarter_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":859
 *         return ts._get_start_end_field("is_quarter_end", self)
 * 
 *     def is_year_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year start.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start, "\n        Return boolean whether a timestamp occurs on the year start.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_year_start(ts)\n        True\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start = {"is_year_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_year_start (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 859, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_year_start") < 0)) __PYX_ERR(0, 859, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_year_start", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 859, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_year_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 859, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_year_start", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":870
 *         True
 *         """
 *         return ts._get_start_end_field("is_year_start", self)             # <<<<<<<<<<<<<<
 * 
 *     def is_year_end(self, _Timestamp ts):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_year_start, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 870, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 870, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":859
 *         return ts._get_start_end_field("is_quarter_end", self)
 * 
 *     def is_year_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year start.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_year_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":872
 *         return ts._get_start_end_field("is_year_start", self)
 * 
 *     def is_year_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year end.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end, "\n        Return boolean whether a timestamp occurs on the year end.\n\n        Examples\n        --------\n        >>> ts = pd.Timestamp(2022, 1, 1)\n        >>> freq = pd.offsets.Hour(5)\n        >>> freq.is_year_end(ts)\n        False\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end = {"is_year_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_year_end (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_ts,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ts)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 872, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_year_end") < 0)) __PYX_ERR(0, 872, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_ts = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_year_end", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 872, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_year_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_ts), __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp, 1, "ts", 0))) __PYX_ERR(0, 872, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v_ts);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp *__pyx_v_ts) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_year_end", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":883
 *         False
 *         """
 *         return ts._get_start_end_field("is_year_end", self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp *)__pyx_v_ts->__pyx_vtab)->_get_start_end_field(__pyx_v_ts, __pyx_n_u_is_year_end, ((PyObject *)__pyx_v_self)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 883, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":872
 *         return ts._get_start_end_field("is_year_start", self)
 * 
 *     def is_year_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year end.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.is_year_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pxd":10
 * cdef class BaseOffset:
 *     cdef readonly:
 *         int64_t n             # <<<<<<<<<<<<<<
 *         bint normalize
 *         dict _cache
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.n.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pxd":11
 *     cdef readonly:
 *         int64_t n
 *         bint normalize             # <<<<<<<<<<<<<<
 *         dict _cache
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.normalize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pxd":12
 *         int64_t n
 *         bint normalize
 *         dict _cache             # <<<<<<<<<<<<<<
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_cache);
  __pyx_r = __pyx_v_self->_cache;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_66__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_66__reduce_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self._cache, self.n, self.normalize)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->normalize); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->_cache);
  __Pyx_GIVEREF(__pyx_v_self->_cache);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->_cache)) __PYX_ERR(5, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(5, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict)) __PYX_ERR(5, 8, __pyx_L1_error);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._cache is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self._cache is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->_cache != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._cache is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self._cache is not None
 *     if use_setstate:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyx_unpickle_BaseOffset); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_171034093);
    __Pyx_GIVEREF(__pyx_int_171034093);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_171034093)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None)) __PYX_ERR(5, 13, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(5, 13, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._cache is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_BaseOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_171034093);
    __Pyx_GIVEREF(__pyx_int_171034093);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_171034093)) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state)) __PYX_ERR(5, 15, __pyx_L1_error);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(5, 15, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(5, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(5, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_68__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_68__setstate_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(5, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_BaseOffset__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BaseOffset.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":887
 * 
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":888
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         # default _from_name calls cls with no args
 *         if suffix:
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 887, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 887, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 887, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SingleConstructorOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset__from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":887
 * 
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset__from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":890
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 *         if suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Bad freq suffix {suffix}")
 *         return cls()
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 890, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":891
 *         # default _from_name calls cls with no args
 *         if suffix:
 *             raise ValueError(f"Bad freq suffix {suffix}")             # <<<<<<<<<<<<<<
 *         return cls()
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_suffix, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Bad_freq_suffix, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 891, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 891, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":890
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 *         if suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Bad freq suffix {suffix}")
 *         return cls()
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":892
 *         if suffix:
 *             raise ValueError(f"Bad freq suffix {suffix}")
 *         return cls()             # <<<<<<<<<<<<<<
 * 
 *     def __reduce__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_v_cls)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":887
 * 
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SingleConstructorOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__ = {"__reduce__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_2__reduce__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":900
 *         #  from attributes that do get pickled.
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None             # <<<<<<<<<<<<<<
 *             for attr in self._attributes
 *         )
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 900, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___2generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_reduce___locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SingleConstructorOffset.__reduce__.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___2generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 900, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":901
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None
 *             for attr in self._attributes             # <<<<<<<<<<<<<<
 *         )
 *         return type(self), tup
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 901, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 901, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 901, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 901, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 901, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 901, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 901, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_attr);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_attr, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":900
 *         #  from attributes that do get pickled.
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None             # <<<<<<<<<<<<<<
 *             for attr in self._attributes
 *         )
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_attr, __pyx_n_u_calendar, Py_NE)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 900, __pyx_L1_error)
    if (__pyx_t_5) {
      if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 900, __pyx_L1_error) }
      __pyx_t_6 = ((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_GetAttr(__pyx_t_6, __pyx_cur_scope->__pyx_v_attr); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 900, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_4 = __pyx_t_7;
      __pyx_t_7 = 0;
    } else {
      __Pyx_INCREF(Py_None);
      __pyx_t_4 = Py_None;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 900, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":901
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None
 *             for attr in self._attributes             # <<<<<<<<<<<<<<
 *         )
 *         return type(self), tup
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "pandas/_libs/tslibs/offsets.pyx":900
 *         #  from attributes that do get pickled.
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None             # <<<<<<<<<<<<<<
 *             for attr in self._attributes
 *         )
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_2__reduce__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset *__pyx_v_self) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *__pyx_cur_scope;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___2generator3 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce__", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 894, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "pandas/_libs/tslibs/offsets.pyx":901
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None
 *             for attr in self._attributes             # <<<<<<<<<<<<<<
 *         )
 *         return type(self), tup
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_attributes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 901, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pandas/_libs/tslibs/offsets.pyx":900
 *         #  from attributes that do get pickled.
 *         tup = tuple(
 *             getattr(self, attr) if attr != "calendar" else None             # <<<<<<<<<<<<<<
 *             for attr in self._attributes
 *         )
 */
  __pyx_t_2 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":899
 *         # np.busdaycalendar objects do not pickle nicely, but we can reconstruct
 *         #  from attributes that do get pickled.
 *         tup = tuple(             # <<<<<<<<<<<<<<
 *             getattr(self, attr) if attr != "calendar" else None
 *             for attr in self._attributes
 */
  __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 899, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tup = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":903
 *             for attr in self._attributes
 *         )
 *         return type(self), tup             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_cur_scope->__pyx_v_self))));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_cur_scope->__pyx_v_self))));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_cur_scope->__pyx_v_self))))) __PYX_ERR(0, 903, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_tup);
  __Pyx_GIVEREF(__pyx_v_tup);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_tup)) __PYX_ERR(0, 903, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SingleConstructorOffset.__reduce__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_10__reduce___2generator3);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":915
 *     _attributes = tuple(["n", "normalize"])
 * 
 *     def __init__(self, n=1, normalize=False):             # <<<<<<<<<<<<<<
 *         n = self._validate_n(n)
 *         self.n = n
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 915, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 915, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 915, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 915, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_n);

  /* "pandas/_libs/tslibs/offsets.pyx":916
 * 
 *     def __init__(self, n=1, normalize=False):
 *         n = self._validate_n(n)             # <<<<<<<<<<<<<<
 *         self.n = n
 *         self.normalize = False
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_validate_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":917
 *     def __init__(self, n=1, normalize=False):
 *         n = self._validate_n(n)
 *         self.n = n             # <<<<<<<<<<<<<<
 *         self.normalize = False
 *         self._cache = {}
 */
  __pyx_t_5 = __Pyx_PyInt_As_npy_int64(__pyx_v_n); if (unlikely((__pyx_t_5 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 917, __pyx_L1_error)
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":918
 *         n = self._validate_n(n)
 *         self.n = n
 *         self.normalize = False             # <<<<<<<<<<<<<<
 *         self._cache = {}
 *         if normalize:
 */
  __pyx_v_self->__pyx_base.__pyx_base.normalize = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":919
 *         self.n = n
 *         self.normalize = False
 *         self._cache = {}             # <<<<<<<<<<<<<<
 *         if normalize:
 *             # GH#21427
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 919, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __pyx_v_self->__pyx_base.__pyx_base._cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":920
 *         self.normalize = False
 *         self._cache = {}
 *         if normalize:             # <<<<<<<<<<<<<<
 *             # GH#21427
 *             raise ValueError(
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_normalize); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 920, __pyx_L1_error)
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/tslibs/offsets.pyx":922
 *         if normalize:
 *             # GH#21427
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "Tick offset with `normalize=True` are not allowed."
 *             )
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 922, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":920
 *         self.normalize = False
 *         self._cache = {}
 *         if normalize:             # <<<<<<<<<<<<<<
 *             # GH#21427
 *             raise ValueError(
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":915
 *     _attributes = tuple(["n", "normalize"])
 * 
 *     def __init__(self, n=1, normalize=False):             # <<<<<<<<<<<<<<
 *         n = self._validate_n(n)
 *         self.n = n
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":928
 *     # Note: Without making this cpdef, we get AttributeError when calling
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):             # <<<<<<<<<<<<<<
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Tick__next_higher_resolution(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, int __pyx_skip_dispatch) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_next_higher_resolution", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_higher_resolution); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 928, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 928, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick))))) __PYX_ERR(0, 928, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":929
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):
 *         if type(self) is Day:             # <<<<<<<<<<<<<<
 *             return Hour(self.n * 24)
 *         if type(self) is Hour:
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":930
 *     cpdef Tick _next_higher_resolution(Tick self):
 *         if type(self) is Day:
 *             return Hour(self.n * 24)             # <<<<<<<<<<<<<<
 *         if type(self) is Hour:
 *             return Minute(self.n * 60)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 24)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 930, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":929
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):
 *         if type(self) is Day:             # <<<<<<<<<<<<<<
 *             return Hour(self.n * 24)
 *         if type(self) is Hour:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":931
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 *         if type(self) is Hour:             # <<<<<<<<<<<<<<
 *             return Minute(self.n * 60)
 *         if type(self) is Minute:
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":932
 *             return Hour(self.n * 24)
 *         if type(self) is Hour:
 *             return Minute(self.n * 60)             # <<<<<<<<<<<<<<
 *         if type(self) is Minute:
 *             return Second(self.n * 60)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 60)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":931
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 *         if type(self) is Hour:             # <<<<<<<<<<<<<<
 *             return Minute(self.n * 60)
 *         if type(self) is Minute:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":933
 *         if type(self) is Hour:
 *             return Minute(self.n * 60)
 *         if type(self) is Minute:             # <<<<<<<<<<<<<<
 *             return Second(self.n * 60)
 *         if type(self) is Second:
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":934
 *             return Minute(self.n * 60)
 *         if type(self) is Minute:
 *             return Second(self.n * 60)             # <<<<<<<<<<<<<<
 *         if type(self) is Second:
 *             return Milli(self.n * 1000)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 60)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":933
 *         if type(self) is Hour:
 *             return Minute(self.n * 60)
 *         if type(self) is Minute:             # <<<<<<<<<<<<<<
 *             return Second(self.n * 60)
 *         if type(self) is Second:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":935
 *         if type(self) is Minute:
 *             return Second(self.n * 60)
 *         if type(self) is Second:             # <<<<<<<<<<<<<<
 *             return Milli(self.n * 1000)
 *         if type(self) is Milli:
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":936
 *             return Second(self.n * 60)
 *         if type(self) is Second:
 *             return Milli(self.n * 1000)             # <<<<<<<<<<<<<<
 *         if type(self) is Milli:
 *             return Micro(self.n * 1000)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 0x3E8)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 936, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":935
 *         if type(self) is Minute:
 *             return Second(self.n * 60)
 *         if type(self) is Second:             # <<<<<<<<<<<<<<
 *             return Milli(self.n * 1000)
 *         if type(self) is Milli:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":937
 *         if type(self) is Second:
 *             return Milli(self.n * 1000)
 *         if type(self) is Milli:             # <<<<<<<<<<<<<<
 *             return Micro(self.n * 1000)
 *         if type(self) is Micro:
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":938
 *             return Milli(self.n * 1000)
 *         if type(self) is Milli:
 *             return Micro(self.n * 1000)             # <<<<<<<<<<<<<<
 *         if type(self) is Micro:
 *             return Nano(self.n * 1000)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 0x3E8)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":937
 *         if type(self) is Second:
 *             return Milli(self.n * 1000)
 *         if type(self) is Milli:             # <<<<<<<<<<<<<<
 *             return Micro(self.n * 1000)
 *         if type(self) is Micro:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":939
 *         if type(self) is Milli:
 *             return Micro(self.n * 1000)
 *         if type(self) is Micro:             # <<<<<<<<<<<<<<
 *             return Nano(self.n * 1000)
 *         raise ValueError("Could not convert to integer offset at any resolution")
 */
  __pyx_t_6 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro));
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":940
 *             return Micro(self.n * 1000)
 *         if type(self) is Micro:
 *             return Nano(self.n * 1000)             # <<<<<<<<<<<<<<
 *         raise ValueError("Could not convert to integer offset at any resolution")
 * 
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64((__pyx_v_self->__pyx_base.__pyx_base.n * 0x3E8)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano), __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 940, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":939
 *         if type(self) is Milli:
 *             return Micro(self.n * 1000)
 *         if type(self) is Micro:             # <<<<<<<<<<<<<<
 *             return Nano(self.n * 1000)
 *         raise ValueError("Could not convert to integer offset at any resolution")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":941
 *         if type(self) is Micro:
 *             return Nano(self.n * 1000)
 *         raise ValueError("Could not convert to integer offset at any resolution")             # <<<<<<<<<<<<<<
 * 
 *     # --------------------------------------------------------------------
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 941, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":928
 *     # Note: Without making this cpdef, we get AttributeError when calling
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):             # <<<<<<<<<<<<<<
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick._next_higher_resolution", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution = {"_next_higher_resolution", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_next_higher_resolution (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_next_higher_resolution", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_next_higher_resolution", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_2_next_higher_resolution(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_2_next_higher_resolution(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_next_higher_resolution", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Tick__next_higher_resolution(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick._next_higher_resolution", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":945
 *     # --------------------------------------------------------------------
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         # Since cdef classes have no __dict__, we need to override
 *         return ""
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs = {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_attrs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_attrs", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_attrs", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_4_repr_attrs(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_4_repr_attrs(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_attrs", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":947
 *     def _repr_attrs(self) -> str:
 *         # Since cdef classes have no __dict__, we need to override
 *         return ""             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_r = __pyx_kp_u__15;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":945
 *     # --------------------------------------------------------------------
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         # Since cdef classes have no __dict__, we need to override
 *         return ""
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":949
 *         return ""
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def delta(self):
 *         return self.n * Timedelta(self._nanos_inc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":951
 *     @property
 *     def delta(self):
 *         return self.n * Timedelta(self._nanos_inc)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nanos_inc); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 951, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":949
 *         return ""
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def delta(self):
 *         return self.n * Timedelta(self._nanos_inc)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.delta.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":953
 *         return self.n * Timedelta(self._nanos_inc)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nanos(self) -> int64_t:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":968
 *         18000000000000
 *         """
 *         return self.n * self._nanos_inc             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nanos_inc); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":953
 *         return self.n * Timedelta(self._nanos_inc)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nanos(self) -> int64_t:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.nanos.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":970
 *         return self.n * self._nanos_inc
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         return True
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 970, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 970, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 970, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 970, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_6is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_6is_on_offset(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, CYTHON_UNUSED PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":971
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def is_anchored(self) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":970
 *         return self.n * self._nanos_inc
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         return True
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":973
 *         return True
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored = {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_anchored", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_anchored", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_8is_anchored(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_8is_anchored(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":974
 * 
 *     def is_anchored(self) -> bool:
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     # This is identical to BaseOffset.__hash__, but has to be redefined here
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":973
 *         return True
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":978
 *     # This is identical to BaseOffset.__hash__, but has to be redefined here
 *     # for Python 3, because we've redefined __eq__.
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash(self._params)
 * 
 */

/* Python wrapper */
static Py_hash_t __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_11__hash__(PyObject *__pyx_v_self); /*proto*/
static Py_hash_t __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_11__hash__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__hash__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_10__hash__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_hash_t __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_10__hash__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self) {
  Py_hash_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_hash_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__hash__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":979
 *     # for Python 3, because we've redefined __eq__.
 *     def __hash__(self) -> int:
 *         return hash(self._params)             # <<<<<<<<<<<<<<
 * 
 *     # --------------------------------------------------------------------
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_params); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Hash(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_hash_t)-1))) __PYX_ERR(0, 979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":978
 *     # This is identical to BaseOffset.__hash__, but has to be redefined here
 *     # for Python 3, because we've redefined __eq__.
 *     def __hash__(self) -> int:             # <<<<<<<<<<<<<<
 *         return hash(self._params)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__hash__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  if (unlikely(__pyx_r == -1) && !PyErr_Occurred()) __pyx_r = -2;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":984
 *     # Comparison and Arithmetic Methods
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, str):
 *             try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_13__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_13__eq__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__eq__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_12__eq__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_12__eq__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__eq__", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":985
 * 
 *     def __eq__(self, other):
 *         if isinstance(other, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # GH#23524 if to_offset fails, we are dealing with an
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_other); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":986
 *     def __eq__(self, other):
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":989
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 *                 other = to_offset(other)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 # e.g. "infer"
 */
        __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset(__pyx_v_other, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 989, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":986
 *     def __eq__(self, other):
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":990
 *                 #  incomparable type so == is False and != is True
 *                 other = to_offset(other)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 # e.g. "infer"
 *                 return False
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 990, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);

        /* "pandas/_libs/tslibs/offsets.pyx":992
 *             except ValueError:
 *                 # e.g. "infer"
 *                 return False             # <<<<<<<<<<<<<<
 *         return self.delta == other
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "pandas/_libs/tslibs/offsets.pyx":986
 *     def __eq__(self, other):
 *         if isinstance(other, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # GH#23524 if to_offset fails, we are dealing with an
 *                 #  incomparable type so == is False and != is True
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":985
 * 
 *     def __eq__(self, other):
 *         if isinstance(other, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # GH#23524 if to_offset fails, we are dealing with an
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":993
 *                 # e.g. "infer"
 *                 return False
 *         return self.delta == other             # <<<<<<<<<<<<<<
 * 
 *     def __ne__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_8, __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 993, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":984
 *     # Comparison and Arithmetic Methods
 * 
 *     def __eq__(self, other):             # <<<<<<<<<<<<<<
 *         if isinstance(other, str):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__eq__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":995
 *         return self.delta == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_15__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_15__ne__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ne__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_14__ne__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_14__ne__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ne__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":996
 * 
 *     def __ne__(self, other):
 *         return not (self == other)             # <<<<<<<<<<<<<<
 * 
 *     def __le__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_self), __pyx_v_other, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 996, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong((!__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":995
 *         return self.delta == other
 * 
 *     def __ne__(self, other):             # <<<<<<<<<<<<<<
 *         return not (self == other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__ne__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":998
 *         return not (self == other)
 * 
 *     def __le__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__le__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_17__le__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_17__le__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__le__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_16__le__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_16__le__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__le__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":999
 * 
 *     def __le__(self, other):
 *         return self.delta.__le__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __lt__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_le); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":998
 *         return not (self == other)
 * 
 *     def __le__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__le__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__le__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1001
 *         return self.delta.__le__(other)
 * 
 *     def __lt__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__lt__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_19__lt__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_19__lt__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__lt__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_18__lt__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_18__lt__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__lt__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1002
 * 
 *     def __lt__(self, other):
 *         return self.delta.__lt__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __ge__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1002, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1001
 *         return self.delta.__le__(other)
 * 
 *     def __lt__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__lt__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__lt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1004
 *         return self.delta.__lt__(other)
 * 
 *     def __ge__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__ge__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_21__ge__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_21__ge__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__ge__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_20__ge__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_20__ge__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__ge__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1005
 * 
 *     def __ge__(self, other):
 *         return self.delta.__ge__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __gt__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ge); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1004
 *         return self.delta.__lt__(other)
 * 
 *     def __ge__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__ge__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__ge__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1007
 *         return self.delta.__ge__(other)
 * 
 *     def __gt__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__gt__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_23__gt__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_23__gt__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__gt__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_22__gt__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_22__gt__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__gt__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1008
 * 
 *     def __gt__(self, other):
 *         return self.delta.__gt__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __mul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_gt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1007
 *         return self.delta.__ge__(other)
 * 
 *     def __gt__(self, other):             # <<<<<<<<<<<<<<
 *         return self.delta.__gt__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__gt__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1010
 *         return self.delta.__gt__(other)
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # TODO(cython3), remove this, this moved to __rmul__
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_25__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_25__mul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__mul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_24__mul__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_24__mul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_n = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_new_self = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__mul__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1011
 * 
 *     def __mul__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # TODO(cython3), remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1014
 *             # TODO(cython3), remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 *             return other.__mul__(self)             # <<<<<<<<<<<<<<
 *         if is_float_object(other):
 *             n = other * self.n
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_mul); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1014, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1011
 * 
 *     def __mul__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # TODO(cython3), remove this, this moved to __rmul__
 *             # cython semantics, this is __rmul__
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1015
 *             # cython semantics, this is __rmul__
 *             return other.__mul__(self)
 *         if is_float_object(other):             # <<<<<<<<<<<<<<
 *             n = other * self.n
 *             # If the new `n` is an integer, we can represent it using the
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1015, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1016
 *             return other.__mul__(self)
 *         if is_float_object(other):
 *             n = other * self.n             # <<<<<<<<<<<<<<
 *             # If the new `n` is an integer, we can represent it using the
 *             #  same Tick subclass as self, otherwise we need to move up
 */
    __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_other, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1016, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_n = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1020
 *             #  same Tick subclass as self, otherwise we need to move up
 *             #  to a higher-resolution subclass
 *             if np.isclose(n % 1, 0):             # <<<<<<<<<<<<<<
 *                 return type(self)(int(n))
 *             new_self = self._next_higher_resolution()
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_isclose); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_RemainderObjC(__pyx_v_n, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_3, __pyx_int_0};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1020, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1020, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1021
 *             #  to a higher-resolution subclass
 *             if np.isclose(n % 1, 0):
 *                 return type(self)(int(n))             # <<<<<<<<<<<<<<
 *             new_self = self._next_higher_resolution()
 *             return new_self * other
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1021, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
      __pyx_t_3 = ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))); __pyx_t_7 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1021, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1020
 *             #  same Tick subclass as self, otherwise we need to move up
 *             #  to a higher-resolution subclass
 *             if np.isclose(n % 1, 0):             # <<<<<<<<<<<<<<
 *                 return type(self)(int(n))
 *             new_self = self._next_higher_resolution()
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1022
 *             if np.isclose(n % 1, 0):
 *                 return type(self)(int(n))
 *             new_self = self._next_higher_resolution()             # <<<<<<<<<<<<<<
 *             return new_self * other
 *         return BaseOffset.__mul__(self, other)
 */
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self->__pyx_vtab)->_next_higher_resolution(__pyx_v_self, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1022, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_new_self = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1023
 *                 return type(self)(int(n))
 *             new_self = self._next_higher_resolution()
 *             return new_self * other             # <<<<<<<<<<<<<<
 *         return BaseOffset.__mul__(self, other)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyNumber_Multiply(((PyObject *)__pyx_v_new_self), __pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1023, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1015
 *             # cython semantics, this is __rmul__
 *             return other.__mul__(self)
 *         if is_float_object(other):             # <<<<<<<<<<<<<<
 *             n = other * self.n
 *             # If the new `n` is an integer, we can represent it using the
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1024
 *             new_self = self._next_higher_resolution()
 *             return new_self * other
 *         return BaseOffset.__mul__(self, other)             # <<<<<<<<<<<<<<
 * 
 *     def __rmul__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_mul); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, ((PyObject *)__pyx_v_self), __pyx_v_other};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1010
 *         return self.delta.__gt__(other)
 * 
 *     def __mul__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # TODO(cython3), remove this, this moved to __rmul__
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__mul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF((PyObject *)__pyx_v_new_self);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1026
 *         return BaseOffset.__mul__(self, other)
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_27__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_27__rmul__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rmul__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_26__rmul__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_26__rmul__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rmul__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1027
 * 
 *     def __rmul__(self, other):
 *         return self.__mul__(other)             # <<<<<<<<<<<<<<
 * 
 *     def __truediv__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_mul); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1026
 *         return BaseOffset.__mul__(self, other)
 * 
 *     def __rmul__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__mul__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__rmul__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1029
 *         return self.__mul__(other)
 * 
 *     def __truediv__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # cython semantics mean the args are sometimes swapped
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_29__truediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_29__truediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__truediv__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_28__truediv__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_28__truediv__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__truediv__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1030
 * 
 *     def __truediv__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # cython semantics mean the args are sometimes swapped
 *             result = other.delta.__rtruediv__(self)
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1032
 *         if not isinstance(self, Tick):
 *             # cython semantics mean the args are sometimes swapped
 *             result = other.delta.__rtruediv__(self)             # <<<<<<<<<<<<<<
 *         else:
 *             result = self.delta.__truediv__(other)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_delta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1032, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_rtruediv); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1032, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1032, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1030
 * 
 *     def __truediv__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # cython semantics mean the args are sometimes swapped
 *             result = other.delta.__rtruediv__(self)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1034
 *             result = other.delta.__rtruediv__(self)
 *         else:
 *             result = self.delta.__truediv__(other)             # <<<<<<<<<<<<<<
 *         return _wrap_timedelta_result(result)
 * 
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_truediv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1034, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_result = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1035
 *         else:
 *             result = self.delta.__truediv__(other)
 *         return _wrap_timedelta_result(result)             # <<<<<<<<<<<<<<
 * 
 *     def __rtruediv__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__wrap_timedelta_result(__pyx_v_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1029
 *         return self.__mul__(other)
 * 
 *     def __truediv__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # cython semantics mean the args are sometimes swapped
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__truediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1037
 *         return _wrap_timedelta_result(result)
 * 
 *     def __rtruediv__(self, other):             # <<<<<<<<<<<<<<
 *         result = self.delta.__rtruediv__(other)
 *         return _wrap_timedelta_result(result)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_31__rtruediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_31__rtruediv__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__rtruediv__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_30__rtruediv__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_30__rtruediv__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__rtruediv__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1038
 * 
 *     def __rtruediv__(self, other):
 *         result = self.delta.__rtruediv__(other)             # <<<<<<<<<<<<<<
 *         return _wrap_timedelta_result(result)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_rtruediv); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1038, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1039
 *     def __rtruediv__(self, other):
 *         result = self.delta.__rtruediv__(other)
 *         return _wrap_timedelta_result(result)             # <<<<<<<<<<<<<<
 * 
 *     def __add__(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__wrap_timedelta_result(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1037
 *         return _wrap_timedelta_result(result)
 * 
 *     def __rtruediv__(self, other):             # <<<<<<<<<<<<<<
 *         result = self.delta.__rtruediv__(other)
 *         return _wrap_timedelta_result(result)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__rtruediv__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1041
 *         return _wrap_timedelta_result(result)
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # cython semantics; this is __radd__
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_33__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_33__add__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__add__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_32__add__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_32__add__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__add__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1042
 * 
 *     def __add__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1045
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 *             return other.__add__(self)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(other, Tick):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_add); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1045, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_self)};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1042
 * 
 *     def __add__(self, other):
 *         if not isinstance(self, Tick):             # <<<<<<<<<<<<<<
 *             # cython semantics; this is __radd__
 *             # TODO(cython3): remove this, this moved to __radd__
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1047
 *             return other.__add__(self)
 * 
 *         if isinstance(other, Tick):             # <<<<<<<<<<<<<<
 *             if type(self) == type(other):
 *                 return type(self)(self.n + other.n)
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); 
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1048
 * 
 *         if isinstance(other, Tick):
 *             if type(self) == type(other):             # <<<<<<<<<<<<<<
 *                 return type(self)(self.n + other.n)
 *             else:
 */
    __pyx_t_3 = PyObject_RichCompare(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), ((PyObject *)Py_TYPE(__pyx_v_other)), Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1048, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1048, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1049
 *         if isinstance(other, Tick):
 *             if type(self) == type(other):
 *                 return type(self)(self.n + other.n)             # <<<<<<<<<<<<<<
 *             else:
 *                 return delta_to_tick(self.delta + other.delta)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
      __pyx_t_5 = ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))); __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_7};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1049, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1048
 * 
 *         if isinstance(other, Tick):
 *             if type(self) == type(other):             # <<<<<<<<<<<<<<
 *                 return type(self)(self.n + other.n)
 *             else:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1051
 *                 return type(self)(self.n + other.n)
 *             else:
 *                 return delta_to_tick(self.delta + other.delta)             # <<<<<<<<<<<<<<
 *         try:
 *             return self._apply(other)
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_delta_to_tick); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_delta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyNumber_Add(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1051, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1047
 *             return other.__add__(self)
 * 
 *         if isinstance(other, Tick):             # <<<<<<<<<<<<<<
 *             if type(self) == type(other):
 *                 return type(self)(self.n + other.n)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1052
 *             else:
 *                 return delta_to_tick(self.delta + other.delta)
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    /*try:*/ {

      /* "pandas/_libs/tslibs/offsets.pyx":1053
 *                 return delta_to_tick(self.delta + other.delta)
 *         try:
 *             return self._apply(other)             # <<<<<<<<<<<<<<
 *         except ApplyTypeError:
 *             # Includes pd.Period
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1053, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_v_other};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1053, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L10_try_return;

      /* "pandas/_libs/tslibs/offsets.pyx":1052
 *             else:
 *                 return delta_to_tick(self.delta + other.delta)
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
    }
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1054
 *         try:
 *             return self._apply(other)
 *         except ApplyTypeError:             # <<<<<<<<<<<<<<
 *             # Includes pd.Period
 *             return NotImplemented
 */
    __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_5, &__pyx_t_8);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1054, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_ErrRestore(__pyx_t_3, __pyx_t_5, __pyx_t_8);
    __pyx_t_3 = 0; __pyx_t_5 = 0; __pyx_t_8 = 0;
    if (__pyx_t_6) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_5, &__pyx_t_3) < 0) __PYX_ERR(0, 1054, __pyx_L8_except_error)
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);

      /* "pandas/_libs/tslibs/offsets.pyx":1056
 *         except ApplyTypeError:
 *             # Includes pd.Period
 *             return NotImplemented             # <<<<<<<<<<<<<<
 *         except OverflowError as err:
 *             raise OverflowError(
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_builtin_NotImplemented);
      __pyx_r = __pyx_builtin_NotImplemented;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L9_except_return;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1057
 *             # Includes pd.Period
 *             return NotImplemented
 *         except OverflowError as err:             # <<<<<<<<<<<<<<
 *             raise OverflowError(
 *                 f"the add operation between {self} and {other} will overflow"
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OverflowError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 1057, __pyx_L8_except_error)
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_v_err = __pyx_t_5;
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":1059
 *         except OverflowError as err:
 *             raise OverflowError(
 *                 f"the add operation between {self} and {other} will overflow"             # <<<<<<<<<<<<<<
 *             ) from err
 * 
 */
        __pyx_t_4 = PyTuple_New(5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1059, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = 0;
        __pyx_t_13 = 127;
        __Pyx_INCREF(__pyx_kp_u_the_add_operation_between);
        __pyx_t_12 += 26;
        __Pyx_GIVEREF(__pyx_kp_u_the_add_operation_between);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_the_add_operation_between);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(((PyObject *)__pyx_v_self), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1059, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_u_and);
        __pyx_t_12 += 5;
        __Pyx_GIVEREF(__pyx_kp_u_and);
        PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u_and);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_other, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1059, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_u_will_overflow);
        __pyx_t_12 += 14;
        __Pyx_GIVEREF(__pyx_kp_u_will_overflow);
        PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_kp_u_will_overflow);
        __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_4, 5, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1059, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1058
 *             return NotImplemented
 *         except OverflowError as err:
 *             raise OverflowError(             # <<<<<<<<<<<<<<
 *                 f"the add operation between {self} and {other} will overflow"
 *             ) from err
 */
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_OverflowError, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1058, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1060
 *             raise OverflowError(
 *                 f"the add operation between {self} and {other} will overflow"
 *             ) from err             # <<<<<<<<<<<<<<
 * 
 *     def __radd__(self, other):
 */
        __Pyx_Raise(__pyx_t_4, 0, 0, __pyx_v_err);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1058, __pyx_L19_error)
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1057
 *             # Includes pd.Period
 *             return NotImplemented
 *         except OverflowError as err:             # <<<<<<<<<<<<<<
 *             raise OverflowError(
 *                 f"the add operation between {self} and {other} will overflow"
 */
      /*finally:*/ {
        __pyx_L19_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_6 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L8_except_error;
        }
      }
    }
    goto __pyx_L8_except_error;

    /* "pandas/_libs/tslibs/offsets.pyx":1052
 *             else:
 *                 return delta_to_tick(self.delta + other.delta)
 *         try:             # <<<<<<<<<<<<<<
 *             return self._apply(other)
 *         except ApplyTypeError:
 */
    __pyx_L8_except_error:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L1_error;
    __pyx_L10_try_return:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L0;
    __pyx_L9_except_return:;
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1041
 *         return _wrap_timedelta_result(result)
 * 
 *     def __add__(self, other):             # <<<<<<<<<<<<<<
 *         if not isinstance(self, Tick):
 *             # cython semantics; this is __radd__
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__add__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1062
 *             ) from err
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__add__(other)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_35__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_35__radd__(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__radd__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_34__radd__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_34__radd__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__radd__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1063
 * 
 *     def __radd__(self, other):
 *         return self.__add__(other)             # <<<<<<<<<<<<<<
 * 
 *     def _apply(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_add); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1062
 *             ) from err
 * 
 *     def __radd__(self, other):             # <<<<<<<<<<<<<<
 *         return self.__add__(other)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__radd__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1065
 *         return self.__add__(other)
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1065, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 1065, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1065, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_36_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_36_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1067
 *     def _apply(self, other):
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):             # <<<<<<<<<<<<<<
 *             # GH#15126
 *             return other + self.delta
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_other, __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1069
 *         if isinstance(other, _Timestamp):
 *             # GH#15126
 *             return other + self.delta             # <<<<<<<<<<<<<<
 *         elif other is NaT:
 *             return NaT
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1069, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_v_other, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1069, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1067
 *     def _apply(self, other):
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):             # <<<<<<<<<<<<<<
 *             # GH#15126
 *             return other + self.delta
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1070
 *             # GH#15126
 *             return other + self.delta
 *         elif other is NaT:             # <<<<<<<<<<<<<<
 *             return NaT
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 */
  __pyx_t_1 = (__pyx_v_other == ((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT));
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1071
 *             return other + self.delta
 *         elif other is NaT:
 *             return NaT             # <<<<<<<<<<<<<<
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 *             # PyDate_Check includes date, datetime
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT);
    __pyx_r = ((PyObject *)__pyx_v_6pandas_5_libs_6tslibs_7nattype_c_NaT);
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1070
 *             # GH#15126
 *             return other + self.delta
 *         elif other is NaT:             # <<<<<<<<<<<<<<
 *             return NaT
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1072
 *         elif other is NaT:
 *             return NaT
 *         elif is_datetime64_object(other) or PyDate_Check(other):             # <<<<<<<<<<<<<<
 *             # PyDate_Check includes date, datetime
 *             return Timestamp(other) + self
 */
  __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_datetime64_object(__pyx_v_other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1072, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyDate_Check(__pyx_v_other);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1074
 *         elif is_datetime64_object(other) or PyDate_Check(other):
 *             # PyDate_Check includes date, datetime
 *             return Timestamp(other) + self             # <<<<<<<<<<<<<<
 * 
 *         if util.is_timedelta64_object(other) or PyDelta_Check(other):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_other};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1074, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Add(__pyx_t_3, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1074, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1072
 *         elif other is NaT:
 *             return NaT
 *         elif is_datetime64_object(other) or PyDate_Check(other):             # <<<<<<<<<<<<<<
 *             # PyDate_Check includes date, datetime
 *             return Timestamp(other) + self
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1076
 *             return Timestamp(other) + self
 * 
 *         if util.is_timedelta64_object(other) or PyDelta_Check(other):             # <<<<<<<<<<<<<<
 *             return other + self.delta
 * 
 */
  __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(__pyx_v_other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1076, __pyx_L1_error)
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = PyDelta_Check(__pyx_v_other);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1077
 * 
 *         if util.is_timedelta64_object(other) or PyDelta_Check(other):
 *             return other + self.delta             # <<<<<<<<<<<<<<
 * 
 *         raise ApplyTypeError(f"Unhandled type: {type(other).__name__}")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_delta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1077, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_v_other, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1077, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1076
 *             return Timestamp(other) + self
 * 
 *         if util.is_timedelta64_object(other) or PyDelta_Check(other):             # <<<<<<<<<<<<<<
 *             return other + self.delta
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1079
 *             return other + self.delta
 * 
 *         raise ApplyTypeError(f"Unhandled type: {type(other).__name__}")             # <<<<<<<<<<<<<<
 * 
 *     # --------------------------------------------------------------------
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_other)), __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Unhandled_type, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1079, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(0, 1079, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1065
 *         return self.__add__(other)
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1084
 *     # Pickle Methods
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state["n"]
 *         self.normalize = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1084, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1084, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1084, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_38__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Tick_38__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1085
 * 
 *     def __setstate__(self, state):
 *         self.n = state["n"]             # <<<<<<<<<<<<<<
 *         self.normalize = False
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_state, __pyx_n_u_n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1085, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_2 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1085, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":1086
 *     def __setstate__(self, state):
 *         self.n = state["n"]
 *         self.normalize = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->__pyx_base.__pyx_base.normalize = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1084
 *     # Pickle Methods
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state["n"]
 *         self.normalize = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Tick.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1145
 * 
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:             # <<<<<<<<<<<<<<
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 */

/* Python wrapper */
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7delta_to_tick(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_7delta_to_tick = {"delta_to_tick", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7delta_to_tick, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7delta_to_tick(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_Delta *__pyx_v_delta = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("delta_to_tick (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delta,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_delta)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1145, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "delta_to_tick") < 0)) __PYX_ERR(0, 1145, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_delta = ((PyDateTime_Delta *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("delta_to_tick", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1145, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.delta_to_tick", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_delta), __pyx_ptype_7cpython_8datetime_timedelta, 0, "delta", 0))) __PYX_ERR(0, 1145, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6delta_to_tick(__pyx_self, __pyx_v_delta);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6delta_to_tick(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_Delta *__pyx_v_delta) {
  PyObject *__pyx_v_seconds = NULL;
  PyObject *__pyx_v_nanos = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("delta_to_tick", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1146
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:             # <<<<<<<<<<<<<<
 *         # nanoseconds only for pd.Timedelta
 *         if delta.seconds == 0:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_delta), __pyx_n_s_microseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_delta), __pyx_n_u_nanoseconds, __pyx_int_0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1148
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 *         if delta.seconds == 0:             # <<<<<<<<<<<<<<
 *             return Day(delta.days)
 *         else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_delta), __pyx_n_s_seconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1148, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":1149
 *         # nanoseconds only for pd.Timedelta
 *         if delta.seconds == 0:
 *             return Day(delta.days)             # <<<<<<<<<<<<<<
 *         else:
 *             seconds = delta.days * 86400 + delta.seconds
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_delta), __pyx_n_s_days); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day), __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1149, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_4);
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1148
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 *         if delta.seconds == 0:             # <<<<<<<<<<<<<<
 *             return Day(delta.days)
 *         else:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1151
 *             return Day(delta.days)
 *         else:
 *             seconds = delta.days * 86400 + delta.seconds             # <<<<<<<<<<<<<<
 *             if seconds % 3600 == 0:
 *                 return Hour(seconds / 3600)
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_delta), __pyx_n_s_days); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyInt_MultiplyObjC(__pyx_t_4, __pyx_int_86400, 0x15180, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_delta), __pyx_n_s_seconds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_seconds = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1152
 *         else:
 *             seconds = delta.days * 86400 + delta.seconds
 *             if seconds % 3600 == 0:             # <<<<<<<<<<<<<<
 *                 return Hour(seconds / 3600)
 *             elif seconds % 60 == 0:
 */
      __pyx_t_5 = __Pyx_PyInt_RemainderObjC(__pyx_v_seconds, __pyx_int_3600, 0xE10, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_5, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1152, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_1) {

        /* "pandas/_libs/tslibs/offsets.pyx":1153
 *             seconds = delta.days * 86400 + delta.seconds
 *             if seconds % 3600 == 0:
 *                 return Hour(seconds / 3600)             # <<<<<<<<<<<<<<
 *             elif seconds % 60 == 0:
 *                 return Minute(seconds / 60)
 */
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __pyx_t_5 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_seconds, __pyx_int_3600, 0xE10, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_4);
        __pyx_t_4 = 0;
        goto __pyx_L0;

        /* "pandas/_libs/tslibs/offsets.pyx":1152
 *         else:
 *             seconds = delta.days * 86400 + delta.seconds
 *             if seconds % 3600 == 0:             # <<<<<<<<<<<<<<
 *                 return Hour(seconds / 3600)
 *             elif seconds % 60 == 0:
 */
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1154
 *             if seconds % 3600 == 0:
 *                 return Hour(seconds / 3600)
 *             elif seconds % 60 == 0:             # <<<<<<<<<<<<<<
 *                 return Minute(seconds / 60)
 *             else:
 */
      __pyx_t_4 = __Pyx_PyInt_RemainderObjC(__pyx_v_seconds, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_4, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1154, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_1) {

        /* "pandas/_libs/tslibs/offsets.pyx":1155
 *                 return Hour(seconds / 3600)
 *             elif seconds % 60 == 0:
 *                 return Minute(seconds / 60)             # <<<<<<<<<<<<<<
 *             else:
 *                 return Second(seconds)
 */
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __pyx_t_4 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_seconds, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1155, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1155, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L0;

        /* "pandas/_libs/tslibs/offsets.pyx":1154
 *             if seconds % 3600 == 0:
 *                 return Hour(seconds / 3600)
 *             elif seconds % 60 == 0:             # <<<<<<<<<<<<<<
 *                 return Minute(seconds / 60)
 *             else:
 */
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1157
 *                 return Minute(seconds / 60)
 *             else:
 *                 return Second(seconds)             # <<<<<<<<<<<<<<
 *     else:
 *         nanos = delta_to_nanoseconds(delta)
 */
      /*else*/ {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second), __pyx_v_seconds); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1157, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L0;
      }
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1146
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:             # <<<<<<<<<<<<<<
 *         # nanoseconds only for pd.Timedelta
 *         if delta.seconds == 0:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1159
 *                 return Second(seconds)
 *     else:
 *         nanos = delta_to_nanoseconds(delta)             # <<<<<<<<<<<<<<
 *         if nanos % 1_000_000 == 0:
 *             return Milli(nanos // 1_000_000)
 */
  /*else*/ {
    __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds(((PyObject *)__pyx_v_delta), 0, NULL); if (unlikely(__pyx_t_6 == ((__pyx_t_5numpy_int64_t)-1LL) && PyErr_Occurred())) __PYX_ERR(0, 1159, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyInt_From_npy_int64(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_nanos = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1160
 *     else:
 *         nanos = delta_to_nanoseconds(delta)
 *         if nanos % 1_000_000 == 0:             # <<<<<<<<<<<<<<
 *             return Milli(nanos // 1_000_000)
 *         elif nanos % 1000 == 0:
 */
    __pyx_t_5 = __Pyx_PyInt_RemainderObjC(__pyx_v_nanos, __pyx_int_1000000, 0xF4240, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_5, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1160, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":1161
 *         nanos = delta_to_nanoseconds(delta)
 *         if nanos % 1_000_000 == 0:
 *             return Milli(nanos // 1_000_000)             # <<<<<<<<<<<<<<
 *         elif nanos % 1000 == 0:
 *             return Micro(nanos // 1000)
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_nanos, __pyx_int_1000000, 0xF4240, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli), __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_4);
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1160
 *     else:
 *         nanos = delta_to_nanoseconds(delta)
 *         if nanos % 1_000_000 == 0:             # <<<<<<<<<<<<<<
 *             return Milli(nanos // 1_000_000)
 *         elif nanos % 1000 == 0:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1162
 *         if nanos % 1_000_000 == 0:
 *             return Milli(nanos // 1_000_000)
 *         elif nanos % 1000 == 0:             # <<<<<<<<<<<<<<
 *             return Micro(nanos // 1000)
 *         else:  # pragma: no cover
 */
    __pyx_t_4 = __Pyx_PyInt_RemainderObjC(__pyx_v_nanos, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_4, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1162, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":1163
 *             return Milli(nanos // 1_000_000)
 *         elif nanos % 1000 == 0:
 *             return Micro(nanos // 1000)             # <<<<<<<<<<<<<<
 *         else:  # pragma: no cover
 *             return Nano(nanos)
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_4 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_nanos, __pyx_int_1000, 0x3E8, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro), __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1162
 *         if nanos % 1_000_000 == 0:
 *             return Milli(nanos // 1_000_000)
 *         elif nanos % 1000 == 0:             # <<<<<<<<<<<<<<
 *             return Micro(nanos // 1000)
 *         else:  # pragma: no cover
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1165
 *             return Micro(nanos // 1000)
 *         else:  # pragma: no cover
 *             return Nano(nanos)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano), __pyx_v_nanos); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L0;
    }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1145
 * 
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:             # <<<<<<<<<<<<<<
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.delta_to_tick", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_seconds);
  __Pyx_XDECREF(__pyx_v_nanos);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1177
 *     _adjust_dst = False
 * 
 *     def __init__(self, n=1, normalize=False, **kwds):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         off, use_rd = _determine_offset(kwds)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_kwds = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_v_kwds = PyDict_New(); if (unlikely(!__pyx_v_kwds)) return -1;
  __Pyx_GOTREF(__pyx_v_kwds);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1177, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1177, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, __pyx_v_kwds, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1177, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, __pyx_nargs); __PYX_ERR(0, 1177, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_DECREF(__pyx_v_kwds); __pyx_v_kwds = 0;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_kwds);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_kwds);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_kwds) {
  PyObject *__pyx_v_off = NULL;
  PyObject *__pyx_v_use_rd = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_val = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1178
 * 
 *     def __init__(self, n=1, normalize=False, **kwds):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 *         off, use_rd = _determine_offset(kwds)
 *         object.__setattr__(self, "_offset", off)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1179
 *     def __init__(self, n=1, normalize=False, **kwds):
 *         BaseOffset.__init__(self, n, normalize)
 *         off, use_rd = _determine_offset(kwds)             # <<<<<<<<<<<<<<
 *         object.__setattr__(self, "_offset", off)
 *         object.__setattr__(self, "_use_relativedelta", use_rd)
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(__pyx_v_kwds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1179, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(0, 1179, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1179, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_off = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_use_rd = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1180
 *         BaseOffset.__init__(self, n, normalize)
 *         off, use_rd = _determine_offset(kwds)
 *         object.__setattr__(self, "_offset", off)             # <<<<<<<<<<<<<<
 *         object.__setattr__(self, "_use_relativedelta", use_rd)
 *         for key in kwds:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_setattr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_n_u_offset, __pyx_v_off};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1181
 *         off, use_rd = _determine_offset(kwds)
 *         object.__setattr__(self, "_offset", off)
 *         object.__setattr__(self, "_use_relativedelta", use_rd)             # <<<<<<<<<<<<<<
 *         for key in kwds:
 *             val = kwds[key]
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_setattr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, ((PyObject *)__pyx_v_self), __pyx_n_u_use_relativedelta, __pyx_v_use_rd};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1182
 *         object.__setattr__(self, "_offset", off)
 *         object.__setattr__(self, "_use_relativedelta", use_rd)
 *         for key in kwds:             # <<<<<<<<<<<<<<
 *             val = kwds[key]
 *             object.__setattr__(self, key, val)
 */
  __pyx_t_7 = 0;
  __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_kwds, 1, ((PyObject *)NULL), (&__pyx_t_8), (&__pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  while (1) {
    __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_8, &__pyx_t_7, &__pyx_t_3, NULL, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_9 == 0)) break;
    if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(0, 1182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1183
 *         object.__setattr__(self, "_use_relativedelta", use_rd)
 *         for key in kwds:
 *             val = kwds[key]             # <<<<<<<<<<<<<<
 *             object.__setattr__(self, key, val)
 * 
 */
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_kwds, __pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1184
 *         for key in kwds:
 *             val = kwds[key]
 *             object.__setattr__(self, key, val)             # <<<<<<<<<<<<<<
 * 
 *     def __getstate__(self):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_n_s_setattr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_5, ((PyObject *)__pyx_v_self), __pyx_v_key, __pyx_v_val};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1177
 *     _adjust_dst = False
 * 
 *     def __init__(self, n=1, normalize=False, **kwds):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         off, use_rd = _determine_offset(kwds)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_off);
  __Pyx_XDECREF(__pyx_v_use_rd);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1186
 *             object.__setattr__(self, key, val)
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__, "\n        Return a pickleable state\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__ = {"__getstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__getstate__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__getstate__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self) {
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getstate__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1192
 *         # RelativeDeltaOffset (technically DateOffset) is the only non-cdef
 *         #  class, so the only one with __dict__
 *         state = self.__dict__.copy()             # <<<<<<<<<<<<<<
 *         state["n"] = self.n
 *         state["normalize"] = self.normalize
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_dict); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_state = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1193
 *         #  class, so the only one with __dict__
 *         state = self.__dict__.copy()
 *         state["n"] = self.n             # <<<<<<<<<<<<<<
 *         state["normalize"] = self.normalize
 *         return state
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_v_state, __pyx_n_u_n, __pyx_t_1) < 0))) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1194
 *         state = self.__dict__.copy()
 *         state["n"] = self.n
 *         state["normalize"] = self.normalize             # <<<<<<<<<<<<<<
 *         return state
 * 
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.normalize); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_v_state, __pyx_n_u_normalize, __pyx_t_1) < 0))) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1195
 *         state["n"] = self.n
 *         state["normalize"] = self.normalize
 *         return state             # <<<<<<<<<<<<<<
 * 
 *     def __setstate__(self, state):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_state);
  __pyx_r = __pyx_v_state;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1186
 *             object.__setattr__(self, key, val)
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1197
 *         return state
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__, "\n        Reconstruct an instance from a pickled state\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1197, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1197, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1197, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1202
 *         """
 * 
 *         if "offset" in state:             # <<<<<<<<<<<<<<
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset_2, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1204
 *         if "offset" in state:
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover             # <<<<<<<<<<<<<<
 *                 raise AssertionError("Unexpected key `_offset`")
 *             state["_offset"] = state.pop("offset")
 */
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1204, __pyx_L1_error)
    if (unlikely(__pyx_t_1)) {

      /* "pandas/_libs/tslibs/offsets.pyx":1205
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover
 *                 raise AssertionError("Unexpected key `_offset`")             # <<<<<<<<<<<<<<
 *             state["_offset"] = state.pop("offset")
 *             state["kwds"]["offset"] = state["_offset"]
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_AssertionError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 1205, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":1204
 *         if "offset" in state:
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover             # <<<<<<<<<<<<<<
 *                 raise AssertionError("Unexpected key `_offset`")
 *             state["_offset"] = state.pop("offset")
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1206
 *             if "_offset" in state:  # pragma: no cover
 *                 raise AssertionError("Unexpected key `_offset`")
 *             state["_offset"] = state.pop("offset")             # <<<<<<<<<<<<<<
 *             state["kwds"]["offset"] = state["_offset"]
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_offset_2};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (unlikely((PyObject_SetItem(__pyx_v_state, __pyx_n_u_offset, __pyx_t_2) < 0))) __PYX_ERR(0, 1206, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1207
 *                 raise AssertionError("Unexpected key `_offset`")
 *             state["_offset"] = state.pop("offset")
 *             state["kwds"]["offset"] = state["_offset"]             # <<<<<<<<<<<<<<
 * 
 *         self.n = state.pop("n")
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_state, __pyx_n_u_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_state, __pyx_n_u_kwds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_n_u_offset_2, __pyx_t_2) < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1202
 *         """
 * 
 *         if "offset" in state:             # <<<<<<<<<<<<<<
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1209
 *             state["kwds"]["offset"] = state["_offset"]
 * 
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self._cache = state.pop("_cache", {})
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_n};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1209, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_2); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":1210
 * 
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self._cache = state.pop("_cache", {})
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_normalize};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_self->__pyx_base.normalize = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":1211
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self._cache = state.pop("_cache", {})             # <<<<<<<<<<<<<<
 * 
 *         self.__dict__.update(state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_n_u_cache, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_2))) __PYX_ERR(0, 1211, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base._cache);
  __Pyx_DECREF(__pyx_v_self->__pyx_base._cache);
  __pyx_v_self->__pyx_base._cache = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1213
 *         self._cache = state.pop("_cache", {})
 * 
 *         self.__dict__.update(state)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_dict); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_update); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_state};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1197
 *         return state
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1215
 *         self.__dict__.update(state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1215, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 1215, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1215, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 1216, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_6_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_tzinfo = NULL;
  PyObject *__pyx_v_td_nano = NULL;
  CYTHON_UNUSED __pyx_t_5numpy_int64_t __pyx_v_i;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __pyx_t_5numpy_int64_t __pyx_t_8;
  __pyx_t_5numpy_int64_t __pyx_t_9;
  __pyx_t_5numpy_int64_t __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":1217
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:             # <<<<<<<<<<<<<<
 *             other = _as_datetime(other)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_use_relativedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1218
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:
 *             other = _as_datetime(other)             # <<<<<<<<<<<<<<
 * 
 *         if len(self.kwds) > 0:
 */
    __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets__as_datetime(__pyx_v_other)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1217
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:             # <<<<<<<<<<<<<<
 *             other = _as_datetime(other)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1220
 *             other = _as_datetime(other)
 * 
 *         if len(self.kwds) > 0:             # <<<<<<<<<<<<<<
 *             tzinfo = getattr(other, "tzinfo", None)
 *             if tzinfo is not None and self._use_relativedelta:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__pyx_t_3 > 0);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1221
 * 
 *         if len(self.kwds) > 0:
 *             tzinfo = getattr(other, "tzinfo", None)             # <<<<<<<<<<<<<<
 *             if tzinfo is not None and self._use_relativedelta:
 *                 # perform calculation in UTC
 */
    __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_other), __pyx_n_u_tzinfo, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_tzinfo = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1222
 *         if len(self.kwds) > 0:
 *             tzinfo = getattr(other, "tzinfo", None)
 *             if tzinfo is not None and self._use_relativedelta:             # <<<<<<<<<<<<<<
 *                 # perform calculation in UTC
 *                 other = other.replace(tzinfo=None)
 */
    __pyx_t_4 = (__pyx_v_tzinfo != Py_None);
    if (__pyx_t_4) {
    } else {
      __pyx_t_2 = __pyx_t_4;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_use_relativedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1222, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_4;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1224
 *             if tzinfo is not None and self._use_relativedelta:
 *                 # perform calculation in UTC
 *                 other = other.replace(tzinfo=None)             # <<<<<<<<<<<<<<
 * 
 *             if hasattr(self, "nanoseconds"):
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_other), __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_tzinfo, Py_None) < 0) __PYX_ERR(0, 1224, __pyx_L1_error)
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1224, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_6));
      __pyx_t_6 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1222
 *         if len(self.kwds) > 0:
 *             tzinfo = getattr(other, "tzinfo", None)
 *             if tzinfo is not None and self._use_relativedelta:             # <<<<<<<<<<<<<<
 *                 # perform calculation in UTC
 *                 other = other.replace(tzinfo=None)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1226
 *                 other = other.replace(tzinfo=None)
 * 
 *             if hasattr(self, "nanoseconds"):             # <<<<<<<<<<<<<<
 *                 td_nano = Timedelta(nanoseconds=self.nanoseconds)
 *             else:
 */
    __pyx_t_2 = __Pyx_HasAttr(((PyObject *)__pyx_v_self), __pyx_n_u_nanoseconds); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 1226, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1227
 * 
 *             if hasattr(self, "nanoseconds"):
 *                 td_nano = Timedelta(nanoseconds=self.nanoseconds)             # <<<<<<<<<<<<<<
 *             else:
 *                 td_nano = Timedelta(0)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nanoseconds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_nanoseconds, __pyx_t_1) < 0) __PYX_ERR(0, 1227, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_td_nano = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1226
 *                 other = other.replace(tzinfo=None)
 * 
 *             if hasattr(self, "nanoseconds"):             # <<<<<<<<<<<<<<
 *                 td_nano = Timedelta(nanoseconds=self.nanoseconds)
 *             else:
 */
      goto __pyx_L8;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1229
 *                 td_nano = Timedelta(nanoseconds=self.nanoseconds)
 *             else:
 *                 td_nano = Timedelta(0)             # <<<<<<<<<<<<<<
 * 
 *             if self.n > 0:
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1229, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_int_0};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1229, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_td_nano = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L8:;

    /* "pandas/_libs/tslibs/offsets.pyx":1231
 *                 td_nano = Timedelta(0)
 * 
 *             if self.n > 0:             # <<<<<<<<<<<<<<
 *                 for i in range(self.n):
 *                     other = other + self._offset + td_nano
 */
    __pyx_t_2 = (__pyx_v_self->__pyx_base.n > 0);
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1232
 * 
 *             if self.n > 0:
 *                 for i in range(self.n):             # <<<<<<<<<<<<<<
 *                     other = other + self._offset + td_nano
 *             else:
 */
      __pyx_t_8 = __pyx_v_self->__pyx_base.n;
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_i = __pyx_t_10;

        /* "pandas/_libs/tslibs/offsets.pyx":1233
 *             if self.n > 0:
 *                 for i in range(self.n):
 *                     other = other + self._offset + td_nano             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(-self.n):
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1233, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_v_other), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1233, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyNumber_Add(__pyx_t_5, __pyx_v_td_nano); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1233, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1233, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_1));
        __pyx_t_1 = 0;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1231
 *                 td_nano = Timedelta(0)
 * 
 *             if self.n > 0:             # <<<<<<<<<<<<<<
 *                 for i in range(self.n):
 *                     other = other + self._offset + td_nano
 */
      goto __pyx_L9;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1235
 *                     other = other + self._offset + td_nano
 *             else:
 *                 for i in range(-self.n):             # <<<<<<<<<<<<<<
 *                     other = other - self._offset - td_nano
 * 
 */
    /*else*/ {
      __pyx_t_8 = (-__pyx_v_self->__pyx_base.n);
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
        __pyx_v_i = __pyx_t_10;

        /* "pandas/_libs/tslibs/offsets.pyx":1236
 *             else:
 *                 for i in range(-self.n):
 *                     other = other - self._offset - td_nano             # <<<<<<<<<<<<<<
 * 
 *             if tzinfo is not None and self._use_relativedelta:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1236, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = PyNumber_Subtract(((PyObject *)__pyx_v_other), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1236, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyNumber_Subtract(__pyx_t_5, __pyx_v_td_nano); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1236, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1236, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_1));
        __pyx_t_1 = 0;
      }
    }
    __pyx_L9:;

    /* "pandas/_libs/tslibs/offsets.pyx":1238
 *                     other = other - self._offset - td_nano
 * 
 *             if tzinfo is not None and self._use_relativedelta:             # <<<<<<<<<<<<<<
 *                 # bring tz back from UTC calculation
 *                 other = localize_pydatetime(other, tzinfo)
 */
    __pyx_t_4 = (__pyx_v_tzinfo != Py_None);
    if (__pyx_t_4) {
    } else {
      __pyx_t_2 = __pyx_t_4;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_use_relativedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 1238, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_4;
    __pyx_L15_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1240
 *             if tzinfo is not None and self._use_relativedelta:
 *                 # bring tz back from UTC calculation
 *                 other = localize_pydatetime(other, tzinfo)             # <<<<<<<<<<<<<<
 * 
 *             return Timestamp(other)
 */
      if (!(likely(((__pyx_v_tzinfo) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_tzinfo, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 1240, __pyx_L1_error)
      __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(__pyx_v_other, ((PyDateTime_TZInfo *)__pyx_v_tzinfo), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1240, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1238
 *                     other = other - self._offset - td_nano
 * 
 *             if tzinfo is not None and self._use_relativedelta:             # <<<<<<<<<<<<<<
 *                 # bring tz back from UTC calculation
 *                 other = localize_pydatetime(other, tzinfo)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1242
 *                 other = localize_pydatetime(other, tzinfo)
 * 
 *             return Timestamp(other)             # <<<<<<<<<<<<<<
 *         else:
 *             return other + timedelta(self.n)
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_other)};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1242, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1220
 *             other = _as_datetime(other)
 * 
 *         if len(self.kwds) > 0:             # <<<<<<<<<<<<<<
 *             tzinfo = getattr(other, "tzinfo", None)
 *             if tzinfo is not None and self._use_relativedelta:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1244
 *             return Timestamp(other)
 *         else:
 *             return other + timedelta(self.n)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  /*else*/ {
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(((PyObject *)__pyx_v_other), __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1244, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1215
 *         self.__dict__.update(state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tzinfo);
  __Pyx_XDECREF(__pyx_v_td_nano);
  __Pyx_XDECREF((PyObject *)__pyx_v_other);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1246
 *             return other + timedelta(self.n)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1246, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 1246, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1246, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_8_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyObject *__pyx_v_dt64other = NULL;
  PyObject *__pyx_v_kwds = NULL;
  PyObject *__pyx_v_relativedelta_fast = NULL;
  PyObject *__pyx_v_months = NULL;
  PyObject *__pyx_v_shifted = NULL;
  PyObject *__pyx_v_weeks = NULL;
  PyObject *__pyx_v_delta = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *__pyx_v_td = NULL;
  PyObject *__pyx_v_timedelta_kwds = NULL;
  PyObject *__pyx_v_num_nano = NULL;
  PyObject *__pyx_v_rem_nano = NULL;
  PyObject *__pyx_v_kwd = NULL;
  PyObject *__pyx_9genexpr11__pyx_v_k = NULL;
  PyObject *__pyx_9genexpr11__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  NPY_DATETIMEUNIT __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_UCS4 __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1248
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *         dt64other = np.asarray(dtarr)
 *         kwds = self.kwds
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 1248, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":1249
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         dt64other = np.asarray(dtarr)             # <<<<<<<<<<<<<<
 *         kwds = self.kwds
 *         relativedelta_fast = {
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_dtarr};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_dt64other = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1250
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         dt64other = np.asarray(dtarr)
 *         kwds = self.kwds             # <<<<<<<<<<<<<<
 *         relativedelta_fast = {
 *             "years",
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_kwds = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1252
 *         kwds = self.kwds
 *         relativedelta_fast = {
 *             "years",             # <<<<<<<<<<<<<<
 *             "months",
 *             "weeks",
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PySet_Add(__pyx_t_1, __pyx_n_u_years) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_months) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_weeks) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_days) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_hours) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_minutes) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_seconds) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  if (PySet_Add(__pyx_t_1, __pyx_n_u_microseconds) < 0) __PYX_ERR(0, 1252, __pyx_L1_error)
  __pyx_v_relativedelta_fast = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1262
 *         }
 *         # relativedelta/_offset path only valid for base DateOffset
 *         if self._use_relativedelta and set(kwds).issubset(relativedelta_fast):             # <<<<<<<<<<<<<<
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_use_relativedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PySet_New(__pyx_v_kwds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_issubset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_relativedelta_fast};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1262, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1264
 *         if self._use_relativedelta and set(kwds).issubset(relativedelta_fast):
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n             # <<<<<<<<<<<<<<
 *             if months:
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_kwds, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyInt_MultiplyObjC(__pyx_t_3, __pyx_int_12, 12, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_kwds, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyNumber_Multiply(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1264, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_months = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1265
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n
 *             if months:             # <<<<<<<<<<<<<<
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)
 *                 dt64other = shifted.view(dtarr.dtype)
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_months); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1265, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1266
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n
 *             if months:
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)             # <<<<<<<<<<<<<<
 *                 dt64other = shifted.view(dtarr.dtype)
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_shift_months); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dt64other, __pyx_n_s_view); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_n_u_i8};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1266, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 1266, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_months);
      __Pyx_GIVEREF(__pyx_v_months);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_months)) __PYX_ERR(0, 1266, __pyx_L1_error);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(__pyx_v_reso); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_reso, __pyx_t_8) < 0) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1266, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_shifted = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1267
 *             if months:
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)
 *                 dt64other = shifted.view(dtarr.dtype)             # <<<<<<<<<<<<<<
 * 
 *             weeks = kwds.get("weeks", 0) * self.n
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_shifted, __pyx_n_s_view); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1267, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1267, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_dt64other, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1265
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n
 *             if months:             # <<<<<<<<<<<<<<
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)
 *                 dt64other = shifted.view(dtarr.dtype)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1269
 *                 dt64other = shifted.view(dtarr.dtype)
 * 
 *             weeks = kwds.get("weeks", 0) * self.n             # <<<<<<<<<<<<<<
 *             if weeks:
 *                 delta = Timedelta(days=7 * weeks)
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_kwds, __pyx_n_s_get); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_4, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1269, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_weeks = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1270
 * 
 *             weeks = kwds.get("weeks", 0) * self.n
 *             if weeks:             # <<<<<<<<<<<<<<
 *                 delta = Timedelta(days=7 * weeks)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_weeks); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1270, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1271
 *             weeks = kwds.get("weeks", 0) * self.n
 *             if weeks:
 *                 delta = Timedelta(days=7 * weeks)             # <<<<<<<<<<<<<<
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 *                 dt64other = dt64other + td
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_PyInt_MultiplyCObj(__pyx_int_7, __pyx_v_weeks, 7, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_days, __pyx_t_4) < 0) __PYX_ERR(0, 1271, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1271, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_delta = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1272
 *             if weeks:
 *                 delta = Timedelta(days=7 * weeks)
 *                 td = (<_Timedelta>delta)._as_creso(reso)             # <<<<<<<<<<<<<<
 *                 dt64other = dt64other + td
 * 
 */
      __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta)->__pyx_vtab)->_as_creso(((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta), __pyx_v_reso, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1272, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_td = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1273
 *                 delta = Timedelta(days=7 * weeks)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 *                 dt64other = dt64other + td             # <<<<<<<<<<<<<<
 * 
 *             timedelta_kwds = {
 */
      __pyx_t_4 = PyNumber_Add(__pyx_v_dt64other, ((PyObject *)__pyx_v_td)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_dt64other, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1270
 * 
 *             weeks = kwds.get("weeks", 0) * self.n
 *             if weeks:             # <<<<<<<<<<<<<<
 *                 delta = Timedelta(days=7 * weeks)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1275
 *                 dt64other = dt64other + td
 * 
 *             timedelta_kwds = {             # <<<<<<<<<<<<<<
 *                 k: v
 *                 for k, v in kwds.items()
 */
    { /* enter inner scope */
      __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1275, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "pandas/_libs/tslibs/offsets.pyx":1277
 *             timedelta_kwds = {
 *                 k: v
 *                 for k, v in kwds.items()             # <<<<<<<<<<<<<<
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]
 *             }
 */
      __pyx_t_9 = 0;
      if (unlikely(__pyx_v_kwds == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
        __PYX_ERR(0, 1277, __pyx_L10_error)
      }
      __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_kwds, 0, __pyx_n_s_items, (&__pyx_t_10), (&__pyx_t_5)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1277, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_8);
      __pyx_t_8 = __pyx_t_3;
      __pyx_t_3 = 0;
      while (1) {
        __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_8, __pyx_t_10, &__pyx_t_9, &__pyx_t_3, &__pyx_t_1, NULL, __pyx_t_5);
        if (unlikely(__pyx_t_11 == 0)) break;
        if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 1277, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_k, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_9genexpr11__pyx_v_v, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1278
 *                 k: v
 *                 for k, v in kwds.items()
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]             # <<<<<<<<<<<<<<
 *             }
 *             if timedelta_kwds:
 */
        __Pyx_INCREF(__pyx_9genexpr11__pyx_v_k);
        __pyx_t_1 = __pyx_9genexpr11__pyx_v_k;
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_days, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1278, __pyx_L10_error)
        if (!__pyx_t_7) {
        } else {
          __pyx_t_6 = __pyx_t_7;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_hours, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1278, __pyx_L10_error)
        if (!__pyx_t_7) {
        } else {
          __pyx_t_6 = __pyx_t_7;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_minutes, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1278, __pyx_L10_error)
        if (!__pyx_t_7) {
        } else {
          __pyx_t_6 = __pyx_t_7;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_seconds, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1278, __pyx_L10_error)
        if (!__pyx_t_7) {
        } else {
          __pyx_t_6 = __pyx_t_7;
          goto __pyx_L14_bool_binop_done;
        }
        __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_microseconds, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1278, __pyx_L10_error)
        __pyx_t_6 = __pyx_t_7;
        __pyx_L14_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_7 = __pyx_t_6;
        if (__pyx_t_7) {

          /* "pandas/_libs/tslibs/offsets.pyx":1276
 * 
 *             timedelta_kwds = {
 *                 k: v             # <<<<<<<<<<<<<<
 *                 for k, v in kwds.items()
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]
 */
          if (unlikely(PyDict_SetItem(__pyx_t_4, (PyObject*)__pyx_9genexpr11__pyx_v_k, (PyObject*)__pyx_9genexpr11__pyx_v_v))) __PYX_ERR(0, 1276, __pyx_L10_error)

          /* "pandas/_libs/tslibs/offsets.pyx":1278
 *                 k: v
 *                 for k, v in kwds.items()
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]             # <<<<<<<<<<<<<<
 *             }
 *             if timedelta_kwds:
 */
        }
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k); __pyx_9genexpr11__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
      goto __pyx_L19_exit_scope;
      __pyx_L10_error:;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k); __pyx_9genexpr11__pyx_v_k = 0;
      __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v); __pyx_9genexpr11__pyx_v_v = 0;
      goto __pyx_L1_error;
      __pyx_L19_exit_scope:;
    } /* exit inner scope */
    __pyx_v_timedelta_kwds = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1280
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]
 *             }
 *             if timedelta_kwds:             # <<<<<<<<<<<<<<
 *                 delta = Timedelta(**timedelta_kwds)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 */
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_timedelta_kwds); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1280, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":1281
 *             }
 *             if timedelta_kwds:
 *                 delta = Timedelta(**timedelta_kwds)             # <<<<<<<<<<<<<<
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 *                 dt64other = dt64other + (self.n * td)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyDict_Copy(__pyx_v_timedelta_kwds); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF_SET(__pyx_v_delta, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1282
 *             if timedelta_kwds:
 *                 delta = Timedelta(**timedelta_kwds)
 *                 td = (<_Timedelta>delta)._as_creso(reso)             # <<<<<<<<<<<<<<
 *                 dt64other = dt64other + (self.n * td)
 *             return dt64other
 */
      __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta)->__pyx_vtab)->_as_creso(((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta), __pyx_v_reso, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_td, ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1283
 *                 delta = Timedelta(**timedelta_kwds)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 *                 dt64other = dt64other + (self.n * td)             # <<<<<<<<<<<<<<
 *             return dt64other
 *         elif not self._use_relativedelta and hasattr(self, "_offset"):
 */
      __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = PyNumber_Multiply(__pyx_t_1, ((PyObject *)__pyx_v_td)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_v_dt64other, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF_SET(__pyx_v_dt64other, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1280
 *                 if k in ["days", "hours", "minutes", "seconds", "microseconds"]
 *             }
 *             if timedelta_kwds:             # <<<<<<<<<<<<<<
 *                 delta = Timedelta(**timedelta_kwds)
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1284
 *                 td = (<_Timedelta>delta)._as_creso(reso)
 *                 dt64other = dt64other + (self.n * td)
 *             return dt64other             # <<<<<<<<<<<<<<
 *         elif not self._use_relativedelta and hasattr(self, "_offset"):
 *             # timedelta
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_dt64other);
    __pyx_r = __pyx_v_dt64other;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1262
 *         }
 *         # relativedelta/_offset path only valid for base DateOffset
 *         if self._use_relativedelta and set(kwds).issubset(relativedelta_fast):             # <<<<<<<<<<<<<<
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1285
 *                 dt64other = dt64other + (self.n * td)
 *             return dt64other
 *         elif not self._use_relativedelta and hasattr(self, "_offset"):             # <<<<<<<<<<<<<<
 *             # timedelta
 *             num_nano = getattr(self, "nanoseconds", 0)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_use_relativedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_12 = (!__pyx_t_6);
  if (__pyx_t_12) {
  } else {
    __pyx_t_7 = __pyx_t_12;
    goto __pyx_L21_bool_binop_done;
  }
  __pyx_t_12 = __Pyx_HasAttr(((PyObject *)__pyx_v_self), __pyx_n_u_offset); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 1285, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_12;
  __pyx_L21_bool_binop_done:;
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1287
 *         elif not self._use_relativedelta and hasattr(self, "_offset"):
 *             # timedelta
 *             num_nano = getattr(self, "nanoseconds", 0)             # <<<<<<<<<<<<<<
 *             if num_nano != 0:
 *                 rem_nano = Timedelta(nanoseconds=num_nano)
 */
    __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_u_nanoseconds, __pyx_int_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_num_nano = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1288
 *             # timedelta
 *             num_nano = getattr(self, "nanoseconds", 0)
 *             if num_nano != 0:             # <<<<<<<<<<<<<<
 *                 rem_nano = Timedelta(nanoseconds=num_nano)
 *                 delta = Timedelta((self._offset + rem_nano) * self.n)
 */
    __pyx_t_7 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_num_nano, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1288, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":1289
 *             num_nano = getattr(self, "nanoseconds", 0)
 *             if num_nano != 0:
 *                 rem_nano = Timedelta(nanoseconds=num_nano)             # <<<<<<<<<<<<<<
 *                 delta = Timedelta((self._offset + rem_nano) * self.n)
 *             else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_nanoseconds, __pyx_v_num_nano) < 0) __PYX_ERR(0, 1289, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_rem_nano = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1290
 *             if num_nano != 0:
 *                 rem_nano = Timedelta(nanoseconds=num_nano)
 *                 delta = Timedelta((self._offset + rem_nano) * self.n)             # <<<<<<<<<<<<<<
 *             else:
 *                 delta = Timedelta(self._offset * self.n)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_v_rem_nano); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = PyNumber_Multiply(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_13};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1290, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_v_delta = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1288
 *             # timedelta
 *             num_nano = getattr(self, "nanoseconds", 0)
 *             if num_nano != 0:             # <<<<<<<<<<<<<<
 *                 rem_nano = Timedelta(nanoseconds=num_nano)
 *                 delta = Timedelta((self._offset + rem_nano) * self.n)
 */
      goto __pyx_L23;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1292
 *                 delta = Timedelta((self._offset + rem_nano) * self.n)
 *             else:
 *                 delta = Timedelta(self._offset * self.n)             # <<<<<<<<<<<<<<
 *             td = (<_Timedelta>delta)._as_creso(reso)
 *             return dt64other + td
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = PyNumber_Multiply(__pyx_t_13, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_3};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1292, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_v_delta = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_L23:;

    /* "pandas/_libs/tslibs/offsets.pyx":1293
 *             else:
 *                 delta = Timedelta(self._offset * self.n)
 *             td = (<_Timedelta>delta)._as_creso(reso)             # <<<<<<<<<<<<<<
 *             return dt64other + td
 *         else:
 */
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta)->__pyx_vtab)->_as_creso(((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_v_delta), __pyx_v_reso, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_td = ((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1294
 *                 delta = Timedelta(self._offset * self.n)
 *             td = (<_Timedelta>delta)._as_creso(reso)
 *             return dt64other + td             # <<<<<<<<<<<<<<
 *         else:
 *             # relativedelta with other keywords
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = PyNumber_Add(__pyx_v_dt64other, ((PyObject *)__pyx_v_td)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1294, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1285
 *                 dt64other = dt64other + (self.n * td)
 *             return dt64other
 *         elif not self._use_relativedelta and hasattr(self, "_offset"):             # <<<<<<<<<<<<<<
 *             # timedelta
 *             num_nano = getattr(self, "nanoseconds", 0)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1297
 *         else:
 *             # relativedelta with other keywords
 *             kwd = set(kwds) - relativedelta_fast             # <<<<<<<<<<<<<<
 *             raise NotImplementedError(
 *                 "DateOffset with relativedelta "
 */
  /*else*/ {
    __pyx_t_4 = PySet_New(__pyx_v_kwds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = PyNumber_Subtract(__pyx_t_4, __pyx_v_relativedelta_fast); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_kwd = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1299
 *             kwd = set(kwds) - relativedelta_fast
 *             raise NotImplementedError(
 *                 "DateOffset with relativedelta "             # <<<<<<<<<<<<<<
 *                 f"keyword(s) {kwd} not able to be "
 *                 "applied vectorized"
 */
    __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_10 = 0;
    __pyx_t_14 = 127;
    __Pyx_INCREF(__pyx_kp_u_DateOffset_with_relativedelta_ke);
    __pyx_t_10 += 41;
    __Pyx_GIVEREF(__pyx_kp_u_DateOffset_with_relativedelta_ke);
    PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_kp_u_DateOffset_with_relativedelta_ke);

    /* "pandas/_libs/tslibs/offsets.pyx":1300
 *             raise NotImplementedError(
 *                 "DateOffset with relativedelta "
 *                 f"keyword(s) {kwd} not able to be "             # <<<<<<<<<<<<<<
 *                 "applied vectorized"
 *             )
 */
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_kwd, __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_14) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_14;
    __pyx_t_10 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_kp_u_not_able_to_be_applied_vectoriz);
    __pyx_t_10 += 34;
    __Pyx_GIVEREF(__pyx_kp_u_not_able_to_be_applied_vectoriz);
    PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_kp_u_not_able_to_be_applied_vectoriz);

    /* "pandas/_libs/tslibs/offsets.pyx":1299
 *             kwd = set(kwds) - relativedelta_fast
 *             raise NotImplementedError(
 *                 "DateOffset with relativedelta "             # <<<<<<<<<<<<<<
 *                 f"keyword(s) {kwd} not able to be "
 *                 "applied vectorized"
 */
    __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_8, 3, __pyx_t_10, __pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1298
 *             # relativedelta with other keywords
 *             kwd = set(kwds) - relativedelta_fast
 *             raise NotImplementedError(             # <<<<<<<<<<<<<<
 *                 "DateOffset with relativedelta "
 *                 f"keyword(s) {kwd} not able to be "
 */
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_NotImplementedError, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 1298, __pyx_L1_error)
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1246
 *             return other + timedelta(self.n)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dt64other);
  __Pyx_XDECREF(__pyx_v_kwds);
  __Pyx_XDECREF(__pyx_v_relativedelta_fast);
  __Pyx_XDECREF(__pyx_v_months);
  __Pyx_XDECREF(__pyx_v_shifted);
  __Pyx_XDECREF(__pyx_v_weeks);
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XDECREF((PyObject *)__pyx_v_td);
  __Pyx_XDECREF(__pyx_v_timedelta_kwds);
  __Pyx_XDECREF(__pyx_v_num_nano);
  __Pyx_XDECREF(__pyx_v_rem_nano);
  __Pyx_XDECREF(__pyx_v_kwd);
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_k);
  __Pyx_XDECREF(__pyx_9genexpr11__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1304
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1304, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 1304, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1304, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 1304, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_10is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_10is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1305
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return True
 */
  if (__pyx_v_self->__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1305, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1306
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1305
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return True
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1307
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1304
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_12__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_12__reduce_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self._cache, self.n, self.normalize)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.normalize); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->__pyx_base._cache);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base._cache);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->__pyx_base._cache)) __PYX_ERR(5, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(5, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_3 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v__dict = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":7
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_4 = (__pyx_v__dict != Py_None);
  if (__pyx_t_4) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v__dict)) __PYX_ERR(5, 8, __pyx_L1_error);
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._cache is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self._cache, self.n, self.normalize)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self._cache is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, None), state
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_v_self->__pyx_base._cache != ((PyObject*)Py_None));
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._cache is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self._cache is not None
 *     if use_setstate:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyx_unpickle_RelativeDeltaOffs); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_171034093);
    __Pyx_GIVEREF(__pyx_int_171034093);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_171034093)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, Py_None)) __PYX_ERR(5, 13, __pyx_L1_error);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(5, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(5, 13, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self._cache is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, None), state
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pyx_unpickle_RelativeDeltaOffs); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_171034093);
    __Pyx_GIVEREF(__pyx_int_171034093);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_171034093)) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state)) __PYX_ERR(5, 15, __pyx_L1_error);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(5, 15, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(5, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(5, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_14__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_14__setstate_cython__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(5, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_RelativeDeltaOffset__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.RelativeDeltaOffset.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1316
 *     """
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __instancecheck__(cls, obj) -> bool:
 *         return isinstance(obj, BaseOffset)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_1__instancecheck__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_1__instancecheck__ = {"__instancecheck__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_1__instancecheck__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_1__instancecheck__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__instancecheck__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1316, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1316, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__instancecheck__", 1, 2, 2, 1); __PYX_ERR(0, 1316, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__instancecheck__") < 0)) __PYX_ERR(0, 1316, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_obj = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__instancecheck__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1316, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.OffsetMeta.__instancecheck__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta___instancecheck__(__pyx_self, __pyx_v_cls, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta___instancecheck__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__instancecheck__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1318
 *     @classmethod
 *     def __instancecheck__(cls, obj) -> bool:
 *         return isinstance(obj, BaseOffset)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1316
 *     """
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __instancecheck__(cls, obj) -> bool:
 *         return isinstance(obj, BaseOffset)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.OffsetMeta.__instancecheck__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1320
 *         return isinstance(obj, BaseOffset)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __subclasscheck__(cls, obj) -> bool:
 *         return issubclass(obj, BaseOffset)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_3__subclasscheck__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_3__subclasscheck__ = {"__subclasscheck__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_3__subclasscheck__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_3__subclasscheck__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__subclasscheck__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cls,&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_cls)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1320, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1320, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__subclasscheck__", 1, 2, 2, 1); __PYX_ERR(0, 1320, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__subclasscheck__") < 0)) __PYX_ERR(0, 1320, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_cls = values[0];
    __pyx_v_obj = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__subclasscheck__", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1320, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.OffsetMeta.__subclasscheck__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_2__subclasscheck__(__pyx_self, __pyx_v_cls, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_2__subclasscheck__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_cls, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__subclasscheck__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1322
 *     @classmethod
 *     def __subclasscheck__(cls, obj) -> bool:
 *         return issubclass(obj, BaseOffset)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_IsSubclass(__pyx_v_obj, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 1322, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1320
 *         return isinstance(obj, BaseOffset)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __subclasscheck__(cls, obj) -> bool:
 *         return issubclass(obj, BaseOffset)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.OffsetMeta.__subclasscheck__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1431
 *     Timestamp('2017-01-01 08:10:11')
 *     """
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         raise AttributeError("DateOffset objects are immutable.")
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10DateOffset_1__setattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10DateOffset_1__setattr__ = {"__setattr__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10DateOffset_1__setattr__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10DateOffset_1__setattr__(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED PyObject *__pyx_v_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setattr__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_name_2,&__pyx_n_s_value_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_self)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1431, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1431, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__setattr__", 1, 3, 3, 1); __PYX_ERR(0, 1431, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_value_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1431, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__setattr__", 1, 3, 3, 2); __PYX_ERR(0, 1431, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setattr__") < 0)) __PYX_ERR(0, 1431, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_value = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setattr__", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1431, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.DateOffset.__setattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10DateOffset___setattr__(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_value);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10DateOffset___setattr__(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, CYTHON_UNUSED PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setattr__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1432
 *     """
 *     def __setattr__(self, name, value):
 *         raise AttributeError("DateOffset objects are immutable.")             # <<<<<<<<<<<<<<
 * 
 * # --------------------------------------------------------------------
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_AttributeError, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 1432, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1431
 *     Timestamp('2017-01-01 08:10:11')
 *     """
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         raise AttributeError("DateOffset objects are immutable.")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.DateOffset.__setattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1447
 *         object weekmask, holidays, calendar
 * 
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self._offset = offset
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_offset = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_offset_2,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(__pyx_k__33);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1447, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1447, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1447, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1447, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_offset = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 1447, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_offset);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1448
 * 
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 *         self._offset = offset
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1449
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):
 *         BaseOffset.__init__(self, n, normalize)
 *         self._offset = offset             # <<<<<<<<<<<<<<
 * 
 *     cpdef _init_custom(self, weekmask, holidays, calendar):
 */
  if (!(likely(((__pyx_v_offset) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_offset, __pyx_ptype_7cpython_8datetime_timedelta))))) __PYX_ERR(0, 1449, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_offset;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_offset);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_offset);
  __pyx_v_self->_offset = ((PyDateTime_Delta *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1447
 *         object weekmask, holidays, calendar
 * 
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self._offset = offset
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1451
 *         self._offset = offset
 * 
 *     cpdef _init_custom(self, weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *         """
 *         Additional __init__ for Custom subclasses.
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__init_custom(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_custom", 0);
  __Pyx_INCREF(__pyx_v_holidays);
  __Pyx_INCREF(__pyx_v_calendar);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_init_custom); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1451, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1455
 *         Additional __init__ for Custom subclasses.
 *         """
 *         calendar, holidays = _get_calendar(             # <<<<<<<<<<<<<<
 *             weekmask=weekmask, holidays=holidays, calendar=calendar
 *         )
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__get_calendar(__pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 1455, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1455, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
    index = 0; __pyx_t_2 = __pyx_t_6(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1455, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 1455, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __Pyx_DECREF_SET(__pyx_v_calendar, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1461
 *         # following two attributes. See DateOffset._params()
 *         # holidays, weekmask
 *         self.weekmask = weekmask             # <<<<<<<<<<<<<<
 *         self.holidays = holidays
 *         self.calendar = calendar
 */
  __Pyx_INCREF(__pyx_v_weekmask);
  __Pyx_GIVEREF(__pyx_v_weekmask);
  __Pyx_GOTREF(__pyx_v_self->weekmask);
  __Pyx_DECREF(__pyx_v_self->weekmask);
  __pyx_v_self->weekmask = __pyx_v_weekmask;

  /* "pandas/_libs/tslibs/offsets.pyx":1462
 *         # holidays, weekmask
 *         self.weekmask = weekmask
 *         self.holidays = holidays             # <<<<<<<<<<<<<<
 *         self.calendar = calendar
 * 
 */
  __Pyx_INCREF(__pyx_v_holidays);
  __Pyx_GIVEREF(__pyx_v_holidays);
  __Pyx_GOTREF(__pyx_v_self->holidays);
  __Pyx_DECREF(__pyx_v_self->holidays);
  __pyx_v_self->holidays = __pyx_v_holidays;

  /* "pandas/_libs/tslibs/offsets.pyx":1463
 *         self.weekmask = weekmask
 *         self.holidays = holidays
 *         self.calendar = calendar             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_INCREF(__pyx_v_calendar);
  __Pyx_GIVEREF(__pyx_v_calendar);
  __Pyx_GOTREF(__pyx_v_self->calendar);
  __Pyx_DECREF(__pyx_v_self->calendar);
  __pyx_v_self->calendar = __pyx_v_calendar;

  /* "pandas/_libs/tslibs/offsets.pyx":1451
 *         self._offset = offset
 * 
 *     cpdef _init_custom(self, weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *         """
 *         Additional __init__ for Custom subclasses.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin._init_custom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_holidays);
  __Pyx_XDECREF(__pyx_v_calendar);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_2_init_custom, "\n        Additional __init__ for Custom subclasses.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom = {"_init_custom", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_2_init_custom};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_weekmask = 0;
  PyObject *__pyx_v_holidays = 0;
  PyObject *__pyx_v_calendar = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_custom (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_weekmask,&__pyx_n_s_holidays,&__pyx_n_s_calendar,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekmask)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1451, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_holidays)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1451, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_init_custom", 1, 3, 3, 1); __PYX_ERR(0, 1451, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_calendar)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1451, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_init_custom", 1, 3, 3, 2); __PYX_ERR(0, 1451, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_init_custom") < 0)) __PYX_ERR(0, 1451, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_weekmask = values[0];
    __pyx_v_holidays = values[1];
    __pyx_v_calendar = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_init_custom", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 1451, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin._init_custom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_2_init_custom(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_2_init_custom(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_custom", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__init_custom(__pyx_v_self, __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin._init_custom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1465
 *         self.calendar = calendar
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def offset(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1471
 *         """
 *         # Alias for backward compat
 *         return self._offset             # <<<<<<<<<<<<<<
 * 
 *     def _repr_attrs(self) -> str:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_offset);
  __pyx_r = ((PyObject *)__pyx_v_self->_offset);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1465
 *         self.calendar = calendar
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def offset(self):
 *         """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1473
 *         return self._offset
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.offset:
 *             attrs = [f"offset={repr(self.offset)}"]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs = {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_attrs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_attrs", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_attrs", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_4_repr_attrs(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_4_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr_attrs", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1474
 * 
 *     def _repr_attrs(self) -> str:
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             attrs = [f"offset={repr(self.offset)}"]
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1475
 *     def _repr_attrs(self) -> str:
 *         if self.offset:
 *             attrs = [f"offset={repr(self.offset)}"]             # <<<<<<<<<<<<<<
 *         else:
 *             attrs = []
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_offset_3, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 1475, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_v_attrs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1474
 * 
 *     def _repr_attrs(self) -> str:
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             attrs = [f"offset={repr(self.offset)}"]
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1477
 *             attrs = [f"offset={repr(self.offset)}"]
 *         else:
 *             attrs = []             # <<<<<<<<<<<<<<
 *         out = ""
 *         if attrs:
 */
  /*else*/ {
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_attrs = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1478
 *         else:
 *             attrs = []
 *         out = ""             # <<<<<<<<<<<<<<
 *         if attrs:
 *             out += ": " + ", ".join(attrs)
 */
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_v_out = __pyx_kp_u__15;

  /* "pandas/_libs/tslibs/offsets.pyx":1479
 *             attrs = []
 *         out = ""
 *         if attrs:             # <<<<<<<<<<<<<<
 *             out += ": " + ", ".join(attrs)
 *         return out
 */
  __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_attrs) != 0);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1480
 *         out = ""
 *         if attrs:
 *             out += ": " + ", ".join(attrs)             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
    __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__21, __pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u__20, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_ConcatInPlace(__pyx_v_out, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_out, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1479
 *             attrs = []
 *         out = ""
 *         if attrs:             # <<<<<<<<<<<<<<
 *             out += ": " + ", ".join(attrs)
 *         return out
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1481
 *         if attrs:
 *             out += ": " + ", ".join(attrs)
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1473
 *         return self._offset
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.offset:
 *             attrs = [f"offset={repr(self.offset)}"]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin._repr_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1483
 *         return out
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_weekmask = NULL;
  PyObject *__pyx_v_holidays = NULL;
  PyObject *__pyx_v_calendar = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1483, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1485
 *     cpdef __setstate__(self, state):
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1485, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1486
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")             # <<<<<<<<<<<<<<
 *         elif "offset" in state:
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_offset};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_timedelta))))) __PYX_ERR(0, 1486, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_offset);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_offset);
    __pyx_v_self->_offset = ((PyDateTime_Delta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1485
 *     cpdef __setstate__(self, state):
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1487
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:             # <<<<<<<<<<<<<<
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             self._offset = state.pop("offset")
 */
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset_2, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1487, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1489
 *         elif "offset" in state:
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             self._offset = state.pop("offset")             # <<<<<<<<<<<<<<
 * 
 *         if self._prefix.startswith("C"):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_offset_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_timedelta))))) __PYX_ERR(0, 1489, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->_offset);
    __Pyx_DECREF((PyObject *)__pyx_v_self->_offset);
    __pyx_v_self->_offset = ((PyDateTime_Delta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1487
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:             # <<<<<<<<<<<<<<
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             self._offset = state.pop("offset")
 */
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1491
 *             self._offset = state.pop("offset")
 * 
 *         if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *             # i.e. this is a Custom class
 *             weekmask = state.pop("weekmask")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_startswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_C};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1493
 *         if self._prefix.startswith("C"):
 *             # i.e. this is a Custom class
 *             weekmask = state.pop("weekmask")             # <<<<<<<<<<<<<<
 *             holidays = state.pop("holidays")
 *             calendar, holidays = _get_calendar(weekmask=weekmask,
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_weekmask};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_weekmask = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1494
 *             # i.e. this is a Custom class
 *             weekmask = state.pop("weekmask")
 *             holidays = state.pop("holidays")             # <<<<<<<<<<<<<<
 *             calendar, holidays = _get_calendar(weekmask=weekmask,
 *                                                holidays=holidays,
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1494, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_holidays};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1494, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_holidays = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1495
 *             weekmask = state.pop("weekmask")
 *             holidays = state.pop("holidays")
 *             calendar, holidays = _get_calendar(weekmask=weekmask,             # <<<<<<<<<<<<<<
 *                                                holidays=holidays,
 *                                                calendar=None)
 */
    __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__get_calendar(__pyx_v_weekmask, __pyx_v_holidays, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1495, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1495, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
      index = 0; __pyx_t_3 = __pyx_t_7(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_4), 2) < 0) __PYX_ERR(0, 1495, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1495, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __pyx_v_calendar = __pyx_t_3;
    __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_holidays, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1498
 *                                                holidays=holidays,
 *                                                calendar=None)
 *             self.weekmask = weekmask             # <<<<<<<<<<<<<<
 *             self.calendar = calendar
 *             self.holidays = holidays
 */
    __Pyx_INCREF(__pyx_v_weekmask);
    __Pyx_GIVEREF(__pyx_v_weekmask);
    __Pyx_GOTREF(__pyx_v_self->weekmask);
    __Pyx_DECREF(__pyx_v_self->weekmask);
    __pyx_v_self->weekmask = __pyx_v_weekmask;

    /* "pandas/_libs/tslibs/offsets.pyx":1499
 *                                                calendar=None)
 *             self.weekmask = weekmask
 *             self.calendar = calendar             # <<<<<<<<<<<<<<
 *             self.holidays = holidays
 * 
 */
    __Pyx_INCREF(__pyx_v_calendar);
    __Pyx_GIVEREF(__pyx_v_calendar);
    __Pyx_GOTREF(__pyx_v_self->calendar);
    __Pyx_DECREF(__pyx_v_self->calendar);
    __pyx_v_self->calendar = __pyx_v_calendar;

    /* "pandas/_libs/tslibs/offsets.pyx":1500
 *             self.weekmask = weekmask
 *             self.calendar = calendar
 *             self.holidays = holidays             # <<<<<<<<<<<<<<
 * 
 *         BaseOffset.__setstate__(self, state)
 */
    __Pyx_INCREF(__pyx_v_holidays);
    __Pyx_GIVEREF(__pyx_v_holidays);
    __Pyx_GOTREF(__pyx_v_self->holidays);
    __Pyx_DECREF(__pyx_v_self->holidays);
    __pyx_v_self->holidays = __pyx_v_holidays;

    /* "pandas/_libs/tslibs/offsets.pyx":1491
 *             self._offset = state.pop("offset")
 * 
 *         if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *             # i.e. this is a Custom class
 *             weekmask = state.pop("weekmask")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1502
 *             self.holidays = holidays
 * 
 *         BaseOffset.__setstate__(self, state)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_setstate); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_state};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1483
 *         return out
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_weekmask);
  __Pyx_XDECREF(__pyx_v_holidays);
  __Pyx_XDECREF(__pyx_v_calendar);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1483, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1483, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1483, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessMixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1443
 * 
 *     cdef readonly:
 *         timedelta _offset             # <<<<<<<<<<<<<<
 *         # Only Custom subclasses use weekmask, holiday, calendar
 *         object weekmask, holidays, calendar
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_offset);
  __pyx_r = ((PyObject *)__pyx_v_self->_offset);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1445
 *         timedelta _offset
 *         # Only Custom subclasses use weekmask, holiday, calendar
 *         object weekmask, holidays, calendar             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->weekmask);
  __pyx_r = __pyx_v_self->weekmask;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->holidays);
  __pyx_r = __pyx_v_self->holidays;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->calendar);
  __pyx_r = __pyx_v_self->calendar;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1537
 *     _attributes = tuple(["n", "normalize", "offset"])
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1537, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1538
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         if "_offset" in state:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1538, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":1539
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1539, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":1540
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         if "_offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:
 */
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1540, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":1541
 *         self.normalize = state.pop("normalize")
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")             # <<<<<<<<<<<<<<
 *         elif "offset" in state:
 *             self._offset = state.pop("offset")
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1541, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_offset};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1541, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_timedelta))))) __PYX_ERR(0, 1541, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->__pyx_base._offset);
    __Pyx_DECREF((PyObject *)__pyx_v_self->__pyx_base._offset);
    __pyx_v_self->__pyx_base._offset = ((PyDateTime_Delta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1540
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         if "_offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1542
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("offset")
 *         self._cache = state.pop("_cache", {})
 */
  __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_offset_2, __pyx_v_state, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1542, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":1543
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:
 *             self._offset = state.pop("offset")             # <<<<<<<<<<<<<<
 *         self._cache = state.pop("_cache", {})
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1543, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_offset_2};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1543, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_timedelta))))) __PYX_ERR(0, 1543, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->__pyx_base._offset);
    __Pyx_DECREF((PyObject *)__pyx_v_self->__pyx_base._offset);
    __pyx_v_self->__pyx_base._offset = ((PyDateTime_Delta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1542
 *         if "_offset" in state:
 *             self._offset = state.pop("_offset")
 *         elif "offset" in state:             # <<<<<<<<<<<<<<
 *             self._offset = state.pop("offset")
 *         self._cache = state.pop("_cache", {})
 */
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1544
 *         elif "offset" in state:
 *             self._offset = state.pop("offset")
 *         self._cache = state.pop("_cache", {})             # <<<<<<<<<<<<<<
 * 
 *     def _offset_str(self) -> str:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_n_u_cache, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 1544, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._cache);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._cache);
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base._cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1537
 *     _attributes = tuple(["n", "normalize", "offset"])
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1537, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1537, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1537, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1546
 *         self._cache = state.pop("_cache", {})
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         def get_str(td):
 *             off_str = ""
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str = {"_offset_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_offset_str (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_offset_str", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_offset_str", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_2_offset_str(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1547
 * 
 *     def _offset_str(self) -> str:
 *         def get_str(td):             # <<<<<<<<<<<<<<
 *             off_str = ""
 *             if td.days > 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_1get_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_1get_str = {"get_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_1get_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_1get_str(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_td = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_str (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_td,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_td)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1547, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_str") < 0)) __PYX_ERR(0, 1547, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_td = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_str", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1547, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._offset_str.get_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_get_str(__pyx_self, __pyx_v_td);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_get_str(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_td) {
  PyObject *__pyx_v_off_str = NULL;
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_hrs = NULL;
  PyObject *__pyx_v_mts = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_str", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1548
 *     def _offset_str(self) -> str:
 *         def get_str(td):
 *             off_str = ""             # <<<<<<<<<<<<<<
 *             if td.days > 0:
 *                 off_str += str(td.days) + "D"
 */
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_v_off_str = __pyx_kp_u__15;

  /* "pandas/_libs/tslibs/offsets.pyx":1549
 *         def get_str(td):
 *             off_str = ""
 *             if td.days > 0:             # <<<<<<<<<<<<<<
 *                 off_str += str(td.days) + "D"
 *             if td.seconds > 0:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_days); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":1550
 *             off_str = ""
 *             if td.days > 0:
 *                 off_str += str(td.days) + "D"             # <<<<<<<<<<<<<<
 *             if td.seconds > 0:
 *                 s = td.seconds
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_days); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Str(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_n_u_D); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyUnicode_ConcatInPlace(__pyx_v_off_str, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1550, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_off_str, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1549
 *         def get_str(td):
 *             off_str = ""
 *             if td.days > 0:             # <<<<<<<<<<<<<<
 *                 off_str += str(td.days) + "D"
 *             if td.seconds > 0:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1551
 *             if td.days > 0:
 *                 off_str += str(td.days) + "D"
 *             if td.seconds > 0:             # <<<<<<<<<<<<<<
 *                 s = td.seconds
 *                 hrs = int(s / 3600)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_seconds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1551, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":1552
 *                 off_str += str(td.days) + "D"
 *             if td.seconds > 0:
 *                 s = td.seconds             # <<<<<<<<<<<<<<
 *                 hrs = int(s / 3600)
 *                 if hrs != 0:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_seconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_s = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1553
 *             if td.seconds > 0:
 *                 s = td.seconds
 *                 hrs = int(s / 3600)             # <<<<<<<<<<<<<<
 *                 if hrs != 0:
 *                     off_str += str(hrs) + "H"
 */
    __pyx_t_2 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_s, __pyx_int_3600, 0xE10, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_hrs = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1554
 *                 s = td.seconds
 *                 hrs = int(s / 3600)
 *                 if hrs != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(hrs) + "H"
 *                     s -= hrs * 3600
 */
    __pyx_t_3 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_hrs, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1554, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "pandas/_libs/tslibs/offsets.pyx":1555
 *                 hrs = int(s / 3600)
 *                 if hrs != 0:
 *                     off_str += str(hrs) + "H"             # <<<<<<<<<<<<<<
 *                     s -= hrs * 3600
 *                 mts = int(s / 60)
 */
      __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_hrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_n_u_H); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_off_str, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1555, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_off_str, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1556
 *                 if hrs != 0:
 *                     off_str += str(hrs) + "H"
 *                     s -= hrs * 3600             # <<<<<<<<<<<<<<
 *                 mts = int(s / 60)
 *                 if mts != 0:
 */
      __pyx_t_1 = __Pyx_PyInt_MultiplyObjC(__pyx_v_hrs, __pyx_int_3600, 0xE10, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_InPlaceSubtract(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1554
 *                 s = td.seconds
 *                 hrs = int(s / 3600)
 *                 if hrs != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(hrs) + "H"
 *                     s -= hrs * 3600
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1557
 *                     off_str += str(hrs) + "H"
 *                     s -= hrs * 3600
 *                 mts = int(s / 60)             # <<<<<<<<<<<<<<
 *                 if mts != 0:
 *                     off_str += str(mts) + "Min"
 */
    __pyx_t_2 = __Pyx_PyInt_TrueDivideObjC(__pyx_v_s, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_mts = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1558
 *                     s -= hrs * 3600
 *                 mts = int(s / 60)
 *                 if mts != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(mts) + "Min"
 *                     s -= mts * 60
 */
    __pyx_t_3 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_mts, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1558, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "pandas/_libs/tslibs/offsets.pyx":1559
 *                 mts = int(s / 60)
 *                 if mts != 0:
 *                     off_str += str(mts) + "Min"             # <<<<<<<<<<<<<<
 *                     s -= mts * 60
 *                 if s != 0:
 */
      __pyx_t_1 = __Pyx_PyObject_Str(__pyx_v_mts); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1559, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_n_u_Min); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1559, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_off_str, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1559, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_off_str, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1560
 *                 if mts != 0:
 *                     off_str += str(mts) + "Min"
 *                     s -= mts * 60             # <<<<<<<<<<<<<<
 *                 if s != 0:
 *                     off_str += str(s) + "s"
 */
      __pyx_t_1 = __Pyx_PyInt_MultiplyObjC(__pyx_v_mts, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = PyNumber_InPlaceSubtract(__pyx_v_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1558
 *                     s -= hrs * 3600
 *                 mts = int(s / 60)
 *                 if mts != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(mts) + "Min"
 *                     s -= mts * 60
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1561
 *                     off_str += str(mts) + "Min"
 *                     s -= mts * 60
 *                 if s != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(s) + "s"
 *             if td.microseconds > 0:
 */
    __pyx_t_3 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_s, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1561, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "pandas/_libs/tslibs/offsets.pyx":1562
 *                     s -= mts * 60
 *                 if s != 0:
 *                     off_str += str(s) + "s"             # <<<<<<<<<<<<<<
 *             if td.microseconds > 0:
 *                 off_str += str(td.microseconds) + "us"
 */
      __pyx_t_2 = __Pyx_PyObject_Str(__pyx_v_s); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_n_u_s); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_off_str, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_off_str, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1561
 *                     off_str += str(mts) + "Min"
 *                     s -= mts * 60
 *                 if s != 0:             # <<<<<<<<<<<<<<
 *                     off_str += str(s) + "s"
 *             if td.microseconds > 0:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1551
 *             if td.days > 0:
 *                 off_str += str(td.days) + "D"
 *             if td.seconds > 0:             # <<<<<<<<<<<<<<
 *                 s = td.seconds
 *                 hrs = int(s / 3600)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1563
 *                 if s != 0:
 *                     off_str += str(s) + "s"
 *             if td.microseconds > 0:             # <<<<<<<<<<<<<<
 *                 off_str += str(td.microseconds) + "us"
 *             return off_str
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_microseconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_2, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":1564
 *                     off_str += str(s) + "s"
 *             if td.microseconds > 0:
 *                 off_str += str(td.microseconds) + "us"             # <<<<<<<<<<<<<<
 *             return off_str
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_microseconds); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Str(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_n_u_us); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_off_str, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_off_str, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1563
 *                 if s != 0:
 *                     off_str += str(s) + "s"
 *             if td.microseconds > 0:             # <<<<<<<<<<<<<<
 *                 off_str += str(td.microseconds) + "us"
 *             return off_str
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1565
 *             if td.microseconds > 0:
 *                 off_str += str(td.microseconds) + "us"
 *             return off_str             # <<<<<<<<<<<<<<
 * 
 *         if PyDelta_Check(self.offset):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_off_str);
  __pyx_r = __pyx_v_off_str;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1547
 * 
 *     def _offset_str(self) -> str:
 *         def get_str(td):             # <<<<<<<<<<<<<<
 *             off_str = ""
 *             if td.days > 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._offset_str.get_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_off_str);
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_hrs);
  __Pyx_XDECREF(__pyx_v_mts);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1546
 *         self._cache = state.pop("_cache", {})
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         def get_str(td):
 *             off_str = ""
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_2_offset_str(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self) {
  PyObject *__pyx_v_get_str = 0;
  PyDateTime_Delta *__pyx_v_zero = NULL;
  PyObject *__pyx_v_off_str = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_offset_str", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1547
 * 
 *     def _offset_str(self) -> str:
 *         def get_str(td):             # <<<<<<<<<<<<<<
 *             off_str = ""
 *             if td.days > 0:
 */
  __pyx_t_1 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_1get_str, 0, __pyx_n_s_offset_str_locals_get_str, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__35)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_get_str = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1567
 *             return off_str
 * 
 *         if PyDelta_Check(self.offset):             # <<<<<<<<<<<<<<
 *             zero = timedelta(0, 0, 0)
 *             if self.offset >= zero:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyDelta_Check(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1568
 * 
 *         if PyDelta_Check(self.offset):
 *             zero = timedelta(0, 0, 0)             # <<<<<<<<<<<<<<
 *             if self.offset >= zero:
 *                 off_str = "+" + get_str(self.offset)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_zero = ((PyDateTime_Delta *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1569
 *         if PyDelta_Check(self.offset):
 *             zero = timedelta(0, 0, 0)
 *             if self.offset >= zero:             # <<<<<<<<<<<<<<
 *                 off_str = "+" + get_str(self.offset)
 *             else:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, ((PyObject *)__pyx_v_zero), Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1569, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1569, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":1570
 *             zero = timedelta(0, 0, 0)
 *             if self.offset >= zero:
 *                 off_str = "+" + get_str(self.offset)             # <<<<<<<<<<<<<<
 *             else:
 *                 off_str = "-" + get_str(-self.offset)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_get_str(__pyx_v_get_str, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyNumber_Add(__pyx_kp_u__37, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1570, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_off_str = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1569
 *         if PyDelta_Check(self.offset):
 *             zero = timedelta(0, 0, 0)
 *             if self.offset >= zero:             # <<<<<<<<<<<<<<
 *                 off_str = "+" + get_str(self.offset)
 *             else:
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1572
 *                 off_str = "+" + get_str(self.offset)
 *             else:
 *                 off_str = "-" + get_str(-self.offset)             # <<<<<<<<<<<<<<
 *             return off_str
 *         else:
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = PyNumber_Negative(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_11_offset_str_get_str(__pyx_v_get_str, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyNumber_Add(__pyx_kp_u__38, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1572, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_off_str = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "pandas/_libs/tslibs/offsets.pyx":1573
 *             else:
 *                 off_str = "-" + get_str(-self.offset)
 *             return off_str             # <<<<<<<<<<<<<<
 *         else:
 *             return "+" + repr(self.offset)
 */
    __Pyx_XDECREF(__pyx_r);
    if (!(likely(PyUnicode_CheckExact(__pyx_v_off_str))||((__pyx_v_off_str) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_off_str))) __PYX_ERR(0, 1573, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_off_str);
    __pyx_r = ((PyObject*)__pyx_v_off_str);
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1567
 *             return off_str
 * 
 *         if PyDelta_Check(self.offset):             # <<<<<<<<<<<<<<
 *             zero = timedelta(0, 0, 0)
 *             if self.offset >= zero:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1575
 *             return off_str
 *         else:
 *             return "+" + repr(self.offset)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_kp_u__37, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1575, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 1575, __pyx_L1_error)
    __pyx_r = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1546
 *         self._cache = state.pop("_cache", {})
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         def get_str(td):
 *             off_str = ""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._offset_str", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_get_str);
  __Pyx_XDECREF((PyObject *)__pyx_v_zero);
  __Pyx_XDECREF(__pyx_v_off_str);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1577
 *             return "+" + repr(self.offset)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1577, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 1577, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1577, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_4_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_4_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_wday = NULL;
  PyObject *__pyx_v_weeks = NULL;
  PyObject *__pyx_v_days = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_td = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1579
 *     @apply_wraps
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             n = self.n
 *             wday = other.weekday()
 */
  __pyx_t_1 = PyDateTime_Check(__pyx_v_other);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1580
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):
 *             n = self.n             # <<<<<<<<<<<<<<
 *             wday = other.weekday()
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_n = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1581
 *         if PyDateTime_Check(other):
 *             n = self.n
 *             wday = other.weekday()             # <<<<<<<<<<<<<<
 * 
 *             # avoid slowness below by operating on weeks first
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_weekday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_wday = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1584
 * 
 *             # avoid slowness below by operating on weeks first
 *             weeks = n // 5             # <<<<<<<<<<<<<<
 *             days = self._adjust_ndays(wday, weeks)
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_n, __pyx_int_5, 5, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_weeks = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1585
 *             # avoid slowness below by operating on weeks first
 *             weeks = n // 5
 *             days = self._adjust_ndays(wday, weeks)             # <<<<<<<<<<<<<<
 * 
 *             result = other + timedelta(days=7 * weeks + days)
 */
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_wday); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1585, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_weeks); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1585, __pyx_L1_error)
    __pyx_t_7 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self->__pyx_base.__pyx_vtab)->_adjust_ndays(__pyx_v_self, __pyx_t_5, __pyx_t_6); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1585, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_days = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1587
 *             days = self._adjust_ndays(wday, weeks)
 * 
 *             result = other + timedelta(days=7 * weeks + days)             # <<<<<<<<<<<<<<
 *             if self.offset:
 *                 result = result + self.offset
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_MultiplyCObj(__pyx_int_7, __pyx_v_weeks, 7, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_v_days); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_days, __pyx_t_4) < 0) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_v_other, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1588
 * 
 *             result = other + timedelta(days=7 * weeks + days)
 *             if self.offset:             # <<<<<<<<<<<<<<
 *                 result = result + self.offset
 *             return result
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1588, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1588, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":1589
 *             result = other + timedelta(days=7 * weeks + days)
 *             if self.offset:
 *                 result = result + self.offset             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyNumber_Add(__pyx_v_result, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1588
 * 
 *             result = other + timedelta(days=7 * weeks + days)
 *             if self.offset:             # <<<<<<<<<<<<<<
 *                 result = result + self.offset
 *             return result
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1590
 *             if self.offset:
 *                 result = result + self.offset
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         elif is_any_td_scalar(other):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1579
 *     @apply_wraps
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             n = self.n
 *             wday = other.weekday()
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1592
 *             return result
 * 
 *         elif is_any_td_scalar(other):             # <<<<<<<<<<<<<<
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_10timedeltas_is_any_td_scalar(__pyx_v_other); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1592, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1593
 * 
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other             # <<<<<<<<<<<<<<
 *             return BusinessDay(
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_3};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_Add(__pyx_t_4, __pyx_v_other); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_td = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1594
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(             # <<<<<<<<<<<<<<
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize
 *             )
 */
    __Pyx_XDECREF(__pyx_r);

    /* "pandas/_libs/tslibs/offsets.pyx":1595
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize             # <<<<<<<<<<<<<<
 *             )
 *         else:
 */
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pandas/_libs/tslibs/offsets.pyx":1594
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(             # <<<<<<<<<<<<<<
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize
 *             )
 */
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 1594, __pyx_L1_error);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1595
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize             # <<<<<<<<<<<<<<
 *             )
 *         else:
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_to_pytimedelta); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1595, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_offset_2, __pyx_t_3) < 0) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_3) < 0) __PYX_ERR(0, 1595, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1594
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(             # <<<<<<<<<<<<<<
 *                 self.n, offset=td.to_pytimedelta(), normalize=self.normalize
 *             )
 */
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay), __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1592
 *             return result
 * 
 *         elif is_any_td_scalar(other):             # <<<<<<<<<<<<<<
 *             td = Timedelta(self.offset) + other
 *             return BusinessDay(
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1598
 *             )
 *         else:
 *             raise ApplyTypeError(             # <<<<<<<<<<<<<<
 *                 "Only know how to combine business day with datetime or timedelta."
 *             )
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_kp_u_Only_know_how_to_combine_busines};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1598, __pyx_L1_error)
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1577
 *             return "+" + repr(self.offset)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_wday);
  __Pyx_XDECREF(__pyx_v_weeks);
  __Pyx_XDECREF(__pyx_v_days);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_td);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1604
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 *     cdef ndarray _shift_bdays(             # <<<<<<<<<<<<<<
 *         self,
 *         ndarray i8other,
 */

static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyArrayObject *__pyx_v_i8other, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays *__pyx_optional_args) {
  NPY_DATETIMEUNIT __pyx_v_reso = __pyx_k__39;
  int __pyx_v_periods;
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_res_val;
  int __pyx_v_wday;
  int __pyx_v_days;
  npy_datetimestruct __pyx_v_dts;
  __pyx_t_5numpy_int64_t __pyx_v_DAY_PERIODS;
  PyArrayMultiIterObject *__pyx_v_mi = 0;
  PyObject *__pyx_v_weeks = NULL;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int64_t __pyx_t_1;
  npy_intp __pyx_t_2;
  int __pyx_t_3;
  npy_intp *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_shift_bdays", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_reso = __pyx_optional_args->reso;
    }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1622
 *         """
 *         cdef:
 *             int periods = self.n             # <<<<<<<<<<<<<<
 *             Py_ssize_t i, n = i8other.size
 *             ndarray result = cnp.PyArray_EMPTY(
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n;
  __pyx_v_periods = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":1623
 *         cdef:
 *             int periods = self.n
 *             Py_ssize_t i, n = i8other.size             # <<<<<<<<<<<<<<
 *             ndarray result = cnp.PyArray_EMPTY(
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0
 */
  __pyx_t_2 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_i8other); if (unlikely(__pyx_t_2 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(0, 1623, __pyx_L1_error)
  __pyx_v_n = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":1625
 *             Py_ssize_t i, n = i8other.size
 *             ndarray result = cnp.PyArray_EMPTY(
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0             # <<<<<<<<<<<<<<
 *             )
 *             int64_t val, res_val
 */
  __pyx_t_3 = __pyx_f_5numpy_7ndarray_4ndim_ndim(__pyx_v_i8other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1625, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_i8other); if (unlikely(__pyx_t_4 == ((npy_intp *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 1625, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1624
 *             int periods = self.n
 *             Py_ssize_t i, n = i8other.size
 *             ndarray result = cnp.PyArray_EMPTY(             # <<<<<<<<<<<<<<
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0
 *             )
 */
  __pyx_t_5 = PyArray_EMPTY(__pyx_t_3, __pyx_t_4, NPY_INT64, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1624, __pyx_L1_error)
  __pyx_v_result = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1630
 *             int wday, days
 *             npy_datetimestruct dts
 *             int64_t DAY_PERIODS = periods_per_day(reso)             # <<<<<<<<<<<<<<
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(result, i8other)
 * 
 */
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.reso = __pyx_v_reso;
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_6dtypes_periods_per_day(0, &__pyx_t_6); if (unlikely(__pyx_t_1 == ((__pyx_t_5numpy_int64_t)-1LL) && PyErr_Occurred())) __PYX_ERR(0, 1630, __pyx_L1_error)
  __pyx_v_DAY_PERIODS = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":1631
 *             npy_datetimestruct dts
 *             int64_t DAY_PERIODS = periods_per_day(reso)
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(result, i8other)             # <<<<<<<<<<<<<<
 * 
 *         for i in range(n):
 */
  __pyx_t_5 = __pyx_f_5numpy_PyArray_MultiIterNew2(((PyObject *)__pyx_v_result), ((PyObject *)__pyx_v_i8other)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1631, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_broadcast))))) __PYX_ERR(0, 1631, __pyx_L1_error)
  __pyx_v_mi = ((PyArrayMultiIterObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1633
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(result, i8other)
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             # Analogous to: val = i8other[i]
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 */
  __pyx_t_7 = __pyx_v_n;
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "pandas/_libs/tslibs/offsets.pyx":1635
 *         for i in range(n):
 *             # Analogous to: val = i8other[i]
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *             if val == NPY_NAT:
 */
    __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

    /* "pandas/_libs/tslibs/offsets.pyx":1637
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *             if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                 res_val = NPY_NAT
 *             else:
 */
    __pyx_t_10 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
    if (__pyx_t_10) {

      /* "pandas/_libs/tslibs/offsets.pyx":1638
 * 
 *             if val == NPY_NAT:
 *                 res_val = NPY_NAT             # <<<<<<<<<<<<<<
 *             else:
 *                 # The rest of this is effectively a copy of BusinessDay.apply
 */
      __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

      /* "pandas/_libs/tslibs/offsets.pyx":1637
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *             if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                 res_val = NPY_NAT
 *             else:
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1641
 *             else:
 *                 # The rest of this is effectively a copy of BusinessDay.apply
 *                 weeks = periods // 5             # <<<<<<<<<<<<<<
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                 wday = dayofweek(dts.year, dts.month, dts.day)
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyInt_From_long(__Pyx_div_long(__pyx_v_periods, 5)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_weeks, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1642
 *                 # The rest of this is effectively a copy of BusinessDay.apply
 *                 weeks = periods // 5
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                 wday = dayofweek(dts.year, dts.month, dts.day)
 * 
 */
      pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

      /* "pandas/_libs/tslibs/offsets.pyx":1643
 *                 weeks = periods // 5
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                 wday = dayofweek(dts.year, dts.month, dts.day)             # <<<<<<<<<<<<<<
 * 
 *                 days = self._adjust_ndays(wday, weeks)
 */
      __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_dayofweek(__pyx_v_dts.year, __pyx_v_dts.month, __pyx_v_dts.day); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1643, __pyx_L1_error)
      __pyx_v_wday = __pyx_t_3;

      /* "pandas/_libs/tslibs/offsets.pyx":1645
 *                 wday = dayofweek(dts.year, dts.month, dts.day)
 * 
 *                 days = self._adjust_ndays(wday, weeks)             # <<<<<<<<<<<<<<
 *                 res_val = val + (7 * weeks + days) * DAY_PERIODS
 * 
 */
      __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_weeks); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1645, __pyx_L1_error)
      __pyx_t_11 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self->__pyx_base.__pyx_vtab)->_adjust_ndays(__pyx_v_self, __pyx_v_wday, __pyx_t_3); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1645, __pyx_L1_error)
      __pyx_v_days = __pyx_t_11;

      /* "pandas/_libs/tslibs/offsets.pyx":1646
 * 
 *                 days = self._adjust_ndays(wday, weeks)
 *                 res_val = val + (7 * weeks + days) * DAY_PERIODS             # <<<<<<<<<<<<<<
 * 
 *             # Analogous to: out[i] = res_val
 */
      __pyx_t_5 = __Pyx_PyInt_From_npy_int64(__pyx_v_val); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_PyInt_MultiplyCObj(__pyx_int_7, __pyx_v_weeks, 7, 0, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_days); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = PyNumber_Add(__pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyInt_From_npy_int64(__pyx_v_DAY_PERIODS); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_12 = PyNumber_Multiply(__pyx_t_14, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = PyNumber_Add(__pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_1 = __Pyx_PyInt_As_npy_int64(__pyx_t_13); if (unlikely((__pyx_t_1 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1646, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_v_res_val = __pyx_t_1;
    }
    __pyx_L5:;

    /* "pandas/_libs/tslibs/offsets.pyx":1649
 * 
 *             # Analogous to: out[i] = res_val
 *             (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *             cnp.PyArray_MultiIter_NEXT(mi)
 */
    (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

    /* "pandas/_libs/tslibs/offsets.pyx":1651
 *             (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *             cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
    PyArray_MultiIter_NEXT(__pyx_v_mi);
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1653
 *             cnp.PyArray_MultiIter_NEXT(mi)
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cdef int _adjust_ndays(self, int wday, int weeks):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1604
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 *     cdef ndarray _shift_bdays(             # <<<<<<<<<<<<<<
 *         self,
 *         ndarray i8other,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._shift_bdays", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF((PyObject *)__pyx_v_mi);
  __Pyx_XDECREF(__pyx_v_weeks);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1655
 *         return result
 * 
 *     cdef int _adjust_ndays(self, int wday, int weeks):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int n = self.n
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__adjust_ndays(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, int __pyx_v_wday, int __pyx_v_weeks) {
  int __pyx_v_n;
  int __pyx_v_days;
  int __pyx_r;
  __pyx_t_5numpy_int64_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "pandas/_libs/tslibs/offsets.pyx":1657
 *     cdef int _adjust_ndays(self, int wday, int weeks):
 *         cdef:
 *             int n = self.n             # <<<<<<<<<<<<<<
 *             int days
 * 
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n;
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":1660
 *             int days
 * 
 *         if n <= 0 and wday > 4:             # <<<<<<<<<<<<<<
 *             # roll forward
 *             n += 1
 */
  __pyx_t_3 = (__pyx_v_n <= 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_wday > 4);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1662
 *         if n <= 0 and wday > 4:
 *             # roll forward
 *             n += 1             # <<<<<<<<<<<<<<
 * 
 *         n -= 5 * weeks
 */
    __pyx_v_n = (__pyx_v_n + 1);

    /* "pandas/_libs/tslibs/offsets.pyx":1660
 *             int days
 * 
 *         if n <= 0 and wday > 4:             # <<<<<<<<<<<<<<
 *             # roll forward
 *             n += 1
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1664
 *             n += 1
 * 
 *         n -= 5 * weeks             # <<<<<<<<<<<<<<
 * 
 *         # n is always >= 0 at this point
 */
  __pyx_v_n = (__pyx_v_n - (5 * __pyx_v_weeks));

  /* "pandas/_libs/tslibs/offsets.pyx":1667
 * 
 *         # n is always >= 0 at this point
 *         if n == 0 and wday > 4:             # <<<<<<<<<<<<<<
 *             # roll back
 *             days = 4 - wday
 */
  __pyx_t_3 = (__pyx_v_n == 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_wday > 4);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1669
 *         if n == 0 and wday > 4:
 *             # roll back
 *             days = 4 - wday             # <<<<<<<<<<<<<<
 *         elif wday > 4:
 *             # roll forward
 */
    __pyx_v_days = (4 - __pyx_v_wday);

    /* "pandas/_libs/tslibs/offsets.pyx":1667
 * 
 *         # n is always >= 0 at this point
 *         if n == 0 and wday > 4:             # <<<<<<<<<<<<<<
 *             # roll back
 *             days = 4 - wday
 */
    goto __pyx_L6;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1670
 *             # roll back
 *             days = 4 - wday
 *         elif wday > 4:             # <<<<<<<<<<<<<<
 *             # roll forward
 *             days = (7 - wday) + (n - 1)
 */
  __pyx_t_2 = (__pyx_v_wday > 4);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1672
 *         elif wday > 4:
 *             # roll forward
 *             days = (7 - wday) + (n - 1)             # <<<<<<<<<<<<<<
 *         elif wday + n <= 4:
 *             # shift by n days without leaving the current week
 */
    __pyx_v_days = ((7 - __pyx_v_wday) + (__pyx_v_n - 1));

    /* "pandas/_libs/tslibs/offsets.pyx":1670
 *             # roll back
 *             days = 4 - wday
 *         elif wday > 4:             # <<<<<<<<<<<<<<
 *             # roll forward
 *             days = (7 - wday) + (n - 1)
 */
    goto __pyx_L6;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1673
 *             # roll forward
 *             days = (7 - wday) + (n - 1)
 *         elif wday + n <= 4:             # <<<<<<<<<<<<<<
 *             # shift by n days without leaving the current week
 *             days = n
 */
  __pyx_t_2 = ((__pyx_v_wday + __pyx_v_n) <= 4);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1675
 *         elif wday + n <= 4:
 *             # shift by n days without leaving the current week
 *             days = n             # <<<<<<<<<<<<<<
 *         else:
 *             # shift by n days plus 2 to get past the weekend
 */
    __pyx_v_days = __pyx_v_n;

    /* "pandas/_libs/tslibs/offsets.pyx":1673
 *             # roll forward
 *             days = (7 - wday) + (n - 1)
 *         elif wday + n <= 4:             # <<<<<<<<<<<<<<
 *             # shift by n days without leaving the current week
 *             days = n
 */
    goto __pyx_L6;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1678
 *         else:
 *             # shift by n days plus 2 to get past the weekend
 *             days = n + 2             # <<<<<<<<<<<<<<
 *         return days
 * 
 */
  /*else*/ {
    __pyx_v_days = (__pyx_v_n + 2);
  }
  __pyx_L6:;

  /* "pandas/_libs/tslibs/offsets.pyx":1679
 *             # shift by n days plus 2 to get past the weekend
 *             days = n + 2
 *         return days             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __pyx_r = __pyx_v_days;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1655
 *         return result
 * 
 *     cdef int _adjust_ndays(self, int wday, int weeks):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int n = self.n
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1681
 *         return days
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1681, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 1681, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1681, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_6_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_6_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  PyObject *__pyx_v_i8other = NULL;
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  NPY_DATETIMEUNIT __pyx_t_5;
  struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1683
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")             # <<<<<<<<<<<<<<
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         res = self._shift_bdays(i8other, reso=reso)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_i8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_i8other = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1684
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")
 *         reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *         res = self._shift_bdays(i8other, reso=reso)
 *         if self.offset:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 1684, __pyx_L1_error)
  __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":1685
 *         i8other = dtarr.view("i8")
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         res = self._shift_bdays(i8other, reso=reso)             # <<<<<<<<<<<<<<
 *         if self.offset:
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)
 */
  if (!(likely(((__pyx_v_i8other) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_i8other, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 1685, __pyx_L1_error)
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.reso = __pyx_v_reso;
  __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self->__pyx_base.__pyx_vtab)->_shift_bdays(__pyx_v_self, ((PyArrayObject *)__pyx_v_i8other), &__pyx_t_6)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_res = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1686
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         res = self._shift_bdays(i8other, reso=reso)
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)
 *             res = res.view("i8")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":1687
 *         res = self._shift_bdays(i8other, reso=reso)
 *         if self.offset:
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)             # <<<<<<<<<<<<<<
 *             res = res.view("i8")
 *         return res
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1688
 *         if self.offset:
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)
 *             res = res.view("i8")             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_res, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1688, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_u_i8};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1688, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1686
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         res = self._shift_bdays(i8other, reso=reso)
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)
 *             res = res.view("i8")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1689
 *             res = res.view(dtarr.dtype) + Timedelta(self.offset)
 *             res = res.view("i8")
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1681
 *         return days
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i8other);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1691
 *         return res
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1691, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 1691, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1691, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 1691, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_8is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_8is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1692
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.weekday() < 5
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1692, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1693
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return dt.weekday() < 5
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1692
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.weekday() < 5
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1694
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return dt.weekday() < 5             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_weekday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_int_5, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1691
 *         return res
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessDay.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1761
 *         tuple start, end
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)
 *     ):
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_end = 0;
  PyObject *__pyx_v_offset = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_start,&__pyx_n_s_end,&__pyx_n_s_offset_2,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":1762
 * 
 *     def __init__(
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)             # <<<<<<<<<<<<<<
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_09_00));
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_17_00));
    values[4] = __Pyx_Arg_NewRef_VARARGS(__pyx_k__40);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1761, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1761, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1761, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1761, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset_2);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1761, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 1761, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_start = values[2];
    __pyx_v_end = values[3];
    __pyx_v_offset = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 5, __pyx_nargs); __PYX_ERR(0, 1761, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_start, __pyx_v_end, __pyx_v_offset);

  /* "pandas/_libs/tslibs/offsets.pyx":1761
 *         tuple start, end
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)
 *     ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_start, PyObject *__pyx_v_end, PyObject *__pyx_v_offset) {
  PyObject *__pyx_v_num_openings = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_total_secs = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_9genexpr12__pyx_v_x = NULL;
  PyObject *__pyx_9genexpr13__pyx_v_x = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_INCREF(__pyx_v_end);

  /* "pandas/_libs/tslibs/offsets.pyx":1764
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)             # <<<<<<<<<<<<<<
 * 
 *         # must be validated here to equality check
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_offset};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1767
 * 
 *         # must be validated here to equality check
 *         if np.ndim(start) == 0:             # <<<<<<<<<<<<<<
 *             # i.e. not is_list_like
 *             start = [start]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":1769
 *         if np.ndim(start) == 0:
 *             # i.e. not is_list_like
 *             start = [start]             # <<<<<<<<<<<<<<
 *         if not len(start):
 *             raise ValueError("Must include at least 1 start time")
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1769, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_start);
    __Pyx_GIVEREF(__pyx_v_start);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_start)) __PYX_ERR(0, 1769, __pyx_L1_error);
    __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1767
 * 
 *         # must be validated here to equality check
 *         if np.ndim(start) == 0:             # <<<<<<<<<<<<<<
 *             # i.e. not is_list_like
 *             start = [start]
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1770
 *             # i.e. not is_list_like
 *             start = [start]
 *         if not len(start):             # <<<<<<<<<<<<<<
 *             raise ValueError("Must include at least 1 start time")
 * 
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_start); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1770, __pyx_L1_error)
  __pyx_t_5 = (!(__pyx_t_6 != 0));
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1771
 *             start = [start]
 *         if not len(start):
 *             raise ValueError("Must include at least 1 start time")             # <<<<<<<<<<<<<<
 * 
 *         if np.ndim(end) == 0:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1771, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1770
 *             # i.e. not is_list_like
 *             start = [start]
 *         if not len(start):             # <<<<<<<<<<<<<<
 *             raise ValueError("Must include at least 1 start time")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1773
 *             raise ValueError("Must include at least 1 start time")
 * 
 *         if np.ndim(end) == 0:             # <<<<<<<<<<<<<<
 *             # i.e. not is_list_like
 *             end = [end]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_end};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_1, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1773, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":1775
 *         if np.ndim(end) == 0:
 *             # i.e. not is_list_like
 *             end = [end]             # <<<<<<<<<<<<<<
 *         if not len(end):
 *             raise ValueError("Must include at least 1 end time")
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1775, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_end);
    __Pyx_GIVEREF(__pyx_v_end);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_end)) __PYX_ERR(0, 1775, __pyx_L1_error);
    __Pyx_DECREF_SET(__pyx_v_end, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1773
 *             raise ValueError("Must include at least 1 start time")
 * 
 *         if np.ndim(end) == 0:             # <<<<<<<<<<<<<<
 *             # i.e. not is_list_like
 *             end = [end]
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1776
 *             # i.e. not is_list_like
 *             end = [end]
 *         if not len(end):             # <<<<<<<<<<<<<<
 *             raise ValueError("Must include at least 1 end time")
 * 
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_end); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1776, __pyx_L1_error)
  __pyx_t_5 = (!(__pyx_t_6 != 0));
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1777
 *             end = [end]
 *         if not len(end):
 *             raise ValueError("Must include at least 1 end time")             # <<<<<<<<<<<<<<
 * 
 *         start = np.array([_validate_business_time(x) for x in start])
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1777, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1776
 *             # i.e. not is_list_like
 *             end = [end]
 *         if not len(end):             # <<<<<<<<<<<<<<
 *             raise ValueError("Must include at least 1 end time")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1779
 *             raise ValueError("Must include at least 1 end time")
 * 
 *         start = np.array([_validate_business_time(x) for x in start])             # <<<<<<<<<<<<<<
 *         end = np.array([_validate_business_time(x) for x in end])
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1779, __pyx_L9_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (likely(PyList_CheckExact(__pyx_v_start)) || PyTuple_CheckExact(__pyx_v_start)) {
      __pyx_t_7 = __pyx_v_start; __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_start); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1779, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1779, __pyx_L9_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1779, __pyx_L9_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_9 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_6); __Pyx_INCREF(__pyx_t_9); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1779, __pyx_L9_error)
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1779, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1779, __pyx_L9_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_6); __Pyx_INCREF(__pyx_t_9); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1779, __pyx_L9_error)
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1779, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
        }
      } else {
        __pyx_t_9 = __pyx_t_8(__pyx_t_7);
        if (unlikely(!__pyx_t_9)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1779, __pyx_L9_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_9);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr12__pyx_v_x, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_9 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__validate_business_time(__pyx_9genexpr12__pyx_v_x); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1779, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_9))) __PYX_ERR(0, 1779, __pyx_L9_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_x); __pyx_9genexpr12__pyx_v_x = 0;
    goto __pyx_L13_exit_scope;
    __pyx_L9_error:;
    __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_x); __pyx_9genexpr12__pyx_v_x = 0;
    goto __pyx_L1_error;
    __pyx_L13_exit_scope:;
  } /* exit inner scope */
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1780
 * 
 *         start = np.array([_validate_business_time(x) for x in start])
 *         end = np.array([_validate_business_time(x) for x in end])             # <<<<<<<<<<<<<<
 * 
 *         # Validation of input
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  { /* enter inner scope */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1780, __pyx_L16_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (likely(PyList_CheckExact(__pyx_v_end)) || PyTuple_CheckExact(__pyx_v_end)) {
      __pyx_t_7 = __pyx_v_end; __Pyx_INCREF(__pyx_t_7);
      __pyx_t_6 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_end); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1780, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1780, __pyx_L16_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1780, __pyx_L16_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_9 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_6); __Pyx_INCREF(__pyx_t_9); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1780, __pyx_L16_error)
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1780, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_7);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1780, __pyx_L16_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_6); __Pyx_INCREF(__pyx_t_9); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1780, __pyx_L16_error)
          #else
          __pyx_t_9 = __Pyx_PySequence_ITEM(__pyx_t_7, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1780, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_9);
          #endif
        }
      } else {
        __pyx_t_9 = __pyx_t_8(__pyx_t_7);
        if (unlikely(!__pyx_t_9)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1780, __pyx_L16_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_9);
      }
      __Pyx_XDECREF_SET(__pyx_9genexpr13__pyx_v_x, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_9 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__validate_business_time(__pyx_9genexpr13__pyx_v_x); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1780, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_9))) __PYX_ERR(0, 1780, __pyx_L16_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x); __pyx_9genexpr13__pyx_v_x = 0;
    goto __pyx_L20_exit_scope;
    __pyx_L16_error:;
    __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x); __pyx_9genexpr13__pyx_v_x = 0;
    goto __pyx_L1_error;
    __pyx_L20_exit_scope:;
  } /* exit inner scope */
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1780, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_end, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1783
 * 
 *         # Validation of input
 *         if len(start) != len(end):             # <<<<<<<<<<<<<<
 *             raise ValueError("number of starting time and ending time must be the same")
 *         num_openings = len(start)
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_start); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1783, __pyx_L1_error)
  __pyx_t_10 = PyObject_Length(__pyx_v_end); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1783, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != __pyx_t_10);
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1784
 *         # Validation of input
 *         if len(start) != len(end):
 *             raise ValueError("number of starting time and ending time must be the same")             # <<<<<<<<<<<<<<
 *         num_openings = len(start)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1784, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1783
 * 
 *         # Validation of input
 *         if len(start) != len(end):             # <<<<<<<<<<<<<<
 *             raise ValueError("number of starting time and ending time must be the same")
 *         num_openings = len(start)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1785
 *         if len(start) != len(end):
 *             raise ValueError("number of starting time and ending time must be the same")
 *         num_openings = len(start)             # <<<<<<<<<<<<<<
 * 
 *         # sort starting and ending time by starting time
 */
  __pyx_t_10 = PyObject_Length(__pyx_v_start); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1785, __pyx_L1_error)
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1785, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_num_openings = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1788
 * 
 *         # sort starting and ending time by starting time
 *         index = np.argsort(start)             # <<<<<<<<<<<<<<
 * 
 *         # convert to tuple so that start and end are hashable
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_argsort); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1788, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_index = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1791
 * 
 *         # convert to tuple so that start and end are hashable
 *         start = tuple(start[index])             # <<<<<<<<<<<<<<
 *         end = tuple(end[index])
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_start, __pyx_v_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1792
 *         # convert to tuple so that start and end are hashable
 *         start = tuple(start[index])
 *         end = tuple(end[index])             # <<<<<<<<<<<<<<
 * 
 *         total_secs = 0
 */
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_end, __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_end, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1794
 *         end = tuple(end[index])
 * 
 *         total_secs = 0             # <<<<<<<<<<<<<<
 *         for i in range(num_openings):
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_total_secs = __pyx_int_0;

  /* "pandas/_libs/tslibs/offsets.pyx":1795
 * 
 *         total_secs = 0
 *         for i in range(num_openings):             # <<<<<<<<<<<<<<
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 *             total_secs += self._get_business_hours_by_sec(
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_v_num_openings); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1795, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3);
    __pyx_t_10 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_10 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1795, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1795, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 1795, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1795, __pyx_L1_error)
          #endif
          if (__pyx_t_10 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_10); __Pyx_INCREF(__pyx_t_1); __pyx_t_10++; if (unlikely((0 < 0))) __PYX_ERR(0, 1795, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1795, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
      }
    } else {
      __pyx_t_1 = __pyx_t_8(__pyx_t_3);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1795, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1796
 *         total_secs = 0
 *         for i in range(num_openings):
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])             # <<<<<<<<<<<<<<
 *             total_secs += self._get_business_hours_by_sec(
 *                 end[i], start[(i + 1) % num_openings]
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_business_hours_by_sec); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_start, __pyx_v_i); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_end, __pyx_v_i); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_7, __pyx_t_9};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1796, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_total_secs, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_total_secs, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1797
 *         for i in range(num_openings):
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 *             total_secs += self._get_business_hours_by_sec(             # <<<<<<<<<<<<<<
 *                 end[i], start[(i + 1) % num_openings]
 *             )
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_business_hours_by_sec); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1797, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "pandas/_libs/tslibs/offsets.pyx":1798
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 *             total_secs += self._get_business_hours_by_sec(
 *                 end[i], start[(i + 1) % num_openings]             # <<<<<<<<<<<<<<
 *             )
 *         if total_secs != 24 * 60 * 60:
 */
    __pyx_t_9 = __Pyx_PyObject_GetItem(__pyx_v_end, __pyx_v_i); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_11 = PyNumber_Remainder(__pyx_t_7, __pyx_v_num_openings); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_v_start, __pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_9, __pyx_t_7};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1797
 *         for i in range(num_openings):
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 *             total_secs += self._get_business_hours_by_sec(             # <<<<<<<<<<<<<<
 *                 end[i], start[(i + 1) % num_openings]
 *             )
 */
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_total_secs, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1797, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_total_secs, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1795
 * 
 *         total_secs = 0
 *         for i in range(num_openings):             # <<<<<<<<<<<<<<
 *             total_secs += self._get_business_hours_by_sec(start[i], end[i])
 *             total_secs += self._get_business_hours_by_sec(
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1800
 *                 end[i], start[(i + 1) % num_openings]
 *             )
 *         if total_secs != 24 * 60 * 60:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "invalid starting and ending time(s): "
 */
  __pyx_t_5 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_total_secs, __pyx_int_86400, 0x15180, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1800, __pyx_L1_error)
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":1801
 *             )
 *         if total_secs != 24 * 60 * 60:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "invalid starting and ending time(s): "
 *                 "opening hours should not touch or overlap with "
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 1801, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1800
 *                 end[i], start[(i + 1) % num_openings]
 *             )
 *         if total_secs != 24 * 60 * 60:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "invalid starting and ending time(s): "
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1807
 *             )
 * 
 *         self.start = start             # <<<<<<<<<<<<<<
 *         self.end = end
 * 
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_start)) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v_start))) __PYX_ERR(0, 1807, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_start;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->start);
  __Pyx_DECREF(__pyx_v_self->start);
  __pyx_v_self->start = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1808
 * 
 *         self.start = start
 *         self.end = end             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_end)) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v_end))) __PYX_ERR(0, 1808, __pyx_L1_error)
  __pyx_t_3 = __pyx_v_end;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->end);
  __Pyx_DECREF(__pyx_v_self->end);
  __pyx_v_self->end = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1761
 *         tuple start, end
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)
 *     ):
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_openings);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_total_secs);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_9genexpr12__pyx_v_x);
  __Pyx_XDECREF(__pyx_9genexpr13__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_end);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1810
 *         self.end = end
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_end = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1810, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1810, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1811
 * 
 *     cpdef __setstate__(self, state):
 *         start = state.pop("start")             # <<<<<<<<<<<<<<
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 *         end = state.pop("end")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1812
 *     cpdef __setstate__(self, state):
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)             # <<<<<<<<<<<<<<
 *         end = state.pop("end")
 *         end = (end,) if np.ndim(end) == 0 else tuple(end)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ndim); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_start};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1812, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_start);
    __Pyx_GIVEREF(__pyx_v_start);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_start)) __PYX_ERR(0, 1812, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1812, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_start, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1813
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 *         end = state.pop("end")             # <<<<<<<<<<<<<<
 *         end = (end,) if np.ndim(end) == 0 else tuple(end)
 *         self.start = start
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_end};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1813, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_end = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1814
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 *         end = state.pop("end")
 *         end = (end,) if np.ndim(end) == 0 else tuple(end)             # <<<<<<<<<<<<<<
 *         self.start = start
 *         self.end = end
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ndim); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_end};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1814, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_end);
    __Pyx_GIVEREF(__pyx_v_end);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_end)) __PYX_ERR(0, 1814, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  } else {
    __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1814, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_end, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1815
 *         end = state.pop("end")
 *         end = (end,) if np.ndim(end) == 0 else tuple(end)
 *         self.start = start             # <<<<<<<<<<<<<<
 *         self.end = end
 * 
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_start))||((__pyx_v_start) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v_start))) __PYX_ERR(0, 1815, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_start;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->start);
  __Pyx_DECREF(__pyx_v_self->start);
  __pyx_v_self->start = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1816
 *         end = (end,) if np.ndim(end) == 0 else tuple(end)
 *         self.start = start
 *         self.end = end             # <<<<<<<<<<<<<<
 * 
 *         state.pop("kwds", {})
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v_end))||((__pyx_v_end) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v_end))) __PYX_ERR(0, 1816, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_end;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->end);
  __Pyx_DECREF(__pyx_v_self->end);
  __pyx_v_self->end = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1818
 *         self.end = end
 * 
 *         state.pop("kwds", {})             # <<<<<<<<<<<<<<
 *         state.pop("next_bday", None)
 *         BusinessMixin.__setstate__(self, state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_n_u_kwds, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1818, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1819
 * 
 *         state.pop("kwds", {})
 *         state.pop("next_bday", None)             # <<<<<<<<<<<<<<
 *         BusinessMixin.__setstate__(self, state)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1820
 *         state.pop("kwds", {})
 *         state.pop("next_bday", None)
 *         BusinessMixin.__setstate__(self, state)             # <<<<<<<<<<<<<<
 * 
 *     def _repr_attrs(self) -> str:
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_state, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1810
 *         self.end = end
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_end);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1810, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 1810, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1810, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1822
 *         BusinessMixin.__setstate__(self, state)
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs = {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_repr_attrs (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_repr_attrs", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_repr_attrs", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_4_repr_attrs(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_2generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":1826
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_genexpr(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1826, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_2generator4, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_repr_attrs_locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._repr_attrs.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_2generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":1827
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 *         attrs = [f"{self._prefix}={hours}"]
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 1827, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1827, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1827, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1827, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1827, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 1827, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1827, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1827, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 1827, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1827, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1827, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 1827, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_st);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_st, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_en);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_en, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1826
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
    __pyx_t_4 = PyTuple_New(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = 0;
    __pyx_t_10 = 127;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_st, __pyx_n_s_hour); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_Format(__pyx_t_6, __pyx_kp_u_02d); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u__46);
    __pyx_t_9 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__46);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_kp_u__46);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_st, __pyx_n_s_minute); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Format(__pyx_t_5, __pyx_kp_u_02d); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u__38);
    __pyx_t_9 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__38);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_kp_u__38);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_en, __pyx_n_s_hour); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_Format(__pyx_t_6, __pyx_kp_u_02d); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u__46);
    __pyx_t_9 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__46);
    PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_kp_u__46);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_en, __pyx_n_s_minute); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Format(__pyx_t_5, __pyx_kp_u_02d); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_10 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_10) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_10;
    __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_4, 7, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_6))) __PYX_ERR(0, 1826, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1827
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 *         attrs = [f"{self._prefix}={hours}"]
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "pandas/_libs/tslibs/offsets.pyx":1826
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1822
 *         BusinessMixin.__setstate__(self, state)
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_4_repr_attrs(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_hours = NULL;
  PyObject *__pyx_v_attrs = NULL;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_2generator4 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_repr_attrs", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1823
 * 
 *     def _repr_attrs(self) -> str:
 *         out = super()._repr_attrs()             # <<<<<<<<<<<<<<
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour))) __PYX_ERR(0, 1823, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self))) __PYX_ERR(0, 1823, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_repr_attrs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1827
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 *         attrs = [f"{self._prefix}={hours}"]
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->start);
  __Pyx_GIVEREF(__pyx_v_self->start);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->start)) __PYX_ERR(0, 1827, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->end);
  __Pyx_GIVEREF(__pyx_v_self->end);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->end)) __PYX_ERR(0, 1827, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1826
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
  __pyx_t_1 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_genexpr(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1825
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 *         hours = ",".join(             # <<<<<<<<<<<<<<
 *             f"{st.hour:02d}:{st.minute:02d}-{en.hour:02d}:{en.minute:02d}"
 *             for st, en in zip(self.start, self.end)
 */
  __pyx_t_2 = __Pyx_Generator_Next(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__47, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_hours = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1829
 *             for st, en in zip(self.start, self.end)
 *         )
 *         attrs = [f"{self._prefix}={hours}"]             # <<<<<<<<<<<<<<
 *         out += ": " + ", ".join(attrs)
 *         return out
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__19);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__19);
  __pyx_t_3 = __Pyx_PyUnicode_Unicode(__pyx_v_hours); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_3)) __PYX_ERR(0, 1829, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_v_attrs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1830
 *         )
 *         attrs = [f"{self._prefix}={hours}"]
 *         out += ": " + ", ".join(attrs)             # <<<<<<<<<<<<<<
 *         return out
 * 
 */
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__21, __pyx_v_attrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u__20, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_out, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1831
 *         attrs = [f"{self._prefix}={hours}"]
 *         out += ": " + ", ".join(attrs)
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def _get_business_hours_by_sec(self, start, end):
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_out))||((__pyx_v_out) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_out))) __PYX_ERR(0, 1831, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = ((PyObject*)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1822
 *         BusinessMixin.__setstate__(self, state)
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._repr_attrs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_hours);
  __Pyx_XDECREF(__pyx_v_attrs);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11_repr_attrs_2generator4);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1833
 *         return out
 * 
 *     def _get_business_hours_by_sec(self, start, end):             # <<<<<<<<<<<<<<
 *         """
 *         Return business hours in a day by seconds.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec, "\n        Return business hours in a day by seconds.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec = {"_get_business_hours_by_sec", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_end = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_business_hours_by_sec (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_start,&__pyx_n_s_end,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1833, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1833, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_get_business_hours_by_sec", 1, 2, 2, 1); __PYX_ERR(0, 1833, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_business_hours_by_sec") < 0)) __PYX_ERR(0, 1833, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_start = values[0];
    __pyx_v_end = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_business_hours_by_sec", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 1833, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._get_business_hours_by_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_start, __pyx_v_end);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_start, PyObject *__pyx_v_end) {
  PyDateTime_DateTime *__pyx_v_dtstart = NULL;
  long __pyx_v_day;
  PyDateTime_DateTime *__pyx_v_until = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_business_hours_by_sec", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1838
 *         """
 *         # create dummy datetime to calculate business hours in a day
 *         dtstart = datetime(2014, 4, 1, start.hour, start.minute)             # <<<<<<<<<<<<<<
 *         day = 1 if start < end else 2
 *         until = datetime(2014, 4, day, end.hour, end.minute)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_start, __pyx_n_s_hour); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_start, __pyx_n_s_minute); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_int_2014);
  __Pyx_GIVEREF(__pyx_int_2014);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_2014)) __PYX_ERR(0, 1838, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_4);
  __Pyx_GIVEREF(__pyx_int_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_4)) __PYX_ERR(0, 1838, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_int_1)) __PYX_ERR(0, 1838, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_1)) __PYX_ERR(0, 1838, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_2)) __PYX_ERR(0, 1838, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_dtstart = ((PyDateTime_DateTime *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1839
 *         # create dummy datetime to calculate business hours in a day
 *         dtstart = datetime(2014, 4, 1, start.hour, start.minute)
 *         day = 1 if start < end else 2             # <<<<<<<<<<<<<<
 *         until = datetime(2014, 4, day, end.hour, end.minute)
 *         return int((until - dtstart).total_seconds())
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_start, __pyx_v_end, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1839, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1839, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {
    __pyx_t_4 = 1;
  } else {
    __pyx_t_4 = 2;
  }
  __pyx_v_day = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":1840
 *         dtstart = datetime(2014, 4, 1, start.hour, start.minute)
 *         day = 1 if start < end else 2
 *         until = datetime(2014, 4, day, end.hour, end.minute)             # <<<<<<<<<<<<<<
 *         return int((until - dtstart).total_seconds())
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v_day); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_end, __pyx_n_s_hour); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_end, __pyx_n_s_minute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyTuple_New(5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_int_2014);
  __Pyx_GIVEREF(__pyx_int_2014);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_2014)) __PYX_ERR(0, 1840, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_4);
  __Pyx_GIVEREF(__pyx_int_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_int_4)) __PYX_ERR(0, 1840, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_2)) __PYX_ERR(0, 1840, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_3)) __PYX_ERR(0, 1840, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 4, __pyx_t_1)) __PYX_ERR(0, 1840, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_until = ((PyDateTime_DateTime *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1841
 *         day = 1 if start < end else 2
 *         until = datetime(2014, 4, day, end.hour, end.minute)
 *         return int((until - dtstart).total_seconds())             # <<<<<<<<<<<<<<
 * 
 *     def _get_closing_time(self, dt: datetime) -> datetime:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyNumber_Subtract(((PyObject *)__pyx_v_until), ((PyObject *)__pyx_v_dtstart)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_total_seconds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1841, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1833
 *         return out
 * 
 *     def _get_business_hours_by_sec(self, start, end):             # <<<<<<<<<<<<<<
 *         """
 *         Return business hours in a day by seconds.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._get_business_hours_by_sec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_dtstart);
  __Pyx_XDECREF((PyObject *)__pyx_v_until);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1843
 *         return int((until - dtstart).total_seconds())
 * 
 *     def _get_closing_time(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Get the closing time of a business hour interval by its opening time.
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time, "\n        Get the closing time of a business hour interval by its opening time.\n\n        Parameters\n        ----------\n        dt : datetime\n            Opening time of a business hour interval.\n\n        Returns\n        -------\n        result : datetime\n            Corresponding closing time.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time = {"_get_closing_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_closing_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1843, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_closing_time") < 0)) __PYX_ERR(0, 1843, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_closing_time", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1843, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._get_closing_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 1843, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_st = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_closing_time", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1857
 *             Corresponding closing time.
 *         """
 *         for i, st in enumerate(self.start):             # <<<<<<<<<<<<<<
 *             if st.hour == dt.hour and st.minute == dt.minute:
 *                 return dt + timedelta(
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_1 = __pyx_int_0;
  __pyx_t_2 = __pyx_v_self->start; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1857, __pyx_L1_error)
      #endif
      if (__pyx_t_3 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 1857, __pyx_L1_error)
    #else
    __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_st, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1857, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1858
 *         """
 *         for i, st in enumerate(self.start):
 *             if st.hour == dt.hour and st.minute == dt.minute:             # <<<<<<<<<<<<<<
 *                 return dt + timedelta(
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_hour); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_dt); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1858, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_4, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_5 = __pyx_t_9;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_minute); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_6 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_dt); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1858, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_8, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 1858, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __pyx_t_9;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "pandas/_libs/tslibs/offsets.pyx":1859
 *         for i, st in enumerate(self.start):
 *             if st.hour == dt.hour and st.minute == dt.minute:
 *                 return dt + timedelta(             # <<<<<<<<<<<<<<
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])
 *                 )
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);

      /* "pandas/_libs/tslibs/offsets.pyx":1860
 *             if st.hour == dt.hour and st.minute == dt.minute:
 *                 return dt + timedelta(
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])             # <<<<<<<<<<<<<<
 *                 )
 *         assert False
 */
      __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_business_hours_by_sec); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (unlikely(__pyx_v_self->end == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 1860, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyObject_GetItem(__pyx_v_self->end, __pyx_v_i); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = NULL;
      __pyx_t_6 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_6 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_v_st, __pyx_t_10};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1860, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_seconds, __pyx_t_7) < 0) __PYX_ERR(0, 1860, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1859
 *         for i, st in enumerate(self.start):
 *             if st.hour == dt.hour and st.minute == dt.minute:
 *                 return dt + timedelta(             # <<<<<<<<<<<<<<
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])
 *                 )
 */
      __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Add(((PyObject *)__pyx_v_dt), __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1859, __pyx_L1_error)
      __pyx_r = ((PyDateTime_DateTime *)__pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1858
 *         """
 *         for i, st in enumerate(self.start):
 *             if st.hour == dt.hour and st.minute == dt.minute:             # <<<<<<<<<<<<<<
 *                 return dt + timedelta(
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1857
 *             Corresponding closing time.
 *         """
 *         for i, st in enumerate(self.start):             # <<<<<<<<<<<<<<
 *             if st.hour == dt.hour and st.minute == dt.minute:
 *                 return dt + timedelta(
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1862
 *                     seconds=self._get_business_hours_by_sec(st, self.end[i])
 *                 )
 *         assert False             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    if (unlikely(!0)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 1862, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 1862, __pyx_L1_error)
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":1843
 *         return int((until - dtstart).total_seconds())
 * 
 *     def _get_closing_time(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Get the closing time of a business hour interval by its opening time.
 */

  /* function exit code */
  __pyx_r = ((PyDateTime_DateTime *)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._get_closing_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_st);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1864
 *         assert False
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def next_bday(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday, "\n        Used for moving to next business day.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday = {"next_bday", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("next_bday (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("next_bday", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "next_bday", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self) {
  long __pyx_v_nb_offset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("next_bday", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1869
 *         Used for moving to next business day.
 *         """
 *         if self.n >= 0:             # <<<<<<<<<<<<<<
 *             nb_offset = 1
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n >= 0);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1870
 *         """
 *         if self.n >= 0:
 *             nb_offset = 1             # <<<<<<<<<<<<<<
 *         else:
 *             nb_offset = -1
 */
    __pyx_v_nb_offset = 1;

    /* "pandas/_libs/tslibs/offsets.pyx":1869
 *         Used for moving to next business day.
 *         """
 *         if self.n >= 0:             # <<<<<<<<<<<<<<
 *             nb_offset = 1
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1872
 *             nb_offset = 1
 *         else:
 *             nb_offset = -1             # <<<<<<<<<<<<<<
 *         if self._prefix.startswith("C"):
 *             # CustomBusinessHour
 */
  /*else*/ {
    __pyx_v_nb_offset = -1L;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1873
 *         else:
 *             nb_offset = -1
 *         if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *             # CustomBusinessHour
 *             return CustomBusinessDay(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_startswith); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_C};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1873, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":1875
 *         if self._prefix.startswith("C"):
 *             # CustomBusinessHour
 *             return CustomBusinessDay(             # <<<<<<<<<<<<<<
 *                 n=nb_offset,
 *                 weekmask=self.weekmask,
 */
    __Pyx_XDECREF(__pyx_r);

    /* "pandas/_libs/tslibs/offsets.pyx":1876
 *             # CustomBusinessHour
 *             return CustomBusinessDay(
 *                 n=nb_offset,             # <<<<<<<<<<<<<<
 *                 weekmask=self.weekmask,
 *                 holidays=self.holidays,
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyInt_From_long(__pyx_v_nb_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1876, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_n, __pyx_t_4) < 0) __PYX_ERR(0, 1876, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1877
 *             return CustomBusinessDay(
 *                 n=nb_offset,
 *                 weekmask=self.weekmask,             # <<<<<<<<<<<<<<
 *                 holidays=self.holidays,
 *                 calendar=self.calendar,
 */
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_weekmask, __pyx_v_self->__pyx_base.weekmask) < 0) __PYX_ERR(0, 1876, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1878
 *                 n=nb_offset,
 *                 weekmask=self.weekmask,
 *                 holidays=self.holidays,             # <<<<<<<<<<<<<<
 *                 calendar=self.calendar,
 *             )
 */
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_holidays, __pyx_v_self->__pyx_base.holidays) < 0) __PYX_ERR(0, 1876, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1879
 *                 weekmask=self.weekmask,
 *                 holidays=self.holidays,
 *                 calendar=self.calendar,             # <<<<<<<<<<<<<<
 *             )
 *         else:
 */
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_calendar, __pyx_v_self->__pyx_base.calendar) < 0) __PYX_ERR(0, 1876, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":1875
 *         if self._prefix.startswith("C"):
 *             # CustomBusinessHour
 *             return CustomBusinessDay(             # <<<<<<<<<<<<<<
 *                 n=nb_offset,
 *                 weekmask=self.weekmask,
 */
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1875, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1873
 *         else:
 *             nb_offset = -1
 *         if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *             # CustomBusinessHour
 *             return CustomBusinessDay(
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1882
 *             )
 *         else:
 *             return BusinessDay(n=nb_offset)             # <<<<<<<<<<<<<<
 * 
 *     def _next_opening_time(self, other, sign=1):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v_nb_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_n, __pyx_t_2) < 0) __PYX_ERR(0, 1882, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1882, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1864
 *         assert False
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def next_bday(self):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.next_bday", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1884
 *             return BusinessDay(n=nb_offset)
 * 
 *     def _next_opening_time(self, other, sign=1):             # <<<<<<<<<<<<<<
 *         """
 *         If self.n and sign have the same sign, return the earliest opening time
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time, "\n        If self.n and sign have the same sign, return the earliest opening time\n        later than or equal to current time.\n        Otherwise the latest opening time earlier than or equal to current\n        time.\n\n        Opening time always locates on BusinessDay.\n        However, closing time may not if business hour extends over midnight.\n\n        Parameters\n        ----------\n        other : datetime\n            Current time.\n        sign : int, default 1.\n            Either 1 or -1. Going forward in time if it has the same sign as\n            self.n. Going backward in time otherwise.\n\n        Returns\n        -------\n        result : datetime\n            Next opening time.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time = {"_next_opening_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  PyObject *__pyx_v_sign = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_next_opening_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,&__pyx_n_s_sign,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_1));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1884, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_sign);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1884, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_next_opening_time") < 0)) __PYX_ERR(0, 1884, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_other = values[0];
    __pyx_v_sign = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_next_opening_time", 0, 1, 2, __pyx_nargs); __PYX_ERR(0, 1884, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._next_opening_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_other, __pyx_v_sign);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyObject *__pyx_v_other, PyObject *__pyx_v_sign) {
  PyObject *__pyx_v_earliest_start = NULL;
  PyObject *__pyx_v_latest_start = NULL;
  PyObject *__pyx_v_is_same_sign = NULL;
  PyObject *__pyx_v_hour = NULL;
  PyObject *__pyx_v_minute = NULL;
  PyObject *__pyx_v_st = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_next_opening_time", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":1907
 *             Next opening time.
 *         """
 *         earliest_start = self.start[0]             # <<<<<<<<<<<<<<
 *         latest_start = self.start[-1]
 * 
 */
  if (unlikely(__pyx_v_self->start == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1907, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_self->start, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_earliest_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1908
 *         """
 *         earliest_start = self.start[0]
 *         latest_start = self.start[-1]             # <<<<<<<<<<<<<<
 * 
 *         if self.n == 0:
 */
  if (unlikely(__pyx_v_self->start == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 1908, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_self->start, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_latest_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1910
 *         latest_start = self.start[-1]
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             is_same_sign = sign > 0
 *         else:
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n == 0);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":1911
 * 
 *         if self.n == 0:
 *             is_same_sign = sign > 0             # <<<<<<<<<<<<<<
 *         else:
 *             is_same_sign = self.n * sign >= 0
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_sign, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1911, __pyx_L1_error)
    __pyx_v_is_same_sign = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1910
 *         latest_start = self.start[-1]
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             is_same_sign = sign > 0
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1913
 *             is_same_sign = sign > 0
 *         else:
 *             is_same_sign = self.n * sign >= 0             # <<<<<<<<<<<<<<
 * 
 *         if not self.next_bday.is_on_offset(other):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_v_sign); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1913, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_is_same_sign = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":1915
 *             is_same_sign = self.n * sign >= 0
 * 
 *         if not self.next_bday.is_on_offset(other):             # <<<<<<<<<<<<<<
 *             # today is not business day
 *             other = other + sign * self.next_bday
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_bday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_other};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_2);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1917
 *         if not self.next_bday.is_on_offset(other):
 *             # today is not business day
 *             other = other + sign * self.next_bday             # <<<<<<<<<<<<<<
 *             if is_same_sign:
 *                 hour, minute = earliest_start.hour, earliest_start.minute
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_bday); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyNumber_Multiply(__pyx_v_sign, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(__pyx_v_other, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":1918
 *             # today is not business day
 *             other = other + sign * self.next_bday
 *             if is_same_sign:             # <<<<<<<<<<<<<<
 *                 hour, minute = earliest_start.hour, earliest_start.minute
 *             else:
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_is_same_sign); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1918, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1919
 *             other = other + sign * self.next_bday
 *             if is_same_sign:
 *                 hour, minute = earliest_start.hour, earliest_start.minute             # <<<<<<<<<<<<<<
 *             else:
 *                 hour, minute = latest_start.hour, latest_start.minute
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_earliest_start, __pyx_n_s_hour); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1919, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_earliest_start, __pyx_n_s_minute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1919, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_hour = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_minute = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1918
 *             # today is not business day
 *             other = other + sign * self.next_bday
 *             if is_same_sign:             # <<<<<<<<<<<<<<
 *                 hour, minute = earliest_start.hour, earliest_start.minute
 *             else:
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1921
 *                 hour, minute = earliest_start.hour, earliest_start.minute
 *             else:
 *                 hour, minute = latest_start.hour, latest_start.minute             # <<<<<<<<<<<<<<
 *         else:
 *             if is_same_sign:
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_latest_start, __pyx_n_s_hour); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1921, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_latest_start, __pyx_n_s_minute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1921, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_hour = __pyx_t_4;
      __pyx_t_4 = 0;
      __pyx_v_minute = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "pandas/_libs/tslibs/offsets.pyx":1915
 *             is_same_sign = self.n * sign >= 0
 * 
 *         if not self.next_bday.is_on_offset(other):             # <<<<<<<<<<<<<<
 *             # today is not business day
 *             other = other + sign * self.next_bday
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1923
 *                 hour, minute = latest_start.hour, latest_start.minute
 *         else:
 *             if is_same_sign:             # <<<<<<<<<<<<<<
 *                 if latest_start < other.time():
 *                     # current time is after latest starting time in today
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_is_same_sign); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1923, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1924
 *         else:
 *             if is_same_sign:
 *                 if latest_start < other.time():             # <<<<<<<<<<<<<<
 *                     # current time is after latest starting time in today
 *                     other = other + sign * self.next_bday
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1924, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_latest_start, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1924, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1924, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "pandas/_libs/tslibs/offsets.pyx":1926
 *                 if latest_start < other.time():
 *                     # current time is after latest starting time in today
 *                     other = other + sign * self.next_bday             # <<<<<<<<<<<<<<
 *                     hour, minute = earliest_start.hour, earliest_start.minute
 *                 else:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_bday); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1926, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyNumber_Multiply(__pyx_v_sign, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1926, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1926, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1927
 *                     # current time is after latest starting time in today
 *                     other = other + sign * self.next_bday
 *                     hour, minute = earliest_start.hour, earliest_start.minute             # <<<<<<<<<<<<<<
 *                 else:
 *                     # find earliest starting time no earlier than current time
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_earliest_start, __pyx_n_s_hour); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1927, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_earliest_start, __pyx_n_s_minute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1927, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_hour = __pyx_t_4;
        __pyx_t_4 = 0;
        __pyx_v_minute = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1924
 *         else:
 *             if is_same_sign:
 *                 if latest_start < other.time():             # <<<<<<<<<<<<<<
 *                     # current time is after latest starting time in today
 *                     other = other + sign * self.next_bday
 */
        goto __pyx_L7;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1930
 *                 else:
 *                     # find earliest starting time no earlier than current time
 *                     for st in self.start:             # <<<<<<<<<<<<<<
 *                         if other.time() <= st:
 *                             hour, minute = st.hour, st.minute
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->start == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 1930, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_self->start; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1930, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 1930, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1930, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_st, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "pandas/_libs/tslibs/offsets.pyx":1931
 *                     # find earliest starting time no earlier than current time
 *                     for st in self.start:
 *                         if other.time() <= st:             # <<<<<<<<<<<<<<
 *                             hour, minute = st.hour, st.minute
 *                             break
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_8 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1931, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_v_st, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1931, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_6) {

            /* "pandas/_libs/tslibs/offsets.pyx":1932
 *                     for st in self.start:
 *                         if other.time() <= st:
 *                             hour, minute = st.hour, st.minute             # <<<<<<<<<<<<<<
 *                             break
 *             else:
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_hour); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1932, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_minute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1932, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_v_hour = __pyx_t_3;
            __pyx_t_3 = 0;
            __pyx_v_minute = __pyx_t_4;
            __pyx_t_4 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":1933
 *                         if other.time() <= st:
 *                             hour, minute = st.hour, st.minute
 *                             break             # <<<<<<<<<<<<<<
 *             else:
 *                 if other.time() < earliest_start:
 */
            goto __pyx_L9_break;

            /* "pandas/_libs/tslibs/offsets.pyx":1931
 *                     # find earliest starting time no earlier than current time
 *                     for st in self.start:
 *                         if other.time() <= st:             # <<<<<<<<<<<<<<
 *                             hour, minute = st.hour, st.minute
 *                             break
 */
          }

          /* "pandas/_libs/tslibs/offsets.pyx":1930
 *                 else:
 *                     # find earliest starting time no earlier than current time
 *                     for st in self.start:             # <<<<<<<<<<<<<<
 *                         if other.time() <= st:
 *                             hour, minute = st.hour, st.minute
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L11_for_end;
        __pyx_L9_break:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L11_for_end;
        __pyx_L11_for_end:;
      }
      __pyx_L7:;

      /* "pandas/_libs/tslibs/offsets.pyx":1923
 *                 hour, minute = latest_start.hour, latest_start.minute
 *         else:
 *             if is_same_sign:             # <<<<<<<<<<<<<<
 *                 if latest_start < other.time():
 *                     # current time is after latest starting time in today
 */
      goto __pyx_L6;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1935
 *                             break
 *             else:
 *                 if other.time() < earliest_start:             # <<<<<<<<<<<<<<
 *                     # current time is before earliest starting time in today
 *                     other = other + sign * self.next_bday
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1935, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_v_earliest_start, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1935, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "pandas/_libs/tslibs/offsets.pyx":1937
 *                 if other.time() < earliest_start:
 *                     # current time is before earliest starting time in today
 *                     other = other + sign * self.next_bday             # <<<<<<<<<<<<<<
 *                     hour, minute = latest_start.hour, latest_start.minute
 *                 else:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_bday); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1937, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyNumber_Multiply(__pyx_v_sign, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1937, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1937, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1938
 *                     # current time is before earliest starting time in today
 *                     other = other + sign * self.next_bday
 *                     hour, minute = latest_start.hour, latest_start.minute             # <<<<<<<<<<<<<<
 *                 else:
 *                     # find latest starting time no later than current time
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_latest_start, __pyx_n_s_hour); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1938, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_latest_start, __pyx_n_s_minute); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1938, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_hour = __pyx_t_4;
        __pyx_t_4 = 0;
        __pyx_v_minute = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":1935
 *                             break
 *             else:
 *                 if other.time() < earliest_start:             # <<<<<<<<<<<<<<
 *                     # current time is before earliest starting time in today
 *                     other = other + sign * self.next_bday
 */
        goto __pyx_L12;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":1941
 *                 else:
 *                     # find latest starting time no later than current time
 *                     for st in reversed(self.start):             # <<<<<<<<<<<<<<
 *                         if other.time() >= st:
 *                             hour, minute = st.hour, st.minute
 */
      /*else*/ {
        if (unlikely(__pyx_v_self->start == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(0, 1941, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_self->start; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 1941, __pyx_L1_error)
        #endif
        --__pyx_t_7;
        for (;;) {
          if (__pyx_t_7 < 0) break;
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1941, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7--; if (unlikely((0 < 0))) __PYX_ERR(0, 1941, __pyx_L1_error)
          #else
          __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7--; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1941, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_st, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "pandas/_libs/tslibs/offsets.pyx":1942
 *                     # find latest starting time no later than current time
 *                     for st in reversed(self.start):
 *                         if other.time() >= st:             # <<<<<<<<<<<<<<
 *                             hour, minute = st.hour, st.minute
 *                             break
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1942, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_8 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1942, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_v_st, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1942, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 1942, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_6) {

            /* "pandas/_libs/tslibs/offsets.pyx":1943
 *                     for st in reversed(self.start):
 *                         if other.time() >= st:
 *                             hour, minute = st.hour, st.minute             # <<<<<<<<<<<<<<
 *                             break
 * 
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_hour); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1943, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_minute); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1943, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_v_hour = __pyx_t_3;
            __pyx_t_3 = 0;
            __pyx_v_minute = __pyx_t_4;
            __pyx_t_4 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":1944
 *                         if other.time() >= st:
 *                             hour, minute = st.hour, st.minute
 *                             break             # <<<<<<<<<<<<<<
 * 
 *         return datetime(other.year, other.month, other.day, hour, minute)
 */
            goto __pyx_L14_break;

            /* "pandas/_libs/tslibs/offsets.pyx":1942
 *                     # find latest starting time no later than current time
 *                     for st in reversed(self.start):
 *                         if other.time() >= st:             # <<<<<<<<<<<<<<
 *                             hour, minute = st.hour, st.minute
 *                             break
 */
          }

          /* "pandas/_libs/tslibs/offsets.pyx":1941
 *                 else:
 *                     # find latest starting time no later than current time
 *                     for st in reversed(self.start):             # <<<<<<<<<<<<<<
 *                         if other.time() >= st:
 *                             hour, minute = st.hour, st.minute
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L16_for_end;
        __pyx_L14_break:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L16_for_end;
        __pyx_L16_for_end:;
      }
      __pyx_L12:;
    }
    __pyx_L6:;
  }
  __pyx_L4:;

  /* "pandas/_libs/tslibs/offsets.pyx":1946
 *                             break
 * 
 *         return datetime(other.year, other.month, other.day, hour, minute)             # <<<<<<<<<<<<<<
 * 
 *     def _prev_opening_time(self, other: datetime) -> datetime:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_month); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_day); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (unlikely(!__pyx_v_hour)) { __Pyx_RaiseUnboundLocalError("hour"); __PYX_ERR(0, 1946, __pyx_L1_error) }
  if (unlikely(!__pyx_v_minute)) { __Pyx_RaiseUnboundLocalError("minute"); __PYX_ERR(0, 1946, __pyx_L1_error) }
  __pyx_t_8 = PyTuple_New(5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_4)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_3)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_hour);
  __Pyx_GIVEREF(__pyx_v_hour);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 3, __pyx_v_hour)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_minute);
  __Pyx_GIVEREF(__pyx_v_minute);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 4, __pyx_v_minute)) __PYX_ERR(0, 1946, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1884
 *             return BusinessDay(n=nb_offset)
 * 
 *     def _next_opening_time(self, other, sign=1):             # <<<<<<<<<<<<<<
 *         """
 *         If self.n and sign have the same sign, return the earliest opening time
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._next_opening_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_earliest_start);
  __Pyx_XDECREF(__pyx_v_latest_start);
  __Pyx_XDECREF(__pyx_v_is_same_sign);
  __Pyx_XDECREF(__pyx_v_hour);
  __Pyx_XDECREF(__pyx_v_minute);
  __Pyx_XDECREF(__pyx_v_st);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1948
 *         return datetime(other.year, other.month, other.day, hour, minute)
 * 
 *     def _prev_opening_time(self, other: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         If n is positive, return the latest opening time earlier than or equal
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time, "\n        If n is positive, return the latest opening time earlier than or equal\n        to current time.\n        Otherwise the earliest opening time later than or equal to current\n        time.\n\n        Parameters\n        ----------\n        other : datetime\n            Current time.\n\n        Returns\n        -------\n        result : datetime\n            Previous opening time.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time = {"_prev_opening_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_prev_opening_time (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1948, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_prev_opening_time") < 0)) __PYX_ERR(0, 1948, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_prev_opening_time", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1948, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._prev_opening_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 1948, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_prev_opening_time", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1965
 *             Previous opening time.
 *         """
 *         return self._next_opening_time(other, sign=-1)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_other);
  __Pyx_GIVEREF((PyObject *)__pyx_v_other);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_other))) __PYX_ERR(0, 1965, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_sign, __pyx_int_neg_1) < 0) __PYX_ERR(0, 1965, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1965, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1948
 *         return datetime(other.year, other.month, other.day, hour, minute)
 * 
 *     def _prev_opening_time(self, other: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         If n is positive, return the latest opening time earlier than or equal
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._prev_opening_time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1967
 *         return self._next_opening_time(other, sign=-1)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollback(self, dt: datetime) -> datetime:
 *         """
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback, "\n        Roll provided date backward to next offset only if not on offset.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback = {"rollback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rollback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1967, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "rollback") < 0)) __PYX_ERR(0, 1967, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rollback", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1967, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.rollback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 1968, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rollback", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":1972
 *         Roll provided date backward to next offset only if not on offset.
 *         """
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             if self.n >= 0:
 *                 dt = self._prev_opening_time(dt)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1972, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1973
 *         """
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:             # <<<<<<<<<<<<<<
 *                 dt = self._prev_opening_time(dt)
 *             else:
 */
    __pyx_t_6 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n >= 0);
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1974
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:
 *                 dt = self._prev_opening_time(dt)             # <<<<<<<<<<<<<<
 *             else:
 *                 dt = self._next_opening_time(dt)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prev_opening_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1974, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1974, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1974, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_dt, ((PyDateTime_DateTime *)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":1973
 *         """
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:             # <<<<<<<<<<<<<<
 *                 dt = self._prev_opening_time(dt)
 *             else:
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1976
 *                 dt = self._prev_opening_time(dt)
 *             else:
 *                 dt = self._next_opening_time(dt)             # <<<<<<<<<<<<<<
 *             return self._get_closing_time(dt)
 *         return dt
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1976, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1976, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1976, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_dt, ((PyDateTime_DateTime *)__pyx_t_1));
      __pyx_t_1 = 0;
    }
    __pyx_L4:;

    /* "pandas/_libs/tslibs/offsets.pyx":1977
 *             else:
 *                 dt = self._next_opening_time(dt)
 *             return self._get_closing_time(dt)             # <<<<<<<<<<<<<<
 *         return dt
 * 
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_closing_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1977, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1977, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":1972
 *         Roll provided date backward to next offset only if not on offset.
 *         """
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             if self.n >= 0:
 *                 dt = self._prev_opening_time(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1978
 *                 dt = self._next_opening_time(dt)
 *             return self._get_closing_time(dt)
 *         return dt             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_dt);
  __pyx_r = __pyx_v_dt;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1967
 *         return self._next_opening_time(other, sign=-1)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollback(self, dt: datetime) -> datetime:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.rollback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_dt);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1980
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollforward(self, dt: datetime) -> datetime:
 *         """
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward, "\n        Roll provided date forward to next offset only if not on offset.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward = {"rollforward", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rollforward (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1980, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "rollforward") < 0)) __PYX_ERR(0, 1980, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("rollforward", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1980, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.rollforward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 1981, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rollforward", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":1985
 *         Roll provided date forward to next offset only if not on offset.
 *         """
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             if self.n >= 0:
 *                 return self._next_opening_time(dt)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":1986
 *         """
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:             # <<<<<<<<<<<<<<
 *                 return self._next_opening_time(dt)
 *             else:
 */
    __pyx_t_6 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n >= 0);
    if (__pyx_t_6) {

      /* "pandas/_libs/tslibs/offsets.pyx":1987
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:
 *                 return self._next_opening_time(dt)             # <<<<<<<<<<<<<<
 *             else:
 *                 return self._prev_opening_time(dt)
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1987, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1987, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1987, __pyx_L1_error)
      __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":1986
 *         """
 *         if not self.is_on_offset(dt):
 *             if self.n >= 0:             # <<<<<<<<<<<<<<
 *                 return self._next_opening_time(dt)
 *             else:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1989
 *                 return self._next_opening_time(dt)
 *             else:
 *                 return self._prev_opening_time(dt)             # <<<<<<<<<<<<<<
 *         return dt
 * 
 */
    /*else*/ {
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prev_opening_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1989, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1989, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 1989, __pyx_L1_error)
      __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":1985
 *         Roll provided date forward to next offset only if not on offset.
 *         """
 *         if not self.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             if self.n >= 0:
 *                 return self._next_opening_time(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":1990
 *             else:
 *                 return self._prev_opening_time(dt)
 *         return dt             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_dt);
  __pyx_r = __pyx_v_dt;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1980
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollforward(self, dt: datetime) -> datetime:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.rollforward", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1992, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 1992, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1992, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 1993, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_20_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_2generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "pandas/_libs/tslibs/offsets.pyx":2023
 *         # get total business hours by sec in one business day
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 2023, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_2generator5, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_apply_locals_genexpr, __pyx_n_s_pandas__libs_tslibs_offsets); if (unlikely(!gen)) __PYX_ERR(0, 2023, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._apply.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_2generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2023, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2024
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(0, 2024, __pyx_L1_error) }
  if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_genexpr_arg_0)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_genexpr_arg_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2024, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2024, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 2024, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2024, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2024, __pyx_L1_error)
          #endif
          if (__pyx_t_2 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely((0 < 0))) __PYX_ERR(0, 2024, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2024, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 2024, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 2024, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2024, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(0, 2024, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 2024, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_st);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_st, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_en);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_en, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2023
 *         # get total business hours by sec in one business day
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(0, 2023, __pyx_L1_error) }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_self), __pyx_n_s_get_business_hours_by_sec); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2023, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_st, __pyx_cur_scope->__pyx_v_en};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_9, 2+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L8_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 2023, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":2024
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "pandas/_libs/tslibs/offsets.pyx":2023
 *         # get total business hours by sec in one business day
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_Generator_Replace_StopIteration(0);
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_20_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *__pyx_cur_scope;
  PyObject *__pyx_v_nanosecond = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_businesshours = NULL;
  PyObject *__pyx_v_bd = NULL;
  PyObject *__pyx_v_r = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *__pyx_v_skip_bd = NULL;
  PyObject *__pyx_v_prev_open = NULL;
  PyObject *__pyx_v_remain = NULL;
  PyObject *__pyx_v_bhour_remain = NULL;
  PyObject *__pyx_v_bhour = NULL;
  PyObject *__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_2generator5 = 0;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 0);
  __pyx_cur_scope = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1992, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF((PyObject *)__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":1995
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 *         nanosecond = getattr(other, "nanosecond", 0)             # <<<<<<<<<<<<<<
 *         # reset timezone and nanosecond
 *         # other may be a Timestamp, thus not use replace
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_other), __pyx_n_u_nanosecond, __pyx_int_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1995, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_nanosecond = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1999
 *         # other may be a Timestamp, thus not use replace
 *         other = datetime(
 *             other.year,             # <<<<<<<<<<<<<<
 *             other.month,
 *             other.day,
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1999, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pandas/_libs/tslibs/offsets.pyx":2000
 *         other = datetime(
 *             other.year,
 *             other.month,             # <<<<<<<<<<<<<<
 *             other.day,
 *             other.hour,
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2000, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/tslibs/offsets.pyx":2001
 *             other.year,
 *             other.month,
 *             other.day,             # <<<<<<<<<<<<<<
 *             other.hour,
 *             other.minute,
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2001, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/tslibs/offsets.pyx":2002
 *             other.month,
 *             other.day,
 *             other.hour,             # <<<<<<<<<<<<<<
 *             other.minute,
 *             other.second,
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2002, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pandas/_libs/tslibs/offsets.pyx":2003
 *             other.day,
 *             other.hour,
 *             other.minute,             # <<<<<<<<<<<<<<
 *             other.second,
 *             other.microsecond,
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2003, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "pandas/_libs/tslibs/offsets.pyx":2004
 *             other.hour,
 *             other.minute,
 *             other.second,             # <<<<<<<<<<<<<<
 *             other.microsecond,
 *         )
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_6second_second(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2004, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "pandas/_libs/tslibs/offsets.pyx":2005
 *             other.minute,
 *             other.second,
 *             other.microsecond,             # <<<<<<<<<<<<<<
 *         )
 *         n = self.n
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2005, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "pandas/_libs/tslibs/offsets.pyx":1998
 *         # reset timezone and nanosecond
 *         # other may be a Timestamp, thus not use replace
 *         other = datetime(             # <<<<<<<<<<<<<<
 *             other.year,
 *             other.month,
 */
  __pyx_t_9 = PyTuple_New(7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_3)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_4)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_5)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_6)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 5, __pyx_t_7)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 6, __pyx_t_8)) __PYX_ERR(0, 1998, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
  __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2007
 *             other.microsecond,
 *         )
 *         n = self.n             # <<<<<<<<<<<<<<
 * 
 *         # adjust other to reduce number of cases to handle
 */
  __pyx_t_8 = __Pyx_PyInt_From_npy_int64(__pyx_cur_scope->__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_v_n = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2010
 * 
 *         # adjust other to reduce number of cases to handle
 *         if n >= 0:             # <<<<<<<<<<<<<<
 *             if other.time() in self.end or not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)
 */
  __pyx_t_8 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2010, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__pyx_t_10) {

    /* "pandas/_libs/tslibs/offsets.pyx":2011
 *         # adjust other to reduce number of cases to handle
 *         if n >= 0:
 *             if other.time() in self.end or not self._is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 other = self._next_opening_time(other)
 *         else:
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_other), __pyx_n_s_time); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 0+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_t_8, __pyx_cur_scope->__pyx_v_self->end, Py_EQ)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (!__pyx_t_11) {
    } else {
      __pyx_t_10 = __pyx_t_11;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_is_on_offset_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_other)};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2011, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 2011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_12 = (!__pyx_t_11);
    __pyx_t_10 = __pyx_t_12;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_10) {

      /* "pandas/_libs/tslibs/offsets.pyx":2012
 *         if n >= 0:
 *             if other.time() in self.end or not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)             # <<<<<<<<<<<<<<
 *         else:
 *             if other.time() in self.start:
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2012, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_other)};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2012, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2012, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2011
 *         # adjust other to reduce number of cases to handle
 *         if n >= 0:
 *             if other.time() in self.end or not self._is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 other = self._next_opening_time(other)
 *         else:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2010
 * 
 *         # adjust other to reduce number of cases to handle
 *         if n >= 0:             # <<<<<<<<<<<<<<
 *             if other.time() in self.end or not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2014
 *                 other = self._next_opening_time(other)
 *         else:
 *             if other.time() in self.start:             # <<<<<<<<<<<<<<
 *                 # adjustment to move to previous business day
 *                 other = other - timedelta(seconds=1)
 */
  /*else*/ {
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_other), __pyx_n_s_time); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2014, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 0+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2014, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_t_8, __pyx_cur_scope->__pyx_v_self->start, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2014, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_10) {

      /* "pandas/_libs/tslibs/offsets.pyx":2016
 *             if other.time() in self.start:
 *                 # adjustment to move to previous business day
 *                 other = other - timedelta(seconds=1)             # <<<<<<<<<<<<<<
 *             if not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)
 */
      __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_seconds, __pyx_int_1) < 0) __PYX_ERR(0, 2016, __pyx_L1_error)
      __pyx_t_9 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Subtract(((PyObject *)__pyx_v_other), __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2016, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2016, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2014
 *                 other = self._next_opening_time(other)
 *         else:
 *             if other.time() in self.start:             # <<<<<<<<<<<<<<
 *                 # adjustment to move to previous business day
 *                 other = other - timedelta(seconds=1)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2017
 *                 # adjustment to move to previous business day
 *                 other = other - timedelta(seconds=1)
 *             if not self._is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 other = self._next_opening_time(other)
 *                 other = self._get_closing_time(other)
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_is_on_offset_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2017, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_other)};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2017, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2017, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_12 = (!__pyx_t_10);
    if (__pyx_t_12) {

      /* "pandas/_libs/tslibs/offsets.pyx":2018
 *                 other = other - timedelta(seconds=1)
 *             if not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)             # <<<<<<<<<<<<<<
 *                 other = self._get_closing_time(other)
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2018, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_other)};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2018, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2018, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2019
 *             if not self._is_on_offset(other):
 *                 other = self._next_opening_time(other)
 *                 other = self._get_closing_time(other)             # <<<<<<<<<<<<<<
 * 
 *         # get total business hours by sec in one business day
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_closing_time); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2019, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, ((PyObject *)__pyx_v_other)};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2019, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2019, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2017
 *                 # adjustment to move to previous business day
 *                 other = other - timedelta(seconds=1)
 *             if not self._is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 other = self._next_opening_time(other)
 *                 other = self._get_closing_time(other)
 */
    }
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":2024
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)
 *             for st, en in zip(self.start, self.end)             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self->start);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self->start);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_cur_scope->__pyx_v_self->start)) __PYX_ERR(0, 2024, __pyx_L1_error);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_self->end);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_self->end);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_cur_scope->__pyx_v_self->end)) __PYX_ERR(0, 2024, __pyx_L1_error);
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2023
 *         # get total business hours by sec in one business day
 *         businesshours = sum(
 *             self._get_business_hours_by_sec(st, en)             # <<<<<<<<<<<<<<
 *             for st, en in zip(self.start, self.end)
 *         )
 */
  __pyx_t_8 = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_genexpr(((PyObject*)__pyx_cur_scope), __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2022
 * 
 *         # get total business hours by sec in one business day
 *         businesshours = sum(             # <<<<<<<<<<<<<<
 *             self._get_business_hours_by_sec(st, en)
 *             for st, en in zip(self.start, self.end)
 */
  __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_v_businesshours = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2027
 *         )
 * 
 *         bd, r = divmod(abs(n * 60), businesshours // 60)             # <<<<<<<<<<<<<<
 *         if n < 0:
 *             bd, r = -bd, -r
 */
  __pyx_t_9 = __Pyx_PyInt_MultiplyObjC(__pyx_v_n, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyNumber_Absolute(__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_businesshours, __pyx_int_60, 60, 0, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = PyNumber_Divmod(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
    PyObject* sequence = __pyx_t_7;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 2027, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_t_8);
    #else
    __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    #endif
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_9 = __pyx_t_13(__pyx_t_6); if (unlikely(!__pyx_t_9)) goto __pyx_L9_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_9);
    index = 1; __pyx_t_8 = __pyx_t_13(__pyx_t_6); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_8);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_6), 2) < 0) __PYX_ERR(0, 2027, __pyx_L1_error)
    __pyx_t_13 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_unpacking_done;
    __pyx_L9_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_13 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 2027, __pyx_L1_error)
    __pyx_L10_unpacking_done:;
  }
  __pyx_v_bd = __pyx_t_9;
  __pyx_t_9 = 0;
  __pyx_v_r = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2028
 * 
 *         bd, r = divmod(abs(n * 60), businesshours // 60)
 *         if n < 0:             # <<<<<<<<<<<<<<
 *             bd, r = -bd, -r
 * 
 */
  __pyx_t_7 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2028, __pyx_L1_error)
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_12) {

    /* "pandas/_libs/tslibs/offsets.pyx":2029
 *         bd, r = divmod(abs(n * 60), businesshours // 60)
 *         if n < 0:
 *             bd, r = -bd, -r             # <<<<<<<<<<<<<<
 * 
 *         # adjust by business days first
 */
    __pyx_t_7 = PyNumber_Negative(__pyx_v_bd); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyNumber_Negative(__pyx_v_r); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2029, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF_SET(__pyx_v_bd, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_DECREF_SET(__pyx_v_r, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2028
 * 
 *         bd, r = divmod(abs(n * 60), businesshours // 60)
 *         if n < 0:             # <<<<<<<<<<<<<<
 *             bd, r = -bd, -r
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2032
 * 
 *         # adjust by business days first
 *         if bd != 0:             # <<<<<<<<<<<<<<
 *             if self._prefix.startswith("C"):
 *                 # GH#30593 this is a Custom offset
 */
  __pyx_t_12 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_bd, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2032, __pyx_L1_error)
  if (__pyx_t_12) {

    /* "pandas/_libs/tslibs/offsets.pyx":2033
 *         # adjust by business days first
 *         if bd != 0:
 *             if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *                 # GH#30593 this is a Custom offset
 *                 skip_bd = CustomBusinessDay(
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_startswith); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_n_u_C};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2033, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2033, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_12) {

      /* "pandas/_libs/tslibs/offsets.pyx":2036
 *                 # GH#30593 this is a Custom offset
 *                 skip_bd = CustomBusinessDay(
 *                     n=bd,             # <<<<<<<<<<<<<<
 *                     weekmask=self.weekmask,
 *                     holidays=self.holidays,
 */
      __pyx_t_8 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2036, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_n, __pyx_v_bd) < 0) __PYX_ERR(0, 2036, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":2037
 *                 skip_bd = CustomBusinessDay(
 *                     n=bd,
 *                     weekmask=self.weekmask,             # <<<<<<<<<<<<<<
 *                     holidays=self.holidays,
 *                     calendar=self.calendar,
 */
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_weekmask, __pyx_cur_scope->__pyx_v_self->__pyx_base.weekmask) < 0) __PYX_ERR(0, 2036, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":2038
 *                     n=bd,
 *                     weekmask=self.weekmask,
 *                     holidays=self.holidays,             # <<<<<<<<<<<<<<
 *                     calendar=self.calendar,
 *                 )
 */
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_holidays, __pyx_cur_scope->__pyx_v_self->__pyx_base.holidays) < 0) __PYX_ERR(0, 2036, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":2039
 *                     weekmask=self.weekmask,
 *                     holidays=self.holidays,
 *                     calendar=self.calendar,             # <<<<<<<<<<<<<<
 *                 )
 *             else:
 */
      if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_calendar, __pyx_cur_scope->__pyx_v_self->__pyx_base.calendar) < 0) __PYX_ERR(0, 2036, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":2035
 *             if self._prefix.startswith("C"):
 *                 # GH#30593 this is a Custom offset
 *                 skip_bd = CustomBusinessDay(             # <<<<<<<<<<<<<<
 *                     n=bd,
 *                     weekmask=self.weekmask,
 */
      __pyx_t_9 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay), __pyx_empty_tuple, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_skip_bd = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_t_9);
      __pyx_t_9 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2033
 *         # adjust by business days first
 *         if bd != 0:
 *             if self._prefix.startswith("C"):             # <<<<<<<<<<<<<<
 *                 # GH#30593 this is a Custom offset
 *                 skip_bd = CustomBusinessDay(
 */
      goto __pyx_L13;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2042
 *                 )
 *             else:
 *                 skip_bd = BusinessDay(n=bd)             # <<<<<<<<<<<<<<
 *             # midnight business hour may not on BusinessDay
 *             if not self.next_bday.is_on_offset(other):
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2042, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_n, __pyx_v_bd) < 0) __PYX_ERR(0, 2042, __pyx_L1_error)
      __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay), __pyx_empty_tuple, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2042, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_skip_bd = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_t_8);
      __pyx_t_8 = 0;
    }
    __pyx_L13:;

    /* "pandas/_libs/tslibs/offsets.pyx":2044
 *                 skip_bd = BusinessDay(n=bd)
 *             # midnight business hour may not on BusinessDay
 *             if not self.next_bday.is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 prev_open = self._prev_opening_time(other)
 *                 remain = other - prev_open
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_bday); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = NULL;
    __pyx_t_2 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_2 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_v_other)};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2044, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_10 = (!__pyx_t_12);
    if (__pyx_t_10) {

      /* "pandas/_libs/tslibs/offsets.pyx":2045
 *             # midnight business hour may not on BusinessDay
 *             if not self.next_bday.is_on_offset(other):
 *                 prev_open = self._prev_opening_time(other)             # <<<<<<<<<<<<<<
 *                 remain = other - prev_open
 *                 other = prev_open + skip_bd + remain
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_prev_opening_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2045, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_v_other)};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2045, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_v_prev_open = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2046
 *             if not self.next_bday.is_on_offset(other):
 *                 prev_open = self._prev_opening_time(other)
 *                 remain = other - prev_open             # <<<<<<<<<<<<<<
 *                 other = prev_open + skip_bd + remain
 *             else:
 */
      __pyx_t_8 = PyNumber_Subtract(((PyObject *)__pyx_v_other), __pyx_v_prev_open); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2046, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_v_remain = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2047
 *                 prev_open = self._prev_opening_time(other)
 *                 remain = other - prev_open
 *                 other = prev_open + skip_bd + remain             # <<<<<<<<<<<<<<
 *             else:
 *                 other = other + skip_bd
 */
      __pyx_t_8 = PyNumber_Add(__pyx_v_prev_open, ((PyObject *)__pyx_v_skip_bd)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyNumber_Add(__pyx_t_8, __pyx_v_remain); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2047, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2047, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2044
 *                 skip_bd = BusinessDay(n=bd)
 *             # midnight business hour may not on BusinessDay
 *             if not self.next_bday.is_on_offset(other):             # <<<<<<<<<<<<<<
 *                 prev_open = self._prev_opening_time(other)
 *                 remain = other - prev_open
 */
      goto __pyx_L14;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2049
 *                 other = prev_open + skip_bd + remain
 *             else:
 *                 other = other + skip_bd             # <<<<<<<<<<<<<<
 * 
 *         # remaining business hours to adjust
 */
    /*else*/ {
      __pyx_t_7 = PyNumber_Add(((PyObject *)__pyx_v_other), ((PyObject *)__pyx_v_skip_bd)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2049, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2049, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_7));
      __pyx_t_7 = 0;
    }
    __pyx_L14:;

    /* "pandas/_libs/tslibs/offsets.pyx":2032
 * 
 *         # adjust by business days first
 *         if bd != 0:             # <<<<<<<<<<<<<<
 *             if self._prefix.startswith("C"):
 *                 # GH#30593 this is a Custom offset
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2052
 * 
 *         # remaining business hours to adjust
 *         bhour_remain = timedelta(minutes=r)             # <<<<<<<<<<<<<<
 * 
 *         if n >= 0:
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_minutes, __pyx_v_r) < 0) __PYX_ERR(0, 2052, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_bhour_remain = __pyx_t_8;
  __pyx_t_8 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2054
 *         bhour_remain = timedelta(minutes=r)
 * 
 *         if n >= 0:             # <<<<<<<<<<<<<<
 *             while bhour_remain != timedelta(0):
 *                 # business hour left in this business time interval
 */
  __pyx_t_8 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2054, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__pyx_t_10) {

    /* "pandas/_libs/tslibs/offsets.pyx":2055
 * 
 *         if n >= 0:
 *             while bhour_remain != timedelta(0):             # <<<<<<<<<<<<<<
 *                 # business hour left in this business time interval
 *                 bhour = (
 */
    while (1) {
      __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2055, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_bhour_remain, __pyx_t_8, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2055, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2055, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!__pyx_t_10) break;

      /* "pandas/_libs/tslibs/offsets.pyx":2058
 *                 # business hour left in this business time interval
 *                 bhour = (
 *                     self._get_closing_time(self._prev_opening_time(other)) - other             # <<<<<<<<<<<<<<
 *                 )
 *                 if bhour_remain < bhour:
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_closing_time); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_prev_opening_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_other)};
        __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2058, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __pyx_t_6 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_9};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2058, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = PyNumber_Subtract(__pyx_t_7, ((PyObject *)__pyx_v_other)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_bhour, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2060
 *                     self._get_closing_time(self._prev_opening_time(other)) - other
 *                 )
 *                 if bhour_remain < bhour:             # <<<<<<<<<<<<<<
 *                     # finish adjusting if possible
 *                     other += bhour_remain
 */
      __pyx_t_8 = PyObject_RichCompare(__pyx_v_bhour_remain, __pyx_v_bhour, Py_LT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2060, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2060, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_10) {

        /* "pandas/_libs/tslibs/offsets.pyx":2062
 *                 if bhour_remain < bhour:
 *                     # finish adjusting if possible
 *                     other += bhour_remain             # <<<<<<<<<<<<<<
 *                     bhour_remain = timedelta(0)
 *                 else:
 */
        __pyx_t_8 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_other), __pyx_v_bhour_remain); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2062, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2062, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2063
 *                     # finish adjusting if possible
 *                     other += bhour_remain
 *                     bhour_remain = timedelta(0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     # go to next business time interval
 */
        __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2063, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_bhour_remain, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2060
 *                     self._get_closing_time(self._prev_opening_time(other)) - other
 *                 )
 *                 if bhour_remain < bhour:             # <<<<<<<<<<<<<<
 *                     # finish adjusting if possible
 *                     other += bhour_remain
 */
        goto __pyx_L18;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2066
 *                 else:
 *                     # go to next business time interval
 *                     bhour_remain -= bhour             # <<<<<<<<<<<<<<
 *                     other = self._next_opening_time(other + bhour)
 *         else:
 */
      /*else*/ {
        __pyx_t_8 = PyNumber_InPlaceSubtract(__pyx_v_bhour_remain, __pyx_v_bhour); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2066, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_bhour_remain, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2067
 *                     # go to next business time interval
 *                     bhour_remain -= bhour
 *                     other = self._next_opening_time(other + bhour)             # <<<<<<<<<<<<<<
 *         else:
 *             while bhour_remain != timedelta(0):
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2067, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_9 = PyNumber_Add(((PyObject *)__pyx_v_other), __pyx_v_bhour); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2067, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = NULL;
        __pyx_t_2 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_2 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_9};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2067, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2067, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
        __pyx_t_8 = 0;
      }
      __pyx_L18:;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2054
 *         bhour_remain = timedelta(minutes=r)
 * 
 *         if n >= 0:             # <<<<<<<<<<<<<<
 *             while bhour_remain != timedelta(0):
 *                 # business hour left in this business time interval
 */
    goto __pyx_L15;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2069
 *                     other = self._next_opening_time(other + bhour)
 *         else:
 *             while bhour_remain != timedelta(0):             # <<<<<<<<<<<<<<
 *                 # business hour left in this business time interval
 *                 bhour = self._next_opening_time(other) - other
 */
  /*else*/ {
    while (1) {
      __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2069, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_bhour_remain, __pyx_t_8, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2069, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 2069, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!__pyx_t_10) break;

      /* "pandas/_libs/tslibs/offsets.pyx":2071
 *             while bhour_remain != timedelta(0):
 *                 # business hour left in this business time interval
 *                 bhour = self._next_opening_time(other) - other             # <<<<<<<<<<<<<<
 *                 if (
 *                     bhour_remain > bhour
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_2 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_2 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_v_other)};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2071, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __pyx_t_8 = PyNumber_Subtract(__pyx_t_7, ((PyObject *)__pyx_v_other)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_bhour, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2073
 *                 bhour = self._next_opening_time(other) - other
 *                 if (
 *                     bhour_remain > bhour             # <<<<<<<<<<<<<<
 *                     or bhour_remain == bhour
 *                     and nanosecond != 0
 */
      __pyx_t_8 = PyObject_RichCompare(__pyx_v_bhour_remain, __pyx_v_bhour, Py_GT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2073, __pyx_L1_error)
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2073, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (!__pyx_t_12) {
      } else {
        __pyx_t_10 = __pyx_t_12;
        goto __pyx_L22_bool_binop_done;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2074
 *                 if (
 *                     bhour_remain > bhour
 *                     or bhour_remain == bhour             # <<<<<<<<<<<<<<
 *                     and nanosecond != 0
 *                 ):
 */
      __pyx_t_8 = PyObject_RichCompare(__pyx_v_bhour_remain, __pyx_v_bhour, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2074, __pyx_L1_error)
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2074, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (__pyx_t_12) {
      } else {
        __pyx_t_10 = __pyx_t_12;
        goto __pyx_L22_bool_binop_done;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2075
 *                     bhour_remain > bhour
 *                     or bhour_remain == bhour
 *                     and nanosecond != 0             # <<<<<<<<<<<<<<
 *                 ):
 *                     # finish adjusting if possible
 */
      __pyx_t_12 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_nanosecond, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 2075, __pyx_L1_error)
      __pyx_t_10 = __pyx_t_12;
      __pyx_L22_bool_binop_done:;

      /* "pandas/_libs/tslibs/offsets.pyx":2072
 *                 # business hour left in this business time interval
 *                 bhour = self._next_opening_time(other) - other
 *                 if (             # <<<<<<<<<<<<<<
 *                     bhour_remain > bhour
 *                     or bhour_remain == bhour
 */
      if (__pyx_t_10) {

        /* "pandas/_libs/tslibs/offsets.pyx":2078
 *                 ):
 *                     # finish adjusting if possible
 *                     other += bhour_remain             # <<<<<<<<<<<<<<
 *                     bhour_remain = timedelta(0)
 *                 else:
 */
        __pyx_t_8 = PyNumber_InPlaceAdd(((PyObject *)__pyx_v_other), __pyx_v_bhour_remain); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2078, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2078, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2079
 *                     # finish adjusting if possible
 *                     other += bhour_remain
 *                     bhour_remain = timedelta(0)             # <<<<<<<<<<<<<<
 *                 else:
 *                     # go to next business time interval
 */
        __pyx_t_8 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2079, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_bhour_remain, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2072
 *                 # business hour left in this business time interval
 *                 bhour = self._next_opening_time(other) - other
 *                 if (             # <<<<<<<<<<<<<<
 *                     bhour_remain > bhour
 *                     or bhour_remain == bhour
 */
        goto __pyx_L21;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2082
 *                 else:
 *                     # go to next business time interval
 *                     bhour_remain -= bhour             # <<<<<<<<<<<<<<
 *                     other = self._get_closing_time(
 *                         self._next_opening_time(
 */
      /*else*/ {
        __pyx_t_8 = PyNumber_InPlaceSubtract(__pyx_v_bhour_remain, __pyx_v_bhour); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2082, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_bhour_remain, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":2083
 *                     # go to next business time interval
 *                     bhour_remain -= bhour
 *                     other = self._get_closing_time(             # <<<<<<<<<<<<<<
 *                         self._next_opening_time(
 *                             other + bhour - timedelta(seconds=1)
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_get_closing_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2083, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "pandas/_libs/tslibs/offsets.pyx":2084
 *                     bhour_remain -= bhour
 *                     other = self._get_closing_time(
 *                         self._next_opening_time(             # <<<<<<<<<<<<<<
 *                             other + bhour - timedelta(seconds=1)
 *                         )
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2084, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "pandas/_libs/tslibs/offsets.pyx":2085
 *                     other = self._get_closing_time(
 *                         self._next_opening_time(
 *                             other + bhour - timedelta(seconds=1)             # <<<<<<<<<<<<<<
 *                         )
 *                     )
 */
        __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_v_other), __pyx_v_bhour); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_seconds, __pyx_int_1) < 0) __PYX_ERR(0, 2085, __pyx_L1_error)
        __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyNumber_Subtract(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2085, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        __pyx_t_2 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_2 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_4};
          __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2084, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_t_6 = NULL;
        __pyx_t_2 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_2 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_9};
          __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_2, 1+__pyx_t_2);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2083, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }

        /* "pandas/_libs/tslibs/offsets.pyx":2083
 *                     # go to next business time interval
 *                     bhour_remain -= bhour
 *                     other = self._get_closing_time(             # <<<<<<<<<<<<<<
 *                         self._next_opening_time(
 *                             other + bhour - timedelta(seconds=1)
 */
        if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2083, __pyx_L1_error)
        __Pyx_DECREF_SET(__pyx_v_other, ((PyDateTime_DateTime *)__pyx_t_8));
        __pyx_t_8 = 0;
      }
      __pyx_L21:;
    }
  }
  __pyx_L15:;

  /* "pandas/_libs/tslibs/offsets.pyx":2089
 *                     )
 * 
 *         return other             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_other);
  __pyx_r = __pyx_v_other;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nanosecond);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_businesshours);
  __Pyx_XDECREF(__pyx_v_bd);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF((PyObject *)__pyx_v_skip_bd);
  __Pyx_XDECREF(__pyx_v_prev_open);
  __Pyx_XDECREF(__pyx_v_remain);
  __Pyx_XDECREF(__pyx_v_bhour_remain);
  __Pyx_XDECREF(__pyx_v_bhour);
  __Pyx_XDECREF(__pyx_gb_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_apply_2generator5);
  __Pyx_XDECREF((PyObject *)__pyx_v_other);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2091
 *         return other
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2091, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2091, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2091, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2091, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_22is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_22is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":2092
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2092, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2093
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         if dt.tzinfo is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2092
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2095
 *             return False
 * 
 *         if dt.tzinfo is not None:             # <<<<<<<<<<<<<<
 *             dt = datetime(
 *                 dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second, dt.microsecond
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_dt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2095, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = (__pyx_t_4 != Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2097
 *         if dt.tzinfo is not None:
 *             dt = datetime(
 *                 dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second, dt.microsecond             # <<<<<<<<<<<<<<
 *             )
 *         # Valid BH can be on the different BusinessDay during midnight
 */
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_6second_second(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2097, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);

    /* "pandas/_libs/tslibs/offsets.pyx":2096
 * 
 *         if dt.tzinfo is not None:
 *             dt = datetime(             # <<<<<<<<<<<<<<
 *                 dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second, dt.microsecond
 *             )
 */
    __pyx_t_12 = PyTuple_New(7); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_4)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_6)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 2, __pyx_t_7)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 3, __pyx_t_8)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 4, __pyx_t_9)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_10);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 5, __pyx_t_10)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_11);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_12, 6, __pyx_t_11)) __PYX_ERR(0, 2096, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;
    __pyx_t_11 = 0;
    __pyx_t_11 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_12, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2096, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF_SET(__pyx_v_dt, ((PyDateTime_DateTime *)__pyx_t_11));
    __pyx_t_11 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2095
 *             return False
 * 
 *         if dt.tzinfo is not None:             # <<<<<<<<<<<<<<
 *             dt = datetime(
 *                 dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second, dt.microsecond
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2101
 *         # Valid BH can be on the different BusinessDay during midnight
 *         # Distinguish by the time spent from previous opening time
 *         return self._is_on_offset(dt)             # <<<<<<<<<<<<<<
 * 
 *     def _is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_on_offset_2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 2101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_10 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, ((PyObject *)__pyx_v_dt)};
    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 2101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __pyx_r = __pyx_t_11;
  __pyx_t_11 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2091
 *         return other
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2103
 *         return self._is_on_offset(dt)
 * 
 *     def _is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Slight speedups using calculated values.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset, "\n        Slight speedups using calculated values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset = {"_is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2103, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_is_on_offset") < 0)) __PYX_ERR(0, 2103, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2103, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2103, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_op = NULL;
  PyObject *__pyx_v_span = NULL;
  PyObject *__pyx_v_businesshours = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_st = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2111
 *         # Valid BH can be on the different BusinessDay during midnight
 *         # Distinguish by the time spent from previous opening time
 *         if self.n >= 0:             # <<<<<<<<<<<<<<
 *             op = self._prev_opening_time(dt)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n >= 0);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2112
 *         # Distinguish by the time spent from previous opening time
 *         if self.n >= 0:
 *             op = self._prev_opening_time(dt)             # <<<<<<<<<<<<<<
 *         else:
 *             op = self._next_opening_time(dt)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prev_opening_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2112, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_dt)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_op = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2111
 *         # Valid BH can be on the different BusinessDay during midnight
 *         # Distinguish by the time spent from previous opening time
 *         if self.n >= 0:             # <<<<<<<<<<<<<<
 *             op = self._prev_opening_time(dt)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2114
 *             op = self._prev_opening_time(dt)
 *         else:
 *             op = self._next_opening_time(dt)             # <<<<<<<<<<<<<<
 *         span = (dt - op).total_seconds()
 *         businesshours = 0
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_next_opening_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_dt)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_op = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":2115
 *         else:
 *             op = self._next_opening_time(dt)
 *         span = (dt - op).total_seconds()             # <<<<<<<<<<<<<<
 *         businesshours = 0
 *         for i, st in enumerate(self.start):
 */
  __pyx_t_3 = PyNumber_Subtract(((PyObject *)__pyx_v_dt), __pyx_v_op); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_total_seconds); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_span = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2116
 *             op = self._next_opening_time(dt)
 *         span = (dt - op).total_seconds()
 *         businesshours = 0             # <<<<<<<<<<<<<<
 *         for i, st in enumerate(self.start):
 *             if op.hour == st.hour and op.minute == st.minute:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_businesshours = __pyx_int_0;

  /* "pandas/_libs/tslibs/offsets.pyx":2117
 *         span = (dt - op).total_seconds()
 *         businesshours = 0
 *         for i, st in enumerate(self.start):             # <<<<<<<<<<<<<<
 *             if op.hour == st.hour and op.minute == st.minute:
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_2 = __pyx_int_0;
  __pyx_t_4 = __pyx_v_self->start; __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 2117, __pyx_L1_error)
      #endif
      if (__pyx_t_6 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 2117, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_st, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2118
 *         businesshours = 0
 *         for i, st in enumerate(self.start):
 *             if op.hour == st.hour and op.minute == st.minute:             # <<<<<<<<<<<<<<
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 *         if span <= businesshours:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_op, __pyx_n_s_hour); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_hour); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_3, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_9) {
    } else {
      __pyx_t_1 = __pyx_t_9;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_op, __pyx_n_s_minute); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_st, __pyx_n_s_minute); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_8, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 2118, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_9;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":2119
 *         for i, st in enumerate(self.start):
 *             if op.hour == st.hour and op.minute == st.minute:
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])             # <<<<<<<<<<<<<<
 *         if span <= businesshours:
 *             return True
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_business_hours_by_sec); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (unlikely(__pyx_v_self->end == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 2119, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_self->end, __pyx_v_i); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_10, __pyx_v_st, __pyx_t_8};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2119, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF_SET(__pyx_v_businesshours, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2118
 *         businesshours = 0
 *         for i, st in enumerate(self.start):
 *             if op.hour == st.hour and op.minute == st.minute:             # <<<<<<<<<<<<<<
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 *         if span <= businesshours:
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2117
 *         span = (dt - op).total_seconds()
 *         businesshours = 0
 *         for i, st in enumerate(self.start):             # <<<<<<<<<<<<<<
 *             if op.hour == st.hour and op.minute == st.minute:
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2120
 *             if op.hour == st.hour and op.minute == st.minute:
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 *         if span <= businesshours:             # <<<<<<<<<<<<<<
 *             return True
 *         else:
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_span, __pyx_v_businesshours, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2120, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2121
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 *         if span <= businesshours:
 *             return True             # <<<<<<<<<<<<<<
 *         else:
 *             return False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2120
 *             if op.hour == st.hour and op.minute == st.minute:
 *                 businesshours = self._get_business_hours_by_sec(st, self.end[i])
 *         if span <= businesshours:             # <<<<<<<<<<<<<<
 *             return True
 *         else:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2123
 *             return True
 *         else:
 *             return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2103
 *         return self._is_on_offset(dt)
 * 
 *     def _is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Slight speedups using calculated values.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.BusinessHour._is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_op);
  __Pyx_XDECREF(__pyx_v_span);
  __Pyx_XDECREF(__pyx_v_businesshours);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_st);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":1759
 * 
 *     cdef readonly:
 *         tuple start, end             # <<<<<<<<<<<<<<
 * 
 *     def __init__(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->start);
  __pyx_r = __pyx_v_self->start;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->end);
  __pyx_r = __pyx_v_self->end;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2134
 *         int weekday, week
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekday = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekday,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2134, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2134, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2134, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2134, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekday = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2134, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2135
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 *         self.weekday = weekday
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2136
 *     def __init__(self, n=1, normalize=False, weekday=0):
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday             # <<<<<<<<<<<<<<
 * 
 *         if weekday < 0 or weekday > 6:
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_weekday); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2136, __pyx_L1_error)
  __pyx_v_self->weekday = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":2138
 *         self.weekday = weekday
 * 
 *         if weekday < 0 or weekday > 6:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_weekday, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_weekday, __pyx_int_6, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2138, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":2139
 * 
 *         if weekday < 0 or weekday > 6:
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Day_must_be_0_day_6_got, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 2139, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":2138
 *         self.weekday = weekday
 * 
 *         if weekday < 0 or weekday > 6:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2134
 *         int weekday, week
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2141
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2141, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2141, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2141, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2142, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_2_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_compare_day = NULL;
  __pyx_t_5numpy_int64_t __pyx_v_months;
  PyObject *__pyx_v_shifted = NULL;
  PyObject *__pyx_v_to_day = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2143
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)             # <<<<<<<<<<<<<<
 * 
 *         months = self.n
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_other)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_compare_day = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2145
 *         compare_day = self._get_offset_day(other)
 * 
 *         months = self.n             # <<<<<<<<<<<<<<
 *         months = roll_convention(other.day, months, compare_day)
 * 
 */
  __pyx_t_5 = __pyx_v_self->__pyx_base.__pyx_base.n;
  __pyx_v_months = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2146
 * 
 *         months = self.n
 *         months = roll_convention(other.day, months, compare_day)             # <<<<<<<<<<<<<<
 * 
 *         shifted = shift_month(other, months, "start")
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2146, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_compare_day); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2146, __pyx_L1_error)
  __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_t_4, __pyx_v_months, __pyx_t_6, 0); if (unlikely(__pyx_t_7 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2146, __pyx_L1_error)
  __pyx_v_months = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2148
 *         months = roll_convention(other.day, months, compare_day)
 * 
 *         shifted = shift_month(other, months, "start")             # <<<<<<<<<<<<<<
 *         to_day = self._get_offset_day(shifted)
 *         return _shift_day(shifted, to_day - shifted.day)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_months); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_8, ((PyObject *)__pyx_v_other), __pyx_t_3, __pyx_n_u_start};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 3+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_shifted = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2149
 * 
 *         shifted = shift_month(other, months, "start")
 *         to_day = self._get_offset_day(shifted)             # <<<<<<<<<<<<<<
 *         return _shift_day(shifted, to_day - shifted.day)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_shifted};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_to_day = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2150
 *         shifted = shift_month(other, months, "start")
 *         to_day = self._get_offset_day(shifted)
 *         return _shift_day(shifted, to_day - shifted.day)             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_shifted) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_shifted, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2150, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_shifted, __pyx_n_s_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_to_day, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(((PyDateTime_DateTime *)__pyx_v_shifted), __pyx_t_7)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2141
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_compare_day);
  __Pyx_XDECREF(__pyx_v_shifted);
  __Pyx_XDECREF(__pyx_v_to_day);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2152
 *         return _shift_day(shifted, to_day - shifted.day)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2152, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2152, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2152, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2152, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2153
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day == self._get_offset_day(dt)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2153, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2154
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return dt.day == self._get_offset_day(dt)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2153
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day == self._get_offset_day(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2155
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return dt.day == self._get_offset_day(dt)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2155, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, ((PyObject *)__pyx_v_dt)};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2155, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2152
 *         return _shift_day(shifted, to_day - shifted.day)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2157
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         weekday = int_to_weekday.get(self.weekday, "")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self) {
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2159
 *     @property
 *     def rule_code(self) -> str:
 *         weekday = int_to_weekday.get(self.weekday, "")             # <<<<<<<<<<<<<<
 *         if self.week == -1:
 *             # LastWeekOfMonth
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_int_to_weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, __pyx_kp_u__15};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_weekday = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2160
 *     def rule_code(self) -> str:
 *         weekday = int_to_weekday.get(self.weekday, "")
 *         if self.week == -1:             # <<<<<<<<<<<<<<
 *             # LastWeekOfMonth
 *             return f"{self._prefix}-{weekday}"
 */
  __pyx_t_6 = (__pyx_v_self->week == -1L);
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":2162
 *         if self.week == -1:
 *             # LastWeekOfMonth
 *             return f"{self._prefix}-{weekday}"             # <<<<<<<<<<<<<<
 *         return f"{self._prefix}-{self.week + 1}{weekday}"
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_kp_u__38);
    __pyx_t_7 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__38);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__38);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2160
 *     def rule_code(self) -> str:
 *         weekday = int_to_weekday.get(self.weekday, "")
 *         if self.week == -1:             # <<<<<<<<<<<<<<
 *             # LastWeekOfMonth
 *             return f"{self._prefix}-{weekday}"
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2163
 *             # LastWeekOfMonth
 *             return f"{self._prefix}-{weekday}"
 *         return f"{self._prefix}-{self.week + 1}{weekday}"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = 0;
  __pyx_t_8 = 127;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_7 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__38);
  __pyx_t_3 = __Pyx_PyUnicode_From_long((__pyx_v_self->week + 1), 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_8;
  __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 4, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2157
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         weekday = int_to_weekday.get(self.weekday, "")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2132
 * 
 *     cdef readonly:
 *         int weekday, week             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->weekday); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.weekday.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->week); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonthMixin.week.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2181
 *         int month
 * 
 *     def __init__(self, n=1, normalize=False, month=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_month = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_month,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2181, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2181, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_month);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2181, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2181, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_month = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2181, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_month);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_month) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_month);

  /* "pandas/_libs/tslibs/offsets.pyx":2182
 * 
 *     def __init__(self, n=1, normalize=False, month=None):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 * 
 *         month = month if month is not None else self._default_month
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2184
 *         BaseOffset.__init__(self, n, normalize)
 * 
 *         month = month if month is not None else self._default_month             # <<<<<<<<<<<<<<
 *         self.month = month
 * 
 */
  __pyx_t_5 = (__pyx_v_month != Py_None);
  if (__pyx_t_5) {
    __Pyx_INCREF(__pyx_v_month);
    __pyx_t_1 = __pyx_v_month;
  } else {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_default_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __Pyx_DECREF_SET(__pyx_v_month, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2185
 * 
 *         month = month if month is not None else self._default_month
 *         self.month = month             # <<<<<<<<<<<<<<
 * 
 *         if month < 1 or month > 12:
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_month); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2185, __pyx_L1_error)
  __pyx_v_self->month = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":2187
 *         self.month = month
 * 
 *         if month < 1 or month > 12:             # <<<<<<<<<<<<<<
 *             raise ValueError("Month must go from 1 to 12")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_month, __pyx_int_1, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_month, __pyx_int_12, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2187, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2187, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":2188
 * 
 *         if month < 1 or month > 12:
 *             raise ValueError("Month must go from 1 to 12")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 2188, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":2187
 *         self.month = month
 * 
 *         if month < 1 or month > 12:             # <<<<<<<<<<<<<<
 *             raise ValueError("Month must go from 1 to 12")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2181
 *         int month
 * 
 *     def __init__(self, n=1, normalize=False, month=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_month);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2190
 *             raise ValueError("Month must go from 1 to 12")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_10YearOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2190, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2191
 * 
 *     cpdef __setstate__(self, state):
 *         self.month = state.pop("month")             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_month};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->month = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2192
 *     cpdef __setstate__(self, state):
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self._cache = {}
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2193
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self._cache = {}
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2194
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self._cache = {}             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __pyx_v_self->__pyx_base.__pyx_base._cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2190
 *             raise ValueError("Month must go from 1 to 12")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2190, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 2190, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2190, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_10YearOffset___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2196
 *         self._cache = {}
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":2197
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         kwargs = {}
 *         if suffix:
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2196, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 2196, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2196, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_4_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":2196
 *         self._cache = {}
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_v_kwargs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2198
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}             # <<<<<<<<<<<<<<
 *         if suffix:
 *             kwargs["month"] = MONTH_TO_CAL_NUM[suffix]
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_kwargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2199
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 *         if suffix:             # <<<<<<<<<<<<<<
 *             kwargs["month"] = MONTH_TO_CAL_NUM[suffix]
 *         return cls(**kwargs)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2199, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":2200
 *         kwargs = {}
 *         if suffix:
 *             kwargs["month"] = MONTH_TO_CAL_NUM[suffix]             # <<<<<<<<<<<<<<
 *         return cls(**kwargs)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MONTH_TO_CAL_NUM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_suffix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_u_month, __pyx_t_3) < 0))) __PYX_ERR(0, 2200, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2199
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 *         if suffix:             # <<<<<<<<<<<<<<
 *             kwargs["month"] = MONTH_TO_CAL_NUM[suffix]
 *         return cls(**kwargs)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2201
 *         if suffix:
 *             kwargs["month"] = MONTH_TO_CAL_NUM[suffix]
 *         return cls(**kwargs)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2196
 *         self._cache = {}
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2203
 *         return cls(**kwargs)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.month]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self) {
  PyObject *__pyx_v_month = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2205
 *     @property
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.month]             # <<<<<<<<<<<<<<
 *         return f"{self._prefix}-{month}"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MONTH_ALIASES); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_self->month, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_month = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2206
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.month]
 *         return f"{self._prefix}-{month}"             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_3 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__38);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_month, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2203
 *         return cls(**kwargs)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.month]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_month);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2208
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2208, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2208, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2208, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2208, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_6is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_6is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2209
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2209, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2210
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2209
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2211
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)             # <<<<<<<<<<<<<<
 * 
 *     def _get_offset_day(self, other: datetime) -> int:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2211, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_5 == __pyx_v_self->month);
  if (__pyx_t_1) {
  } else {
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2211, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_v_dt)};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = PyObject_RichCompare(__pyx_t_6, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2211, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_4 = __pyx_t_8;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_L6_bool_binop_done:;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2208
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2213
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # override BaseOffset method to use self.month instead of other.month
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day = {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_offset_day (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2213, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_offset_day") < 0)) __PYX_ERR(0, 2213, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_offset_day", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2213, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2213, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_8_get_offset_day(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_8_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  npy_datetimestruct __pyx_v_dts;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_offset_day", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2217
 *         cdef:
 *             npy_datetimestruct dts
 *         pydate_to_dtstruct(other, &dts)             # <<<<<<<<<<<<<<
 *         dts.month = self.month
 *         return get_day_of_month(&dts, self._day_opt)
 */
  if (!(likely(__Pyx_TypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_date)))) __PYX_ERR(0, 2217, __pyx_L1_error)
  __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dtstruct(((PyDateTime_Date *)__pyx_v_other), (&__pyx_v_dts)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2217, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2218
 *             npy_datetimestruct dts
 *         pydate_to_dtstruct(other, &dts)
 *         dts.month = self.month             # <<<<<<<<<<<<<<
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 */
  __pyx_t_1 = __pyx_v_self->month;
  __pyx_v_dts.month = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":2219
 *         pydate_to_dtstruct(other, &dts)
 *         dts.month = self.month
 *         return get_day_of_month(&dts, self._day_opt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_2))) __PYX_ERR(0, 2219, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month((&__pyx_v_dts), ((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_2)) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_2))) __PYX_ERR(0, 2219, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2213
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # override BaseOffset method to use self.month instead of other.month
 *         cdef:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2221
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2221, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2221, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2221, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2222, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_10_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_10_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_years = NULL;
  PyObject *__pyx_v_months = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2223
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)             # <<<<<<<<<<<<<<
 *         months = years * 12 + (self.month - other.month)
 *         return shift_month(other, months, self._day_opt)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_roll_qtrday); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->month); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF((PyObject *)__pyx_v_other);
  __Pyx_GIVEREF((PyObject *)__pyx_v_other);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_other))) __PYX_ERR(0, 2223, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 2223, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3)) __PYX_ERR(0, 2223, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4)) __PYX_ERR(0, 2223, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_modby, __pyx_int_12) < 0) __PYX_ERR(0, 2223, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_years = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2224
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 *         months = years * 12 + (self.month - other.month)             # <<<<<<<<<<<<<<
 *         return shift_month(other, months, self._day_opt)
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_MultiplyObjC(__pyx_v_years, __pyx_int_12, 12, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2224, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_self->month - __pyx_t_6)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_months = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2225
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 *         months = years * 12 + (self.month - other.month)
 *         return shift_month(other, months, self._day_opt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_1, ((PyObject *)__pyx_v_other), __pyx_v_months, __pyx_t_3};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2225, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_5);
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2221
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_years);
  __Pyx_XDECREF(__pyx_v_months);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2227
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2227, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 2227, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2227, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_12_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_12_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyArrayObject *__pyx_v_shifted = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  NPY_DATETIMEUNIT __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2229
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *         shifted = shift_quarters(
 *             dtarr.view("i8"), self.n, self.month, self._day_opt, modby=12, reso=reso
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 2229, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":2231
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_quarters(
 *             dtarr.view("i8"), self.n, self.month, self._day_opt, modby=12, reso=reso             # <<<<<<<<<<<<<<
 *         )
 *         return shifted
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_i8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2231, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_3))) __PYX_ERR(0, 2231, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2230
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_quarters(             # <<<<<<<<<<<<<<
 *             dtarr.view("i8"), self.n, self.month, self._day_opt, modby=12, reso=reso
 *         )
 */
  __pyx_t_6.__pyx_n = 2;
  __pyx_t_6.modby = 12;
  __pyx_t_6.reso = __pyx_v_reso;
  __pyx_t_4 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets_shift_quarters(((PyArrayObject *)__pyx_t_1), __pyx_v_self->__pyx_base.__pyx_base.n, __pyx_v_self->month, ((PyObject*)__pyx_t_3), &__pyx_t_6)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shifted = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2233
 *             dtarr.view("i8"), self.n, self.month, self._day_opt, modby=12, reso=reso
 *         )
 *         return shifted             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_shifted);
  __pyx_r = ((PyObject *)__pyx_v_shifted);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2227
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_shifted);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2179
 * 
 *     cdef readonly:
 *         int month             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, month=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearOffset.month.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2304
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, month=None):             # <<<<<<<<<<<<<<
 *         # Because YearEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_month = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_month,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2304, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2304, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_month);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2304, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2304, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_month = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2304, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_month);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_month) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2307
 *         # Because YearEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 *         YearOffset.__init__(self, n, normalize, month)             # <<<<<<<<<<<<<<
 *         self._period_dtype_code = PeriodDtypeCode.A + self.month % 12
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_month};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2308
 *         #  _period_dtype_code at construction for performance
 *         YearOffset.__init__(self, n, normalize, month)
 *         self._period_dtype_code = PeriodDtypeCode.A + self.month % 12             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->_period_dtype_code = (__pyx_e_6pandas_5_libs_6tslibs_6dtypes_A + __Pyx_mod_long(__pyx_v_self->__pyx_base.month, 12));

  /* "pandas/_libs/tslibs/offsets.pyx":2304
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, month=None):             # <<<<<<<<<<<<<<
 *         # Because YearEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2302
 * 
 *     cdef readonly:
 *         int _period_dtype_code             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, month=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_period_dtype_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.YearEnd._period_dtype_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2359
 *         int startingMonth
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_startingMonth = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_startingMonth,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2359, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2359, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startingMonth);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2359, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2359, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_startingMonth = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2359, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_startingMonth);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_startingMonth) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_startingMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":2360
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 * 
 *         if startingMonth is None:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2362
 *         BaseOffset.__init__(self, n, normalize)
 * 
 *         if startingMonth is None:             # <<<<<<<<<<<<<<
 *             startingMonth = self._default_starting_month
 *         self.startingMonth = startingMonth
 */
  __pyx_t_5 = (__pyx_v_startingMonth == Py_None);
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":2363
 * 
 *         if startingMonth is None:
 *             startingMonth = self._default_starting_month             # <<<<<<<<<<<<<<
 *         self.startingMonth = startingMonth
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_default_starting_month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2363, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_startingMonth, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2362
 *         BaseOffset.__init__(self, n, normalize)
 * 
 *         if startingMonth is None:             # <<<<<<<<<<<<<<
 *             startingMonth = self._default_starting_month
 *         self.startingMonth = startingMonth
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2364
 *         if startingMonth is None:
 *             startingMonth = self._default_starting_month
 *         self.startingMonth = startingMonth             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_startingMonth); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2364, __pyx_L1_error)
  __pyx_v_self->startingMonth = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":2359
 *         int startingMonth
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_startingMonth);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2366
 *         self.startingMonth = startingMonth
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2366, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2366, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2367
 * 
 *     cpdef __setstate__(self, state):
 *         self.startingMonth = state.pop("startingMonth")             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_startingMonth};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2367, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->startingMonth = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2368
 *     cpdef __setstate__(self, state):
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2368, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2369
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2366
 *         self.startingMonth = startingMonth
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2366, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 2366, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2366, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2371
 *         self.normalize = state.pop("normalize")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":2372
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         kwargs = {}
 *         if suffix:
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2371, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 2371, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2371, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_4_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":2371
 *         self.normalize = state.pop("normalize")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_v_kwargs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2373
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}             # <<<<<<<<<<<<<<
 *         if suffix:
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_kwargs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2374
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 *         if suffix:             # <<<<<<<<<<<<<<
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 2374, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":2375
 *         kwargs = {}
 *         if suffix:
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]             # <<<<<<<<<<<<<<
 *         else:
 *             if cls._from_name_starting_month is not None:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MONTH_TO_CAL_NUM); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_suffix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2375, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_u_startingMonth, __pyx_t_3) < 0))) __PYX_ERR(0, 2375, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2374
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 *         if suffix:             # <<<<<<<<<<<<<<
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2377
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]
 *         else:
 *             if cls._from_name_starting_month is not None:             # <<<<<<<<<<<<<<
 *                 kwargs["startingMonth"] = cls._from_name_starting_month
 *         return cls(**kwargs)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_from_name_starting_month); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2377, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = (__pyx_t_3 != Py_None);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":2378
 *         else:
 *             if cls._from_name_starting_month is not None:
 *                 kwargs["startingMonth"] = cls._from_name_starting_month             # <<<<<<<<<<<<<<
 *         return cls(**kwargs)
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_from_name_starting_month); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely((PyDict_SetItem(__pyx_v_kwargs, __pyx_n_u_startingMonth, __pyx_t_3) < 0))) __PYX_ERR(0, 2378, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2377
 *             kwargs["startingMonth"] = MONTH_TO_CAL_NUM[suffix]
 *         else:
 *             if cls._from_name_starting_month is not None:             # <<<<<<<<<<<<<<
 *                 kwargs["startingMonth"] = cls._from_name_starting_month
 *         return cls(**kwargs)
 */
    }
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":2379
 *             if cls._from_name_starting_month is not None:
 *                 kwargs["startingMonth"] = cls._from_name_starting_month
 *         return cls(**kwargs)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyDict_Copy(__pyx_v_kwargs); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2371
 *         self.normalize = state.pop("normalize")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2381
 *         return cls(**kwargs)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.startingMonth]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self) {
  PyObject *__pyx_v_month = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2383
 *     @property
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.startingMonth]             # <<<<<<<<<<<<<<
 *         return f"{self._prefix}-{month}"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MONTH_ALIASES); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_self->startingMonth, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_month = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2384
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.startingMonth]
 *         return f"{self._prefix}-{month}"             # <<<<<<<<<<<<<<
 * 
 *     def is_anchored(self) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_3 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__38);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_month, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2381
 *         return cls(**kwargs)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         month = MONTH_ALIASES[self.startingMonth]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_month);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2386
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.startingMonth is not None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored = {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_anchored", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_anchored", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_6is_anchored(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_6is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_anchored", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2387
 * 
 *     def is_anchored(self) -> bool:
 *         return self.n == 1 and self.startingMonth is not None             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base.n == 1);
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->startingMonth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2386
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.startingMonth is not None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.is_anchored", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2389
 *         return self.n == 1 and self.startingMonth is not None
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2389, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2389, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2389, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2389, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_8is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_8is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  long __pyx_v_mod_month;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2390
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         mod_month = (dt.month - self.startingMonth) % 3
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2390, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2391
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         mod_month = (dt.month - self.startingMonth) % 3
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2390
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         mod_month = (dt.month - self.startingMonth) % 3
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2392
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         mod_month = (dt.month - self.startingMonth) % 3             # <<<<<<<<<<<<<<
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 * 
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2392, __pyx_L1_error)
  __pyx_v_mod_month = __Pyx_mod_long((__pyx_t_4 - __pyx_v_self->startingMonth), 3);

  /* "pandas/_libs/tslibs/offsets.pyx":2393
 *             return False
 *         mod_month = (dt.month - self.startingMonth) % 3
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (__pyx_v_mod_month == 0);
  if (__pyx_t_1) {
  } else {
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2393, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, ((PyObject *)__pyx_v_dt)};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_t_8 = PyObject_RichCompare(__pyx_t_6, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_5 = __pyx_t_8;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_L6_bool_binop_done:;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2389
 *         return self.n == 1 and self.startingMonth is not None
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2395
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # months_since: find the calendar quarter containing other.month,
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2395, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2395, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2395, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2396, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_10_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_10_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_months_since = NULL;
  PyObject *__pyx_v_qtrs = NULL;
  PyObject *__pyx_v_months = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2402
 *         # self.  `months_since` is the number of months to shift other.month
 *         # to get to this on-offset month.
 *         months_since = other.month % 3 - self.startingMonth % 3             # <<<<<<<<<<<<<<
 *         qtrs = roll_qtrday(
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2402, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_long((__Pyx_mod_long(__pyx_t_1, 3) - __Pyx_mod_long(__pyx_v_self->startingMonth, 3))); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_months_since = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2403
 *         # to get to this on-offset month.
 *         months_since = other.month % 3 - self.startingMonth % 3
 *         qtrs = roll_qtrday(             # <<<<<<<<<<<<<<
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3
 *         )
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_roll_qtrday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pandas/_libs/tslibs/offsets.pyx":2404
 *         months_since = other.month % 3 - self.startingMonth % 3
 *         qtrs = roll_qtrday(
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3             # <<<<<<<<<<<<<<
 *         )
 *         months = qtrs * 3 - months_since
 */
  __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->startingMonth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/tslibs/offsets.pyx":2403
 *         # to get to this on-offset month.
 *         months_since = other.month % 3 - self.startingMonth % 3
 *         qtrs = roll_qtrday(             # <<<<<<<<<<<<<<
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3
 *         )
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF((PyObject *)__pyx_v_other);
  __Pyx_GIVEREF((PyObject *)__pyx_v_other);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_other))) __PYX_ERR(0, 2403, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(0, 2403, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2404
 *         months_since = other.month % 3 - self.startingMonth % 3
 *         qtrs = roll_qtrday(
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3             # <<<<<<<<<<<<<<
 *         )
 *         months = qtrs * 3 - months_since
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_day_opt_2, __pyx_t_3) < 0) __PYX_ERR(0, 2404, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_modby, __pyx_int_3) < 0) __PYX_ERR(0, 2404, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2403
 *         # to get to this on-offset month.
 *         months_since = other.month % 3 - self.startingMonth % 3
 *         qtrs = roll_qtrday(             # <<<<<<<<<<<<<<
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3
 *         )
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_qtrs = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2406
 *             other, self.n, self.startingMonth, day_opt=self._day_opt, modby=3
 *         )
 *         months = qtrs * 3 - months_since             # <<<<<<<<<<<<<<
 *         return shift_month(other, months, self._day_opt)
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_MultiplyObjC(__pyx_v_qtrs, __pyx_int_3, 3, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Subtract(__pyx_t_3, __pyx_v_months_since); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_months = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2407
 *         )
 *         months = qtrs * 3 - months_since
 *         return shift_month(other, months, self._day_opt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  __pyx_t_1 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_1 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_2, ((PyObject *)__pyx_v_other), __pyx_v_months, __pyx_t_5};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_1, 3+__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2407, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2395
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # months_since: find the calendar quarter containing other.month,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_months_since);
  __Pyx_XDECREF(__pyx_v_qtrs);
  __Pyx_XDECREF(__pyx_v_months);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2409
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2409, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 2409, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2409, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_12_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_12_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyArrayObject *__pyx_v_shifted = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  NPY_DATETIMEUNIT __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2411
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *         shifted = shift_quarters(
 *             dtarr.view("i8"),
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 2411, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":2413
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_quarters(
 *             dtarr.view("i8"),             # <<<<<<<<<<<<<<
 *             self.n,
 *             self.startingMonth,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_i8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2413, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2416
 *             self.n,
 *             self.startingMonth,
 *             self._day_opt,             # <<<<<<<<<<<<<<
 *             modby=3,
 *             reso=reso,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_3))) __PYX_ERR(0, 2416, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2412
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_quarters(             # <<<<<<<<<<<<<<
 *             dtarr.view("i8"),
 *             self.n,
 */
  __pyx_t_6.__pyx_n = 2;
  __pyx_t_6.modby = 3;
  __pyx_t_6.reso = __pyx_v_reso;
  __pyx_t_4 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets_shift_quarters(((PyArrayObject *)__pyx_t_1), __pyx_v_self->__pyx_base.__pyx_base.n, __pyx_v_self->startingMonth, ((PyObject*)__pyx_t_3), &__pyx_t_6)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shifted = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2420
 *             reso=reso,
 *         )
 *         return shifted             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_shifted);
  __pyx_r = ((PyObject *)__pyx_v_shifted);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2409
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_shifted);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2357
 * 
 *     cdef readonly:
 *         int startingMonth             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->startingMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterOffset.startingMonth.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2500
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):             # <<<<<<<<<<<<<<
 *         # Because QuarterEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_startingMonth = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_startingMonth,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2500, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2500, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startingMonth);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2500, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2500, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_startingMonth = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2500, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_startingMonth);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_startingMonth) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2503
 *         # Because QuarterEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 *         QuarterOffset.__init__(self, n, normalize, startingMonth)             # <<<<<<<<<<<<<<
 *         self._period_dtype_code = PeriodDtypeCode.Q_DEC + self.startingMonth % 12
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_startingMonth};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2503, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2504
 *         #  _period_dtype_code at construction for performance
 *         QuarterOffset.__init__(self, n, normalize, startingMonth)
 *         self._period_dtype_code = PeriodDtypeCode.Q_DEC + self.startingMonth % 12             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->_period_dtype_code = (__pyx_e_6pandas_5_libs_6tslibs_6dtypes_Q_DEC + __Pyx_mod_long(__pyx_v_self->__pyx_base.startingMonth, 12));

  /* "pandas/_libs/tslibs/offsets.pyx":2500
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):             # <<<<<<<<<<<<<<
 *         # Because QuarterEnd can be the freq for a Period, define its
 *         #  _period_dtype_code at construction for performance
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterEnd.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2498
 * 
 *     cdef readonly:
 *         int _period_dtype_code             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, startingMonth=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_period_dtype_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.QuarterEnd._period_dtype_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2531
 * 
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2531, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2531, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2531, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2531, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2532
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day == self._get_offset_day(dt)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2532, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2533
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return dt.day == self._get_offset_day(dt)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2532
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day == self._get_offset_day(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2534
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return dt.day == self._get_offset_day(dt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2534, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, ((PyObject *)__pyx_v_dt)};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2531
 * 
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2536
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2536, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2536, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2536, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2537, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_2_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_compare_day = NULL;
  int __pyx_v_n;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2538
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)             # <<<<<<<<<<<<<<
 *         n = roll_convention(other.day, self.n, compare_day)
 *         return shift_month(other, n, self._day_opt)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_offset_day); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_other)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_compare_day = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2539
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 *         n = roll_convention(other.day, self.n, compare_day)             # <<<<<<<<<<<<<<
 *         return shift_month(other, n, self._day_opt)
 * 
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2539, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_compare_day); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2539, __pyx_L1_error)
  __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_t_4, __pyx_v_self->__pyx_base.__pyx_base.n, __pyx_t_5, 0); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2539, __pyx_L1_error)
  __pyx_v_n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2540
 *         compare_day = self._get_offset_day(other)
 *         n = roll_convention(other.day, self.n, compare_day)
 *         return shift_month(other, n, self._day_opt)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_8, ((PyObject *)__pyx_v_other), __pyx_t_3, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2540, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2536
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_compare_day);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2542
 *         return shift_month(other, n, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2542, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 2542, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2542, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_4_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_4_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyObject *__pyx_v_shifted = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  NPY_DATETIMEUNIT __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2544
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *         shifted = shift_months(dtarr.view("i8"), self.n, self._day_opt, reso=reso)
 *         return shifted
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 2544, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2544, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":2545
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_months(dtarr.view("i8"), self.n, self._day_opt, reso=reso)             # <<<<<<<<<<<<<<
 *         return shifted
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_shift_months); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_n_u_i8};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_day_opt); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3)) __PYX_ERR(0, 2545, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4)) __PYX_ERR(0, 2545, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_5)) __PYX_ERR(0, 2545, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(__pyx_v_reso); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_reso, __pyx_t_4) < 0) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_shifted = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2546
 *         reso = get_unit_from_dtype(dtarr.dtype)
 *         shifted = shift_months(dtarr.view("i8"), self.n, self._day_opt, reso=reso)
 *         return shifted             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_shifted);
  __pyx_r = __pyx_v_shifted;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2542
 *         return shift_month(other, n, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_shifted);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2548
 *         return shifted
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11MonthOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2548, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2548, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2549
 * 
 *     cpdef __setstate__(self, state):
 *         state.pop("_use_relativedelta", False)             # <<<<<<<<<<<<<<
 *         state.pop("offset", None)
 *         state.pop("_offset", None)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2550
 *     cpdef __setstate__(self, state):
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)             # <<<<<<<<<<<<<<
 *         state.pop("_offset", None)
 *         state.pop("kwds", {})
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2551
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 *         state.pop("_offset", None)             # <<<<<<<<<<<<<<
 *         state.pop("kwds", {})
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2552
 *         state.pop("offset", None)
 *         state.pop("_offset", None)
 *         state.pop("kwds", {})             # <<<<<<<<<<<<<<
 * 
 *         BaseOffset.__setstate__(self, state)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_n_u_kwds, __pyx_t_3};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2554
 *         state.pop("kwds", {})
 * 
 *         BaseOffset.__setstate__(self, state)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_state};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2554, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2548
 *         return shifted
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2548, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 2548, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2548, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_6__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_6__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11MonthOffset___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.MonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2658
 *         int day_of_month
 * 
 *     def __init__(self, n=1, normalize=False, day_of_month=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_day_of_month = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_day_of_month,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2658, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2658, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_day_of_month);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2658, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2658, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_day_of_month = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2658, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_day_of_month);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_day_of_month) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_UCS4 __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_day_of_month);

  /* "pandas/_libs/tslibs/offsets.pyx":2659
 * 
 *     def __init__(self, n=1, normalize=False, day_of_month=None):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 * 
 *         if day_of_month is None:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2661
 *         BaseOffset.__init__(self, n, normalize)
 * 
 *         if day_of_month is None:             # <<<<<<<<<<<<<<
 *             day_of_month = self._default_day_of_month
 * 
 */
  __pyx_t_5 = (__pyx_v_day_of_month == Py_None);
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":2662
 * 
 *         if day_of_month is None:
 *             day_of_month = self._default_day_of_month             # <<<<<<<<<<<<<<
 * 
 *         self.day_of_month = int(day_of_month)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_default_day_of_month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2662, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_day_of_month, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2661
 *         BaseOffset.__init__(self, n, normalize)
 * 
 *         if day_of_month is None:             # <<<<<<<<<<<<<<
 *             day_of_month = self._default_day_of_month
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2664
 *             day_of_month = self._default_day_of_month
 * 
 *         self.day_of_month = int(day_of_month)             # <<<<<<<<<<<<<<
 *         if not self._min_day_of_month <= self.day_of_month <= 27:
 *             raise ValueError(
 */
  __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_day_of_month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->day_of_month = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":2665
 * 
 *         self.day_of_month = int(day_of_month)
 *         if not self._min_day_of_month <= self.day_of_month <= 27:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "day_of_month must be "
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_min_day_of_month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->day_of_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2665, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_int_27, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2665, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 2665, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/tslibs/offsets.pyx":2667
 *         if not self._min_day_of_month <= self.day_of_month <= 27:
 *             raise ValueError(
 *                 "day_of_month must be "             # <<<<<<<<<<<<<<
 *                 f"{self._min_day_of_month}<=day_of_month<=27, "
 *                 f"got {self.day_of_month}"
 */
    __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = 0;
    __pyx_t_8 = 127;
    __Pyx_INCREF(__pyx_kp_u_day_of_month_must_be);
    __pyx_t_7 += 21;
    __Pyx_GIVEREF(__pyx_kp_u_day_of_month_must_be);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_day_of_month_must_be);

    /* "pandas/_libs/tslibs/offsets.pyx":2668
 *             raise ValueError(
 *                 "day_of_month must be "
 *                 f"{self._min_day_of_month}<=day_of_month<=27, "             # <<<<<<<<<<<<<<
 *                 f"got {self.day_of_month}"
 *             )
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_min_day_of_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2668, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2668, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_8) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_8;
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_INCREF(__pyx_kp_u_day_of_month_27_got);
    __pyx_t_7 += 24;
    __Pyx_GIVEREF(__pyx_kp_u_day_of_month_27_got);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_day_of_month_27_got);

    /* "pandas/_libs/tslibs/offsets.pyx":2669
 *                 "day_of_month must be "
 *                 f"{self._min_day_of_month}<=day_of_month<=27, "
 *                 f"got {self.day_of_month}"             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __pyx_t_1 = __Pyx_PyUnicode_From_int(__pyx_v_self->day_of_month, 0, ' ', 'd'); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2669, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2667
 *         if not self._min_day_of_month <= self.day_of_month <= 27:
 *             raise ValueError(
 *                 "day_of_month must be "             # <<<<<<<<<<<<<<
 *                 f"{self._min_day_of_month}<=day_of_month<=27, "
 *                 f"got {self.day_of_month}"
 */
    __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, __pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2666
 *         self.day_of_month = int(day_of_month)
 *         if not self._min_day_of_month <= self.day_of_month <= 27:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "day_of_month must be "
 *                 f"{self._min_day_of_month}<=day_of_month<=27, "
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2666, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":2665
 * 
 *         self.day_of_month = int(day_of_month)
 *         if not self._min_day_of_month <= self.day_of_month <= 27:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "day_of_month must be "
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2658
 *         int day_of_month
 * 
 *     def __init__(self, n=1, normalize=False, day_of_month=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_day_of_month);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2672
 *             )
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2672, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2672, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2673
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self.day_of_month = state.pop("day_of_month")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2674
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self.day_of_month = state.pop("day_of_month")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2675
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self.day_of_month = state.pop("day_of_month")             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_day_of_month};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2675, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->day_of_month = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2672
 *             )
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2672, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 2672, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2672, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2677
 *         self.day_of_month = state.pop("day_of_month")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":2678
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         return cls(day_of_month=suffix)
 * 
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2677, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 2677, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 2677, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_4_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":2677
 *         self.day_of_month = state.pop("day_of_month")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_4_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2679
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_day_of_month, __pyx_v_suffix) < 0) __PYX_ERR(0, 2679, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2677
 *         self.day_of_month = state.pop("day_of_month")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2681
 *         return cls(day_of_month=suffix)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = f"-{self.day_of_month}"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self) {
  PyObject *__pyx_v_suffix = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2683
 *     @property
 *     def rule_code(self) -> str:
 *         suffix = f"-{self.day_of_month}"             # <<<<<<<<<<<<<<
 *         return self._prefix + suffix
 * 
 */
  __pyx_t_1 = __Pyx_PyUnicode_From_int(__pyx_v_self->day_of_month, 0, ' ', 'd'); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__38, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_suffix = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2684
 *     def rule_code(self) -> str:
 *         suffix = f"-{self.day_of_month}"
 *         return self._prefix + suffix             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_suffix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2681
 *         return cls(day_of_month=suffix)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = f"-{self.day_of_month}"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_suffix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2686
 *         return self._prefix + suffix
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         is_start = isinstance(self, SemiMonthBegin)
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2686, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2686, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2686, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 2687, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_6_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  int __pyx_v_is_start;
  PyObject *__pyx_v_n = NULL;
  __pyx_t_5numpy_int32_t __pyx_v_days_in_month;
  PyObject *__pyx_v_months = NULL;
  long __pyx_v_to_day;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __pyx_t_5numpy_int32_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  long __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2688
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         is_start = isinstance(self, SemiMonthBegin)             # <<<<<<<<<<<<<<
 * 
 *         # shift `other` to self.day_of_month, incrementing `n` if necessary
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin); 
  __pyx_v_is_start = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":2691
 * 
 *         # shift `other` to self.day_of_month, incrementing `n` if necessary
 *         n = roll_convention(other.day, self.n, self.day_of_month)             # <<<<<<<<<<<<<<
 * 
 *         days_in_month = get_days_in_month(other.year, other.month)
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2691, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_t_2, __pyx_v_self->__pyx_base.__pyx_base.n, __pyx_v_self->day_of_month, 0); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2691, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_n = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2693
 *         n = roll_convention(other.day, self.n, self.day_of_month)
 * 
 *         days_in_month = get_days_in_month(other.year, other.month)             # <<<<<<<<<<<<<<
 *         # For SemiMonthBegin on other.day == 1 and
 *         # SemiMonthEnd on other.day == days_in_month,
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2693, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2693, __pyx_L1_error)
  __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_t_3, __pyx_t_2, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2693, __pyx_L1_error)
  __pyx_v_days_in_month = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2699
 *         # incrementing/decrementing `n`, regardless of whether it is
 *         # initially positive.
 *         if is_start and (self.n <= 0 and other.day == 1):             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):
 */
  if (__pyx_v_is_start) {
  } else {
    __pyx_t_1 = __pyx_v_is_start;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_self->__pyx_base.__pyx_base.n <= 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2699, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_2 == 1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2700
 *         # initially positive.
 *         if is_start and (self.n <= 0 and other.day == 1):
 *             n -= 1             # <<<<<<<<<<<<<<
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):
 *             n += 1
 */
    __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2700, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2699
 *         # incrementing/decrementing `n`, regardless of whether it is
 *         # initially positive.
 *         if is_start and (self.n <= 0 and other.day == 1):             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2701
 *         if is_start and (self.n <= 0 and other.day == 1):
 *             n -= 1
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):             # <<<<<<<<<<<<<<
 *             n += 1
 * 
 */
  __pyx_t_6 = (!__pyx_v_is_start);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_self->__pyx_base.__pyx_base.n > 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2701, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_2 == __pyx_v_days_in_month);
  __pyx_t_1 = __pyx_t_6;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2702
 *             n -= 1
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):
 *             n += 1             # <<<<<<<<<<<<<<
 * 
 *         if is_start:
 */
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2701
 *         if is_start and (self.n <= 0 and other.day == 1):
 *             n -= 1
 *         elif (not is_start) and (self.n > 0 and other.day == days_in_month):             # <<<<<<<<<<<<<<
 *             n += 1
 * 
 */
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":2704
 *             n += 1
 * 
 *         if is_start:             # <<<<<<<<<<<<<<
 *             months = n // 2 + n % 2
 *             to_day = 1 if n % 2 else self.day_of_month
 */
  if (__pyx_v_is_start) {

    /* "pandas/_libs/tslibs/offsets.pyx":2705
 * 
 *         if is_start:
 *             months = n // 2 + n % 2             # <<<<<<<<<<<<<<
 *             to_day = 1 if n % 2 else self.day_of_month
 *         else:
 */
    __pyx_t_4 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_n, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyInt_RemainderObjC(__pyx_v_n, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyNumber_Add(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_months = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2706
 *         if is_start:
 *             months = n // 2 + n % 2
 *             to_day = 1 if n % 2 else self.day_of_month             # <<<<<<<<<<<<<<
 *         else:
 *             months = n // 2
 */
    __pyx_t_8 = __Pyx_PyInt_RemainderObjC(__pyx_v_n, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2706, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_1) {
      __pyx_t_9 = 1;
    } else {
      __pyx_t_9 = __pyx_v_self->day_of_month;
    }
    __pyx_v_to_day = __pyx_t_9;

    /* "pandas/_libs/tslibs/offsets.pyx":2704
 *             n += 1
 * 
 *         if is_start:             # <<<<<<<<<<<<<<
 *             months = n // 2 + n % 2
 *             to_day = 1 if n % 2 else self.day_of_month
 */
    goto __pyx_L10;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2708
 *             to_day = 1 if n % 2 else self.day_of_month
 *         else:
 *             months = n // 2             # <<<<<<<<<<<<<<
 *             to_day = 31 if n % 2 else self.day_of_month
 * 
 */
  /*else*/ {
    __pyx_t_8 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_n, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2708, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_v_months = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2709
 *         else:
 *             months = n // 2
 *             to_day = 31 if n % 2 else self.day_of_month             # <<<<<<<<<<<<<<
 * 
 *         return shift_month(other, months, to_day)
 */
    __pyx_t_8 = __Pyx_PyInt_RemainderObjC(__pyx_v_n, __pyx_int_2, 2, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2709, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_1) {
      __pyx_t_9 = 31;
    } else {
      __pyx_t_9 = __pyx_v_self->day_of_month;
    }
    __pyx_v_to_day = __pyx_t_9;
  }
  __pyx_L10:;

  /* "pandas/_libs/tslibs/offsets.pyx":2711
 *             to_day = 31 if n % 2 else self.day_of_month
 * 
 *         return shift_month(other, months, to_day)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyInt_From_long(__pyx_v_to_day); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = NULL;
  __pyx_t_2 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_2 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_10, ((PyObject *)__pyx_v_other), __pyx_v_months, __pyx_t_4};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_2, 3+__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 2711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 2711, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_8);
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2686
 *         return self._prefix + suffix
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         is_start = isinstance(self, SemiMonthBegin)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_months);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2713
 *         return shift_month(other, months, to_day)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2713, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 2713, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2713, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_8_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  PyArrayObject *__pyx_v_i8other = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_res_val;
  PyArrayObject *__pyx_v_out = 0;
  npy_datetimestruct __pyx_v_dts;
  int __pyx_v_months;
  int __pyx_v_to_day;
  int __pyx_v_nadj;
  int __pyx_v_n;
  int __pyx_v_days_in_month;
  int __pyx_v_day;
  int __pyx_v_anchor_dom;
  int __pyx_v_is_start;
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyArrayMultiIterObject *__pyx_v_mi = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  npy_intp *__pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_t_8;
  NPY_DATETIMEUNIT __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  __pyx_t_5numpy_int32_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2718
 *     def _apply_array(self, dtarr):
 *         cdef:
 *             ndarray i8other = dtarr.view("i8")             # <<<<<<<<<<<<<<
 *             Py_ssize_t i, count = dtarr.size
 *             int64_t val, res_val
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_i8};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2718, __pyx_L1_error)
  __pyx_v_i8other = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2719
 *         cdef:
 *             ndarray i8other = dtarr.view("i8")
 *             Py_ssize_t i, count = dtarr.size             # <<<<<<<<<<<<<<
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_1); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 2719, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_count = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2722
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0             # <<<<<<<<<<<<<<
 *             )
 *             npy_datetimestruct dts
 */
  __pyx_t_4 = __pyx_f_5numpy_7ndarray_4ndim_ndim(__pyx_v_i8other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2722, __pyx_L1_error)
  __pyx_t_6 = __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_i8other); if (unlikely(__pyx_t_6 == ((npy_intp *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 2722, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2721
 *             Py_ssize_t i, count = dtarr.size
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(             # <<<<<<<<<<<<<<
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0
 *             )
 */
  __pyx_t_1 = PyArray_EMPTY(__pyx_t_4, __pyx_t_6, NPY_INT64, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2721, __pyx_L1_error)
  __pyx_v_out = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2725
 *             )
 *             npy_datetimestruct dts
 *             int months, to_day, nadj, n = self.n             # <<<<<<<<<<<<<<
 *             int days_in_month, day, anchor_dom = self.day_of_month
 *             bint is_start = isinstance(self, SemiMonthBegin)
 */
  __pyx_t_7 = __pyx_v_self->__pyx_base.__pyx_base.n;
  __pyx_v_n = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2726
 *             npy_datetimestruct dts
 *             int months, to_day, nadj, n = self.n
 *             int days_in_month, day, anchor_dom = self.day_of_month             # <<<<<<<<<<<<<<
 *             bint is_start = isinstance(self, SemiMonthBegin)
 *             NPY_DATETIMEUNIT reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_t_4 = __pyx_v_self->day_of_month;
  __pyx_v_anchor_dom = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":2727
 *             int months, to_day, nadj, n = self.n
 *             int days_in_month, day, anchor_dom = self.day_of_month
 *             bint is_start = isinstance(self, SemiMonthBegin)             # <<<<<<<<<<<<<<
 *             NPY_DATETIMEUNIT reso = get_unit_from_dtype(dtarr.dtype)
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 */
  __pyx_t_8 = __Pyx_TypeCheck(((PyObject *)__pyx_v_self), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin); 
  __pyx_v_is_start = __pyx_t_8;

  /* "pandas/_libs/tslibs/offsets.pyx":2728
 *             int days_in_month, day, anchor_dom = self.day_of_month
 *             bint is_start = isinstance(self, SemiMonthBegin)
 *             NPY_DATETIMEUNIT reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 2728, __pyx_L1_error)
  __pyx_t_9 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_reso = __pyx_t_9;

  /* "pandas/_libs/tslibs/offsets.pyx":2729
 *             bint is_start = isinstance(self, SemiMonthBegin)
 *             NPY_DATETIMEUNIT reso = get_unit_from_dtype(dtarr.dtype)
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  __pyx_t_1 = __pyx_f_5numpy_PyArray_MultiIterNew2(((PyObject *)__pyx_v_out), ((PyObject *)__pyx_v_i8other)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5numpy_broadcast))))) __PYX_ERR(0, 2729, __pyx_L1_error)
  __pyx_v_mi = ((PyArrayMultiIterObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2731
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":2732
 * 
 *         with nogil:
 *             for i in range(count):             # <<<<<<<<<<<<<<
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 */
        __pyx_t_5 = __pyx_v_count;
        __pyx_t_10 = __pyx_t_5;
        for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
          __pyx_v_i = __pyx_t_11;

          /* "pandas/_libs/tslibs/offsets.pyx":2734
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *                 if val == NPY_NAT:
 */
          __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

          /* "pandas/_libs/tslibs/offsets.pyx":2736
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 * 
 */
          __pyx_t_8 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
          if (__pyx_t_8) {

            /* "pandas/_libs/tslibs/offsets.pyx":2737
 * 
 *                 if val == NPY_NAT:
 *                     res_val = NPY_NAT             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
            __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

            /* "pandas/_libs/tslibs/offsets.pyx":2736
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 * 
 */
            goto __pyx_L8;
          }

          /* "pandas/_libs/tslibs/offsets.pyx":2740
 * 
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                     day = dts.day
 * 
 */
          /*else*/ {
            pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

            /* "pandas/_libs/tslibs/offsets.pyx":2741
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                     day = dts.day             # <<<<<<<<<<<<<<
 * 
 *                     # Adjust so that we are always looking at self.day_of_month,
 */
            __pyx_t_12 = __pyx_v_dts.day;
            __pyx_v_day = __pyx_t_12;

            /* "pandas/_libs/tslibs/offsets.pyx":2745
 *                     # Adjust so that we are always looking at self.day_of_month,
 *                     #  incrementing/decrementing n if necessary.
 *                     nadj = roll_convention(day, n, anchor_dom)             # <<<<<<<<<<<<<<
 * 
 *                     days_in_month = get_days_in_month(dts.year, dts.month)
 */
            __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_v_day, __pyx_v_n, __pyx_v_anchor_dom, 0); if (unlikely(__pyx_t_4 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2745, __pyx_L4_error)
            __pyx_v_nadj = __pyx_t_4;

            /* "pandas/_libs/tslibs/offsets.pyx":2747
 *                     nadj = roll_convention(day, n, anchor_dom)
 * 
 *                     days_in_month = get_days_in_month(dts.year, dts.month)             # <<<<<<<<<<<<<<
 *                     # For SemiMonthBegin on other.day == 1 and
 *                     #  SemiMonthEnd on other.day == days_in_month,
 */
            __pyx_t_12 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_dts.year, __pyx_v_dts.month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2747, __pyx_L4_error)
            __pyx_v_days_in_month = __pyx_t_12;

            /* "pandas/_libs/tslibs/offsets.pyx":2753
 *                     #  incrementing/decrementing `n`, regardless of whether it is
 *                     #  initially positive.
 *                     if is_start and (n <= 0 and day == 1):             # <<<<<<<<<<<<<<
 *                         nadj -= 1
 *                     elif (not is_start) and (n > 0 and day == days_in_month):
 */
            if (__pyx_v_is_start) {
            } else {
              __pyx_t_8 = __pyx_v_is_start;
              goto __pyx_L10_bool_binop_done;
            }
            __pyx_t_13 = (__pyx_v_n <= 0);
            if (__pyx_t_13) {
            } else {
              __pyx_t_8 = __pyx_t_13;
              goto __pyx_L10_bool_binop_done;
            }
            __pyx_t_13 = (__pyx_v_day == 1);
            __pyx_t_8 = __pyx_t_13;
            __pyx_L10_bool_binop_done:;
            if (__pyx_t_8) {

              /* "pandas/_libs/tslibs/offsets.pyx":2754
 *                     #  initially positive.
 *                     if is_start and (n <= 0 and day == 1):
 *                         nadj -= 1             # <<<<<<<<<<<<<<
 *                     elif (not is_start) and (n > 0 and day == days_in_month):
 *                         nadj += 1
 */
              __pyx_v_nadj = (__pyx_v_nadj - 1);

              /* "pandas/_libs/tslibs/offsets.pyx":2753
 *                     #  incrementing/decrementing `n`, regardless of whether it is
 *                     #  initially positive.
 *                     if is_start and (n <= 0 and day == 1):             # <<<<<<<<<<<<<<
 *                         nadj -= 1
 *                     elif (not is_start) and (n > 0 and day == days_in_month):
 */
              goto __pyx_L9;
            }

            /* "pandas/_libs/tslibs/offsets.pyx":2755
 *                     if is_start and (n <= 0 and day == 1):
 *                         nadj -= 1
 *                     elif (not is_start) and (n > 0 and day == days_in_month):             # <<<<<<<<<<<<<<
 *                         nadj += 1
 * 
 */
            __pyx_t_13 = (!__pyx_v_is_start);
            if (__pyx_t_13) {
            } else {
              __pyx_t_8 = __pyx_t_13;
              goto __pyx_L13_bool_binop_done;
            }
            __pyx_t_13 = (__pyx_v_n > 0);
            if (__pyx_t_13) {
            } else {
              __pyx_t_8 = __pyx_t_13;
              goto __pyx_L13_bool_binop_done;
            }
            __pyx_t_13 = (__pyx_v_day == __pyx_v_days_in_month);
            __pyx_t_8 = __pyx_t_13;
            __pyx_L13_bool_binop_done:;
            if (__pyx_t_8) {

              /* "pandas/_libs/tslibs/offsets.pyx":2756
 *                         nadj -= 1
 *                     elif (not is_start) and (n > 0 and day == days_in_month):
 *                         nadj += 1             # <<<<<<<<<<<<<<
 * 
 *                     if is_start:
 */
              __pyx_v_nadj = (__pyx_v_nadj + 1);

              /* "pandas/_libs/tslibs/offsets.pyx":2755
 *                     if is_start and (n <= 0 and day == 1):
 *                         nadj -= 1
 *                     elif (not is_start) and (n > 0 and day == days_in_month):             # <<<<<<<<<<<<<<
 *                         nadj += 1
 * 
 */
            }
            __pyx_L9:;

            /* "pandas/_libs/tslibs/offsets.pyx":2758
 *                         nadj += 1
 * 
 *                     if is_start:             # <<<<<<<<<<<<<<
 *                         # See also: SemiMonthBegin._apply
 *                         months = nadj // 2 + nadj % 2
 */
            if (__pyx_v_is_start) {

              /* "pandas/_libs/tslibs/offsets.pyx":2760
 *                     if is_start:
 *                         # See also: SemiMonthBegin._apply
 *                         months = nadj // 2 + nadj % 2             # <<<<<<<<<<<<<<
 *                         to_day = 1 if nadj % 2 else anchor_dom
 * 
 */
              __pyx_v_months = (__Pyx_div_long(__pyx_v_nadj, 2) + __Pyx_mod_long(__pyx_v_nadj, 2));

              /* "pandas/_libs/tslibs/offsets.pyx":2761
 *                         # See also: SemiMonthBegin._apply
 *                         months = nadj // 2 + nadj % 2
 *                         to_day = 1 if nadj % 2 else anchor_dom             # <<<<<<<<<<<<<<
 * 
 *                     else:
 */
              __pyx_t_8 = (__Pyx_mod_long(__pyx_v_nadj, 2) != 0);
              if (__pyx_t_8) {
                __pyx_t_4 = 1;
              } else {
                __pyx_t_4 = __pyx_v_anchor_dom;
              }
              __pyx_v_to_day = __pyx_t_4;

              /* "pandas/_libs/tslibs/offsets.pyx":2758
 *                         nadj += 1
 * 
 *                     if is_start:             # <<<<<<<<<<<<<<
 *                         # See also: SemiMonthBegin._apply
 *                         months = nadj // 2 + nadj % 2
 */
              goto __pyx_L16;
            }

            /* "pandas/_libs/tslibs/offsets.pyx":2765
 *                     else:
 *                         # See also: SemiMonthEnd._apply
 *                         months = nadj // 2             # <<<<<<<<<<<<<<
 *                         to_day = 31 if nadj % 2 else anchor_dom
 * 
 */
            /*else*/ {
              __pyx_v_months = __Pyx_div_long(__pyx_v_nadj, 2);

              /* "pandas/_libs/tslibs/offsets.pyx":2766
 *                         # See also: SemiMonthEnd._apply
 *                         months = nadj // 2
 *                         to_day = 31 if nadj % 2 else anchor_dom             # <<<<<<<<<<<<<<
 * 
 *                     dts.year = year_add_months(dts, months)
 */
              __pyx_t_8 = (__Pyx_mod_long(__pyx_v_nadj, 2) != 0);
              if (__pyx_t_8) {
                __pyx_t_4 = 31;
              } else {
                __pyx_t_4 = __pyx_v_anchor_dom;
              }
              __pyx_v_to_day = __pyx_t_4;
            }
            __pyx_L16:;

            /* "pandas/_libs/tslibs/offsets.pyx":2768
 *                         to_day = 31 if nadj % 2 else anchor_dom
 * 
 *                     dts.year = year_add_months(dts, months)             # <<<<<<<<<<<<<<
 *                     dts.month = month_add_months(dts, months)
 *                     days_in_month = get_days_in_month(dts.year, dts.month)
 */
            __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(__pyx_v_dts, __pyx_v_months); if (unlikely(__pyx_t_4 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2768, __pyx_L4_error)
            __pyx_v_dts.year = __pyx_t_4;

            /* "pandas/_libs/tslibs/offsets.pyx":2769
 * 
 *                     dts.year = year_add_months(dts, months)
 *                     dts.month = month_add_months(dts, months)             # <<<<<<<<<<<<<<
 *                     days_in_month = get_days_in_month(dts.year, dts.month)
 *                     dts.day = min(to_day, days_in_month)
 */
            __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(__pyx_v_dts, __pyx_v_months); if (unlikely(__pyx_t_4 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2769, __pyx_L4_error)
            __pyx_v_dts.month = __pyx_t_4;

            /* "pandas/_libs/tslibs/offsets.pyx":2770
 *                     dts.year = year_add_months(dts, months)
 *                     dts.month = month_add_months(dts, months)
 *                     days_in_month = get_days_in_month(dts.year, dts.month)             # <<<<<<<<<<<<<<
 *                     dts.day = min(to_day, days_in_month)
 * 
 */
            __pyx_t_12 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_dts.year, __pyx_v_dts.month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2770, __pyx_L4_error)
            __pyx_v_days_in_month = __pyx_t_12;

            /* "pandas/_libs/tslibs/offsets.pyx":2771
 *                     dts.month = month_add_months(dts, months)
 *                     days_in_month = get_days_in_month(dts.year, dts.month)
 *                     dts.day = min(to_day, days_in_month)             # <<<<<<<<<<<<<<
 * 
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)
 */
            __pyx_t_4 = __pyx_v_days_in_month;
            __pyx_t_14 = __pyx_v_to_day;
            __pyx_t_8 = (__pyx_t_4 < __pyx_t_14);
            if (__pyx_t_8) {
              __pyx_t_15 = __pyx_t_4;
            } else {
              __pyx_t_15 = __pyx_t_14;
            }
            __pyx_v_dts.day = __pyx_t_15;

            /* "pandas/_libs/tslibs/offsets.pyx":2773
 *                     dts.day = min(to_day, days_in_month)
 * 
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)             # <<<<<<<<<<<<<<
 * 
 *                 # Analogous to: out[i] = res_val
 */
            __pyx_v_res_val = npy_datetimestruct_to_datetime(__pyx_v_reso, (&__pyx_v_dts));
          }
          __pyx_L8:;

          /* "pandas/_libs/tslibs/offsets.pyx":2776
 * 
 *                 # Analogous to: out[i] = res_val
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 */
          (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

          /* "pandas/_libs/tslibs/offsets.pyx":2778
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *         return out
 */
          PyArray_MultiIter_NEXT(__pyx_v_mi);
        }
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2731
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2780
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 * 
 *         return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2713
 *         return shift_month(other, months, to_day)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_i8other);
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XDECREF((PyObject *)__pyx_v_mi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2656
 * 
 *     cdef readonly:
 *         int day_of_month             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, day_of_month=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->day_of_month); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthOffset.day_of_month.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2816
 *     _min_day_of_month = 1
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2816, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2816, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2816, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthEnd.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2816, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  __pyx_t_5numpy_int32_t __pyx_v_days_in_month;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  __pyx_t_5numpy_int32_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2817
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         days_in_month = get_days_in_month(dt.year, dt.month)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2817, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2818
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         days_in_month = get_days_in_month(dt.year, dt.month)
 *         return dt.day in (self.day_of_month, days_in_month)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2817
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         days_in_month = get_days_in_month(dt.year, dt.month)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2819
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         days_in_month = get_days_in_month(dt.year, dt.month)             # <<<<<<<<<<<<<<
 *         return dt.day in (self.day_of_month, days_in_month)
 * 
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2819, __pyx_L1_error)
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2819, __pyx_L1_error)
  __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_t_4, __pyx_t_5, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2819, __pyx_L1_error)
  __pyx_v_days_in_month = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2820
 *             return False
 *         days_in_month = get_days_in_month(dt.year, dt.month)
 *         return dt.day in (self.day_of_month, days_in_month)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2820, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_5 == __pyx_v_self->__pyx_base.day_of_month);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_t_5 == __pyx_v_days_in_month);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L6_bool_binop_done:;
  __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 2820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2816
 *     _min_day_of_month = 1
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthEnd.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2842
 *     _prefix = "SMS"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2842, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 2842, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2842, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthBegin.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 2842, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2843
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day in (1, self.day_of_month)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2843, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2844
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return dt.day in (1, self.day_of_month)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2843
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return dt.day in (1, self.day_of_month)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2845
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return dt.day in (1, self.day_of_month)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2845, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_4 == 1);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_t_4 == __pyx_v_self->__pyx_base.day_of_month);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L6_bool_binop_done:;
  __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2842
 *     _prefix = "SMS"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.SemiMonthBegin.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2896
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, weekday=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekday = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekday,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2896, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2896, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2896, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 2896, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekday = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 2896, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2897
 * 
 *     def __init__(self, n=1, normalize=False, weekday=None):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 *         self.weekday = weekday
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2898
 *     def __init__(self, n=1, normalize=False, weekday=None):
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday             # <<<<<<<<<<<<<<
 * 
 *         if self.weekday is not None:
 */
  __Pyx_INCREF(__pyx_v_weekday);
  __Pyx_GIVEREF(__pyx_v_weekday);
  __Pyx_GOTREF(__pyx_v_self->weekday);
  __Pyx_DECREF(__pyx_v_self->weekday);
  __pyx_v_self->weekday = __pyx_v_weekday;

  /* "pandas/_libs/tslibs/offsets.pyx":2900
 *         self.weekday = weekday
 * 
 *         if self.weekday is not None:             # <<<<<<<<<<<<<<
 *             if self.weekday < 0 or self.weekday > 6:
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")
 */
  __pyx_t_5 = (__pyx_v_self->weekday != Py_None);
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":2901
 * 
 *         if self.weekday is not None:
 *             if self.weekday < 0 or self.weekday > 6:             # <<<<<<<<<<<<<<
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")
 * 
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->weekday, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2901, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2901, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_self->weekday, __pyx_int_6, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2901, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 2901, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __pyx_t_6;
    __pyx_L5_bool_binop_done:;
    if (unlikely(__pyx_t_5)) {

      /* "pandas/_libs/tslibs/offsets.pyx":2902
 *         if self.weekday is not None:
 *             if self.weekday < 0 or self.weekday > 6:
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")             # <<<<<<<<<<<<<<
 * 
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7
 */
      __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_self->weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2902, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Day_must_be_0_day_6_got, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2902, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2902, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 2902, __pyx_L1_error)

      /* "pandas/_libs/tslibs/offsets.pyx":2901
 * 
 *         if self.weekday is not None:
 *             if self.weekday < 0 or self.weekday > 6:             # <<<<<<<<<<<<<<
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")
 * 
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2904
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")
 * 
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
    __pyx_t_1 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_W_SUN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_weekday, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_RemainderObjC(__pyx_t_2, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyNumber_Add(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2904, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_self->_period_dtype_code = __pyx_t_4;

    /* "pandas/_libs/tslibs/offsets.pyx":2900
 *         self.weekday = weekday
 * 
 *         if self.weekday is not None:             # <<<<<<<<<<<<<<
 *             if self.weekday < 0 or self.weekday > 6:
 *                 raise ValueError(f"Day must be 0<=day<=6, got {self.weekday}")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2896
 *         int _period_dtype_code
 * 
 *     def __init__(self, n=1, normalize=False, weekday=None):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self.weekday = weekday
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2906
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2906, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2906, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2907
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2907, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 2907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":2908
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self.weekday = state.pop("weekday")
 *         self._cache = state.pop("_cache", {})
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2908, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":2909
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")             # <<<<<<<<<<<<<<
 *         self._cache = state.pop("_cache", {})
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->weekday);
  __Pyx_DECREF(__pyx_v_self->weekday);
  __pyx_v_self->weekday = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2910
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 *         self._cache = state.pop("_cache", {})             # <<<<<<<<<<<<<<
 * 
 *     def is_anchored(self) -> bool:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_n_u_cache, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(0, 2910, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base._cache);
  __pyx_v_self->__pyx_base.__pyx_base._cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2906
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2906, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 2906, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2906, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2912
 *         self._cache = state.pop("_cache", {})
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.weekday is not None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored = {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_anchored", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_anchored", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_4is_anchored(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_4is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_anchored", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2913
 * 
 *     def is_anchored(self) -> bool:
 *         return self.n == 1 and self.weekday is not None             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base.n == 1);
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2913, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->weekday != Py_None);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2912
 *         self._cache = state.pop("_cache", {})
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.weekday is not None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.is_anchored", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2915
 *         return self.n == 1 and self.weekday is not None
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.weekday is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2915, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 2915, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2915, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_6_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_6_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_otherDay = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 0);
  __Pyx_INCREF(__pyx_v_other);

  /* "pandas/_libs/tslibs/offsets.pyx":2917
 *     @apply_wraps
 *     def _apply(self, other):
 *         if self.weekday is None:             # <<<<<<<<<<<<<<
 *             return other + self.n * self._inc
 * 
 */
  __pyx_t_1 = (__pyx_v_self->weekday == Py_None);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2918
 *     def _apply(self, other):
 *         if self.weekday is None:
 *             return other + self.n * self._inc             # <<<<<<<<<<<<<<
 * 
 *         if not PyDateTime_Check(other):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_inc_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyNumber_Multiply(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_v_other, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2917
 *     @apply_wraps
 *     def _apply(self, other):
 *         if self.weekday is None:             # <<<<<<<<<<<<<<
 *             return other + self.n * self._inc
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2920
 *             return other + self.n * self._inc
 * 
 *         if not PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f"Cannot add {type(other).__name__} to {type(self).__name__}"
 */
  __pyx_t_1 = (!PyDateTime_Check(__pyx_v_other));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":2922
 *         if not PyDateTime_Check(other):
 *             raise TypeError(
 *                 f"Cannot add {type(other).__name__} to {type(self).__name__}"             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = 0;
    __pyx_t_6 = 127;
    __Pyx_INCREF(__pyx_kp_u_Cannot_add);
    __pyx_t_5 += 11;
    __Pyx_GIVEREF(__pyx_kp_u_Cannot_add);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Cannot_add);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_other)), __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_kp_u_to);
    __pyx_t_5 += 4;
    __Pyx_GIVEREF(__pyx_kp_u_to);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_to);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_6;
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_3, 4, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2921
 * 
 *         if not PyDateTime_Check(other):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f"Cannot add {type(other).__name__} to {type(self).__name__}"
 *             )
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2921, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 2921, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":2920
 *             return other + self.n * self._inc
 * 
 *         if not PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f"Cannot add {type(other).__name__} to {type(self).__name__}"
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2925
 *             )
 * 
 *         k = self.n             # <<<<<<<<<<<<<<
 *         otherDay = other.weekday()
 *         if otherDay != self.weekday:
 */
  __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_k = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2926
 * 
 *         k = self.n
 *         otherDay = other.weekday()             # <<<<<<<<<<<<<<
 *         if otherDay != self.weekday:
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_weekday); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2926, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_otherDay = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2927
 *         k = self.n
 *         otherDay = other.weekday()
 *         if otherDay != self.weekday:             # <<<<<<<<<<<<<<
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 *             if k > 0:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_otherDay, __pyx_v_self->weekday, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2927, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2927, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2928
 *         otherDay = other.weekday()
 *         if otherDay != self.weekday:
 *             other = other + timedelta((self.weekday - otherDay) % 7)             # <<<<<<<<<<<<<<
 *             if k > 0:
 *                 k -= 1
 */
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_self->weekday, __pyx_v_otherDay); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_RemainderObjC(__pyx_t_3, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_other, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2929
 *         if otherDay != self.weekday:
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 *             if k > 0:             # <<<<<<<<<<<<<<
 *                 k -= 1
 * 
 */
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_k, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2929, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 2929, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":2930
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 *             if k > 0:
 *                 k -= 1             # <<<<<<<<<<<<<<
 * 
 *         return other + timedelta(weeks=k)
 */
      __pyx_t_4 = __Pyx_PyInt_SubtractObjC(__pyx_v_k, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2930, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_k, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":2929
 *         if otherDay != self.weekday:
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 *             if k > 0:             # <<<<<<<<<<<<<<
 *                 k -= 1
 * 
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":2927
 *         k = self.n
 *         otherDay = other.weekday()
 *         if otherDay != self.weekday:             # <<<<<<<<<<<<<<
 *             other = other + timedelta((self.weekday - otherDay) % 7)
 *             if k > 0:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2932
 *                 k -= 1
 * 
 *         return other + timedelta(weeks=k)             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_weeks, __pyx_v_k) < 0) __PYX_ERR(0, 2932, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_v_other, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2915
 *         return self.n == 1 and self.weekday is not None
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.weekday is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_otherDay);
  __Pyx_XDECREF(__pyx_v_other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2934
 *         return other + timedelta(weeks=k)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array = {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_dtarr = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtarr,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtarr)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2934, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply_array") < 0)) __PYX_ERR(0, 2934, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dtarr = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply_array", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 2934, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_8_apply_array(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self), __pyx_v_dtarr);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_8_apply_array(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyObject *__pyx_v_dtarr) {
  PyDateTime_Delta *__pyx_v_td = NULL;
  PyObject *__pyx_v_td64 = NULL;
  NPY_DATETIMEUNIT __pyx_v_reso;
  PyObject *__pyx_v_i8other = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  NPY_DATETIMEUNIT __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply_array", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2936
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:             # <<<<<<<<<<<<<<
 *             td = timedelta(days=7 * self.n)
 *             td64 = np.timedelta64(td, "ns")
 */
  __pyx_t_1 = (__pyx_v_self->weekday == Py_None);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":2937
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:
 *             td = timedelta(days=7 * self.n)             # <<<<<<<<<<<<<<
 *             td64 = np.timedelta64(td, "ns")
 *             return dtarr + td64
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_From_npy_int64((7 * __pyx_v_self->__pyx_base.__pyx_base.n)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_days, __pyx_t_3) < 0) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_td = ((PyDateTime_Delta *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2938
 *         if self.weekday is None:
 *             td = timedelta(days=7 * self.n)
 *             td64 = np.timedelta64(td, "ns")             # <<<<<<<<<<<<<<
 *             return dtarr + td64
 *         else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_timedelta64); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_2, ((PyObject *)__pyx_v_td), __pyx_n_u_ns};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2938, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_td64 = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2939
 *             td = timedelta(days=7 * self.n)
 *             td64 = np.timedelta64(td, "ns")
 *             return dtarr + td64             # <<<<<<<<<<<<<<
 *         else:
 *             reso = get_unit_from_dtype(dtarr.dtype)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyNumber_Add(__pyx_v_dtarr, __pyx_v_td64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2939, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":2936
 *     @apply_array_wraps
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:             # <<<<<<<<<<<<<<
 *             td = timedelta(days=7 * self.n)
 *             td64 = np.timedelta64(td, "ns")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2941
 *             return dtarr + td64
 *         else:
 *             reso = get_unit_from_dtype(dtarr.dtype)             # <<<<<<<<<<<<<<
 *             i8other = dtarr.view("i8")
 *             return self._end_apply_index(i8other, reso=reso)
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_dtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(0, 2941, __pyx_L1_error)
    __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype(((PyArray_Descr *)__pyx_t_3)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 2941, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_reso = __pyx_t_6;

    /* "pandas/_libs/tslibs/offsets.pyx":2942
 *         else:
 *             reso = get_unit_from_dtype(dtarr.dtype)
 *             i8other = dtarr.view("i8")             # <<<<<<<<<<<<<<
 *             return self._end_apply_index(i8other, reso=reso)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtarr, __pyx_n_s_view); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2942, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_i8};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2942, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_i8other = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":2943
 *             reso = get_unit_from_dtype(dtarr.dtype)
 *             i8other = dtarr.view("i8")
 *             return self._end_apply_index(i8other, reso=reso)             # <<<<<<<<<<<<<<
 * 
 *     @cython.wraparound(False)
 */
    __Pyx_XDECREF(__pyx_r);
    if (!(likely(((__pyx_v_i8other) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_i8other, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2943, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self->__pyx_vtab)->_end_apply_index(__pyx_v_self, ((PyArrayObject *)__pyx_v_i8other), __pyx_v_reso)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 2943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2934
 *         return other + timedelta(weeks=k)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._apply_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_td);
  __Pyx_XDECREF(__pyx_v_td64);
  __Pyx_XDECREF(__pyx_v_i8other);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2947
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 *     cdef ndarray _end_apply_index(self, ndarray i8other, NPY_DATETIMEUNIT reso):             # <<<<<<<<<<<<<<
 *         """
 *         Add self to the given DatetimeIndex, specialized for case where
 */

static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week__end_apply_index(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyArrayObject *__pyx_v_i8other, NPY_DATETIMEUNIT __pyx_v_reso) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_res_val;
  PyArrayObject *__pyx_v_out = 0;
  npy_datetimestruct __pyx_v_dts;
  int __pyx_v_wday;
  int __pyx_v_days;
  int __pyx_v_weeks;
  int __pyx_v_n;
  int __pyx_v_anchor_weekday;
  __pyx_t_5numpy_int64_t __pyx_v_DAY_PERIODS;
  PyArrayMultiIterObject *__pyx_v_mi = 0;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  npy_intp __pyx_t_1;
  int __pyx_t_2;
  npy_intp *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __pyx_t_5numpy_int64_t __pyx_t_5;
  struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_end_apply_index", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":2962
 *         """
 *         cdef:
 *             Py_ssize_t i, count = i8other.size             # <<<<<<<<<<<<<<
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(
 */
  __pyx_t_1 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_i8other); if (unlikely(__pyx_t_1 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(0, 2962, __pyx_L1_error)
  __pyx_v_count = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":2965
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0             # <<<<<<<<<<<<<<
 *             )
 *             npy_datetimestruct dts
 */
  __pyx_t_2 = __pyx_f_5numpy_7ndarray_4ndim_ndim(__pyx_v_i8other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2965, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_i8other); if (unlikely(__pyx_t_3 == ((npy_intp *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 2965, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2964
 *             Py_ssize_t i, count = i8other.size
 *             int64_t val, res_val
 *             ndarray out = cnp.PyArray_EMPTY(             # <<<<<<<<<<<<<<
 *                 i8other.ndim, i8other.shape, cnp.NPY_INT64, 0
 *             )
 */
  __pyx_t_4 = PyArray_EMPTY(__pyx_t_2, __pyx_t_3, NPY_INT64, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 2964, __pyx_L1_error)
  __pyx_v_out = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2968
 *             )
 *             npy_datetimestruct dts
 *             int wday, days, weeks, n = self.n             # <<<<<<<<<<<<<<
 *             int anchor_weekday = self.weekday
 *             int64_t DAY_PERIODS = periods_per_day(reso)
 */
  __pyx_t_5 = __pyx_v_self->__pyx_base.__pyx_base.n;
  __pyx_v_n = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2969
 *             npy_datetimestruct dts
 *             int wday, days, weeks, n = self.n
 *             int anchor_weekday = self.weekday             # <<<<<<<<<<<<<<
 *             int64_t DAY_PERIODS = periods_per_day(reso)
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 */
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_self->weekday); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 2969, __pyx_L1_error)
  __pyx_v_anchor_weekday = __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":2970
 *             int wday, days, weeks, n = self.n
 *             int anchor_weekday = self.weekday
 *             int64_t DAY_PERIODS = periods_per_day(reso)             # <<<<<<<<<<<<<<
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 */
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.reso = __pyx_v_reso;
  __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_6dtypes_periods_per_day(0, &__pyx_t_6); if (unlikely(__pyx_t_5 == ((__pyx_t_5numpy_int64_t)-1LL) && PyErr_Occurred())) __PYX_ERR(0, 2970, __pyx_L1_error)
  __pyx_v_DAY_PERIODS = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":2971
 *             int anchor_weekday = self.weekday
 *             int64_t DAY_PERIODS = periods_per_day(reso)
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  __pyx_t_4 = __pyx_f_5numpy_PyArray_MultiIterNew2(((PyObject *)__pyx_v_out), ((PyObject *)__pyx_v_i8other)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 2971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_broadcast))))) __PYX_ERR(0, 2971, __pyx_L1_error)
  __pyx_v_mi = ((PyArrayMultiIterObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2973
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":2974
 * 
 *         with nogil:
 *             for i in range(count):             # <<<<<<<<<<<<<<
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 */
        __pyx_t_7 = __pyx_v_count;
        __pyx_t_8 = __pyx_t_7;
        for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
          __pyx_v_i = __pyx_t_9;

          /* "pandas/_libs/tslibs/offsets.pyx":2976
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *                 if val == NPY_NAT:
 */
          __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

          /* "pandas/_libs/tslibs/offsets.pyx":2978
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
          __pyx_t_10 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
          if (__pyx_t_10) {

            /* "pandas/_libs/tslibs/offsets.pyx":2979
 * 
 *                 if val == NPY_NAT:
 *                     res_val = NPY_NAT             # <<<<<<<<<<<<<<
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 */
            __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

            /* "pandas/_libs/tslibs/offsets.pyx":2978
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
            goto __pyx_L8;
          }

          /* "pandas/_libs/tslibs/offsets.pyx":2981
 *                     res_val = NPY_NAT
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                     wday = dayofweek(dts.year, dts.month, dts.day)
 * 
 */
          /*else*/ {
            pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

            /* "pandas/_libs/tslibs/offsets.pyx":2982
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                     wday = dayofweek(dts.year, dts.month, dts.day)             # <<<<<<<<<<<<<<
 * 
 *                     days = 0
 */
            __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_dayofweek(__pyx_v_dts.year, __pyx_v_dts.month, __pyx_v_dts.day); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 2982, __pyx_L4_error)
            __pyx_v_wday = __pyx_t_2;

            /* "pandas/_libs/tslibs/offsets.pyx":2984
 *                     wday = dayofweek(dts.year, dts.month, dts.day)
 * 
 *                     days = 0             # <<<<<<<<<<<<<<
 *                     weeks = n
 *                     if wday != anchor_weekday:
 */
            __pyx_v_days = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":2985
 * 
 *                     days = 0
 *                     weeks = n             # <<<<<<<<<<<<<<
 *                     if wday != anchor_weekday:
 *                         days = (anchor_weekday - wday) % 7
 */
            __pyx_v_weeks = __pyx_v_n;

            /* "pandas/_libs/tslibs/offsets.pyx":2986
 *                     days = 0
 *                     weeks = n
 *                     if wday != anchor_weekday:             # <<<<<<<<<<<<<<
 *                         days = (anchor_weekday - wday) % 7
 *                         if weeks > 0:
 */
            __pyx_t_10 = (__pyx_v_wday != __pyx_v_anchor_weekday);
            if (__pyx_t_10) {

              /* "pandas/_libs/tslibs/offsets.pyx":2987
 *                     weeks = n
 *                     if wday != anchor_weekday:
 *                         days = (anchor_weekday - wday) % 7             # <<<<<<<<<<<<<<
 *                         if weeks > 0:
 *                             weeks -= 1
 */
              __pyx_v_days = __Pyx_mod_long((__pyx_v_anchor_weekday - __pyx_v_wday), 7);

              /* "pandas/_libs/tslibs/offsets.pyx":2988
 *                     if wday != anchor_weekday:
 *                         days = (anchor_weekday - wday) % 7
 *                         if weeks > 0:             # <<<<<<<<<<<<<<
 *                             weeks -= 1
 * 
 */
              __pyx_t_10 = (__pyx_v_weeks > 0);
              if (__pyx_t_10) {

                /* "pandas/_libs/tslibs/offsets.pyx":2989
 *                         days = (anchor_weekday - wday) % 7
 *                         if weeks > 0:
 *                             weeks -= 1             # <<<<<<<<<<<<<<
 * 
 *                     res_val = val + (7 * weeks + days) * DAY_PERIODS
 */
                __pyx_v_weeks = (__pyx_v_weeks - 1);

                /* "pandas/_libs/tslibs/offsets.pyx":2988
 *                     if wday != anchor_weekday:
 *                         days = (anchor_weekday - wday) % 7
 *                         if weeks > 0:             # <<<<<<<<<<<<<<
 *                             weeks -= 1
 * 
 */
              }

              /* "pandas/_libs/tslibs/offsets.pyx":2986
 *                     days = 0
 *                     weeks = n
 *                     if wday != anchor_weekday:             # <<<<<<<<<<<<<<
 *                         days = (anchor_weekday - wday) % 7
 *                         if weeks > 0:
 */
            }

            /* "pandas/_libs/tslibs/offsets.pyx":2991
 *                             weeks -= 1
 * 
 *                     res_val = val + (7 * weeks + days) * DAY_PERIODS             # <<<<<<<<<<<<<<
 * 
 *                 # Analogous to: out[i] = res_val
 */
            __pyx_v_res_val = (__pyx_v_val + (((7 * __pyx_v_weeks) + __pyx_v_days) * __pyx_v_DAY_PERIODS));
          }
          __pyx_L8:;

          /* "pandas/_libs/tslibs/offsets.pyx":2994
 * 
 *                 # Analogous to: out[i] = res_val
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 */
          (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

          /* "pandas/_libs/tslibs/offsets.pyx":2996
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *         return out
 */
          PyArray_MultiIter_NEXT(__pyx_v_mi);
        }
      }

      /* "pandas/_libs/tslibs/offsets.pyx":2973
 *             cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, i8other)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":2998
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 * 
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":2947
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 *     cdef ndarray _end_apply_index(self, ndarray i8other, NPY_DATETIMEUNIT reso):             # <<<<<<<<<<<<<<
 *         """
 *         Add self to the given DatetimeIndex, specialized for case where
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._end_apply_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XDECREF((PyObject *)__pyx_v_mi);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3000
 *         return out
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3000, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 3000, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3000, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3000, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_10is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_10is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3001
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.weekday is None:
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3001, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3002
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         elif self.weekday is None:
 *             return True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3001
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         elif self.weekday is None:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3003
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         elif self.weekday is None:             # <<<<<<<<<<<<<<
 *             return True
 *         return dt.weekday() == self.weekday
 */
  __pyx_t_1 = (__pyx_v_self->weekday == Py_None);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3004
 *             return False
 *         elif self.weekday is None:
 *             return True             # <<<<<<<<<<<<<<
 *         return dt.weekday() == self.weekday
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3003
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         elif self.weekday is None:             # <<<<<<<<<<<<<<
 *             return True
 *         return dt.weekday() == self.weekday
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3005
 *         elif self.weekday is None:
 *             return True
 *         return dt.weekday() == self.weekday             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_dt), __pyx_n_s_weekday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3005, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_v_self->weekday, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3005, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3000
 *         return out
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3007
 *         return dt.weekday() == self.weekday
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = ""
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self) {
  PyObject *__pyx_v_suffix = NULL;
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3009
 *     @property
 *     def rule_code(self) -> str:
 *         suffix = ""             # <<<<<<<<<<<<<<
 *         if self.weekday is not None:
 *             weekday = int_to_weekday[self.weekday]
 */
  __Pyx_INCREF(__pyx_kp_u__15);
  __pyx_v_suffix = __pyx_kp_u__15;

  /* "pandas/_libs/tslibs/offsets.pyx":3010
 *     def rule_code(self) -> str:
 *         suffix = ""
 *         if self.weekday is not None:             # <<<<<<<<<<<<<<
 *             weekday = int_to_weekday[self.weekday]
 *             suffix = f"-{weekday}"
 */
  __pyx_t_1 = (__pyx_v_self->weekday != Py_None);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3011
 *         suffix = ""
 *         if self.weekday is not None:
 *             weekday = int_to_weekday[self.weekday]             # <<<<<<<<<<<<<<
 *             suffix = f"-{weekday}"
 *         return self._prefix + suffix
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_int_to_weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_self->weekday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3011, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_weekday = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3012
 *         if self.weekday is not None:
 *             weekday = int_to_weekday[self.weekday]
 *             suffix = f"-{weekday}"             # <<<<<<<<<<<<<<
 *         return self._prefix + suffix
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__38, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3012, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_suffix, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3010
 *     def rule_code(self) -> str:
 *         suffix = ""
 *         if self.weekday is not None:             # <<<<<<<<<<<<<<
 *             weekday = int_to_weekday[self.weekday]
 *             suffix = f"-{weekday}"
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3013
 *             weekday = int_to_weekday[self.weekday]
 *             suffix = f"-{weekday}"
 *         return self._prefix + suffix             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_suffix); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3007
 *         return dt.weekday() == self.weekday
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = ""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_suffix);
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3015
 *         return self._prefix + suffix
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":3016
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         if not suffix:
 *             weekday = None
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3015, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 3015, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 3015, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_12_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":3015
 *         return self._prefix + suffix
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_12_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3017
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             weekday = None
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3017, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":3018
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 *             weekday = None             # <<<<<<<<<<<<<<
 *         else:
 *             weekday = weekday_to_int[suffix]
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_weekday = Py_None;

    /* "pandas/_libs/tslibs/offsets.pyx":3017
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             weekday = None
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3020
 *             weekday = None
 *         else:
 *             weekday = weekday_to_int[suffix]             # <<<<<<<<<<<<<<
 *         return cls(weekday=weekday)
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_weekday_to_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_suffix); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_weekday = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3021
 *         else:
 *             weekday = weekday_to_int[suffix]
 *         return cls(weekday=weekday)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_weekday, __pyx_v_weekday) < 0) __PYX_ERR(0, 3021, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3015
 *         return self._prefix + suffix
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2893
 * 
 *     cdef readonly:
 *         object weekday  # int or None             # <<<<<<<<<<<<<<
 *         int _period_dtype_code
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->weekday);
  __pyx_r = __pyx_v_self->weekday;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":2894
 *     cdef readonly:
 *         object weekday  # int or None
 *         int _period_dtype_code             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, weekday=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_period_dtype_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Week._period_dtype_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3055
 *     _attributes = tuple(["n", "normalize", "week", "weekday"])
 * 
 *     def __init__(self, n=1, normalize=False, week=0, weekday=0):             # <<<<<<<<<<<<<<
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = week
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_week = 0;
  PyObject *__pyx_v_weekday = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_week,&__pyx_n_s_weekday,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_week);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3055, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3055, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_week = values[2];
    __pyx_v_weekday = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 4, __pyx_nargs); __PYX_ERR(0, 3055, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_week, __pyx_v_weekday);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_week, PyObject *__pyx_v_weekday) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3056
 * 
 *     def __init__(self, n=1, normalize=False, week=0, weekday=0):
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)             # <<<<<<<<<<<<<<
 *         self.week = week
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3056, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3057
 *     def __init__(self, n=1, normalize=False, week=0, weekday=0):
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = week             # <<<<<<<<<<<<<<
 * 
 *         if self.week < 0 or self.week > 3:
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_week); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3057, __pyx_L1_error)
  __pyx_v_self->__pyx_base.week = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3059
 *         self.week = week
 * 
 *         if self.week < 0 or self.week > 3:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 */
  __pyx_t_6 = (__pyx_v_self->__pyx_base.week < 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__pyx_v_self->__pyx_base.week > 3);
  __pyx_t_5 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3060
 * 
 *         if self.week < 0 or self.week > 3:
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
    __pyx_t_1 = __Pyx_PyUnicode_From_int(__pyx_v_self->__pyx_base.week, 0, ' ', 'd'); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Week_must_be_0_week_3_got, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3060, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3060, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3059
 *         self.week = week
 * 
 *         if self.week < 0 or self.week > 3:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3055
 *     _attributes = tuple(["n", "normalize", "week", "weekday"])
 * 
 *     def __init__(self, n=1, normalize=False, week=0, weekday=0):             # <<<<<<<<<<<<<<
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = week
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3062
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3062, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3062, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3063
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3063, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":3064
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self.weekday = state.pop("weekday")
 *         self.week = state.pop("week")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3064, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":3065
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")             # <<<<<<<<<<<<<<
 *         self.week = state.pop("week")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.weekday = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":3066
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 *         self.week = state.pop("week")             # <<<<<<<<<<<<<<
 * 
 *     def _get_offset_day(self, other: datetime) -> int:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_week};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3066, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3066, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.week = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":3062
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3062, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3062, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3062, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3068
 *         self.week = state.pop("week")
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day, "\n        Find the day in the same month as other that has the same\n        weekday as self.weekday and is the self.week'th such day in the month.\n\n        Parameters\n        ----------\n        other : datetime\n\n        Returns\n        -------\n        day : int\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day = {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_offset_day (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3068, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_offset_day") < 0)) __PYX_ERR(0, 3068, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_offset_day", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3068, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3068, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyDateTime_DateTime *__pyx_v_mstart = NULL;
  PyObject *__pyx_v_wday = NULL;
  PyObject *__pyx_v_shift_days = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_offset_day", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3081
 *         day : int
 *         """
 *         mstart = datetime(other.year, other.month, 1)             # <<<<<<<<<<<<<<
 *         wday = mstart.weekday()
 *         shift_days = (self.weekday - wday) % 7
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3081, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3081, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 3081, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3)) __PYX_ERR(0, 3081, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_int_1)) __PYX_ERR(0, 3081, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_mstart = ((PyDateTime_DateTime *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3082
 *         """
 *         mstart = datetime(other.year, other.month, 1)
 *         wday = mstart.weekday()             # <<<<<<<<<<<<<<
 *         shift_days = (self.weekday - wday) % 7
 *         return 1 + shift_days + self.week * 7
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_mstart), __pyx_n_s_weekday); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  __pyx_t_1 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_1 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_1, 0+__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_wday = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3083
 *         mstart = datetime(other.year, other.month, 1)
 *         wday = mstart.weekday()
 *         shift_days = (self.weekday - wday) % 7             # <<<<<<<<<<<<<<
 *         return 1 + shift_days + self.week * 7
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.weekday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_Subtract(__pyx_t_3, __pyx_v_wday); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_RemainderObjC(__pyx_t_4, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_shift_days = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3084
 *         wday = mstart.weekday()
 *         shift_days = (self.weekday - wday) % 7
 *         return 1 + shift_days + self.week * 7             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_AddCObj(__pyx_int_1, __pyx_v_shift_days, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_long((__pyx_v_self->__pyx_base.week * 7)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyNumber_Add(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_2))) __PYX_ERR(0, 3084, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3068
 *         self.week = state.pop("week")
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_mstart);
  __Pyx_XDECREF(__pyx_v_wday);
  __Pyx_XDECREF(__pyx_v_shift_days);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3086
 *         return 1 + shift_days + self.week * 7
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":3087
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         if not suffix:
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3086, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 3086, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 3086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_6_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":3086
 *         return 1 + shift_days + self.week * 7
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_6_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_v_week = NULL;
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3088
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3088, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3089
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")             # <<<<<<<<<<<<<<
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 *         week = int(suffix[0]) - 1
 */
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Prefix);
    __pyx_t_4 += 7;
    __Pyx_GIVEREF(__pyx_kp_u_Prefix);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Prefix);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyObject_Repr(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_requires_a_suffix);
    __pyx_t_4 += 19;
    __Pyx_GIVEREF(__pyx_kp_u_requires_a_suffix);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_requires_a_suffix);
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3089, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 3089, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3088
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3091
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 *         week = int(suffix[0]) - 1             # <<<<<<<<<<<<<<
 *         weekday = weekday_to_int[suffix[1:]]
 *         return cls(week=week, weekday=weekday)
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_suffix, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_t_6, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_week = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3092
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 *         week = int(suffix[0]) - 1
 *         weekday = weekday_to_int[suffix[1:]]             # <<<<<<<<<<<<<<
 *         return cls(week=week, weekday=weekday)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_weekday_to_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_v_suffix, 1, 0, NULL, NULL, &__pyx_slice__53, 1, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_weekday = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3093
 *         week = int(suffix[0]) - 1
 *         weekday = weekday_to_int[suffix[1:]]
 *         return cls(week=week, weekday=weekday)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_week, __pyx_v_week) < 0) __PYX_ERR(0, 3093, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_weekday, __pyx_v_weekday) < 0) __PYX_ERR(0, 3093, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3086
 *         return 1 + shift_days + self.week * 7
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.WeekOfMonth._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_week);
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3126
 *     _attributes = tuple(["n", "normalize", "weekday"])
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):             # <<<<<<<<<<<<<<
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = -1
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekday = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekday,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3126, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3126, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3126, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3126, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekday = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 3, __pyx_nargs); __PYX_ERR(0, 3126, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3127
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)             # <<<<<<<<<<<<<<
 *         self.week = -1
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3128
 *     def __init__(self, n=1, normalize=False, weekday=0):
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = -1             # <<<<<<<<<<<<<<
 * 
 *         if self.n == 0:
 */
  __pyx_v_self->__pyx_base.week = -1;

  /* "pandas/_libs/tslibs/offsets.pyx":3130
 *         self.week = -1
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("N cannot be 0")
 * 
 */
  __pyx_t_5 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n == 0);
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3131
 * 
 *         if self.n == 0:
 *             raise ValueError("N cannot be 0")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3131, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3130
 *         self.week = -1
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("N cannot be 0")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3126
 *     _attributes = tuple(["n", "normalize", "weekday"])
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):             # <<<<<<<<<<<<<<
 *         WeekOfMonthMixin.__init__(self, n, normalize, weekday)
 *         self.week = -1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3133
 *             raise ValueError("N cannot be 0")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3133, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3134
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":3135
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self.weekday = state.pop("weekday")
 *         self.week = -1
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":3136
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")             # <<<<<<<<<<<<<<
 *         self.week = -1
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3136, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.weekday = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":3137
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 *         self.week = -1             # <<<<<<<<<<<<<<
 * 
 *     def _get_offset_day(self, other: datetime) -> int:
 */
  __pyx_v_self->__pyx_base.week = -1;

  /* "pandas/_libs/tslibs/offsets.pyx":3133
 *             raise ValueError("N cannot be 0")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3133, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3133, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3133, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3139
 *         self.week = -1
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day, "\n        Find the day in the same month as other that has the same\n        weekday as self.weekday and is the last such day in the month.\n\n        Parameters\n        ----------\n        other: datetime\n\n        Returns\n        -------\n        day: int\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day = {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_offset_day (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3139, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_offset_day") < 0)) __PYX_ERR(0, 3139, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_offset_day", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3139, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3139, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_dim = NULL;
  PyDateTime_DateTime *__pyx_v_mend = NULL;
  PyObject *__pyx_v_wday = NULL;
  PyObject *__pyx_v_shift_days = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int32_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_offset_day", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3152
 *         day: int
 *         """
 *         dim = get_days_in_month(other.year, other.month)             # <<<<<<<<<<<<<<
 *         mend = datetime(other.year, other.month, dim)
 *         wday = mend.weekday()
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3152, __pyx_L1_error)
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3152, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_t_1, __pyx_t_2, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3152, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_npy_int32(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_dim = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3153
 *         """
 *         dim = get_days_in_month(other.year, other.month)
 *         mend = datetime(other.year, other.month, dim)             # <<<<<<<<<<<<<<
 *         wday = mend.weekday()
 *         shift_days = (wday - self.weekday) % 7
 */
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3153, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3153, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4)) __PYX_ERR(0, 3153, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5)) __PYX_ERR(0, 3153, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_dim);
  __Pyx_GIVEREF(__pyx_v_dim);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_dim)) __PYX_ERR(0, 3153, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_mend = ((PyDateTime_DateTime *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3154
 *         dim = get_days_in_month(other.year, other.month)
 *         mend = datetime(other.year, other.month, dim)
 *         wday = mend.weekday()             # <<<<<<<<<<<<<<
 *         shift_days = (wday - self.weekday) % 7
 *         return dim - shift_days
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_mend), __pyx_n_s_weekday); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  __pyx_t_2 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_2 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_2, 0+__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_v_wday = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3155
 *         mend = datetime(other.year, other.month, dim)
 *         wday = mend.weekday()
 *         shift_days = (wday - self.weekday) % 7             # <<<<<<<<<<<<<<
 *         return dim - shift_days
 * 
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.weekday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyNumber_Subtract(__pyx_v_wday, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_RemainderObjC(__pyx_t_6, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_shift_days = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3156
 *         wday = mend.weekday()
 *         shift_days = (wday - self.weekday) % 7
 *         return dim - shift_days             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyNumber_Subtract(__pyx_v_dim, __pyx_v_shift_days); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_5))) __PYX_ERR(0, 3156, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3139
 *         self.week = -1
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth._get_offset_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dim);
  __Pyx_XDECREF((PyObject *)__pyx_v_mend);
  __Pyx_XDECREF(__pyx_v_wday);
  __Pyx_XDECREF(__pyx_v_shift_days);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3158
 *         return dim - shift_days
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name = {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_suffix = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_suffix,0};

    /* "pandas/_libs/tslibs/offsets.pyx":3159
 * 
 *     @classmethod
 *     def _from_name(cls, suffix=None):             # <<<<<<<<<<<<<<
 *         if not suffix:
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 */
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_suffix);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3158, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_from_name") < 0)) __PYX_ERR(0, 3158, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_suffix = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_from_name", 0, 0, 1, __pyx_nargs); __PYX_ERR(0, 3158, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_6_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_suffix);

  /* "pandas/_libs/tslibs/offsets.pyx":3158
 *         return dim - shift_days
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_6_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_suffix) {
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3160
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         weekday = weekday_to_int[suffix]
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_suffix); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3160, __pyx_L1_error)
  __pyx_t_2 = (!__pyx_t_1);
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3161
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")             # <<<<<<<<<<<<<<
 *         weekday = weekday_to_int[suffix]
 *         return cls(weekday=weekday)
 */
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_Prefix);
    __pyx_t_4 += 7;
    __Pyx_GIVEREF(__pyx_kp_u_Prefix);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Prefix);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyObject_Repr(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_7, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_requires_a_suffix);
    __pyx_t_4 += 19;
    __Pyx_GIVEREF(__pyx_kp_u_requires_a_suffix);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_requires_a_suffix);
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 3161, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3160
 *     @classmethod
 *     def _from_name(cls, suffix=None):
 *         if not suffix:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         weekday = weekday_to_int[suffix]
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3162
 *         if not suffix:
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         weekday = weekday_to_int[suffix]             # <<<<<<<<<<<<<<
 *         return cls(weekday=weekday)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_weekday_to_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_suffix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_weekday = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3163
 *             raise ValueError(f"Prefix {repr(cls._prefix)} requires a suffix.")
 *         weekday = weekday_to_int[suffix]
 *         return cls(weekday=weekday)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_weekday, __pyx_v_weekday) < 0) __PYX_ERR(0, 3163, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3158
 *         return dim - shift_days
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.LastWeekOfMonth._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3175
 *         str variation
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self, n=1, normalize=False, weekday=0, startingMonth=1, variation="nearest"
 *     ):
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekday = 0;
  PyObject *__pyx_v_startingMonth = 0;
  PyObject *__pyx_v_variation = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekday,&__pyx_n_s_startingMonth,&__pyx_n_s_variation,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":3176
 * 
 *     def __init__(
 *         self, n=1, normalize=False, weekday=0, startingMonth=1, variation="nearest"             # <<<<<<<<<<<<<<
 *     ):
 *         BaseOffset.__init__(self, n, normalize)
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_nearest));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startingMonth);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_variation);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3175, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3175, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekday = values[2];
    __pyx_v_startingMonth = values[3];
    __pyx_v_variation = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 5, __pyx_nargs); __PYX_ERR(0, 3175, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday, __pyx_v_startingMonth, __pyx_v_variation);

  /* "pandas/_libs/tslibs/offsets.pyx":3175
 *         str variation
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self, n=1, normalize=False, weekday=0, startingMonth=1, variation="nearest"
 *     ):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday, PyObject *__pyx_v_startingMonth, PyObject *__pyx_v_variation) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3178
 *         self, n=1, normalize=False, weekday=0, startingMonth=1, variation="nearest"
 *     ):
 *         BaseOffset.__init__(self, n, normalize)             # <<<<<<<<<<<<<<
 *         self.startingMonth = startingMonth
 *         self.weekday = weekday
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3179
 *     ):
 *         BaseOffset.__init__(self, n, normalize)
 *         self.startingMonth = startingMonth             # <<<<<<<<<<<<<<
 *         self.weekday = weekday
 *         self.variation = variation
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_startingMonth); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3179, __pyx_L1_error)
  __pyx_v_self->startingMonth = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3180
 *         BaseOffset.__init__(self, n, normalize)
 *         self.startingMonth = startingMonth
 *         self.weekday = weekday             # <<<<<<<<<<<<<<
 *         self.variation = variation
 * 
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_weekday); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3180, __pyx_L1_error)
  __pyx_v_self->weekday = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3181
 *         self.startingMonth = startingMonth
 *         self.weekday = weekday
 *         self.variation = variation             # <<<<<<<<<<<<<<
 * 
 *         if self.n == 0:
 */
  if (!(likely(PyUnicode_CheckExact(__pyx_v_variation))||((__pyx_v_variation) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_variation))) __PYX_ERR(0, 3181, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_variation;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->variation);
  __Pyx_DECREF(__pyx_v_self->variation);
  __pyx_v_self->variation = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3183
 *         self.variation = variation
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("N cannot be 0")
 * 
 */
  __pyx_t_5 = (__pyx_v_self->__pyx_base.__pyx_base.n == 0);
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3184
 * 
 *         if self.n == 0:
 *             raise ValueError("N cannot be 0")             # <<<<<<<<<<<<<<
 * 
 *         if self.variation not in ["nearest", "last"]:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3184, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3183
 *         self.variation = variation
 * 
 *         if self.n == 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("N cannot be 0")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3186
 *             raise ValueError("N cannot be 0")
 * 
 *         if self.variation not in ["nearest", "last"]:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 */
  __Pyx_INCREF(__pyx_v_self->variation);
  __pyx_t_6 = __pyx_v_self->variation;
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_n_u_nearest, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3186, __pyx_L1_error)
  if (__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_6, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3186, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = __pyx_t_5;
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3187
 * 
 *         if self.variation not in ["nearest", "last"]:
 *             raise ValueError(f"{self.variation} is not a valid variation")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
    __pyx_t_1 = __Pyx_PyUnicode_Unicode(__pyx_v_self->variation); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyUnicode_ConcatInPlace(__pyx_t_1, __pyx_kp_u_is_not_a_valid_variation); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 3187, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3186
 *             raise ValueError("N cannot be 0")
 * 
 *         if self.variation not in ["nearest", "last"]:             # <<<<<<<<<<<<<<
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3175
 *         str variation
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self, n=1, normalize=False, weekday=0, startingMonth=1, variation="nearest"
 *     ):
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3189
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3189, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3189, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3190
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":3191
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 *         self.weekday = state.pop("weekday")
 *         self.variation = state.pop("variation")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":3192
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")             # <<<<<<<<<<<<<<
 *         self.variation = state.pop("variation")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_weekday};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->weekday = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":3193
 *         self.normalize = state.pop("normalize")
 *         self.weekday = state.pop("weekday")
 *         self.variation = state.pop("variation")             # <<<<<<<<<<<<<<
 * 
 *     def is_anchored(self) -> bool:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_variation};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 3193, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->variation);
  __Pyx_DECREF(__pyx_v_self->variation);
  __pyx_v_self->variation = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3189
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3189, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3189, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3189, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3195
 *         self.variation = state.pop("variation")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return (
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored = {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_anchored (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_anchored", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_anchored", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_4is_anchored(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_4is_anchored(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_anchored", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3196
 * 
 *     def is_anchored(self) -> bool:
 *         return (             # <<<<<<<<<<<<<<
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None
 *         )
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":3197
 *     def is_anchored(self) -> bool:
 *         return (
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base.n == 1);
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->startingMonth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->weekday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__pyx_t_3 != Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3195
 *         self.variation = state.pop("variation")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return (
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.is_anchored", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3203
 *     # Name-related methods
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         prefix = self._prefix
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_suffix = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3205
 *     @property
 *     def rule_code(self) -> str:
 *         prefix = self._prefix             # <<<<<<<<<<<<<<
 *         suffix = self.get_rule_code_suffix()
 *         return f"{prefix}-{suffix}"
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_prefix = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3206
 *     def rule_code(self) -> str:
 *         prefix = self._prefix
 *         suffix = self.get_rule_code_suffix()             # <<<<<<<<<<<<<<
 *         return f"{prefix}-{suffix}"
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_rule_code_suffix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_suffix = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3207
 *         prefix = self._prefix
 *         suffix = self.get_rule_code_suffix()
 *         return f"{prefix}-{suffix}"             # <<<<<<<<<<<<<<
 * 
 *     def _get_suffix_prefix(self) -> str:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_prefix, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__38);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_suffix, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3203
 *     # Name-related methods
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         prefix = self._prefix
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_suffix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3209
 *         return f"{prefix}-{suffix}"
 * 
 *     def _get_suffix_prefix(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.variation == "nearest":
 *             return "N"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix = {"_get_suffix_prefix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_suffix_prefix (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_get_suffix_prefix", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_get_suffix_prefix", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_6_get_suffix_prefix(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_6_get_suffix_prefix(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_suffix_prefix", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3210
 * 
 *     def _get_suffix_prefix(self) -> str:
 *         if self.variation == "nearest":             # <<<<<<<<<<<<<<
 *             return "N"
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->variation, __pyx_n_u_nearest, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3210, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3211
 *     def _get_suffix_prefix(self) -> str:
 *         if self.variation == "nearest":
 *             return "N"             # <<<<<<<<<<<<<<
 *         else:
 *             return "L"
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_N);
    __pyx_r = __pyx_n_u_N;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3210
 * 
 *     def _get_suffix_prefix(self) -> str:
 *         if self.variation == "nearest":             # <<<<<<<<<<<<<<
 *             return "N"
 *         else:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3213
 *             return "N"
 *         else:
 *             return "L"             # <<<<<<<<<<<<<<
 * 
 *     def get_rule_code_suffix(self) -> str:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_n_u_L);
    __pyx_r = __pyx_n_u_L;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3209
 *         return f"{prefix}-{suffix}"
 * 
 *     def _get_suffix_prefix(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.variation == "nearest":
 *             return "N"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin._get_suffix_prefix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3215
 *             return "L"
 * 
 *     def get_rule_code_suffix(self) -> str:             # <<<<<<<<<<<<<<
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix = {"get_rule_code_suffix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_rule_code_suffix (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_rule_code_suffix", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_rule_code_suffix", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_8get_rule_code_suffix(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_8get_rule_code_suffix(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_month = NULL;
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_rule_code_suffix", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3216
 * 
 *     def get_rule_code_suffix(self) -> str:
 *         prefix = self._get_suffix_prefix()             # <<<<<<<<<<<<<<
 *         month = MONTH_ALIASES[self.startingMonth]
 *         weekday = int_to_weekday[self.weekday]
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_suffix_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_prefix = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3217
 *     def get_rule_code_suffix(self) -> str:
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]             # <<<<<<<<<<<<<<
 *         weekday = int_to_weekday[self.weekday]
 *         return f"{prefix}-{month}-{weekday}"
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MONTH_ALIASES); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, __pyx_v_self->startingMonth, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_month = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3218
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]
 *         weekday = int_to_weekday[self.weekday]             # <<<<<<<<<<<<<<
 *         return f"{prefix}-{month}-{weekday}"
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_int_to_weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, __pyx_v_self->weekday, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_weekday = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3219
 *         month = MONTH_ALIASES[self.startingMonth]
 *         weekday = int_to_weekday[self.weekday]
 *         return f"{prefix}-{month}-{weekday}"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_prefix, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__38);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_month, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__38);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_weekday, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3215
 *             return "L"
 * 
 *     def get_rule_code_suffix(self) -> str:             # <<<<<<<<<<<<<<
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.get_rule_code_suffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_month);
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3171
 * cdef class FY5253Mixin(SingleConstructorOffset):
 *     cdef readonly:
 *         int startingMonth             # <<<<<<<<<<<<<<
 *         int weekday
 *         str variation
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->startingMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.startingMonth.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3172
 *     cdef readonly:
 *         int startingMonth
 *         int weekday             # <<<<<<<<<<<<<<
 *         str variation
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->weekday); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Mixin.weekday.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3173
 *         int startingMonth
 *         int weekday
 *         str variation             # <<<<<<<<<<<<<<
 * 
 *     def __init__(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->variation);
  __pyx_r = __pyx_v_self->variation;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3279
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3279, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 3279, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3279, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3279, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_year_end = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 0);
  __Pyx_INCREF((PyObject *)__pyx_v_dt);

  /* "pandas/_libs/tslibs/offsets.pyx":3280
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         dt = datetime(dt.year, dt.month, dt.day)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3280, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3281
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         dt = datetime(dt.year, dt.month, dt.day)
 *         year_end = self.get_year_end(dt)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3280
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         dt = datetime(dt.year, dt.month, dt.day)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3282
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         dt = datetime(dt.year, dt.month, dt.day)             # <<<<<<<<<<<<<<
 *         year_end = self.get_year_end(dt)
 * 
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3282, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3282, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3282, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5)) __PYX_ERR(0, 3282, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6)) __PYX_ERR(0, 3282, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7)) __PYX_ERR(0, 3282, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF_SET(__pyx_v_dt, ((PyDateTime_DateTime *)__pyx_t_7));
  __pyx_t_7 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3283
 *             return False
 *         dt = datetime(dt.year, dt.month, dt.day)
 *         year_end = self.get_year_end(dt)             # <<<<<<<<<<<<<<
 * 
 *         if self.variation == "nearest":
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, ((PyObject *)__pyx_v_dt)};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __pyx_v_year_end = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3285
 *         year_end = self.get_year_end(dt)
 * 
 *         if self.variation == "nearest":             # <<<<<<<<<<<<<<
 *             # We have to check the year end of "this" cal year AND the previous
 *             return year_end == dt or self.get_year_end(shift_month(dt, -1, None)) == dt
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->__pyx_base.variation, __pyx_n_u_nearest, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3285, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3287
 *         if self.variation == "nearest":
 *             # We have to check the year end of "this" cal year AND the previous
 *             return year_end == dt or self.get_year_end(shift_month(dt, -1, None)) == dt             # <<<<<<<<<<<<<<
 *         else:
 *             return year_end == dt
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_8 = PyObject_RichCompare(__pyx_v_year_end, ((PyObject *)__pyx_v_dt), Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3287, __pyx_L1_error)
    if (!__pyx_t_1) {
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_8);
      __pyx_t_7 = __pyx_t_8;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_shift_month); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_10, ((PyObject *)__pyx_v_dt), __pyx_int_neg_1, Py_None};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __pyx_t_9 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_5};
      __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3287, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_8, ((PyObject *)__pyx_v_dt), Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3287, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = __pyx_t_6;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_L7_bool_binop_done:;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3285
 *         year_end = self.get_year_end(dt)
 * 
 *         if self.variation == "nearest":             # <<<<<<<<<<<<<<
 *             # We have to check the year end of "this" cal year AND the previous
 *             return year_end == dt or self.get_year_end(shift_month(dt, -1, None)) == dt
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3289
 *             return year_end == dt or self.get_year_end(shift_month(dt, -1, None)) == dt
 *         else:
 *             return year_end == dt             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_year_end, ((PyObject *)__pyx_v_dt), Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3289, __pyx_L1_error)
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3279
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_year_end);
  __Pyx_XDECREF((PyObject *)__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3291
 *             return year_end == dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         norm = Timestamp(other).normalize()
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3291, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 3291, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3291, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3292, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_2_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_norm = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_prev_year = NULL;
  PyObject *__pyx_v_cur_year = NULL;
  PyObject *__pyx_v_next_year = NULL;
  PyDateTime_DateTime *__pyx_v_shifted = NULL;
  PyObject *__pyx_v_result = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3293
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         norm = Timestamp(other).normalize()             # <<<<<<<<<<<<<<
 * 
 *         n = self.n
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_other)};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_normalize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_norm = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3295
 *         norm = Timestamp(other).normalize()
 * 
 *         n = self.n             # <<<<<<<<<<<<<<
 *         prev_year = self.get_year_end(datetime(other.year - 1, self.startingMonth, 1))
 *         cur_year = self.get_year_end(datetime(other.year, self.startingMonth, 1))
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3296
 * 
 *         n = self.n
 *         prev_year = self.get_year_end(datetime(other.year - 1, self.startingMonth, 1))             # <<<<<<<<<<<<<<
 *         cur_year = self.get_year_end(datetime(other.year, self.startingMonth, 1))
 *         next_year = self.get_year_end(datetime(other.year + 1, self.startingMonth, 1))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3296, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_long((__pyx_t_5 - 1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(0, 3296, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(0, 3296, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_int_1)) __PYX_ERR(0, 3296, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3296, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_prev_year = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3297
 *         n = self.n
 *         prev_year = self.get_year_end(datetime(other.year - 1, self.startingMonth, 1))
 *         cur_year = self.get_year_end(datetime(other.year, self.startingMonth, 1))             # <<<<<<<<<<<<<<
 *         next_year = self.get_year_end(datetime(other.year + 1, self.startingMonth, 1))
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3297, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4)) __PYX_ERR(0, 3297, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_6)) __PYX_ERR(0, 3297, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_int_1)) __PYX_ERR(0, 3297, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_cur_year = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3298
 *         prev_year = self.get_year_end(datetime(other.year - 1, self.startingMonth, 1))
 *         cur_year = self.get_year_end(datetime(other.year, self.startingMonth, 1))
 *         next_year = self.get_year_end(datetime(other.year + 1, self.startingMonth, 1))             # <<<<<<<<<<<<<<
 * 
 *         prev_year = localize_pydatetime(prev_year, other.tzinfo)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3298, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_long((__pyx_t_5 + 1)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(0, 3298, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2)) __PYX_ERR(0, 3298, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_int_1)) __PYX_ERR(0, 3298, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_next_year = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3300
 *         next_year = self.get_year_end(datetime(other.year + 1, self.startingMonth, 1))
 * 
 *         prev_year = localize_pydatetime(prev_year, other.tzinfo)             # <<<<<<<<<<<<<<
 *         cur_year = localize_pydatetime(cur_year, other.tzinfo)
 *         next_year = localize_pydatetime(next_year, other.tzinfo)
 */
  if (!(likely(((__pyx_v_prev_year) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_prev_year, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3300, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 3300, __pyx_L1_error)
  __pyx_t_3 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(((PyDateTime_DateTime *)__pyx_v_prev_year), ((PyDateTime_TZInfo *)__pyx_t_1), 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_prev_year, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3301
 * 
 *         prev_year = localize_pydatetime(prev_year, other.tzinfo)
 *         cur_year = localize_pydatetime(cur_year, other.tzinfo)             # <<<<<<<<<<<<<<
 *         next_year = localize_pydatetime(next_year, other.tzinfo)
 * 
 */
  if (!(likely(((__pyx_v_cur_year) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_cur_year, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3301, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 3301, __pyx_L1_error)
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(((PyDateTime_DateTime *)__pyx_v_cur_year), ((PyDateTime_TZInfo *)__pyx_t_3), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_cur_year, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3302
 *         prev_year = localize_pydatetime(prev_year, other.tzinfo)
 *         cur_year = localize_pydatetime(cur_year, other.tzinfo)
 *         next_year = localize_pydatetime(next_year, other.tzinfo)             # <<<<<<<<<<<<<<
 * 
 *         # Note: next_year.year == other.year + 1, so we will always
 */
  if (!(likely(((__pyx_v_next_year) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_next_year, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3302, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 3302, __pyx_L1_error)
  __pyx_t_3 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(((PyDateTime_DateTime *)__pyx_v_next_year), ((PyDateTime_TZInfo *)__pyx_t_1), 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_next_year, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3306
 *         # Note: next_year.year == other.year + 1, so we will always
 *         # have other < next_year
 *         if norm == prev_year:             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif norm == cur_year:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_prev_year, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3306, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3306, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":3307
 *         # have other < next_year
 *         if norm == prev_year:
 *             n -= 1             # <<<<<<<<<<<<<<
 *         elif norm == cur_year:
 *             pass
 */
    __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3306
 *         # Note: next_year.year == other.year + 1, so we will always
 *         # have other < next_year
 *         if norm == prev_year:             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif norm == cur_year:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3308
 *         if norm == prev_year:
 *             n -= 1
 *         elif norm == cur_year:             # <<<<<<<<<<<<<<
 *             pass
 *         elif n > 0:
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_cur_year, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3308, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_7) {
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3310
 *         elif norm == cur_year:
 *             pass
 *         elif n > 0:             # <<<<<<<<<<<<<<
 *             if norm < prev_year:
 *                 n -= 2
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3310, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":3311
 *             pass
 *         elif n > 0:
 *             if norm < prev_year:             # <<<<<<<<<<<<<<
 *                 n -= 2
 *             elif prev_year < norm < cur_year:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_prev_year, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3311, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3311, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":3312
 *         elif n > 0:
 *             if norm < prev_year:
 *                 n -= 2             # <<<<<<<<<<<<<<
 *             elif prev_year < norm < cur_year:
 *                 n -= 1
 */
      __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_2, 2, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3311
 *             pass
 *         elif n > 0:
 *             if norm < prev_year:             # <<<<<<<<<<<<<<
 *                 n -= 2
 *             elif prev_year < norm < cur_year:
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3313
 *             if norm < prev_year:
 *                 n -= 2
 *             elif prev_year < norm < cur_year:             # <<<<<<<<<<<<<<
 *                 n -= 1
 *             elif cur_year < norm < next_year:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_prev_year, __pyx_v_norm, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3313, __pyx_L1_error)
    if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_cur_year, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3313, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3313, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":3314
 *                 n -= 2
 *             elif prev_year < norm < cur_year:
 *                 n -= 1             # <<<<<<<<<<<<<<
 *             elif cur_year < norm < next_year:
 *                 pass
 */
      __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3313
 *             if norm < prev_year:
 *                 n -= 2
 *             elif prev_year < norm < cur_year:             # <<<<<<<<<<<<<<
 *                 n -= 1
 *             elif cur_year < norm < next_year:
 */
      goto __pyx_L4;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3315
 *             elif prev_year < norm < cur_year:
 *                 n -= 1
 *             elif cur_year < norm < next_year:             # <<<<<<<<<<<<<<
 *                 pass
 *         else:
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_cur_year, __pyx_v_norm, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3315, __pyx_L1_error)
    if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_next_year, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3315, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3315, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {
    }
    __pyx_L4:;

    /* "pandas/_libs/tslibs/offsets.pyx":3310
 *         elif norm == cur_year:
 *             pass
 *         elif n > 0:             # <<<<<<<<<<<<<<
 *             if norm < prev_year:
 *                 n -= 2
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3318
 *                 pass
 *         else:
 *             if cur_year < norm < next_year:             # <<<<<<<<<<<<<<
 *                 n += 1
 *             elif prev_year < norm < cur_year:
 */
  /*else*/ {
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_cur_year, __pyx_v_norm, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3318, __pyx_L1_error)
    if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_next_year, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3318, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":3319
 *         else:
 *             if cur_year < norm < next_year:
 *                 n += 1             # <<<<<<<<<<<<<<
 *             elif prev_year < norm < cur_year:
 *                 pass
 */
      __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3319, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3318
 *                 pass
 *         else:
 *             if cur_year < norm < next_year:             # <<<<<<<<<<<<<<
 *                 n += 1
 *             elif prev_year < norm < cur_year:
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3320
 *             if cur_year < norm < next_year:
 *                 n += 1
 *             elif prev_year < norm < cur_year:             # <<<<<<<<<<<<<<
 *                 pass
 *             elif (
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_prev_year, __pyx_v_norm, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3320, __pyx_L1_error)
    if (__Pyx_PyObject_IsTrue(__pyx_t_3)) {
      __Pyx_DECREF(__pyx_t_3);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_cur_year, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3320, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3320, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_7) {
      goto __pyx_L5;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3323
 *                 pass
 *             elif (
 *                 norm.year == prev_year.year             # <<<<<<<<<<<<<<
 *                 and norm < prev_year
 *                 and prev_year - norm <= timedelta(6)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_norm, __pyx_n_s_year); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_prev_year, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3323, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3324
 *             elif (
 *                 norm.year == prev_year.year
 *                 and norm < prev_year             # <<<<<<<<<<<<<<
 *                 and prev_year - norm <= timedelta(6)
 *             ):
 */
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_norm, __pyx_v_prev_year, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3324, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3324, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3325
 *                 norm.year == prev_year.year
 *                 and norm < prev_year
 *                 and prev_year - norm <= timedelta(6)             # <<<<<<<<<<<<<<
 *             ):
 *                 # GH#14774, error when next_year.year == cur_year.year
 */
    __pyx_t_2 = PyNumber_Subtract(__pyx_v_prev_year, __pyx_v_norm); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3325, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;

    /* "pandas/_libs/tslibs/offsets.pyx":3322
 *             elif prev_year < norm < cur_year:
 *                 pass
 *             elif (             # <<<<<<<<<<<<<<
 *                 norm.year == prev_year.year
 *                 and norm < prev_year
 */
    if (__pyx_t_7) {

      /* "pandas/_libs/tslibs/offsets.pyx":3330
 *                 # e.g. prev_year == datetime(2004, 1, 3),
 *                 # other == datetime(2004, 1, 1)
 *                 n -= 1             # <<<<<<<<<<<<<<
 *             else:
 *                 assert False
 */
      __pyx_t_3 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3330, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3322
 *             elif prev_year < norm < cur_year:
 *                 pass
 *             elif (             # <<<<<<<<<<<<<<
 *                 norm.year == prev_year.year
 *                 and norm < prev_year
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3332
 *                 n -= 1
 *             else:
 *                 assert False             # <<<<<<<<<<<<<<
 * 
 *         shifted = datetime(other.year + n, self.startingMonth, 1)
 */
    /*else*/ {
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(__pyx_assertions_enabled())) {
        if (unlikely(!0)) {
          __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
          __PYX_ERR(0, 3332, __pyx_L1_error)
        }
      }
      #else
      if ((1)); else __PYX_ERR(0, 3332, __pyx_L1_error)
      #endif
    }
    __pyx_L5:;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3334
 *                 assert False
 * 
 *         shifted = datetime(other.year + n, self.startingMonth, 1)             # <<<<<<<<<<<<<<
 *         result = self.get_year_end(shifted)
 *         result = datetime(
 */
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3334, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_v_n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(0, 3334, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(0, 3334, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_1);
  __Pyx_GIVEREF(__pyx_int_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_int_1)) __PYX_ERR(0, 3334, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_shifted = ((PyDateTime_DateTime *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3335
 * 
 *         shifted = datetime(other.year + n, self.startingMonth, 1)
 *         result = self.get_year_end(shifted)             # <<<<<<<<<<<<<<
 *         result = datetime(
 *             result.year,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_year_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_v_shifted)};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3337
 *         result = self.get_year_end(shifted)
 *         result = datetime(
 *             result.year,             # <<<<<<<<<<<<<<
 *             result.month,
 *             result.day,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_year); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/tslibs/offsets.pyx":3338
 *         result = datetime(
 *             result.year,
 *             result.month,             # <<<<<<<<<<<<<<
 *             result.day,
 *             other.hour,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pandas/_libs/tslibs/offsets.pyx":3339
 *             result.year,
 *             result.month,
 *             result.day,             # <<<<<<<<<<<<<<
 *             other.hour,
 *             other.minute,
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_result, __pyx_n_s_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pandas/_libs/tslibs/offsets.pyx":3340
 *             result.month,
 *             result.day,
 *             other.hour,             # <<<<<<<<<<<<<<
 *             other.minute,
 *             other.second,
 */
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3340, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3340, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/tslibs/offsets.pyx":3341
 *             result.day,
 *             other.hour,
 *             other.minute,             # <<<<<<<<<<<<<<
 *             other.second,
 *             other.microsecond,
 */
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3341, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "pandas/_libs/tslibs/offsets.pyx":3342
 *             other.hour,
 *             other.minute,
 *             other.second,             # <<<<<<<<<<<<<<
 *             other.microsecond,
 *         )
 */
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_6second_second(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3342, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "pandas/_libs/tslibs/offsets.pyx":3343
 *             other.minute,
 *             other.second,
 *             other.microsecond,             # <<<<<<<<<<<<<<
 *         )
 *         return result
 */
  __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3343, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "pandas/_libs/tslibs/offsets.pyx":3336
 *         shifted = datetime(other.year + n, self.startingMonth, 1)
 *         result = self.get_year_end(shifted)
 *         result = datetime(             # <<<<<<<<<<<<<<
 *             result.year,
 *             result.month,
 */
  __pyx_t_11 = PyTuple_New(7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_3)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_2)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_t_1)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_4)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_t_6)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 5, __pyx_t_9)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 6, __pyx_t_10)) __PYX_ERR(0, 3336, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_6 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_11, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_10);
  __pyx_t_10 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3345
 *             other.microsecond,
 *         )
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(__Pyx_TypeTest(__pyx_v_result, __pyx_ptype_7cpython_8datetime_datetime)))) __PYX_ERR(0, 3345, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_result);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3291
 *             return year_end == dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         norm = Timestamp(other).normalize()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_norm);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_prev_year);
  __Pyx_XDECREF(__pyx_v_cur_year);
  __Pyx_XDECREF(__pyx_v_next_year);
  __Pyx_XDECREF((PyObject *)__pyx_v_shifted);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3347
 *         return result
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         assert dt.tzinfo is None
 * 
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end = {"get_year_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_year_end (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3347, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_year_end") < 0)) __PYX_ERR(0, 3347, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_year_end", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3347, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253.get_year_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3347, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_4get_year_end(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_4get_year_end(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  __pyx_t_5numpy_int32_t __pyx_v_dim;
  PyDateTime_DateTime *__pyx_v_target_date = NULL;
  PyObject *__pyx_v_wkday_diff = NULL;
  PyObject *__pyx_v_days_forward = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __pyx_t_5numpy_int32_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_year_end", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3348
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:
 *         assert dt.tzinfo is None             # <<<<<<<<<<<<<<
 * 
 *         dim = get_days_in_month(dt.year, self.startingMonth)
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_dt); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3348, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(0, 3348, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 3348, __pyx_L1_error)
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":3350
 *         assert dt.tzinfo is None
 * 
 *         dim = get_days_in_month(dt.year, self.startingMonth)             # <<<<<<<<<<<<<<
 *         target_date = datetime(dt.year, self.startingMonth, dim)
 *         wkday_diff = self.weekday - target_date.weekday()
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3350, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_t_3, __pyx_v_self->__pyx_base.startingMonth, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3350, __pyx_L1_error)
  __pyx_v_dim = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3351
 * 
 *         dim = get_days_in_month(dt.year, self.startingMonth)
 *         target_date = datetime(dt.year, self.startingMonth, dim)             # <<<<<<<<<<<<<<
 *         wkday_diff = self.weekday - target_date.weekday()
 *         if wkday_diff == 0:
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3351, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_npy_int32(__pyx_v_dim); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1)) __PYX_ERR(0, 3351, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(0, 3351, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_6)) __PYX_ERR(0, 3351, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_target_date = ((PyDateTime_DateTime *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3352
 *         dim = get_days_in_month(dt.year, self.startingMonth)
 *         target_date = datetime(dt.year, self.startingMonth, dim)
 *         wkday_diff = self.weekday - target_date.weekday()             # <<<<<<<<<<<<<<
 *         if wkday_diff == 0:
 *             # year_end is the same for "last" and "nearest" cases
 */
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.weekday); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_target_date), __pyx_n_s_weekday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = NULL;
  __pyx_t_3 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_3 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_3, 0+__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_t_5 = PyNumber_Subtract(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_wkday_diff = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3353
 *         target_date = datetime(dt.year, self.startingMonth, dim)
 *         wkday_diff = self.weekday - target_date.weekday()
 *         if wkday_diff == 0:             # <<<<<<<<<<<<<<
 *             # year_end is the same for "last" and "nearest" cases
 *             return target_date
 */
  __pyx_t_2 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_wkday_diff, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3353, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":3355
 *         if wkday_diff == 0:
 *             # year_end is the same for "last" and "nearest" cases
 *             return target_date             # <<<<<<<<<<<<<<
 * 
 *         if self.variation == "last":
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_target_date);
    __pyx_r = __pyx_v_target_date;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3353
 *         target_date = datetime(dt.year, self.startingMonth, dim)
 *         wkday_diff = self.weekday - target_date.weekday()
 *         if wkday_diff == 0:             # <<<<<<<<<<<<<<
 *             # year_end is the same for "last" and "nearest" cases
 *             return target_date
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3357
 *             return target_date
 * 
 *         if self.variation == "last":             # <<<<<<<<<<<<<<
 *             days_forward = (wkday_diff % 7) - 7
 * 
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->__pyx_base.variation, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3357, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":3358
 * 
 *         if self.variation == "last":
 *             days_forward = (wkday_diff % 7) - 7             # <<<<<<<<<<<<<<
 * 
 *             # days_forward is always negative, so we always end up
 */
    __pyx_t_5 = __Pyx_PyInt_RemainderObjC(__pyx_v_wkday_diff, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyInt_SubtractObjC(__pyx_t_5, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3358, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_days_forward = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3362
 *             # days_forward is always negative, so we always end up
 *             # in the same year as dt
 *             return target_date + timedelta(days=days_forward)             # <<<<<<<<<<<<<<
 *         else:
 *             # variation == "nearest":
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_days, __pyx_v_days_forward) < 0) __PYX_ERR(0, 3362, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyNumber_Add(((PyObject *)__pyx_v_target_date), __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3362, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3362, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_7);
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3357
 *             return target_date
 * 
 *         if self.variation == "last":             # <<<<<<<<<<<<<<
 *             days_forward = (wkday_diff % 7) - 7
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3365
 *         else:
 *             # variation == "nearest":
 *             days_forward = wkday_diff % 7             # <<<<<<<<<<<<<<
 *             if days_forward <= 3:
 *                 # The upcoming self.weekday is closer than the previous one
 */
  /*else*/ {
    __pyx_t_7 = __Pyx_PyInt_RemainderObjC(__pyx_v_wkday_diff, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3365, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_v_days_forward = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3366
 *             # variation == "nearest":
 *             days_forward = wkday_diff % 7
 *             if days_forward <= 3:             # <<<<<<<<<<<<<<
 *                 # The upcoming self.weekday is closer than the previous one
 *                 return target_date + timedelta(days_forward)
 */
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_days_forward, __pyx_int_3, Py_LE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3366, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 3366, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_2) {

      /* "pandas/_libs/tslibs/offsets.pyx":3368
 *             if days_forward <= 3:
 *                 # The upcoming self.weekday is closer than the previous one
 *                 return target_date + timedelta(days_forward)             # <<<<<<<<<<<<<<
 *             else:
 *                 # The previous self.weekday is closer than the upcoming one
 */
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_v_days_forward); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_v_target_date), __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3368, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3368, __pyx_L1_error)
      __pyx_r = ((PyDateTime_DateTime *)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":3366
 *             # variation == "nearest":
 *             days_forward = wkday_diff % 7
 *             if days_forward <= 3:             # <<<<<<<<<<<<<<
 *                 # The upcoming self.weekday is closer than the previous one
 *                 return target_date + timedelta(days_forward)
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3371
 *             else:
 *                 # The previous self.weekday is closer than the upcoming one
 *                 return target_date + timedelta(days_forward - 7)             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
    /*else*/ {
      __Pyx_XDECREF((PyObject *)__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_days_forward, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyNumber_Add(((PyObject *)__pyx_v_target_date), __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3371, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3371, __pyx_L1_error)
      __pyx_r = ((PyDateTime_DateTime *)__pyx_t_5);
      __pyx_t_5 = 0;
      goto __pyx_L0;
    }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3347
 *         return result
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         assert dt.tzinfo is None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253.get_year_end", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_target_date);
  __Pyx_XDECREF(__pyx_v_wkday_diff);
  __Pyx_XDECREF(__pyx_v_days_forward);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3373
 *                 return target_date + timedelta(days_forward - 7)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix = {"_parse_suffix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix(PyObject *__pyx_v_cls, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_varion_code = 0;
  PyObject *__pyx_v_startingMonth_code = 0;
  PyObject *__pyx_v_weekday_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_parse_suffix (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_varion_code,&__pyx_n_s_startingMonth_code,&__pyx_n_s_weekday_code,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_varion_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3373, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startingMonth_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3373, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parse_suffix", 1, 3, 3, 1); __PYX_ERR(0, 3373, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3373, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_parse_suffix", 1, 3, 3, 2); __PYX_ERR(0, 3373, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_parse_suffix") < 0)) __PYX_ERR(0, 3373, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_varion_code = values[0];
    __pyx_v_startingMonth_code = values[1];
    __pyx_v_weekday_code = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_parse_suffix", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 3373, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253._parse_suffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_6_parse_suffix(((PyTypeObject*)__pyx_v_cls), __pyx_v_varion_code, __pyx_v_startingMonth_code, __pyx_v_weekday_code);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_6_parse_suffix(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_varion_code, PyObject *__pyx_v_startingMonth_code, PyObject *__pyx_v_weekday_code) {
  PyObject *__pyx_v_variation = NULL;
  PyObject *__pyx_v_startingMonth = NULL;
  PyObject *__pyx_v_weekday = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_suffix", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3375
 *     @classmethod
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":             # <<<<<<<<<<<<<<
 *             variation = "nearest"
 *         elif varion_code == "L":
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_varion_code, __pyx_n_u_N, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3375, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3376
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":
 *             variation = "nearest"             # <<<<<<<<<<<<<<
 *         elif varion_code == "L":
 *             variation = "last"
 */
    __Pyx_INCREF(__pyx_n_u_nearest);
    __pyx_v_variation = __pyx_n_u_nearest;

    /* "pandas/_libs/tslibs/offsets.pyx":3375
 *     @classmethod
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":             # <<<<<<<<<<<<<<
 *             variation = "nearest"
 *         elif varion_code == "L":
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3377
 *         if varion_code == "N":
 *             variation = "nearest"
 *         elif varion_code == "L":             # <<<<<<<<<<<<<<
 *             variation = "last"
 *         else:
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_varion_code, __pyx_n_u_L, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3377, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3378
 *             variation = "nearest"
 *         elif varion_code == "L":
 *             variation = "last"             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(f"Unable to parse varion_code: {varion_code}")
 */
    __Pyx_INCREF(__pyx_n_u_last);
    __pyx_v_variation = __pyx_n_u_last;

    /* "pandas/_libs/tslibs/offsets.pyx":3377
 *         if varion_code == "N":
 *             variation = "nearest"
 *         elif varion_code == "L":             # <<<<<<<<<<<<<<
 *             variation = "last"
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3380
 *             variation = "last"
 *         else:
 *             raise ValueError(f"Unable to parse varion_code: {varion_code}")             # <<<<<<<<<<<<<<
 * 
 *         startingMonth = MONTH_TO_CAL_NUM[startingMonth_code]
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_v_varion_code, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Unable_to_parse_varion_code, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 3380, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3382
 *             raise ValueError(f"Unable to parse varion_code: {varion_code}")
 * 
 *         startingMonth = MONTH_TO_CAL_NUM[startingMonth_code]             # <<<<<<<<<<<<<<
 *         weekday = weekday_to_int[weekday_code]
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MONTH_TO_CAL_NUM); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_startingMonth_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_startingMonth = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3383
 * 
 *         startingMonth = MONTH_TO_CAL_NUM[startingMonth_code]
 *         weekday = weekday_to_int[weekday_code]             # <<<<<<<<<<<<<<
 * 
 *         return {
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_weekday_to_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_weekday_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_weekday = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3385
 *         weekday = weekday_to_int[weekday_code]
 * 
 *         return {             # <<<<<<<<<<<<<<
 *             "weekday": weekday,
 *             "startingMonth": startingMonth,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":3386
 * 
 *         return {
 *             "weekday": weekday,             # <<<<<<<<<<<<<<
 *             "startingMonth": startingMonth,
 *             "variation": variation,
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_weekday, __pyx_v_weekday) < 0) __PYX_ERR(0, 3386, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3387
 *         return {
 *             "weekday": weekday,
 *             "startingMonth": startingMonth,             # <<<<<<<<<<<<<<
 *             "variation": variation,
 *         }
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_startingMonth, __pyx_v_startingMonth) < 0) __PYX_ERR(0, 3386, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3388
 *             "weekday": weekday,
 *             "startingMonth": startingMonth,
 *             "variation": variation,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_variation, __pyx_v_variation) < 0) __PYX_ERR(0, 3386, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3373
 *                 return target_date + timedelta(days_forward - 7)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253._parse_suffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_variation);
  __Pyx_XDECREF(__pyx_v_startingMonth);
  __Pyx_XDECREF(__pyx_v_weekday);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3391
 *         }
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(**cls._parse_suffix(*args))
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name = {"_from_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_from_name", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_8_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6FY5253_8_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3393
 *     @classmethod
 *     def _from_name(cls, *args):
 *         return cls(**cls._parse_suffix(*args))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cls), __pyx_n_s_parse_suffix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_v_args, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 3393, __pyx_L1_error)
  }
  if (likely(PyDict_CheckExact(__pyx_t_3))) {
    __pyx_t_1 = PyDict_Copy(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg((PyObject*)&PyDict_Type, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3391
 *         }
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(**cls._parse_suffix(*args))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3474
 *         int qtr_with_extra_week
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekday = 0;
  PyObject *__pyx_v_startingMonth = 0;
  PyObject *__pyx_v_qtr_with_extra_week = 0;
  PyObject *__pyx_v_variation = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekday,&__pyx_n_s_startingMonth,&__pyx_n_s_qtr_with_extra_week,&__pyx_n_s_variation,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":3477
 *         self,
 *         n=1,
 *         normalize=False,             # <<<<<<<<<<<<<<
 *         weekday=0,
 *         startingMonth=1,
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_0));
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));
    values[5] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_nearest));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekday);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_startingMonth);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_qtr_with_extra_week);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_variation);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3474, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3474, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekday = values[2];
    __pyx_v_startingMonth = values[3];
    __pyx_v_qtr_with_extra_week = values[4];
    __pyx_v_variation = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 6, __pyx_nargs); __PYX_ERR(0, 3474, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday, __pyx_v_startingMonth, __pyx_v_qtr_with_extra_week, __pyx_v_variation);

  /* "pandas/_libs/tslibs/offsets.pyx":3474
 *         int qtr_with_extra_week
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekday, PyObject *__pyx_v_startingMonth, PyObject *__pyx_v_qtr_with_extra_week, PyObject *__pyx_v_variation) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3483
 *         variation="nearest",
 *     ):
 *         FY5253Mixin.__init__(             # <<<<<<<<<<<<<<
 *             self, n, normalize, weekday, startingMonth, variation
 *         )
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pandas/_libs/tslibs/offsets.pyx":3484
 *     ):
 *         FY5253Mixin.__init__(
 *             self, n, normalize, weekday, startingMonth, variation             # <<<<<<<<<<<<<<
 *         )
 *         self.qtr_with_extra_week = qtr_with_extra_week
 */
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[7] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekday, __pyx_v_startingMonth, __pyx_v_variation};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 6+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3486
 *             self, n, normalize, weekday, startingMonth, variation
 *         )
 *         self.qtr_with_extra_week = qtr_with_extra_week             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_qtr_with_extra_week); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3486, __pyx_L1_error)
  __pyx_v_self->qtr_with_extra_week = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3474
 *         int qtr_with_extra_week
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3488
 *         self.qtr_with_extra_week = qtr_with_extra_week
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         FY5253Mixin.__setstate__(self, state)
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3488, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3488, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3489
 * 
 *     cpdef __setstate__(self, state):
 *         FY5253Mixin.__setstate__(self, state)             # <<<<<<<<<<<<<<
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 * 
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)__pyx_v_self), __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3490
 *     cpdef __setstate__(self, state):
 *         FY5253Mixin.__setstate__(self, state)
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_qtr_with_extra_week};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->qtr_with_extra_week = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":3488
 *         self.qtr_with_extra_week = qtr_with_extra_week
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         FY5253Mixin.__setstate__(self, state)
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3488, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3488, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3488, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3492
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _offset(self):
 *         return FY5253(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset = {"_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("_offset", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_offset", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_4_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_4_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3494
 *     @cache_readonly
 *     def _offset(self):
 *         return FY5253(             # <<<<<<<<<<<<<<
 *             startingMonth=self.startingMonth,
 *             weekday=self.weekday,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":3495
 *     def _offset(self):
 *         return FY5253(
 *             startingMonth=self.startingMonth,             # <<<<<<<<<<<<<<
 *             weekday=self.weekday,
 *             variation=self.variation,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.startingMonth); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_startingMonth, __pyx_t_2) < 0) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3496
 *         return FY5253(
 *             startingMonth=self.startingMonth,
 *             weekday=self.weekday,             # <<<<<<<<<<<<<<
 *             variation=self.variation,
 *         )
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.weekday); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_weekday, __pyx_t_2) < 0) __PYX_ERR(0, 3495, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3497
 *             startingMonth=self.startingMonth,
 *             weekday=self.weekday,
 *             variation=self.variation,             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_variation, __pyx_v_self->__pyx_base.variation) < 0) __PYX_ERR(0, 3495, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3494
 *     @cache_readonly
 *     def _offset(self):
 *         return FY5253(             # <<<<<<<<<<<<<<
 *             startingMonth=self.startingMonth,
 *             weekday=self.weekday,
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3492
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _offset(self):
 *         return FY5253(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3500
 *         )
 * 
 *     def _rollback_to_year(self, other: datetime):             # <<<<<<<<<<<<<<
 *         """
 *         Roll `other` back to the most recent date that was on a fiscal year
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year, "\n        Roll `other` back to the most recent date that was on a fiscal year\n        end.\n\n        Return the date of that year-end, the number of full quarters\n        elapsed between that year-end and other, and the remaining Timedelta\n        since the most recent quarter-end.\n\n        Parameters\n        ----------\n        other : datetime or Timestamp\n\n        Returns\n        -------\n        tuple of\n        prev_year_end : Timestamp giving most recent fiscal year end\n        num_qtrs : int\n        tdelta : Timedelta\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year = {"_rollback_to_year", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_rollback_to_year (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3500, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_rollback_to_year") < 0)) __PYX_ERR(0, 3500, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_rollback_to_year", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3500, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._rollback_to_year", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3500, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_num_qtrs = NULL;
  PyObject *__pyx_v_norm = NULL;
  PyObject *__pyx_v_start = NULL;
  PyObject *__pyx_v_qtr_lens = NULL;
  PyDateTime_DateTime *__pyx_v_end = NULL;
  PyObject *__pyx_v_tdelta = NULL;
  PyObject *__pyx_v_qlen = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  NPY_DATETIMEUNIT __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_rollback_to_year", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3520
 *         tdelta : Timedelta
 *         """
 *         num_qtrs = 0             # <<<<<<<<<<<<<<
 * 
 *         norm = Timestamp(other).tz_localize(None)
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_num_qtrs = __pyx_int_0;

  /* "pandas/_libs/tslibs/offsets.pyx":3522
 *         num_qtrs = 0
 * 
 *         norm = Timestamp(other).tz_localize(None)             # <<<<<<<<<<<<<<
 *         start = self._offset.rollback(norm)
 *         # Note: start <= norm and self._offset.is_on_offset(start)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, ((PyObject *)__pyx_v_other)};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, Py_None};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_norm = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3523
 * 
 *         norm = Timestamp(other).tz_localize(None)
 *         start = self._offset.rollback(norm)             # <<<<<<<<<<<<<<
 *         # Note: start <= norm and self._offset.is_on_offset(start)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_rollback); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_norm};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_start = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3526
 *         # Note: start <= norm and self._offset.is_on_offset(start)
 * 
 *         if start < norm:             # <<<<<<<<<<<<<<
 *             # roll adjustment
 *             qtr_lens = self.get_weeks(norm)
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_start, __pyx_v_norm, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3526, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3526, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":3528
 *         if start < norm:
 *             # roll adjustment
 *             qtr_lens = self.get_weeks(norm)             # <<<<<<<<<<<<<<
 * 
 *             # check that qtr_lens is consistent with self._offset addition
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_weeks); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_norm};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_qtr_lens = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3531
 * 
 *             # check that qtr_lens is consistent with self._offset addition
 *             end = _shift_day(start, days=7 * sum(qtr_lens))             # <<<<<<<<<<<<<<
 *             assert self._offset.is_on_offset(end), (start, end, qtr_lens)
 * 
 */
    if (!(likely(((__pyx_v_start) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_start, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3531, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_v_qtr_lens); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyInt_MultiplyCObj(__pyx_int_7, __pyx_t_1, 7, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(((PyDateTime_DateTime *)__pyx_v_start), __pyx_t_5)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_end = ((PyDateTime_DateTime *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3532
 *             # check that qtr_lens is consistent with self._offset addition
 *             end = _shift_day(start, days=7 * sum(qtr_lens))
 *             assert self._offset.is_on_offset(end), (start, end, qtr_lens)             # <<<<<<<<<<<<<<
 * 
 *             tdelta = norm - start
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(__pyx_assertions_enabled())) {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_v_end)};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3532, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_6)) {
        __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_start);
        __Pyx_GIVEREF(__pyx_v_start);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_start)) __PYX_ERR(0, 3532, __pyx_L1_error);
        __Pyx_INCREF((PyObject *)__pyx_v_end);
        __Pyx_GIVEREF((PyObject *)__pyx_v_end);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_end))) __PYX_ERR(0, 3532, __pyx_L1_error);
        __Pyx_INCREF(__pyx_v_qtr_lens);
        __Pyx_GIVEREF(__pyx_v_qtr_lens);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_qtr_lens)) __PYX_ERR(0, 3532, __pyx_L1_error);
        __pyx_t_3 = PyTuple_Pack(1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_Raise(__pyx_builtin_AssertionError, __pyx_t_3, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(0, 3532, __pyx_L1_error)
      }
    }
    #else
    if ((1)); else __PYX_ERR(0, 3532, __pyx_L1_error)
    #endif

    /* "pandas/_libs/tslibs/offsets.pyx":3534
 *             assert self._offset.is_on_offset(end), (start, end, qtr_lens)
 * 
 *             tdelta = norm - start             # <<<<<<<<<<<<<<
 *             for qlen in qtr_lens:
 *                 if qlen * 7 <= tdelta.days:
 */
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_norm, __pyx_v_start); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_tdelta = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3535
 * 
 *             tdelta = norm - start
 *             for qlen in qtr_lens:             # <<<<<<<<<<<<<<
 *                 if qlen * 7 <= tdelta.days:
 *                     num_qtrs += 1
 */
    if (likely(PyList_CheckExact(__pyx_v_qtr_lens)) || PyTuple_CheckExact(__pyx_v_qtr_lens)) {
      __pyx_t_3 = __pyx_v_qtr_lens; __Pyx_INCREF(__pyx_t_3);
      __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_qtr_lens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3535, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3535, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3535, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 3535, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3535, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3535, __pyx_L1_error)
            #endif
            if (__pyx_t_7 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely((0 < 0))) __PYX_ERR(0, 3535, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3535, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_3);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 3535, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_qlen, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3536
 *             tdelta = norm - start
 *             for qlen in qtr_lens:
 *                 if qlen * 7 <= tdelta.days:             # <<<<<<<<<<<<<<
 *                     num_qtrs += 1
 *                     tdelta -= (
 */
      __pyx_t_2 = __Pyx_PyInt_MultiplyObjC(__pyx_v_qlen, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tdelta, __pyx_n_s_days); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3536, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 3536, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "pandas/_libs/tslibs/offsets.pyx":3537
 *             for qlen in qtr_lens:
 *                 if qlen * 7 <= tdelta.days:
 *                     num_qtrs += 1             # <<<<<<<<<<<<<<
 *                     tdelta -= (
 *                         <_Timedelta>Timedelta(days=qlen * 7)
 */
        __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_num_qtrs, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_num_qtrs, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":3539
 *                     num_qtrs += 1
 *                     tdelta -= (
 *                         <_Timedelta>Timedelta(days=qlen * 7)             # <<<<<<<<<<<<<<
 *                     )._as_creso(norm._creso)
 *                 else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyInt_MultiplyObjC(__pyx_v_qlen, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_days, __pyx_t_2) < 0) __PYX_ERR(0, 3539, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3539, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":3540
 *                     tdelta -= (
 *                         <_Timedelta>Timedelta(days=qlen * 7)
 *                     )._as_creso(norm._creso)             # <<<<<<<<<<<<<<
 *                 else:
 *                     break
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_norm, __pyx_n_s_creso); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = ((NPY_DATETIMEUNIT)__Pyx_PyInt_As_NPY_DATETIMEUNIT(__pyx_t_1)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3540, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_t_2)->__pyx_vtab)->_as_creso(((struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta *)__pyx_t_2), __pyx_t_9, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":3538
 *                 if qlen * 7 <= tdelta.days:
 *                     num_qtrs += 1
 *                     tdelta -= (             # <<<<<<<<<<<<<<
 *                         <_Timedelta>Timedelta(days=qlen * 7)
 *                     )._as_creso(norm._creso)
 */
        __pyx_t_2 = PyNumber_InPlaceSubtract(__pyx_v_tdelta, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3538, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_tdelta, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":3536
 *             tdelta = norm - start
 *             for qlen in qtr_lens:
 *                 if qlen * 7 <= tdelta.days:             # <<<<<<<<<<<<<<
 *                     num_qtrs += 1
 *                     tdelta -= (
 */
        goto __pyx_L6;
      }

      /* "pandas/_libs/tslibs/offsets.pyx":3542
 *                     )._as_creso(norm._creso)
 *                 else:
 *                     break             # <<<<<<<<<<<<<<
 *         else:
 *             tdelta = Timedelta(0)
 */
      /*else*/ {
        goto __pyx_L5_break;
      }
      __pyx_L6:;

      /* "pandas/_libs/tslibs/offsets.pyx":3535
 * 
 *             tdelta = norm - start
 *             for qlen in qtr_lens:             # <<<<<<<<<<<<<<
 *                 if qlen * 7 <= tdelta.days:
 *                     num_qtrs += 1
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_for_end;
    __pyx_L5_break:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_for_end;
    __pyx_L7_for_end:;

    /* "pandas/_libs/tslibs/offsets.pyx":3526
 *         # Note: start <= norm and self._offset.is_on_offset(start)
 * 
 *         if start < norm:             # <<<<<<<<<<<<<<
 *             # roll adjustment
 *             qtr_lens = self.get_weeks(norm)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3544
 *                     break
 *         else:
 *             tdelta = Timedelta(0)             # <<<<<<<<<<<<<<
 * 
 *         # Note: we always have tdelta._value>= 0
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3544, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_int_0};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3544, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_tdelta = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3547
 * 
 *         # Note: we always have tdelta._value>= 0
 *         return start, num_qtrs, tdelta             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_start);
  __Pyx_GIVEREF(__pyx_v_start);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_start)) __PYX_ERR(0, 3547, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_num_qtrs);
  __Pyx_GIVEREF(__pyx_v_num_qtrs);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_num_qtrs)) __PYX_ERR(0, 3547, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_tdelta);
  __Pyx_GIVEREF(__pyx_v_tdelta);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_tdelta)) __PYX_ERR(0, 3547, __pyx_L1_error);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3500
 *         )
 * 
 *     def _rollback_to_year(self, other: datetime):             # <<<<<<<<<<<<<<
 *         """
 *         Roll `other` back to the most recent date that was on a fiscal year
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._rollback_to_year", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_num_qtrs);
  __Pyx_XDECREF(__pyx_v_norm);
  __Pyx_XDECREF(__pyx_v_start);
  __Pyx_XDECREF(__pyx_v_qtr_lens);
  __Pyx_XDECREF((PyObject *)__pyx_v_end);
  __Pyx_XDECREF(__pyx_v_tdelta);
  __Pyx_XDECREF(__pyx_v_qlen);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3549
 *         return start, num_qtrs, tdelta
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # Note: self.n == 0 is not allowed.
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3549, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 3549, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3549, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3550, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_8_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_8_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_prev_year_end = NULL;
  PyObject *__pyx_v_num_qtrs = NULL;
  PyObject *__pyx_v_tdelta = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_v_years = NULL;
  PyObject *__pyx_v_qtr_lens = NULL;
  PyObject *__pyx_v_weeks = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3553
 *         # Note: self.n == 0 is not allowed.
 * 
 *         n = self.n             # <<<<<<<<<<<<<<
 * 
 *         prev_year_end, num_qtrs, tdelta = self._rollback_to_year(other)
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3555
 *         n = self.n
 * 
 *         prev_year_end, num_qtrs, tdelta = self._rollback_to_year(other)             # <<<<<<<<<<<<<<
 *         res = prev_year_end
 *         n += num_qtrs
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rollback_to_year); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_other)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 3555, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6);
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 2; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 3555, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 3555, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_prev_year_end = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_num_qtrs = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_tdelta = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3556
 * 
 *         prev_year_end, num_qtrs, tdelta = self._rollback_to_year(other)
 *         res = prev_year_end             # <<<<<<<<<<<<<<
 *         n += num_qtrs
 *         if self.n <= 0 and tdelta._value > 0:
 */
  __Pyx_INCREF(__pyx_v_prev_year_end);
  __pyx_v_res = __pyx_v_prev_year_end;

  /* "pandas/_libs/tslibs/offsets.pyx":3557
 *         prev_year_end, num_qtrs, tdelta = self._rollback_to_year(other)
 *         res = prev_year_end
 *         n += num_qtrs             # <<<<<<<<<<<<<<
 *         if self.n <= 0 and tdelta._value > 0:
 *             n += 1
 */
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_n, __pyx_v_num_qtrs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3558
 *         res = prev_year_end
 *         n += num_qtrs
 *         if self.n <= 0 and tdelta._value > 0:             # <<<<<<<<<<<<<<
 *             n += 1
 * 
 */
  __pyx_t_9 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n <= 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tdelta, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(0, 3558, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_8) {

    /* "pandas/_libs/tslibs/offsets.pyx":3559
 *         n += num_qtrs
 *         if self.n <= 0 and tdelta._value > 0:
 *             n += 1             # <<<<<<<<<<<<<<
 * 
 *         # Possible speedup by handling years first.
 */
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3559, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3558
 *         res = prev_year_end
 *         n += num_qtrs
 *         if self.n <= 0 and tdelta._value > 0:             # <<<<<<<<<<<<<<
 *             n += 1
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3562
 * 
 *         # Possible speedup by handling years first.
 *         years = n // 4             # <<<<<<<<<<<<<<
 *         if years:
 *             res += self._offset * years
 */
  __pyx_t_5 = __Pyx_PyInt_FloorDivideObjC(__pyx_v_n, __pyx_int_4, 4, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_years = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3563
 *         # Possible speedup by handling years first.
 *         years = n // 4
 *         if years:             # <<<<<<<<<<<<<<
 *             res += self._offset * years
 *             n -= years * 4
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_years); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3563, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "pandas/_libs/tslibs/offsets.pyx":3564
 *         years = n // 4
 *         if years:
 *             res += self._offset * years             # <<<<<<<<<<<<<<
 *             n -= years * 4
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyNumber_Multiply(__pyx_t_5, __pyx_v_years); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_res, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3565
 *         if years:
 *             res += self._offset * years
 *             n -= years * 4             # <<<<<<<<<<<<<<
 * 
 *         # Add an extra day to make *sure* we are getting the quarter lengths
 */
    __pyx_t_5 = __Pyx_PyInt_MultiplyObjC(__pyx_v_years, __pyx_int_4, 4, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyNumber_InPlaceSubtract(__pyx_v_n, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3565, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3563
 *         # Possible speedup by handling years first.
 *         years = n // 4
 *         if years:             # <<<<<<<<<<<<<<
 *             res += self._offset * years
 *             n -= years * 4
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3569
 *         # Add an extra day to make *sure* we are getting the quarter lengths
 *         # for the upcoming year, not the previous year
 *         qtr_lens = self.get_weeks(res + Timedelta(days=1))             # <<<<<<<<<<<<<<
 * 
 *         # Note: we always have 0 <= n < 4
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_weeks); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_days, __pyx_int_1) < 0) __PYX_ERR(0, 3569, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyNumber_Add(__pyx_v_res, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_v_qtr_lens = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3572
 * 
 *         # Note: we always have 0 <= n < 4
 *         weeks = sum(qtr_lens[:n])             # <<<<<<<<<<<<<<
 *         if weeks:
 *             res = _shift_day(res, days=weeks * 7)
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_qtr_lens, 0, 0, NULL, &__pyx_v_n, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_sum, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_weeks = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3573
 *         # Note: we always have 0 <= n < 4
 *         weeks = sum(qtr_lens[:n])
 *         if weeks:             # <<<<<<<<<<<<<<
 *             res = _shift_day(res, days=weeks * 7)
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_weeks); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3573, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "pandas/_libs/tslibs/offsets.pyx":3574
 *         weeks = sum(qtr_lens[:n])
 *         if weeks:
 *             res = _shift_day(res, days=weeks * 7)             # <<<<<<<<<<<<<<
 * 
 *         return res
 */
    if (!(likely(((__pyx_v_res) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_res, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3574, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyInt_MultiplyObjC(__pyx_v_weeks, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3574, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(((PyDateTime_DateTime *)__pyx_v_res), __pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3574, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_res, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3573
 *         # Note: we always have 0 <= n < 4
 *         weeks = sum(qtr_lens[:n])
 *         if weeks:             # <<<<<<<<<<<<<<
 *             res = _shift_day(res, days=weeks * 7)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3576
 *             res = _shift_day(res, days=weeks * 7)
 * 
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     def get_weeks(self, dt: datetime):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_res) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_res, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3576, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_res);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_res);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3549
 *         return start, num_qtrs, tdelta
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # Note: self.n == 0 is not allowed.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_prev_year_end);
  __Pyx_XDECREF(__pyx_v_num_qtrs);
  __Pyx_XDECREF(__pyx_v_tdelta);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XDECREF(__pyx_v_years);
  __Pyx_XDECREF(__pyx_v_qtr_lens);
  __Pyx_XDECREF(__pyx_v_weeks);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3578
 *         return res
 * 
 *     def get_weeks(self, dt: datetime):             # <<<<<<<<<<<<<<
 *         ret = [13] * 4
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks = {"get_weeks", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_weeks (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3578, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_weeks") < 0)) __PYX_ERR(0, 3578, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_weeks", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3578, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.get_weeks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3578, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_10get_weeks(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_10get_weeks(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_ret = NULL;
  PyObject *__pyx_v_year_has_extra_week = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  long __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_weeks", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3579
 * 
 *     def get_weeks(self, dt: datetime):
 *         ret = [13] * 4             # <<<<<<<<<<<<<<
 * 
 *         year_has_extra_week = self.year_has_extra_week(dt)
 */
  __pyx_t_1 = PyList_New(1 * 4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < 4; __pyx_temp++) {
      __Pyx_INCREF(__pyx_int_13);
      __Pyx_GIVEREF(__pyx_int_13);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_int_13)) __PYX_ERR(0, 3579, __pyx_L1_error);
    }
  }
  __pyx_v_ret = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3581
 *         ret = [13] * 4
 * 
 *         year_has_extra_week = self.year_has_extra_week(dt)             # <<<<<<<<<<<<<<
 * 
 *         if year_has_extra_week:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_year_has_extra_week); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_dt)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_year_has_extra_week = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3583
 *         year_has_extra_week = self.year_has_extra_week(dt)
 * 
 *         if year_has_extra_week:             # <<<<<<<<<<<<<<
 *             ret[self.qtr_with_extra_week - 1] = 14
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_year_has_extra_week); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3583, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":3584
 * 
 *         if year_has_extra_week:
 *             ret[self.qtr_with_extra_week - 1] = 14             # <<<<<<<<<<<<<<
 * 
 *         return ret
 */
    __pyx_t_6 = (__pyx_v_self->qtr_with_extra_week - 1);
    if (unlikely((__Pyx_SetItemInt(__pyx_v_ret, __pyx_t_6, __pyx_int_14, long, 1, __Pyx_PyInt_From_long, 1, 1, 1) < 0))) __PYX_ERR(0, 3584, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3583
 *         year_has_extra_week = self.year_has_extra_week(dt)
 * 
 *         if year_has_extra_week:             # <<<<<<<<<<<<<<
 *             ret[self.qtr_with_extra_week - 1] = 14
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3586
 *             ret[self.qtr_with_extra_week - 1] = 14
 * 
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     def year_has_extra_week(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ret);
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3578
 *         return res
 * 
 *     def get_weeks(self, dt: datetime):             # <<<<<<<<<<<<<<
 *         ret = [13] * 4
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.get_weeks", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ret);
  __Pyx_XDECREF(__pyx_v_year_has_extra_week);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3588
 *         return ret
 * 
 *     def year_has_extra_week(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         # Avoid round-down errors --> normalize to get
 *         # e.g. '370D' instead of '360D23H'
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week = {"year_has_extra_week", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("year_has_extra_week (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3588, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "year_has_extra_week") < 0)) __PYX_ERR(0, 3588, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("year_has_extra_week", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3588, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.year_has_extra_week", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3588, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_12year_has_extra_week(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_12year_has_extra_week(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_norm = NULL;
  PyObject *__pyx_v_next_year_end = NULL;
  PyObject *__pyx_v_prev_year_end = NULL;
  PyObject *__pyx_v_weeks_in_year = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("year_has_extra_week", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3591
 *         # Avoid round-down errors --> normalize to get
 *         # e.g. '370D' instead of '360D23H'
 *         norm = Timestamp(dt).normalize().tz_localize(None)             # <<<<<<<<<<<<<<
 * 
 *         next_year_end = self._offset.rollforward(norm)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_dt)};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_normalize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 0+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tz_localize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, Py_None};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_norm = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3593
 *         norm = Timestamp(dt).normalize().tz_localize(None)
 * 
 *         next_year_end = self._offset.rollforward(norm)             # <<<<<<<<<<<<<<
 *         prev_year_end = norm - self._offset
 *         weeks_in_year = (next_year_end - prev_year_end).days / 7
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_rollforward); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_norm};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_next_year_end = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3594
 * 
 *         next_year_end = self._offset.rollforward(norm)
 *         prev_year_end = norm - self._offset             # <<<<<<<<<<<<<<
 *         weeks_in_year = (next_year_end - prev_year_end).days / 7
 *         assert weeks_in_year in [52, 53], weeks_in_year
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_norm, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_prev_year_end = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3595
 *         next_year_end = self._offset.rollforward(norm)
 *         prev_year_end = norm - self._offset
 *         weeks_in_year = (next_year_end - prev_year_end).days / 7             # <<<<<<<<<<<<<<
 *         assert weeks_in_year in [52, 53], weeks_in_year
 *         return weeks_in_year == 53
 */
  __pyx_t_2 = PyNumber_Subtract(__pyx_v_next_year_end, __pyx_v_prev_year_end); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_days); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_TrueDivideObjC(__pyx_t_1, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_weeks_in_year = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3596
 *         prev_year_end = norm - self._offset
 *         weeks_in_year = (next_year_end - prev_year_end).days / 7
 *         assert weeks_in_year in [52, 53], weeks_in_year             # <<<<<<<<<<<<<<
 *         return weeks_in_year == 53
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __Pyx_INCREF(__pyx_v_weeks_in_year);
    __pyx_t_2 = __pyx_v_weeks_in_year;
    __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_52, 52, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3596, __pyx_L1_error)
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L3_bool_binop_done;
    }
    __pyx_t_8 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_53, 53, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 3596, __pyx_L1_error)
    __pyx_t_7 = __pyx_t_8;
    __pyx_L3_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_8 = __pyx_t_7;
    if (unlikely(!__pyx_t_8)) {
      __pyx_t_2 = PyTuple_Pack(1, __pyx_v_weeks_in_year); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3596, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_builtin_AssertionError, __pyx_t_2, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(0, 3596, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(0, 3596, __pyx_L1_error)
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":3597
 *         weeks_in_year = (next_year_end - prev_year_end).days / 7
 *         assert weeks_in_year in [52, 53], weeks_in_year
 *         return weeks_in_year == 53             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_v_weeks_in_year, __pyx_int_53, 53, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3588
 *         return ret
 * 
 *     def year_has_extra_week(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         # Avoid round-down errors --> normalize to get
 *         # e.g. '370D' instead of '360D23H'
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.year_has_extra_week", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_norm);
  __Pyx_XDECREF(__pyx_v_next_year_end);
  __Pyx_XDECREF(__pyx_v_prev_year_end);
  __Pyx_XDECREF(__pyx_v_weeks_in_year);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3599
 *         return weeks_in_year == 53
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3599, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 3599, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3599, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3599, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_14is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_14is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_next_year_end = NULL;
  PyObject *__pyx_v_qtr_lens = NULL;
  PyObject *__pyx_v_current = NULL;
  PyObject *__pyx_v_qtr_len = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3600
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         if self._offset.is_on_offset(dt):
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3600, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3601
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         if self._offset.is_on_offset(dt):
 *             return True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3600
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         if self._offset.is_on_offset(dt):
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3602
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         if self._offset.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_is_on_offset); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_dt)};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3602, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3603
 *             return False
 *         if self._offset.is_on_offset(dt):
 *             return True             # <<<<<<<<<<<<<<
 * 
 *         next_year_end = dt - self._offset
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3602
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         if self._offset.is_on_offset(dt):             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3605
 *             return True
 * 
 *         next_year_end = dt - self._offset             # <<<<<<<<<<<<<<
 * 
 *         qtr_lens = self.get_weeks(dt)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyNumber_Subtract(((PyObject *)__pyx_v_dt), __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_next_year_end = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3607
 *         next_year_end = dt - self._offset
 * 
 *         qtr_lens = self.get_weeks(dt)             # <<<<<<<<<<<<<<
 * 
 *         current = next_year_end
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_weeks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_7 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_v_dt)};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3607, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_qtr_lens = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3609
 *         qtr_lens = self.get_weeks(dt)
 * 
 *         current = next_year_end             # <<<<<<<<<<<<<<
 *         for qtr_len in qtr_lens:
 *             current = _shift_day(current, days=qtr_len * 7)
 */
  __Pyx_INCREF(__pyx_v_next_year_end);
  __pyx_v_current = __pyx_v_next_year_end;

  /* "pandas/_libs/tslibs/offsets.pyx":3610
 * 
 *         current = next_year_end
 *         for qtr_len in qtr_lens:             # <<<<<<<<<<<<<<
 *             current = _shift_day(current, days=qtr_len * 7)
 *             if dt == current:
 */
  if (likely(PyList_CheckExact(__pyx_v_qtr_lens)) || PyTuple_CheckExact(__pyx_v_qtr_lens)) {
    __pyx_t_6 = __pyx_v_qtr_lens; __Pyx_INCREF(__pyx_t_6);
    __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_v_qtr_lens); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3610, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3610, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_6))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3610, __pyx_L1_error)
          #endif
          if (__pyx_t_8 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 3610, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_6);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 3610, __pyx_L1_error)
          #endif
          if (__pyx_t_8 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 3610, __pyx_L1_error)
        #else
        __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_6, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3610, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_9(__pyx_t_6);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 3610, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_qtr_len, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3611
 *         current = next_year_end
 *         for qtr_len in qtr_lens:
 *             current = _shift_day(current, days=qtr_len * 7)             # <<<<<<<<<<<<<<
 *             if dt == current:
 *                 return True
 */
    if (!(likely(((__pyx_v_current) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_current, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3611, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyInt_MultiplyObjC(__pyx_v_qtr_len, __pyx_int_7, 7, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3611, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3611, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(((PyDateTime_DateTime *)__pyx_v_current), __pyx_t_7)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3611, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_current, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3612
 *         for qtr_len in qtr_lens:
 *             current = _shift_day(current, days=qtr_len * 7)
 *             if dt == current:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_4 = PyObject_RichCompare(((PyObject *)__pyx_v_dt), __pyx_v_current, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3612, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3612, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":3613
 *             current = _shift_day(current, days=qtr_len * 7)
 *             if dt == current:
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L0;

      /* "pandas/_libs/tslibs/offsets.pyx":3612
 *         for qtr_len in qtr_lens:
 *             current = _shift_day(current, days=qtr_len * 7)
 *             if dt == current:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3610
 * 
 *         current = next_year_end
 *         for qtr_len in qtr_lens:             # <<<<<<<<<<<<<<
 *             current = _shift_day(current, days=qtr_len * 7)
 *             if dt == current:
 */
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3614
 *             if dt == current:
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3599
 *         return weeks_in_year == 53
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_next_year_end);
  __Pyx_XDECREF(__pyx_v_qtr_lens);
  __Pyx_XDECREF(__pyx_v_current);
  __Pyx_XDECREF(__pyx_v_qtr_len);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3616
 *         return False
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = FY5253Mixin.rule_code.__get__(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self) {
  PyObject *__pyx_v_suffix = NULL;
  int __pyx_v_qtr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3618
 *     @property
 *     def rule_code(self) -> str:
 *         suffix = FY5253Mixin.rule_code.__get__(self)             # <<<<<<<<<<<<<<
 *         qtr = self.qtr_with_extra_week
 *         return f"{suffix}-{qtr}"
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin), __pyx_n_s_rule_code); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_suffix = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3619
 *     def rule_code(self) -> str:
 *         suffix = FY5253Mixin.rule_code.__get__(self)
 *         qtr = self.qtr_with_extra_week             # <<<<<<<<<<<<<<
 *         return f"{suffix}-{qtr}"
 * 
 */
  __pyx_t_4 = __pyx_v_self->qtr_with_extra_week;
  __pyx_v_qtr = __pyx_t_4;

  /* "pandas/_libs/tslibs/offsets.pyx":3620
 *         suffix = FY5253Mixin.rule_code.__get__(self)
 *         qtr = self.qtr_with_extra_week
 *         return f"{suffix}-{qtr}"             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_6 = 127;
  __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_suffix, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_6;
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __Pyx_INCREF(__pyx_kp_u__38);
  __pyx_t_5 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__38);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__38);
  __pyx_t_3 = __Pyx_PyUnicode_From_int(__pyx_v_qtr, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3616
 *         return False
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def rule_code(self) -> str:
 *         suffix = FY5253Mixin.rule_code.__get__(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.rule_code.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_suffix);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3622
 *         return f"{suffix}-{qtr}"
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name = {"_from_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name(PyObject *__pyx_v_cls, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_from_name (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "_from_name", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_16_from_name(((PyTypeObject*)__pyx_v_cls), __pyx_v_args);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_16_from_name(PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_from_name", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3624
 *     @classmethod
 *     def _from_name(cls, *args):
 *         return cls(             # <<<<<<<<<<<<<<
 *             **dict(FY5253._parse_suffix(*args[:-1]), qtr_with_extra_week=int(args[-1]))
 *         )
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":3625
 *     def _from_name(cls, *args):
 *         return cls(
 *             **dict(FY5253._parse_suffix(*args[:-1]), qtr_with_extra_week=int(args[-1]))             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253), __pyx_n_s_parse_suffix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyTuple_GetSlice(__pyx_v_args, 0, -1L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(0, 3625, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_GetItemInt_Tuple(__pyx_v_args, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_qtr_with_extra_week, __pyx_t_5) < 0) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)(&PyDict_Type)), __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = PyDict_Copy(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3624
 *     @classmethod
 *     def _from_name(cls, *args):
 *         return cls(             # <<<<<<<<<<<<<<
 *             **dict(FY5253._parse_suffix(*args[:-1]), qtr_with_extra_week=int(args[-1]))
 *         )
 */
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_v_cls), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3622
 *         return f"{suffix}-{qtr}"
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter._from_name", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3472
 * 
 *     cdef readonly:
 *         int qtr_with_extra_week             # <<<<<<<<<<<<<<
 * 
 *     def __init__(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week___get__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week___get__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->qtr_with_extra_week); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.FY5253Quarter.qtr_with_extra_week.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3642
 *     """
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __pyx_t_5numpy_int64_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3642, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3642, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3643
 * 
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")             # <<<<<<<<<<<<<<
 *         self.normalize = state.pop("normalize")
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_n};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_6 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_6 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(0, 3643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.n = __pyx_t_6;

  /* "pandas/_libs/tslibs/offsets.pyx":3644
 *     cpdef __setstate__(self, state):
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_normalize};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3644, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->__pyx_base.__pyx_base.normalize = __pyx_t_7;

  /* "pandas/_libs/tslibs/offsets.pyx":3642
 *     """
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3642, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3642, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3642, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3646
 *         self.normalize = state.pop("normalize")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3646, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 3646, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3646, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3647, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_2_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_2_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_current_easter = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_new = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3648
 *     @apply_wraps
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)             # <<<<<<<<<<<<<<
 *         current_easter = datetime(
 *             current_easter.year, current_easter.month, current_easter.day
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_easter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3648, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_3 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_3 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_3, 1+__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_current_easter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3650
 *         current_easter = easter(other.year)
 *         current_easter = datetime(
 *             current_easter.year, current_easter.month, current_easter.day             # <<<<<<<<<<<<<<
 *         )
 *         current_easter = localize_pydatetime(current_easter, other.tzinfo)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_easter, __pyx_n_s_year); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_easter, __pyx_n_s_month); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_current_easter, __pyx_n_s_day); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/tslibs/offsets.pyx":3649
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)
 *         current_easter = datetime(             # <<<<<<<<<<<<<<
 *             current_easter.year, current_easter.month, current_easter.day
 *         )
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1)) __PYX_ERR(0, 3649, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2)) __PYX_ERR(0, 3649, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(0, 3649, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_current_easter, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3652
 *             current_easter.year, current_easter.month, current_easter.day
 *         )
 *         current_easter = localize_pydatetime(current_easter, other.tzinfo)             # <<<<<<<<<<<<<<
 * 
 *         n = self.n
 */
  if (!(likely(__Pyx_TypeTest(__pyx_v_current_easter, __pyx_ptype_7cpython_8datetime_datetime)))) __PYX_ERR(0, 3652, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 3652, __pyx_L1_error)
  __pyx_t_5 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(((PyDateTime_DateTime *)__pyx_v_current_easter), ((PyDateTime_TZInfo *)__pyx_t_4), 0)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF_SET(__pyx_v_current_easter, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3654
 *         current_easter = localize_pydatetime(current_easter, other.tzinfo)
 * 
 *         n = self.n             # <<<<<<<<<<<<<<
 *         if n >= 0 and other < current_easter:
 *             n -= 1
 */
  __pyx_t_5 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_n = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3655
 * 
 *         n = self.n
 *         if n >= 0 and other < current_easter:             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif n < 0 and other > current_easter:
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3655, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(((PyObject *)__pyx_v_other), __pyx_v_current_easter, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3655, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3655, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":3656
 *         n = self.n
 *         if n >= 0 and other < current_easter:
 *             n -= 1             # <<<<<<<<<<<<<<
 *         elif n < 0 and other > current_easter:
 *             n += 1
 */
    __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3655
 * 
 *         n = self.n
 *         if n >= 0 and other < current_easter:             # <<<<<<<<<<<<<<
 *             n -= 1
 *         elif n < 0 and other > current_easter:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3657
 *         if n >= 0 and other < current_easter:
 *             n -= 1
 *         elif n < 0 and other > current_easter:             # <<<<<<<<<<<<<<
 *             n += 1
 *         # TODO: Why does this handle the 0 case the opposite of others?
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_n, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3657, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(((PyObject *)__pyx_v_other), __pyx_v_current_easter, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3657, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_6 = __pyx_t_7;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_6) {

    /* "pandas/_libs/tslibs/offsets.pyx":3658
 *             n -= 1
 *         elif n < 0 and other > current_easter:
 *             n += 1             # <<<<<<<<<<<<<<
 *         # TODO: Why does this handle the 0 case the opposite of others?
 * 
 */
    __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_v_n, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3658, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_n, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3657
 *         if n >= 0 and other < current_easter:
 *             n -= 1
 *         elif n < 0 and other > current_easter:             # <<<<<<<<<<<<<<
 *             n += 1
 *         # TODO: Why does this handle the 0 case the opposite of others?
 */
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3663
 *         # NOTE: easter returns a datetime.date so we have to convert to type of
 *         # other
 *         new = easter(other.year + n)             # <<<<<<<<<<<<<<
 *         new = datetime(
 *             new.year,
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_easter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3663, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyNumber_Add(__pyx_t_2, __pyx_v_n); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_3 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_3 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_1};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 1+__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3663, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_new = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3665
 *         new = easter(other.year + n)
 *         new = datetime(
 *             new.year,             # <<<<<<<<<<<<<<
 *             new.month,
 *             new.day,
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_new, __pyx_n_s_year); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "pandas/_libs/tslibs/offsets.pyx":3666
 *         new = datetime(
 *             new.year,
 *             new.month,             # <<<<<<<<<<<<<<
 *             new.day,
 *             other.hour,
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_new, __pyx_n_s_month); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/tslibs/offsets.pyx":3667
 *             new.year,
 *             new.month,
 *             new.day,             # <<<<<<<<<<<<<<
 *             other.hour,
 *             other.minute,
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_new, __pyx_n_s_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pandas/_libs/tslibs/offsets.pyx":3668
 *             new.month,
 *             new.day,
 *             other.hour,             # <<<<<<<<<<<<<<
 *             other.minute,
 *             other.second,
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_4hour_hour(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3668, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pandas/_libs/tslibs/offsets.pyx":3669
 *             new.day,
 *             other.hour,
 *             other.minute,             # <<<<<<<<<<<<<<
 *             other.second,
 *             other.microsecond,
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_6minute_minute(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3669, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "pandas/_libs/tslibs/offsets.pyx":3670
 *             other.hour,
 *             other.minute,
 *             other.second,             # <<<<<<<<<<<<<<
 *             other.microsecond,
 *         )
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_6second_second(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3670, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 3670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);

  /* "pandas/_libs/tslibs/offsets.pyx":3671
 *             other.minute,
 *             other.second,
 *             other.microsecond,             # <<<<<<<<<<<<<<
 *         )
 *         return new
 */
  __pyx_t_3 = __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(__pyx_v_other); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3671, __pyx_L1_error)
  __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);

  /* "pandas/_libs/tslibs/offsets.pyx":3664
 *         # other
 *         new = easter(other.year + n)
 *         new = datetime(             # <<<<<<<<<<<<<<
 *             new.year,
 *             new.month,
 */
  __pyx_t_11 = PyTuple_New(7); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 3664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_5)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_4)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_t_1)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_2)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_8);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_t_8)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_9);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 5, __pyx_t_9)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 6, __pyx_t_10)) __PYX_ERR(0, 3664, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_8 = 0;
  __pyx_t_9 = 0;
  __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_t_11, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 3664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF_SET(__pyx_v_new, __pyx_t_10);
  __pyx_t_10 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3673
 *             other.microsecond,
 *         )
 *         return new             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(__Pyx_TypeTest(__pyx_v_new, __pyx_ptype_7cpython_8datetime_datetime)))) __PYX_ERR(0, 3673, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_new);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_new);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3646
 *         self.normalize = state.pop("normalize")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_current_easter);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_new);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3675
 *         return new
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3675, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 3675, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3675, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3675, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_4is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_6Easter_4is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3676
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return date(dt.year, dt.month, dt.day) == easter(dt.year)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3676, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3677
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         return date(dt.year, dt.month, dt.day) == easter(dt.year)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3676
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         return date(dt.year, dt.month, dt.day) == easter(dt.year)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3678
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         return date(dt.year, dt.month, dt.day) == easter(dt.year)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3678, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3678, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3678, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5)) __PYX_ERR(0, 3678, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6)) __PYX_ERR(0, 3678, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7)) __PYX_ERR(0, 3678, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_date), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_easter); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_dt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3678, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_9 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_5};
    __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 3678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_7, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3678, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3675
 *         return new
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.Easter.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3717
 *     _apply_array = BaseOffset._apply_array
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekmask = 0;
  PyObject *__pyx_v_holidays = 0;
  PyObject *__pyx_v_calendar = 0;
  PyObject *__pyx_v_offset = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekmask,&__pyx_n_s_holidays,&__pyx_n_s_calendar,&__pyx_n_s_offset_2,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":3720
 *         self,
 *         n=1,
 *         normalize=False,             # <<<<<<<<<<<<<<
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_Mon_Tue_Wed_Thu_Fri));

    /* "pandas/_libs/tslibs/offsets.pyx":3722
 *         normalize=False,
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,             # <<<<<<<<<<<<<<
 *         calendar=None,
 *         offset=timedelta(0),
 */
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));

    /* "pandas/_libs/tslibs/offsets.pyx":3723
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 *         calendar=None,             # <<<<<<<<<<<<<<
 *         offset=timedelta(0),
 *     ):
 */
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_VARARGS(__pyx_k__56);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekmask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_holidays);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_calendar);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset_2);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3717, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3717, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekmask = values[2];
    __pyx_v_holidays = values[3];
    __pyx_v_calendar = values[4];
    __pyx_v_offset = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 6, __pyx_nargs); __PYX_ERR(0, 3717, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, __pyx_v_offset);

  /* "pandas/_libs/tslibs/offsets.pyx":3717
 *     _apply_array = BaseOffset._apply_array
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3726
 *         offset=timedelta(0),
 *     ):
 *         BusinessDay.__init__(self, n, normalize, offset)             # <<<<<<<<<<<<<<
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_offset};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3727
 *     ):
 *         BusinessDay.__init__(self, n, normalize, offset)
 *         self._init_custom(weekmask, holidays, calendar)             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_custom(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3727, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3717
 *     _apply_array = BaseOffset._apply_array
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3729
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_state, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_setstate); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_state};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3729, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3730
 * 
 *     cpdef __setstate__(self, state):
 *         self.holidays = state.pop("holidays")             # <<<<<<<<<<<<<<
 *         self.weekmask = state.pop("weekmask")
 *         BusinessDay.__setstate__(self, state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_holidays};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3730, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base.holidays);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base.holidays);
  __pyx_v_self->__pyx_base.__pyx_base.holidays = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3731
 *     cpdef __setstate__(self, state):
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")             # <<<<<<<<<<<<<<
 *         BusinessDay.__setstate__(self, state)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_state, __pyx_n_s_pop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_n_u_weekmask};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.__pyx_base.weekmask);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.__pyx_base.weekmask);
  __pyx_v_self->__pyx_base.__pyx_base.weekmask = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3732
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")
 *         BusinessDay.__setstate__(self, state)             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)__pyx_v_self), __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3729
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__ = {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3729, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate__") < 0)) __PYX_ERR(0, 3729, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3729, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_2__setstate__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_v_self), __pyx_v_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_2__setstate__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___setstate__(__pyx_v_self, __pyx_v_state, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.__setstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3734
 *         BusinessDay.__setstate__(self, state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.n <= 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3734, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 3734, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3734, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_4_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_4_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_v_roll = NULL;
  PyObject *__pyx_v_date_in = NULL;
  PyObject *__pyx_v_np_dt = NULL;
  PyObject *__pyx_v_np_incr_dt = NULL;
  PyObject *__pyx_v_dt_date = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_td = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3736
 *     @apply_wraps
 *     def _apply(self, other):
 *         if self.n <= 0:             # <<<<<<<<<<<<<<
 *             roll = "forward"
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.n <= 0);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3737
 *     def _apply(self, other):
 *         if self.n <= 0:
 *             roll = "forward"             # <<<<<<<<<<<<<<
 *         else:
 *             roll = "backward"
 */
    __Pyx_INCREF(__pyx_n_u_forward);
    __pyx_v_roll = __pyx_n_u_forward;

    /* "pandas/_libs/tslibs/offsets.pyx":3736
 *     @apply_wraps
 *     def _apply(self, other):
 *         if self.n <= 0:             # <<<<<<<<<<<<<<
 *             roll = "forward"
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3739
 *             roll = "forward"
 *         else:
 *             roll = "backward"             # <<<<<<<<<<<<<<
 * 
 *         if PyDateTime_Check(other):
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_n_u_backward);
    __pyx_v_roll = __pyx_n_u_backward;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3741
 *             roll = "backward"
 * 
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             date_in = other
 *             np_dt = np.datetime64(date_in.date())
 */
  __pyx_t_1 = PyDateTime_Check(__pyx_v_other);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3742
 * 
 *         if PyDateTime_Check(other):
 *             date_in = other             # <<<<<<<<<<<<<<
 *             np_dt = np.datetime64(date_in.date())
 * 
 */
    __Pyx_INCREF(__pyx_v_other);
    __pyx_v_date_in = __pyx_v_other;

    /* "pandas/_libs/tslibs/offsets.pyx":3743
 *         if PyDateTime_Check(other):
 *             date_in = other
 *             np_dt = np.datetime64(date_in.date())             # <<<<<<<<<<<<<<
 * 
 *             np_incr_dt = np.busday_offset(
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_datetime64); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_date_in, __pyx_n_s_date); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3743, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3743, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_np_dt = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3745
 *             np_dt = np.datetime64(date_in.date())
 * 
 *             np_incr_dt = np.busday_offset(             # <<<<<<<<<<<<<<
 *                 np_dt, self.n, roll=roll, busdaycal=self.calendar
 *             )
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_busday_offset); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3746
 * 
 *             np_incr_dt = np.busday_offset(
 *                 np_dt, self.n, roll=roll, busdaycal=self.calendar             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pandas/_libs/tslibs/offsets.pyx":3745
 *             np_dt = np.datetime64(date_in.date())
 * 
 *             np_incr_dt = np.busday_offset(             # <<<<<<<<<<<<<<
 *                 np_dt, self.n, roll=roll, busdaycal=self.calendar
 *             )
 */
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_np_dt);
    __Pyx_GIVEREF(__pyx_v_np_dt);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_np_dt)) __PYX_ERR(0, 3745, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2)) __PYX_ERR(0, 3745, __pyx_L1_error);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3746
 * 
 *             np_incr_dt = np.busday_offset(
 *                 np_dt, self.n, roll=roll, busdaycal=self.calendar             # <<<<<<<<<<<<<<
 *             )
 * 
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3746, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_roll, __pyx_v_roll) < 0) __PYX_ERR(0, 3746, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_busdaycal, __pyx_v_self->__pyx_base.__pyx_base.calendar) < 0) __PYX_ERR(0, 3746, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":3745
 *             np_dt = np.datetime64(date_in.date())
 * 
 *             np_incr_dt = np.busday_offset(             # <<<<<<<<<<<<<<
 *                 np_dt, self.n, roll=roll, busdaycal=self.calendar
 *             )
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_np_incr_dt = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3749
 *             )
 * 
 *             dt_date = np_incr_dt.astype(datetime)             # <<<<<<<<<<<<<<
 *             result = datetime.combine(dt_date, date_in.time())
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_np_incr_dt, __pyx_n_s_astype); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3749, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_ptype_7cpython_8datetime_datetime)};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_dt_date = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3750
 * 
 *             dt_date = np_incr_dt.astype(datetime)
 *             result = datetime.combine(dt_date, date_in.time())             # <<<<<<<<<<<<<<
 * 
 *             if self.offset:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_7cpython_8datetime_datetime), __pyx_n_s_combine); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_date_in, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_v_dt_date, __pyx_t_3};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3750, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_result = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3752
 *             result = datetime.combine(dt_date, date_in.time())
 * 
 *             if self.offset:             # <<<<<<<<<<<<<<
 *                 result = result + self.offset
 *             return result
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 3752, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":3753
 * 
 *             if self.offset:
 *                 result = result + self.offset             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_2 = PyNumber_Add(__pyx_v_result, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3753, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":3752
 *             result = datetime.combine(dt_date, date_in.time())
 * 
 *             if self.offset:             # <<<<<<<<<<<<<<
 *                 result = result + self.offset
 *             return result
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":3754
 *             if self.offset:
 *                 result = result + self.offset
 *             return result             # <<<<<<<<<<<<<<
 * 
 *         elif is_any_td_scalar(other):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3741
 *             roll = "backward"
 * 
 *         if PyDateTime_Check(other):             # <<<<<<<<<<<<<<
 *             date_in = other
 *             np_dt = np.datetime64(date_in.date())
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3756
 *             return result
 * 
 *         elif is_any_td_scalar(other):             # <<<<<<<<<<<<<<
 *             td = Timedelta(self.offset) + other
 *             return BDay(self.n, offset=td.to_pytimedelta(), normalize=self.normalize)
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_10timedeltas_is_any_td_scalar(__pyx_v_other); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3756, __pyx_L1_error)
  if (likely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":3757
 * 
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other             # <<<<<<<<<<<<<<
 *             return BDay(self.n, offset=td.to_pytimedelta(), normalize=self.normalize)
 *         else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = PyNumber_Add(__pyx_t_2, __pyx_v_other); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_td = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3758
 *         elif is_any_td_scalar(other):
 *             td = Timedelta(self.offset) + other
 *             return BDay(self.n, offset=td.to_pytimedelta(), normalize=self.normalize)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ApplyTypeError(
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_BDay); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(0, 3758, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_td, __pyx_n_s_to_pytimedelta); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3758, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_offset_2, __pyx_t_4) < 0) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.normalize); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_normalize, __pyx_t_4) < 0) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3758, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3756
 *             return result
 * 
 *         elif is_any_td_scalar(other):             # <<<<<<<<<<<<<<
 *             td = Timedelta(self.offset) + other
 *             return BDay(self.n, offset=td.to_pytimedelta(), normalize=self.normalize)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3760
 *             return BDay(self.n, offset=td.to_pytimedelta(), normalize=self.normalize)
 *         else:
 *             raise ApplyTypeError(             # <<<<<<<<<<<<<<
 *                 "Only know how to combine trading day with "
 *                 "datetime, datetime64 or timedelta."
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ApplyTypeError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3760, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_Only_know_how_to_combine_trading};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3760, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 3760, __pyx_L1_error)
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3734
 *         BusinessDay.__setstate__(self, state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.n <= 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_roll);
  __Pyx_XDECREF(__pyx_v_date_in);
  __Pyx_XDECREF(__pyx_v_np_dt);
  __Pyx_XDECREF(__pyx_v_np_incr_dt);
  __Pyx_XDECREF(__pyx_v_dt_date);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_td);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3765
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset = {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_dt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_on_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dt,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dt)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3765, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "is_on_offset") < 0)) __PYX_ERR(0, 3765, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_dt = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("is_on_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3765, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dt), __pyx_ptype_7cpython_8datetime_datetime, 0, "dt", 0))) __PYX_ERR(0, 3765, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_6is_on_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_v_self), __pyx_v_dt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_6is_on_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_self, PyDateTime_DateTime *__pyx_v_dt) {
  PyObject *__pyx_v_day64 = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_on_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3766
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         day64 = _to_dt64D(dt)
 */
  if (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.normalize) {
  } else {
    __pyx_t_1 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.normalize;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__is_normalized(__pyx_v_dt); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3766, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":3767
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):
 *             return False             # <<<<<<<<<<<<<<
 *         day64 = _to_dt64D(dt)
 *         return np.is_busday(day64, busdaycal=self.calendar)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":3766
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 *         if self.normalize and not _is_normalized(dt):             # <<<<<<<<<<<<<<
 *             return False
 *         day64 = _to_dt64D(dt)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3768
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 *         day64 = _to_dt64D(dt)             # <<<<<<<<<<<<<<
 *         return np.is_busday(day64, busdaycal=self.calendar)
 * 
 */
  __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__to_dt64D(((PyObject *)__pyx_v_dt)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_day64 = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3769
 *             return False
 *         day64 = _to_dt64D(dt)
 *         return np.is_busday(day64, busdaycal=self.calendar)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_is_busday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_day64);
  __Pyx_GIVEREF(__pyx_v_day64);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_day64)) __PYX_ERR(0, 3769, __pyx_L1_error);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_busdaycal, __pyx_v_self->__pyx_base.__pyx_base.calendar) < 0) __PYX_ERR(0, 3769, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 3769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3765
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessDay.is_on_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_day64);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3869
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekmask = 0;
  PyObject *__pyx_v_holidays = 0;
  PyObject *__pyx_v_calendar = 0;
  PyObject *__pyx_v_start = 0;
  PyObject *__pyx_v_end = 0;
  PyObject *__pyx_v_offset = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[8] = {0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekmask,&__pyx_n_s_holidays,&__pyx_n_s_calendar,&__pyx_n_s_start,&__pyx_n_s_end,&__pyx_n_s_offset_2,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":3872
 *         self,
 *         n=1,
 *         normalize=False,             # <<<<<<<<<<<<<<
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_Mon_Tue_Wed_Thu_Fri));

    /* "pandas/_libs/tslibs/offsets.pyx":3874
 *         normalize=False,
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,             # <<<<<<<<<<<<<<
 *         calendar=None,
 *         start="09:00",
 */
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));

    /* "pandas/_libs/tslibs/offsets.pyx":3875
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 *         calendar=None,             # <<<<<<<<<<<<<<
 *         start="09:00",
 *         end="17:00",
 */
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_09_00));
    values[6] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_17_00));
    values[7] = __Pyx_Arg_NewRef_VARARGS(__pyx_k__57);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekmask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_holidays);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_calendar);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_start);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_end);
          if (value) { values[6] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset_2);
          if (value) { values[7] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3869, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3869, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekmask = values[2];
    __pyx_v_holidays = values[3];
    __pyx_v_calendar = values[4];
    __pyx_v_start = values[5];
    __pyx_v_end = values[6];
    __pyx_v_offset = values[7];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 8, __pyx_nargs); __PYX_ERR(0, 3869, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessHour.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, __pyx_v_start, __pyx_v_end, __pyx_v_offset);

  /* "pandas/_libs/tslibs/offsets.pyx":3869
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_start, PyObject *__pyx_v_end, PyObject *__pyx_v_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3880
 *         offset=timedelta(0),
 *     ):
 *         BusinessHour.__init__(self, n, normalize, start=start, end=end, offset=offset)             # <<<<<<<<<<<<<<
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour), __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(0, 3880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_n);
  __Pyx_GIVEREF(__pyx_v_n);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_n)) __PYX_ERR(0, 3880, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_normalize);
  __Pyx_GIVEREF(__pyx_v_normalize);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_normalize)) __PYX_ERR(0, 3880, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_start, __pyx_v_start) < 0) __PYX_ERR(0, 3880, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_end, __pyx_v_end) < 0) __PYX_ERR(0, 3880, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_offset_2, __pyx_v_offset) < 0) __PYX_ERR(0, 3880, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3881
 *     ):
 *         BusinessHour.__init__(self, n, normalize, start=start, end=end, offset=offset)
 *         self._init_custom(weekmask, holidays, calendar)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_custom(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 3881, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3869
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.CustomBusinessHour.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3911
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_normalize = 0;
  PyObject *__pyx_v_weekmask = 0;
  PyObject *__pyx_v_holidays = 0;
  PyObject *__pyx_v_calendar = 0;
  PyObject *__pyx_v_offset = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_n,&__pyx_n_s_normalize,&__pyx_n_s_weekmask,&__pyx_n_s_holidays,&__pyx_n_s_calendar,&__pyx_n_s_offset_2,0};
    values[0] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_int_1));

    /* "pandas/_libs/tslibs/offsets.pyx":3914
 *         self,
 *         n=1,
 *         normalize=False,             # <<<<<<<<<<<<<<
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 */
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_False));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_kp_u_Mon_Tue_Wed_Thu_Fri));

    /* "pandas/_libs/tslibs/offsets.pyx":3916
 *         normalize=False,
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,             # <<<<<<<<<<<<<<
 *         calendar=None,
 *         offset=timedelta(0),
 */
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));

    /* "pandas/_libs/tslibs/offsets.pyx":3917
 *         weekmask="Mon Tue Wed Thu Fri",
 *         holidays=None,
 *         calendar=None,             # <<<<<<<<<<<<<<
 *         offset=timedelta(0),
 *     ):
 */
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_VARARGS(__pyx_k__58);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_normalize);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_weekmask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_holidays);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_calendar);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_offset_2);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3911, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 3911, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_n = values[0];
    __pyx_v_normalize = values[1];
    __pyx_v_weekmask = values[2];
    __pyx_v_holidays = values[3];
    __pyx_v_calendar = values[4];
    __pyx_v_offset = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 6, __pyx_nargs); __PYX_ERR(0, 3911, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth___init__(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, __pyx_v_offset);

  /* "pandas/_libs/tslibs/offsets.pyx":3911
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth___init__(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self, PyObject *__pyx_v_n, PyObject *__pyx_v_normalize, PyObject *__pyx_v_weekmask, PyObject *__pyx_v_holidays, PyObject *__pyx_v_calendar, PyObject *__pyx_v_offset) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3920
 *         offset=timedelta(0),
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)             # <<<<<<<<<<<<<<
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3920, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[5] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_v_n, __pyx_v_normalize, __pyx_v_offset};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3920, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3921
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)
 *         self._init_custom(weekmask, holidays, calendar)             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._init_custom(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)__pyx_v_self), __pyx_v_weekmask, __pyx_v_holidays, __pyx_v_calendar, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3911
 *     )
 * 
 *     def __init__(             # <<<<<<<<<<<<<<
 *         self,
 *         n=1,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3923
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def cbday_roll(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll, "\n        Define default roll function to be called in apply method.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll = {"cbday_roll", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cbday_roll (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("cbday_roll", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "cbday_roll", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self) {
  PyObject *__pyx_v_cbday_kwds = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *__pyx_v_cbday = NULL;
  PyObject *__pyx_v_roll_func = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cbday_roll", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3928
 *         Define default roll function to be called in apply method.
 *         """
 *         cbday_kwds = self.kwds.copy()             # <<<<<<<<<<<<<<
 *         cbday_kwds["offset"] = timedelta(0)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_kwds); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_copy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_cbday_kwds = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3929
 *         """
 *         cbday_kwds = self.kwds.copy()
 *         cbday_kwds["offset"] = timedelta(0)             # <<<<<<<<<<<<<<
 * 
 *         cbday = CustomBusinessDay(n=1, normalize=False, **cbday_kwds)
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_v_cbday_kwds, __pyx_n_u_offset_2, __pyx_t_1) < 0))) __PYX_ERR(0, 3929, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3931
 *         cbday_kwds["offset"] = timedelta(0)
 * 
 *         cbday = CustomBusinessDay(n=1, normalize=False, **cbday_kwds)             # <<<<<<<<<<<<<<
 * 
 *         if self._prefix.endswith("S"):
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_n, __pyx_int_1) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_normalize, Py_False) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  if (unlikely(__pyx_v_cbday_kwds == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "argument after ** must be a mapping, not NoneType");
    __PYX_ERR(0, 3931, __pyx_L1_error)
  }
  if (__Pyx_MergeKeywords(__pyx_t_1, __pyx_v_cbday_kwds) < 0) __PYX_ERR(0, 3931, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cbday = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3933
 *         cbday = CustomBusinessDay(n=1, normalize=False, **cbday_kwds)
 * 
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             roll_func = cbday.rollforward
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_endswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_n_u_S};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3933, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":3935
 *         if self._prefix.endswith("S"):
 *             # MonthBegin
 *             roll_func = cbday.rollforward             # <<<<<<<<<<<<<<
 *         else:
 *             # MonthEnd
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cbday), __pyx_n_s_rollforward); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3935, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_roll_func = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3933
 *         cbday = CustomBusinessDay(n=1, normalize=False, **cbday_kwds)
 * 
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             roll_func = cbday.rollforward
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3938
 *         else:
 *             # MonthEnd
 *             roll_func = cbday.rollback             # <<<<<<<<<<<<<<
 *         return roll_func
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_cbday), __pyx_n_s_rollback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3938, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_roll_func = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3939
 *             # MonthEnd
 *             roll_func = cbday.rollback
 *         return roll_func             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_roll_func);
  __pyx_r = __pyx_v_roll_func;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3923
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def cbday_roll(self):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth.cbday_roll", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cbday_kwds);
  __Pyx_XDECREF((PyObject *)__pyx_v_cbday);
  __Pyx_XDECREF(__pyx_v_roll_func);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3941
 *         return roll_func
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset = {"m_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("m_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("m_offset", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "m_offset", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_4m_offset(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_4m_offset(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *__pyx_v_moff = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("m_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3943
 *     @cache_readonly
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             moff = MonthBegin(n=1, normalize=False)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_endswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_S};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3943, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3943, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":3945
 *         if self._prefix.endswith("S"):
 *             # MonthBegin
 *             moff = MonthBegin(n=1, normalize=False)             # <<<<<<<<<<<<<<
 *         else:
 *             # MonthEnd
 */
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_n, __pyx_int_1) < 0) __PYX_ERR(0, 3945, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_normalize, Py_False) < 0) __PYX_ERR(0, 3945, __pyx_L1_error)
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_moff = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3943
 *     @cache_readonly
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             moff = MonthBegin(n=1, normalize=False)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3948
 *         else:
 *             # MonthEnd
 *             moff = MonthEnd(n=1, normalize=False)             # <<<<<<<<<<<<<<
 *         return moff
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_n, __pyx_int_1) < 0) __PYX_ERR(0, 3948, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_normalize, Py_False) < 0) __PYX_ERR(0, 3948, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd), __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3948, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_moff = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)__pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3949
 *             # MonthEnd
 *             moff = MonthEnd(n=1, normalize=False)
 *         return moff             # <<<<<<<<<<<<<<
 * 
 *     @cache_readonly
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_moff);
  __pyx_r = ((PyObject *)__pyx_v_moff);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3941
 *         return roll_func
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth.m_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_moff);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3951
 *         return moff
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def month_roll(self):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll, "\n        Define default roll function to be called in apply method.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll = {"month_roll", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("month_roll (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("month_roll", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "month_roll", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self) {
  PyObject *__pyx_v_roll_func = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("month_roll", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3956
 *         Define default roll function to be called in apply method.
 *         """
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             roll_func = self.m_offset.rollback
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_endswith); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_n_u_S};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3956, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 3956, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":3958
 *         if self._prefix.endswith("S"):
 *             # MonthBegin
 *             roll_func = self.m_offset.rollback             # <<<<<<<<<<<<<<
 *         else:
 *             # MonthEnd
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_m_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_rollback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3958, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_roll_func = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3956
 *         Define default roll function to be called in apply method.
 *         """
 *         if self._prefix.endswith("S"):             # <<<<<<<<<<<<<<
 *             # MonthBegin
 *             roll_func = self.m_offset.rollback
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3961
 *         else:
 *             # MonthEnd
 *             roll_func = self.m_offset.rollforward             # <<<<<<<<<<<<<<
 *         return roll_func
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_m_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 3961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_rollforward); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3961, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_roll_func = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":3962
 *             # MonthEnd
 *             roll_func = self.m_offset.rollforward
 *         return roll_func             # <<<<<<<<<<<<<<
 * 
 *     @apply_wraps
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_roll_func);
  __pyx_r = __pyx_v_roll_func;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3951
 *         return moff
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def month_roll(self):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth.month_roll", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_roll_func);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":3964
 *         return roll_func
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # First move to month offset
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply = {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_apply (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 3964, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_apply") < 0)) __PYX_ERR(0, 3964, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_apply", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 3964, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 3965, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_8_apply(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)__pyx_v_self), __pyx_v_other);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_8_apply(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *__pyx_v_self, PyDateTime_DateTime *__pyx_v_other) {
  PyObject *__pyx_v_cur_month_offset_date = NULL;
  PyObject *__pyx_v_compare_date = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_new = NULL;
  PyObject *__pyx_v_result = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_apply", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":3967
 *     def _apply(self, other: datetime) -> datetime:
 *         # First move to month offset
 *         cur_month_offset_date = self.month_roll(other)             # <<<<<<<<<<<<<<
 * 
 *         # Find this custom month offset
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_month_roll); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_other)};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_cur_month_offset_date = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3970
 * 
 *         # Find this custom month offset
 *         compare_date = self.cbday_roll(cur_month_offset_date)             # <<<<<<<<<<<<<<
 *         n = roll_convention(other.day, self.n, compare_date.day)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cbday_roll); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_cur_month_offset_date};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_compare_date = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3971
 *         # Find this custom month offset
 *         compare_date = self.cbday_roll(cur_month_offset_date)
 *         n = roll_convention(other.day, self.n, compare_date.day)             # <<<<<<<<<<<<<<
 * 
 *         new = cur_month_offset_date + n * self.m_offset
 */
  __pyx_t_4 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_other); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3971, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_compare_date, __pyx_n_s_day); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3971, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_t_4, __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.n, __pyx_t_5, 0); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 3971, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_n = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3973
 *         n = roll_convention(other.day, self.n, compare_date.day)
 * 
 *         new = cur_month_offset_date + n * self.m_offset             # <<<<<<<<<<<<<<
 *         result = self.cbday_roll(new)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_m_offset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_n, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_Add(__pyx_v_cur_month_offset_date, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_new = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3974
 * 
 *         new = cur_month_offset_date + n * self.m_offset
 *         result = self.cbday_roll(new)             # <<<<<<<<<<<<<<
 * 
 *         if self.offset:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_cbday_roll); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_new};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3974, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3976
 *         result = self.cbday_roll(new)
 * 
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             result = result + self.offset
 *         return result
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 3976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {

    /* "pandas/_libs/tslibs/offsets.pyx":3977
 * 
 *         if self.offset:
 *             result = result + self.offset             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_offset_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Add(__pyx_v_result, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3977, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":3976
 *         result = self.cbday_roll(new)
 * 
 *         if self.offset:             # <<<<<<<<<<<<<<
 *             result = result + self.offset
 *         return result
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":3978
 *         if self.offset:
 *             result = result + self.offset
 *         return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_result) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_result, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 3978, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_v_result);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":3964
 *         return roll_func
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # First move to month offset
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._CustomBusinessMonth._apply", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cur_month_offset_date);
  __Pyx_XDECREF(__pyx_v_compare_date);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_new);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4071
 * 
 * # TODO: better name?
 * def _get_offset(name: str) -> BaseOffset:             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object associated with rule name.
 */

/* Python wrapper */
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_9_get_offset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_8_get_offset, "\n    Return DateOffset object associated with rule name.\n\n    Examples\n    --------\n    _get_offset('EOM') --> BMonthEnd(1)\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_9_get_offset = {"_get_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_9_get_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_8_get_offset};
static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_9_get_offset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_name = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name_2,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4071, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_offset") < 0)) __PYX_ERR(0, 4071, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_name = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4071, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._get_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_name), (&PyUnicode_Type), 0, "name", 1))) __PYX_ERR(0, 4071, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_8_get_offset(__pyx_self, __pyx_v_name);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_8_get_offset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_name) {
  PyObject *__pyx_v_split = NULL;
  PyObject *__pyx_v_klass = NULL;
  PyObject *__pyx_v_offset = NULL;
  PyObject *__pyx_v_err = NULL;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_offset", 0);
  __Pyx_INCREF(__pyx_v_name);

  /* "pandas/_libs/tslibs/offsets.pyx":4079
 *     _get_offset('EOM') --> BMonthEnd(1)
 *     """
 *     if name not in _dont_uppercase:             # <<<<<<<<<<<<<<
 *         name = name.upper()
 *         name = _lite_rule_alias.get(name, name)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_dont_uppercase); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4079, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":4080
 *     """
 *     if name not in _dont_uppercase:
 *         name = name.upper()             # <<<<<<<<<<<<<<
 *         name = _lite_rule_alias.get(name, name)
 *         name = _lite_rule_alias.get(name.lower(), name)
 */
    __pyx_t_1 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyUnicode_Type_upper, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4080, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 4080, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_name, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":4081
 *     if name not in _dont_uppercase:
 *         name = name.upper()
 *         name = _lite_rule_alias.get(name, name)             # <<<<<<<<<<<<<<
 *         name = _lite_rule_alias.get(name.lower(), name)
 *     else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_lite_rule_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4081, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4081, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_name, __pyx_v_name};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4081, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 4081, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_name, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":4082
 *         name = name.upper()
 *         name = _lite_rule_alias.get(name, name)
 *         name = _lite_rule_alias.get(name.lower(), name)             # <<<<<<<<<<<<<<
 *     else:
 *         name = _lite_rule_alias.get(name, name)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_lite_rule_alias); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyUnicode_Type_lower, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4082, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_4, __pyx_v_name};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4082, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 4082, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_name, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":4079
 *     _get_offset('EOM') --> BMonthEnd(1)
 *     """
 *     if name not in _dont_uppercase:             # <<<<<<<<<<<<<<
 *         name = name.upper()
 *         name = _lite_rule_alias.get(name, name)
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4084
 *         name = _lite_rule_alias.get(name.lower(), name)
 *     else:
 *         name = _lite_rule_alias.get(name, name)             # <<<<<<<<<<<<<<
 * 
 *     if name not in _offset_map:
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_lite_rule_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_name, __pyx_v_name};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4084, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_1))) __PYX_ERR(0, 4084, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_name, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":4086
 *         name = _lite_rule_alias.get(name, name)
 * 
 *     if name not in _offset_map:             # <<<<<<<<<<<<<<
 *         try:
 *             split = name.split("-")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_offset_map); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_t_1, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 4086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":4087
 * 
 *     if name not in _offset_map:
 *         try:             # <<<<<<<<<<<<<<
 *             split = name.split("-")
 *             klass = prefix_mapping[split[0]]
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":4088
 *     if name not in _offset_map:
 *         try:
 *             split = name.split("-")             # <<<<<<<<<<<<<<
 *             klass = prefix_mapping[split[0]]
 *             # handles case where there's no suffix (and will TypeError if too
 */
        if (unlikely(__pyx_v_name == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "split");
          __PYX_ERR(0, 4088, __pyx_L5_error)
        }
        __pyx_t_1 = PyUnicode_Split(__pyx_v_name, __Pyx_NoneAsNull(__pyx_kp_u__38), -1L); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4088, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_split = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4089
 *         try:
 *             split = name.split("-")
 *             klass = prefix_mapping[split[0]]             # <<<<<<<<<<<<<<
 *             # handles case where there's no suffix (and will TypeError if too
 *             # many '-')
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_prefix_mapping); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4089, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_split, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4089, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4089, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_klass = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4092
 *             # handles case where there's no suffix (and will TypeError if too
 *             # many '-')
 *             offset = klass._from_name(*split[1:])             # <<<<<<<<<<<<<<
 *         except (ValueError, TypeError, KeyError) as err:
 *             # bad prefix or suffix
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_klass, __pyx_n_s_from_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4092, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_split, 1, 0, NULL, NULL, &__pyx_slice__53, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4092, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PySequence_Tuple(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4092, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4092, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_offset = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4087
 * 
 *     if name not in _offset_map:
 *         try:             # <<<<<<<<<<<<<<
 *             split = name.split("-")
 *             klass = prefix_mapping[split[0]]
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":4093
 *             # many '-')
 *             offset = klass._from_name(*split[1:])
 *         except (ValueError, TypeError, KeyError) as err:             # <<<<<<<<<<<<<<
 *             # bad prefix or suffix
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(name)) from err
 */
      __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
      if (__pyx_t_5) {
        __Pyx_AddTraceback("pandas._libs.tslibs.offsets._get_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_3) < 0) __PYX_ERR(0, 4093, __pyx_L7_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_v_err = __pyx_t_1;
        /*try:*/ {

          /* "pandas/_libs/tslibs/offsets.pyx":4095
 *         except (ValueError, TypeError, KeyError) as err:
 *             # bad prefix or suffix
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(name)) from err             # <<<<<<<<<<<<<<
 *         # cache
 *         _offset_map[name] = offset
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_INVALID_FREQ_ERR_MSG); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 4095, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_format); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4095, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __pyx_t_10 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_name};
            __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4095, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
          __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 4095, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_Raise(__pyx_t_11, 0, 0, __pyx_v_err);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __PYX_ERR(0, 4095, __pyx_L16_error)
        }

        /* "pandas/_libs/tslibs/offsets.pyx":4093
 *             # many '-')
 *             offset = klass._from_name(*split[1:])
 *         except (ValueError, TypeError, KeyError) as err:             # <<<<<<<<<<<<<<
 *             # bad prefix or suffix
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(name)) from err
 */
        /*finally:*/ {
          __pyx_L16_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __pyx_t_5 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            }
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
            __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
            goto __pyx_L7_except_error;
          }
        }
      }
      goto __pyx_L7_except_error;

      /* "pandas/_libs/tslibs/offsets.pyx":4087
 * 
 *     if name not in _offset_map:
 *         try:             # <<<<<<<<<<<<<<
 *             split = name.split("-")
 *             klass = prefix_mapping[split[0]]
 */
      __pyx_L7_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L10_try_end:;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4097
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(name)) from err
 *         # cache
 *         _offset_map[name] = offset             # <<<<<<<<<<<<<<
 * 
 *     return _offset_map[name]
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_offset_map); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely((PyObject_SetItem(__pyx_t_3, __pyx_v_name, __pyx_v_offset) < 0))) __PYX_ERR(0, 4097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":4086
 *         name = _lite_rule_alias.get(name, name)
 * 
 *     if name not in _offset_map:             # <<<<<<<<<<<<<<
 *         try:
 *             split = name.split("-")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4099
 *         _offset_map[name] = offset
 * 
 *     return _offset_map[name]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_offset_map); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset))))) __PYX_ERR(0, 4099, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4071
 * 
 * # TODO: better name?
 * def _get_offset(name: str) -> BaseOffset:             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object associated with rule name.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._get_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_split);
  __Pyx_XDECREF(__pyx_v_klass);
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4102
 * 
 * 
 * cpdef to_offset(freq):             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object from string or datetime.timedelta object.
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11to_offset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset(PyObject *__pyx_v_freq, CYTHON_UNUSED int __pyx_skip_dispatch) {
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_v_stride_sign = NULL;
  PyObject *__pyx_v_split = NULL;
  PyObject *__pyx_v_tups = NULL;
  PyObject *__pyx_v_n = NULL;
  PyObject *__pyx_v_sep = NULL;
  PyObject *__pyx_v_stride = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_td = NULL;
  PyObject *__pyx_v_off = NULL;
  PyObject *__pyx_v_offset = NULL;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *(*__pyx_t_18)(PyObject *);
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_offset", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":4143
 *     <Hour>
 *     """
 *     if freq is None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = (__pyx_v_freq == Py_None);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4144
 *     """
 *     if freq is None:
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(freq, BaseOffset):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4143
 *     <Hour>
 *     """
 *     if freq is None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4146
 *         return None
 * 
 *     if isinstance(freq, BaseOffset):             # <<<<<<<<<<<<<<
 *         return freq
 * 
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_freq, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4147
 * 
 *     if isinstance(freq, BaseOffset):
 *         return freq             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(freq, tuple):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_freq);
    __pyx_r = __pyx_v_freq;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4146
 *         return None
 * 
 *     if isinstance(freq, BaseOffset):             # <<<<<<<<<<<<<<
 *         return freq
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4149
 *         return freq
 * 
 *     if isinstance(freq, tuple):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             f"to_offset does not support tuples {freq}, pass as a string instead"
 */
  __pyx_t_1 = PyTuple_Check(__pyx_v_freq); 
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4151
 *     if isinstance(freq, tuple):
 *         raise TypeError(
 *             f"to_offset does not support tuples {freq}, pass as a string instead"             # <<<<<<<<<<<<<<
 *         )
 * 
 */
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = 127;
    __Pyx_INCREF(__pyx_kp_u_to_offset_does_not_support_tuple);
    __pyx_t_3 += 34;
    __Pyx_GIVEREF(__pyx_kp_u_to_offset_does_not_support_tuple);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_to_offset_does_not_support_tuple);
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_freq, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
    __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_u_pass_as_a_string_instead);
    __pyx_t_3 += 26;
    __Pyx_GIVEREF(__pyx_kp_u_pass_as_a_string_instead);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_pass_as_a_string_instead);
    __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/tslibs/offsets.pyx":4150
 * 
 *     if isinstance(freq, tuple):
 *         raise TypeError(             # <<<<<<<<<<<<<<
 *             f"to_offset does not support tuples {freq}, pass as a string instead"
 *         )
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 4150, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":4149
 *         return freq
 * 
 *     if isinstance(freq, tuple):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             f"to_offset does not support tuples {freq}, pass as a string instead"
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4154
 *         )
 * 
 *     elif PyDelta_Check(freq):             # <<<<<<<<<<<<<<
 *         return delta_to_tick(freq)
 * 
 */
  __pyx_t_1 = PyDelta_Check(__pyx_v_freq);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4155
 * 
 *     elif PyDelta_Check(freq):
 *         return delta_to_tick(freq)             # <<<<<<<<<<<<<<
 * 
 *     elif isinstance(freq, str):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_delta_to_tick); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_freq};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4154
 *         )
 * 
 *     elif PyDelta_Check(freq):             # <<<<<<<<<<<<<<
 *         return delta_to_tick(freq)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4157
 *         return delta_to_tick(freq)
 * 
 *     elif isinstance(freq, str):             # <<<<<<<<<<<<<<
 *         delta = None
 *         stride_sign = None
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_freq); 
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4158
 * 
 *     elif isinstance(freq, str):
 *         delta = None             # <<<<<<<<<<<<<<
 *         stride_sign = None
 * 
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_delta = Py_None;

    /* "pandas/_libs/tslibs/offsets.pyx":4159
 *     elif isinstance(freq, str):
 *         delta = None
 *         stride_sign = None             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_stride_sign = Py_None;

    /* "pandas/_libs/tslibs/offsets.pyx":4161
 *         stride_sign = None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             split = opattern.split(freq)
 *             if split[-1] != "" and not split[-1].isspace():
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":4162
 * 
 *         try:
 *             split = opattern.split(freq)             # <<<<<<<<<<<<<<
 *             if split[-1] != "" and not split[-1].isspace():
 *                 # the last element must be blank
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_opattern); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4162, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_split); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4162, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_freq};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4162, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
        __pyx_v_split = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4163
 *         try:
 *             split = opattern.split(freq)
 *             if split[-1] != "" and not split[-1].isspace():             # <<<<<<<<<<<<<<
 *                 # the last element must be blank
 *                 raise ValueError("last element must be blank")
 */
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_split, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4163, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_11 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u__15, Py_NE)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 4163, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_11) {
        } else {
          __pyx_t_1 = __pyx_t_11;
          goto __pyx_L13_bool_binop_done;
        }
        __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_split, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4163, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_isspace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4163, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4163, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 4163, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_12 = (!__pyx_t_11);
        __pyx_t_1 = __pyx_t_12;
        __pyx_L13_bool_binop_done:;
        if (unlikely(__pyx_t_1)) {

          /* "pandas/_libs/tslibs/offsets.pyx":4165
 *             if split[-1] != "" and not split[-1].isspace():
 *                 # the last element must be blank
 *                 raise ValueError("last element must be blank")             # <<<<<<<<<<<<<<
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 */
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4165, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(0, 4165, __pyx_L6_error)

          /* "pandas/_libs/tslibs/offsets.pyx":4163
 *         try:
 *             split = opattern.split(freq)
 *             if split[-1] != "" and not split[-1].isspace():             # <<<<<<<<<<<<<<
 *                 # the last element must be blank
 *                 raise ValueError("last element must be blank")
 */
        }

        /* "pandas/_libs/tslibs/offsets.pyx":4167
 *                 raise ValueError("last element must be blank")
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])             # <<<<<<<<<<<<<<
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():
 */
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_split, __pyx_slice__60); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4167, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_split, __pyx_slice__61); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4167, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_split, __pyx_slice__62); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4167, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_13 = PyTuple_New(3); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4167, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2)) __PYX_ERR(0, 4167, __pyx_L6_error);
        __Pyx_GIVEREF(__pyx_t_5);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_5)) __PYX_ERR(0, 4167, __pyx_L6_error);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_13, 2, __pyx_t_6)) __PYX_ERR(0, 4167, __pyx_L6_error);
        __pyx_t_2 = 0;
        __pyx_t_5 = 0;
        __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_13, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4167, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_v_tups = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4168
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 *             for n, (sep, stride, name) in enumerate(tups):             # <<<<<<<<<<<<<<
 *                 if sep != "" and not sep.isspace():
 *                     raise ValueError("separator must be spaces")
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_6 = __pyx_int_0;
        if (likely(PyList_CheckExact(__pyx_v_tups)) || PyTuple_CheckExact(__pyx_v_tups)) {
          __pyx_t_13 = __pyx_v_tups; __Pyx_INCREF(__pyx_t_13);
          __pyx_t_3 = 0;
          __pyx_t_14 = NULL;
        } else {
          __pyx_t_3 = -1; __pyx_t_13 = PyObject_GetIter(__pyx_v_tups); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4168, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 4168, __pyx_L6_error)
        }
        for (;;) {
          if (likely(!__pyx_t_14)) {
            if (likely(PyList_CheckExact(__pyx_t_13))) {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4168, __pyx_L6_error)
                #endif
                if (__pyx_t_3 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_5 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 4168, __pyx_L6_error)
              #else
              __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4168, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_5);
              #endif
            } else {
              {
                Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_13);
                #if !CYTHON_ASSUME_SAFE_MACROS
                if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 4168, __pyx_L6_error)
                #endif
                if (__pyx_t_3 >= __pyx_temp) break;
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_13, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(0, 4168, __pyx_L6_error)
              #else
              __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4168, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_5);
              #endif
            }
          } else {
            __pyx_t_5 = __pyx_t_14(__pyx_t_13);
            if (unlikely(!__pyx_t_5)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 4168, __pyx_L6_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_5);
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
            PyObject* sequence = __pyx_t_5;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 3)) {
              if (size > 3) __Pyx_RaiseTooManyValuesError(3);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 4168, __pyx_L6_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_15 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_16 = PyTuple_GET_ITEM(sequence, 2); 
            } else {
              __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_15 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_16 = PyList_GET_ITEM(sequence, 2); 
            }
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_16);
            #else
            __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4168, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_15 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4168, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_15);
            __pyx_t_16 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4168, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            #endif
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_17 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 4168, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_17);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_18 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_17);
            index = 0; __pyx_t_2 = __pyx_t_18(__pyx_t_17); if (unlikely(!__pyx_t_2)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_2);
            index = 1; __pyx_t_15 = __pyx_t_18(__pyx_t_17); if (unlikely(!__pyx_t_15)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_15);
            index = 2; __pyx_t_16 = __pyx_t_18(__pyx_t_17); if (unlikely(!__pyx_t_16)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_16);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_18(__pyx_t_17), 3) < 0) __PYX_ERR(0, 4168, __pyx_L6_error)
            __pyx_t_18 = NULL;
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            goto __pyx_L18_unpacking_done;
            __pyx_L17_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
            __pyx_t_18 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 4168, __pyx_L6_error)
            __pyx_L18_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v_sep, __pyx_t_2);
          __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_stride, __pyx_t_15);
          __pyx_t_15 = 0;
          __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_16);
          __pyx_t_16 = 0;
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_XDECREF_SET(__pyx_v_n, __pyx_t_6);
          __pyx_t_5 = __Pyx_PyInt_AddObjC(__pyx_t_6, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4168, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6);
          __pyx_t_6 = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "pandas/_libs/tslibs/offsets.pyx":4169
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():             # <<<<<<<<<<<<<<
 *                     raise ValueError("separator must be spaces")
 *                 prefix = _lite_rule_alias.get(name) or name
 */
          __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_sep, __pyx_kp_u__15, Py_NE)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 4169, __pyx_L6_error)
          if (__pyx_t_12) {
          } else {
            __pyx_t_1 = __pyx_t_12;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_sep, __pyx_n_s_isspace); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4169, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_15 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_16, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_15, NULL};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_7, 0+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4169, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          }
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 4169, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_11 = (!__pyx_t_12);
          __pyx_t_1 = __pyx_t_11;
          __pyx_L20_bool_binop_done:;
          if (unlikely(__pyx_t_1)) {

            /* "pandas/_libs/tslibs/offsets.pyx":4170
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():
 *                     raise ValueError("separator must be spaces")             # <<<<<<<<<<<<<<
 *                 prefix = _lite_rule_alias.get(name) or name
 *                 if stride_sign is None:
 */
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4170, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_Raise(__pyx_t_5, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __PYX_ERR(0, 4170, __pyx_L6_error)

            /* "pandas/_libs/tslibs/offsets.pyx":4169
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():             # <<<<<<<<<<<<<<
 *                     raise ValueError("separator must be spaces")
 *                 prefix = _lite_rule_alias.get(name) or name
 */
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4171
 *                 if sep != "" and not sep.isspace():
 *                     raise ValueError("separator must be spaces")
 *                 prefix = _lite_rule_alias.get(name) or name             # <<<<<<<<<<<<<<
 *                 if stride_sign is None:
 *                     stride_sign = -1 if stride.startswith("-") else 1
 */
          __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_lite_rule_alias); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4171, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4171, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __pyx_t_15 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_v_name};
            __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4171, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          }
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4171, __pyx_L6_error)
          if (!__pyx_t_1) {
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_16);
            __pyx_t_5 = __pyx_t_16;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            goto __pyx_L22_bool_binop_done;
          }
          __Pyx_INCREF(__pyx_v_name);
          __pyx_t_5 = __pyx_v_name;
          __pyx_L22_bool_binop_done:;
          __Pyx_XDECREF_SET(__pyx_v_prefix, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "pandas/_libs/tslibs/offsets.pyx":4172
 *                     raise ValueError("separator must be spaces")
 *                 prefix = _lite_rule_alias.get(name) or name
 *                 if stride_sign is None:             # <<<<<<<<<<<<<<
 *                     stride_sign = -1 if stride.startswith("-") else 1
 *                 if not stride:
 */
          __pyx_t_1 = (__pyx_v_stride_sign == Py_None);
          if (__pyx_t_1) {

            /* "pandas/_libs/tslibs/offsets.pyx":4173
 *                 prefix = _lite_rule_alias.get(name) or name
 *                 if stride_sign is None:
 *                     stride_sign = -1 if stride.startswith("-") else 1             # <<<<<<<<<<<<<<
 *                 if not stride:
 *                     stride = 1
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_stride, __pyx_n_s_startswith); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4173, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_15 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_kp_u__38};
              __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4173, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            }
            __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_16); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4173, __pyx_L6_error)
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (__pyx_t_1) {
              __Pyx_INCREF(__pyx_int_neg_1);
              __pyx_t_5 = __pyx_int_neg_1;
            } else {
              __Pyx_INCREF(__pyx_int_1);
              __pyx_t_5 = __pyx_int_1;
            }
            __Pyx_DECREF_SET(__pyx_v_stride_sign, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4172
 *                     raise ValueError("separator must be spaces")
 *                 prefix = _lite_rule_alias.get(name) or name
 *                 if stride_sign is None:             # <<<<<<<<<<<<<<
 *                     stride_sign = -1 if stride.startswith("-") else 1
 *                 if not stride:
 */
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4174
 *                 if stride_sign is None:
 *                     stride_sign = -1 if stride.startswith("-") else 1
 *                 if not stride:             # <<<<<<<<<<<<<<
 *                     stride = 1
 * 
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_stride); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4174, __pyx_L6_error)
          __pyx_t_11 = (!__pyx_t_1);
          if (__pyx_t_11) {

            /* "pandas/_libs/tslibs/offsets.pyx":4175
 *                     stride_sign = -1 if stride.startswith("-") else 1
 *                 if not stride:
 *                     stride = 1             # <<<<<<<<<<<<<<
 * 
 *                 if prefix in {"D", "H", "T", "S", "L", "U", "N"}:
 */
            __Pyx_INCREF(__pyx_int_1);
            __Pyx_DECREF_SET(__pyx_v_stride, __pyx_int_1);

            /* "pandas/_libs/tslibs/offsets.pyx":4174
 *                 if stride_sign is None:
 *                     stride_sign = -1 if stride.startswith("-") else 1
 *                 if not stride:             # <<<<<<<<<<<<<<
 *                     stride = 1
 * 
 */
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4177
 *                     stride = 1
 * 
 *                 if prefix in {"D", "H", "T", "S", "L", "U", "N"}:             # <<<<<<<<<<<<<<
 *                     # For these prefixes, we have something like "3H" or
 *                     #  "2.5T", so we can construct a Timedelta with the
 */
          __Pyx_INCREF(__pyx_v_prefix);
          __pyx_t_5 = __pyx_v_prefix;
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_D, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_H, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_T, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_S, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_L, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_U, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          if (!__pyx_t_1) {
          } else {
            __pyx_t_11 = __pyx_t_1;
            goto __pyx_L27_bool_binop_done;
          }
          __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_N, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4177, __pyx_L6_error)
          __pyx_t_11 = __pyx_t_1;
          __pyx_L27_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_1 = __pyx_t_11;
          if (__pyx_t_1) {

            /* "pandas/_libs/tslibs/offsets.pyx":4181
 *                     #  "2.5T", so we can construct a Timedelta with the
 *                     #  matching unit and get our offset from delta_to_tick
 *                     td = Timedelta(1, unit=prefix)             # <<<<<<<<<<<<<<
 *                     off = delta_to_tick(td)
 *                     offset = off * float(stride)
 */
            __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4181, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_16 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4181, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_unit, __pyx_v_prefix) < 0) __PYX_ERR(0, 4181, __pyx_L6_error)
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__24, __pyx_t_16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4181, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF_SET(__pyx_v_td, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4182
 *                     #  matching unit and get our offset from delta_to_tick
 *                     td = Timedelta(1, unit=prefix)
 *                     off = delta_to_tick(td)             # <<<<<<<<<<<<<<
 *                     offset = off * float(stride)
 *                     if n != 0:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_delta_to_tick); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4182, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_5 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_16);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_16, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_td};
              __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4182, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_off, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4183
 *                     td = Timedelta(1, unit=prefix)
 *                     off = delta_to_tick(td)
 *                     offset = off * float(stride)             # <<<<<<<<<<<<<<
 *                     if n != 0:
 *                         # If n==0, then stride_sign is already incorporated
 */
            __pyx_t_2 = __Pyx_PyNumber_Float(__pyx_v_stride); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4183, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_16 = PyNumber_Multiply(__pyx_v_off, __pyx_t_2); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4183, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF_SET(__pyx_v_offset, __pyx_t_16);
            __pyx_t_16 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4184
 *                     off = delta_to_tick(td)
 *                     offset = off * float(stride)
 *                     if n != 0:             # <<<<<<<<<<<<<<
 *                         # If n==0, then stride_sign is already incorporated
 *                         #  into the offset
 */
            __pyx_t_1 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_n, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4184, __pyx_L6_error)
            if (__pyx_t_1) {

              /* "pandas/_libs/tslibs/offsets.pyx":4187
 *                         # If n==0, then stride_sign is already incorporated
 *                         #  into the offset
 *                         offset *= stride_sign             # <<<<<<<<<<<<<<
 *                 else:
 *                     stride = int(stride)
 */
              __pyx_t_16 = PyNumber_InPlaceMultiply(__pyx_v_offset, __pyx_v_stride_sign); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4187, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF_SET(__pyx_v_offset, __pyx_t_16);
              __pyx_t_16 = 0;

              /* "pandas/_libs/tslibs/offsets.pyx":4184
 *                     off = delta_to_tick(td)
 *                     offset = off * float(stride)
 *                     if n != 0:             # <<<<<<<<<<<<<<
 *                         # If n==0, then stride_sign is already incorporated
 *                         #  into the offset
 */
            }

            /* "pandas/_libs/tslibs/offsets.pyx":4177
 *                     stride = 1
 * 
 *                 if prefix in {"D", "H", "T", "S", "L", "U", "N"}:             # <<<<<<<<<<<<<<
 *                     # For these prefixes, we have something like "3H" or
 *                     #  "2.5T", so we can construct a Timedelta with the
 */
            goto __pyx_L26;
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4189
 *                         offset *= stride_sign
 *                 else:
 *                     stride = int(stride)             # <<<<<<<<<<<<<<
 *                     offset = _get_offset(name)
 *                     offset = offset * int(np.fabs(stride) * stride_sign)
 */
          /*else*/ {
            __pyx_t_16 = __Pyx_PyNumber_Int(__pyx_v_stride); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4189, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF_SET(__pyx_v_stride, __pyx_t_16);
            __pyx_t_16 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4190
 *                 else:
 *                     stride = int(stride)
 *                     offset = _get_offset(name)             # <<<<<<<<<<<<<<
 *                     offset = offset * int(np.fabs(stride) * stride_sign)
 * 
 */
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_offset); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4190, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_name};
              __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4190, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_offset, __pyx_t_16);
            __pyx_t_16 = 0;

            /* "pandas/_libs/tslibs/offsets.pyx":4191
 *                     stride = int(stride)
 *                     offset = _get_offset(name)
 *                     offset = offset * int(np.fabs(stride) * stride_sign)             # <<<<<<<<<<<<<<
 * 
 *                 if delta is None:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4191, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_fabs); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4191, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_2 = NULL;
            __pyx_t_7 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
              if (likely(__pyx_t_2)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_2);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_5, function);
                __pyx_t_7 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_stride};
              __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4191, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_16);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
            __pyx_t_5 = PyNumber_Multiply(__pyx_t_16, __pyx_v_stride_sign); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4191, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_16 = __Pyx_PyNumber_Int(__pyx_t_5); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4191, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = PyNumber_Multiply(__pyx_v_offset, __pyx_t_16); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4191, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF_SET(__pyx_v_offset, __pyx_t_5);
            __pyx_t_5 = 0;
          }
          __pyx_L26:;

          /* "pandas/_libs/tslibs/offsets.pyx":4193
 *                     offset = offset * int(np.fabs(stride) * stride_sign)
 * 
 *                 if delta is None:             # <<<<<<<<<<<<<<
 *                     delta = offset
 *                 else:
 */
          __pyx_t_1 = (__pyx_v_delta == Py_None);
          if (__pyx_t_1) {

            /* "pandas/_libs/tslibs/offsets.pyx":4194
 * 
 *                 if delta is None:
 *                     delta = offset             # <<<<<<<<<<<<<<
 *                 else:
 *                     delta = delta + offset
 */
            __Pyx_INCREF(__pyx_v_offset);
            __Pyx_DECREF_SET(__pyx_v_delta, __pyx_v_offset);

            /* "pandas/_libs/tslibs/offsets.pyx":4193
 *                     offset = offset * int(np.fabs(stride) * stride_sign)
 * 
 *                 if delta is None:             # <<<<<<<<<<<<<<
 *                     delta = offset
 *                 else:
 */
            goto __pyx_L35;
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4196
 *                     delta = offset
 *                 else:
 *                     delta = delta + offset             # <<<<<<<<<<<<<<
 *         except (ValueError, TypeError) as err:
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(freq)) from err
 */
          /*else*/ {
            __pyx_t_5 = PyNumber_Add(__pyx_v_delta, __pyx_v_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4196, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF_SET(__pyx_v_delta, __pyx_t_5);
            __pyx_t_5 = 0;
          }
          __pyx_L35:;

          /* "pandas/_libs/tslibs/offsets.pyx":4168
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 *             for n, (sep, stride, name) in enumerate(tups):             # <<<<<<<<<<<<<<
 *                 if sep != "" and not sep.isspace():
 *                     raise ValueError("separator must be spaces")
 */
        }
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "pandas/_libs/tslibs/offsets.pyx":4161
 *         stride_sign = None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             split = opattern.split(freq)
 *             if split[-1] != "" and not split[-1].isspace():
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":4197
 *                 else:
 *                     delta = delta + offset
 *         except (ValueError, TypeError) as err:             # <<<<<<<<<<<<<<
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(freq)) from err
 *     else:
 */
      __pyx_t_7 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
      if (__pyx_t_7) {
        __Pyx_AddTraceback("pandas._libs.tslibs.offsets.to_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_13, &__pyx_t_5) < 0) __PYX_ERR(0, 4197, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_13);
        __pyx_v_err = __pyx_t_13;
        /*try:*/ {

          /* "pandas/_libs/tslibs/offsets.pyx":4198
 *                     delta = delta + offset
 *         except (ValueError, TypeError) as err:
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(freq)) from err             # <<<<<<<<<<<<<<
 *     else:
 *         delta = None
 */
          __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_INVALID_FREQ_ERR_MSG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4198, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_format); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4198, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = NULL;
          __pyx_t_7 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_15))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_15);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_15, function);
              __pyx_t_7 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_freq};
            __pyx_t_16 = __Pyx_PyObject_FastCall(__pyx_t_15, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 4198, __pyx_L42_error)
            __Pyx_GOTREF(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __pyx_t_15 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 4198, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_Raise(__pyx_t_15, 0, 0, __pyx_v_err);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          __PYX_ERR(0, 4198, __pyx_L42_error)
        }

        /* "pandas/_libs/tslibs/offsets.pyx":4197
 *                 else:
 *                     delta = delta + offset
 *         except (ValueError, TypeError) as err:             # <<<<<<<<<<<<<<
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(freq)) from err
 *     else:
 */
        /*finally:*/ {
          __pyx_L42_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __Pyx_XGOTREF(__pyx_t_24);
            __Pyx_XGOTREF(__pyx_t_25);
            __Pyx_XGOTREF(__pyx_t_26);
            __pyx_t_7 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_err); __pyx_v_err = 0;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_XGIVEREF(__pyx_t_26);
              __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_25, __pyx_t_26);
            }
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ErrRestore(__pyx_t_21, __pyx_t_22, __pyx_t_23);
            __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
            __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
            goto __pyx_L8_except_error;
          }
        }
      }
      goto __pyx_L8_except_error;

      /* "pandas/_libs/tslibs/offsets.pyx":4161
 *         stride_sign = None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             split = opattern.split(freq)
 *             if split[-1] != "" and not split[-1].isspace():
 */
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L11_try_end:;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4157
 *         return delta_to_tick(freq)
 * 
 *     elif isinstance(freq, str):             # <<<<<<<<<<<<<<
 *         delta = None
 *         stride_sign = None
 */
    goto __pyx_L5;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4200
 *             raise ValueError(INVALID_FREQ_ERR_MSG.format(freq)) from err
 *     else:
 *         delta = None             # <<<<<<<<<<<<<<
 * 
 *     if delta is None:
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_delta = Py_None;
  }
  __pyx_L5:;

  /* "pandas/_libs/tslibs/offsets.pyx":4202
 *         delta = None
 * 
 *     if delta is None:             # <<<<<<<<<<<<<<
 *         raise ValueError(INVALID_FREQ_ERR_MSG.format(freq))
 * 
 */
  __pyx_t_1 = (__pyx_v_delta == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4203
 * 
 *     if delta is None:
 *         raise ValueError(INVALID_FREQ_ERR_MSG.format(freq))             # <<<<<<<<<<<<<<
 * 
 *     return delta
 */
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_INVALID_FREQ_ERR_MSG); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 4203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    __pyx_t_19 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_19 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_freq};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_19, 1+__pyx_t_19);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 4203, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":4202
 *         delta = None
 * 
 *     if delta is None:             # <<<<<<<<<<<<<<
 *         raise ValueError(INVALID_FREQ_ERR_MSG.format(freq))
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4205
 *         raise ValueError(INVALID_FREQ_ERR_MSG.format(freq))
 * 
 *     return delta             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_delta);
  __pyx_r = __pyx_v_delta;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4102
 * 
 * 
 * cpdef to_offset(freq):             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object from string or datetime.timedelta object.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.to_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XDECREF(__pyx_v_stride_sign);
  __Pyx_XDECREF(__pyx_v_split);
  __Pyx_XDECREF(__pyx_v_tups);
  __Pyx_XDECREF(__pyx_v_n);
  __Pyx_XDECREF(__pyx_v_sep);
  __Pyx_XDECREF(__pyx_v_stride);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_td);
  __Pyx_XDECREF(__pyx_v_off);
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11to_offset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_10to_offset, "\n    Return DateOffset object from string or datetime.timedelta object.\n\n    Parameters\n    ----------\n    freq : str, datetime.timedelta, BaseOffset or None\n\n    Returns\n    -------\n    DateOffset or None\n\n    Raises\n    ------\n    ValueError\n        If freq is an invalid frequency\n\n    See Also\n    --------\n    BaseOffset : Standard kind of date increment used for a date range.\n\n    Examples\n    --------\n    >>> to_offset(\"5min\")\n    <5 * Minutes>\n\n    >>> to_offset(\"1D1H\")\n    <25 * Hours>\n\n    >>> to_offset(\"2W\")\n    <2 * Weeks: weekday=6>\n\n    >>> to_offset(\"2B\")\n    <2 * BusinessDays>\n\n    >>> to_offset(pd.Timedelta(days=1))\n    <Day>\n\n    >>> to_offset(Hour())\n    <Hour>\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11to_offset = {"to_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11to_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10to_offset};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11to_offset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_freq = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_offset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_freq,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_freq)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4102, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "to_offset") < 0)) __PYX_ERR(0, 4102, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_freq = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_offset", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 4102, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.to_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_10to_offset(__pyx_self, __pyx_v_freq);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_10to_offset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_freq) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_offset", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset(__pyx_v_freq, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.to_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4211
 * # RelativeDelta Arithmetic
 * 
 * cdef datetime _shift_day(datetime other, int days):             # <<<<<<<<<<<<<<
 *     """
 *     Increment the datetime `other` by the given number of days, retaining
 */

static PyDateTime_DateTime *__pyx_f_6pandas_5_libs_6tslibs_7offsets__shift_day(PyDateTime_DateTime *__pyx_v_other, int __pyx_v_days) {
  PyObject *__pyx_v_tz = NULL;
  PyObject *__pyx_v_naive = NULL;
  PyObject *__pyx_v_shifted = NULL;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_shift_day", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":4227
 *     shifted: datetime or Timestamp
 *     """
 *     if other.tzinfo is None:             # <<<<<<<<<<<<<<
 *         return other + timedelta(days=days)
 * 
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "pandas/_libs/tslibs/offsets.pyx":4228
 *     """
 *     if other.tzinfo is None:
 *         return other + timedelta(days=days)             # <<<<<<<<<<<<<<
 * 
 *     tz = other.tzinfo
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_days); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_days, __pyx_t_3) < 0) __PYX_ERR(0, 4228, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Add(((PyObject *)__pyx_v_other), __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4228, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 4228, __pyx_L1_error)
    __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4227
 *     shifted: datetime or Timestamp
 *     """
 *     if other.tzinfo is None:             # <<<<<<<<<<<<<<
 *         return other + timedelta(days=days)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4230
 *         return other + timedelta(days=days)
 * 
 *     tz = other.tzinfo             # <<<<<<<<<<<<<<
 *     naive = other.replace(tzinfo=None)
 *     shifted = naive + timedelta(days=days)
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(__pyx_v_other); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tz = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4231
 * 
 *     tz = other.tzinfo
 *     naive = other.replace(tzinfo=None)             # <<<<<<<<<<<<<<
 *     shifted = naive + timedelta(days=days)
 *     return localize_pydatetime(shifted, tz)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_other), __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_tzinfo, Py_None) < 0) __PYX_ERR(0, 4231, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_naive = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4232
 *     tz = other.tzinfo
 *     naive = other.replace(tzinfo=None)
 *     shifted = naive + timedelta(days=days)             # <<<<<<<<<<<<<<
 *     return localize_pydatetime(shifted, tz)
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_days); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_days, __pyx_t_3) < 0) __PYX_ERR(0, 4232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_Add(__pyx_v_naive, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_shifted = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4233
 *     naive = other.replace(tzinfo=None)
 *     shifted = naive + timedelta(days=days)
 *     return localize_pydatetime(shifted, tz)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  if (!(likely(((__pyx_v_shifted) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_shifted, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 4233, __pyx_L1_error)
  if (!(likely(((__pyx_v_tz) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_tz, __pyx_ptype_7cpython_8datetime_tzinfo))))) __PYX_ERR(0, 4233, __pyx_L1_error)
  __pyx_t_4 = ((PyObject *)__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime(((PyDateTime_DateTime *)__pyx_v_shifted), ((PyDateTime_TZInfo *)__pyx_v_tz), 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4211
 * # RelativeDelta Arithmetic
 * 
 * cdef datetime _shift_day(datetime other, int days):             # <<<<<<<<<<<<<<
 *     """
 *     Increment the datetime `other` by the given number of days, retaining
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._shift_day", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tz);
  __Pyx_XDECREF(__pyx_v_naive);
  __Pyx_XDECREF(__pyx_v_shifted);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4236
 * 
 * 
 * cdef int year_add_months(npy_datetimestruct dts, int months) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     New year number after shifting npy_datetimestruct number of months.
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(npy_datetimestruct __pyx_v_dts, int __pyx_v_months) {
  int __pyx_r;

  /* "pandas/_libs/tslibs/offsets.pyx":4240
 *     New year number after shifting npy_datetimestruct number of months.
 *     """
 *     return dts.year + (dts.month + months - 1) // 12             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = (__pyx_v_dts.year + __Pyx_div_long(((__pyx_v_dts.month + __pyx_v_months) - 1), 12));
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4236
 * 
 * 
 * cdef int year_add_months(npy_datetimestruct dts, int months) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     New year number after shifting npy_datetimestruct number of months.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4243
 * 
 * 
 * cdef int month_add_months(npy_datetimestruct dts, int months) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     New month number after shifting npy_datetimestruct
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(npy_datetimestruct __pyx_v_dts, int __pyx_v_months) {
  int __pyx_v_new_month;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":4249
 *     """
 *     cdef:
 *         int new_month = (dts.month + months) % 12             # <<<<<<<<<<<<<<
 *     return 12 if new_month == 0 else new_month
 * 
 */
  __pyx_v_new_month = __Pyx_mod_long((__pyx_v_dts.month + __pyx_v_months), 12);

  /* "pandas/_libs/tslibs/offsets.pyx":4250
 *     cdef:
 *         int new_month = (dts.month + months) % 12
 *     return 12 if new_month == 0 else new_month             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__pyx_v_new_month == 0);
  if (__pyx_t_2) {
    __pyx_t_1 = 12;
  } else {
    __pyx_t_1 = __pyx_v_new_month;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4243
 * 
 * 
 * cdef int month_add_months(npy_datetimestruct dts, int months) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     New month number after shifting npy_datetimestruct
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4255
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ndarray shift_quarters(             # <<<<<<<<<<<<<<
 *     ndarray dtindex,
 *     int quarters,
 */

static PyArrayObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets_shift_quarters(PyArrayObject *__pyx_v_dtindex, int __pyx_v_quarters, int __pyx_v_q1start_month, PyObject *__pyx_v_day_opt, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_shift_quarters *__pyx_optional_args) {
  int __pyx_v_modby = ((int)3);
  NPY_DATETIMEUNIT __pyx_v_reso = __pyx_k__64;
  Py_ssize_t __pyx_v_count;
  PyArrayObject *__pyx_v_out = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_res_val;
  int __pyx_v_months_since;
  int __pyx_v_n;
  npy_datetimestruct __pyx_v_dts;
  PyArrayMultiIterObject *__pyx_v_mi = 0;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  npy_intp __pyx_t_5;
  int __pyx_t_6;
  npy_intp *__pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  __pyx_t_5numpy_int32_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shift_quarters", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_modby = __pyx_optional_args->modby;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_reso = __pyx_optional_args->reso;
      }
    }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4280
 *     out : ndarray[int64_t]
 *     """
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:             # <<<<<<<<<<<<<<
 *         raise ValueError("day must be None, 'start', 'end', "
 *                          "'business_start', or 'business_end'")
 */
  __Pyx_INCREF(__pyx_v_day_opt);
  __pyx_t_1 = __pyx_v_day_opt;
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_start, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4280, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_end, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4280, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_business_start, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4280, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_business_end, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4280, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4281
 *     """
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:
 *         raise ValueError("day must be None, 'start', 'end', "             # <<<<<<<<<<<<<<
 *                          "'business_start', or 'business_end'")
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 4281, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":4280
 *     out : ndarray[int64_t]
 *     """
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:             # <<<<<<<<<<<<<<
 *         raise ValueError("day must be None, 'start', 'end', "
 *                          "'business_start', or 'business_end'")
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4285
 * 
 *     cdef:
 *         Py_ssize_t count = dtindex.size             # <<<<<<<<<<<<<<
 *         ndarray out = cnp.PyArray_EMPTY(dtindex.ndim, dtindex.shape, cnp.NPY_INT64, 0)
 *         Py_ssize_t i
 */
  __pyx_t_5 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_dtindex); if (unlikely(__pyx_t_5 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(0, 4285, __pyx_L1_error)
  __pyx_v_count = __pyx_t_5;

  /* "pandas/_libs/tslibs/offsets.pyx":4286
 *     cdef:
 *         Py_ssize_t count = dtindex.size
 *         ndarray out = cnp.PyArray_EMPTY(dtindex.ndim, dtindex.shape, cnp.NPY_INT64, 0)             # <<<<<<<<<<<<<<
 *         Py_ssize_t i
 *         int64_t val, res_val
 */
  __pyx_t_6 = __pyx_f_5numpy_7ndarray_4ndim_ndim(__pyx_v_dtindex); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4286, __pyx_L1_error)
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_dtindex); if (unlikely(__pyx_t_7 == ((npy_intp *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 4286, __pyx_L1_error)
  __pyx_t_4 = PyArray_EMPTY(__pyx_t_6, __pyx_t_7, NPY_INT64, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 4286, __pyx_L1_error)
  __pyx_v_out = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4291
 *         int months_since, n
 *         npy_datetimestruct dts
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __pyx_t_4 = __pyx_f_5numpy_PyArray_MultiIterNew2(((PyObject *)__pyx_v_out), ((PyObject *)__pyx_v_dtindex)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_broadcast))))) __PYX_ERR(0, 4291, __pyx_L1_error)
  __pyx_v_mi = ((PyArrayMultiIterObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4293
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(count):
 *             # Analogous to: val = dtindex[i]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/tslibs/offsets.pyx":4294
 * 
 *     with nogil:
 *         for i in range(count):             # <<<<<<<<<<<<<<
 *             # Analogous to: val = dtindex[i]
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 */
        __pyx_t_8 = __pyx_v_count;
        __pyx_t_9 = __pyx_t_8;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_i = __pyx_t_10;

          /* "pandas/_libs/tslibs/offsets.pyx":4296
 *         for i in range(count):
 *             # Analogous to: val = dtindex[i]
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *             if val == NPY_NAT:
 */
          __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

          /* "pandas/_libs/tslibs/offsets.pyx":4298
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *             if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                 res_val = NPY_NAT
 *             else:
 */
          __pyx_t_3 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
          if (__pyx_t_3) {

            /* "pandas/_libs/tslibs/offsets.pyx":4299
 * 
 *             if val == NPY_NAT:
 *                 res_val = NPY_NAT             # <<<<<<<<<<<<<<
 *             else:
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)
 */
            __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

            /* "pandas/_libs/tslibs/offsets.pyx":4298
 *             val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *             if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                 res_val = NPY_NAT
 *             else:
 */
            goto __pyx_L13;
          }

          /* "pandas/_libs/tslibs/offsets.pyx":4301
 *                 res_val = NPY_NAT
 *             else:
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                 n = quarters
 * 
 */
          /*else*/ {
            pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

            /* "pandas/_libs/tslibs/offsets.pyx":4302
 *             else:
 *                 pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                 n = quarters             # <<<<<<<<<<<<<<
 * 
 *                 months_since = (dts.month - q1start_month) % modby
 */
            __pyx_v_n = __pyx_v_quarters;

            /* "pandas/_libs/tslibs/offsets.pyx":4304
 *                 n = quarters
 * 
 *                 months_since = (dts.month - q1start_month) % modby             # <<<<<<<<<<<<<<
 *                 n = _roll_qtrday(&dts, n, months_since, day_opt)
 * 
 */
            __pyx_t_11 = (__pyx_v_dts.month - __pyx_v_q1start_month);
            if (unlikely(__pyx_v_modby == 0)) {
              #ifdef WITH_THREAD
              PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
              #endif
              PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
              #ifdef WITH_THREAD
              __Pyx_PyGILState_Release(__pyx_gilstate_save);
              #endif
              __PYX_ERR(0, 4304, __pyx_L9_error)
            }
            __pyx_v_months_since = __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_11, __pyx_v_modby);

            /* "pandas/_libs/tslibs/offsets.pyx":4305
 * 
 *                 months_since = (dts.month - q1start_month) % modby
 *                 n = _roll_qtrday(&dts, n, months_since, day_opt)             # <<<<<<<<<<<<<<
 * 
 *                 dts.year = year_add_months(dts, modby * n - months_since)
 */
            __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__roll_qtrday((&__pyx_v_dts), __pyx_v_n, __pyx_v_months_since, __pyx_v_day_opt); if (unlikely(__pyx_t_6 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4305, __pyx_L9_error)
            __pyx_v_n = __pyx_t_6;

            /* "pandas/_libs/tslibs/offsets.pyx":4307
 *                 n = _roll_qtrday(&dts, n, months_since, day_opt)
 * 
 *                 dts.year = year_add_months(dts, modby * n - months_since)             # <<<<<<<<<<<<<<
 *                 dts.month = month_add_months(dts, modby * n - months_since)
 *                 dts.day = get_day_of_month(&dts, day_opt)
 */
            __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(__pyx_v_dts, ((__pyx_v_modby * __pyx_v_n) - __pyx_v_months_since)); if (unlikely(__pyx_t_6 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4307, __pyx_L9_error)
            __pyx_v_dts.year = __pyx_t_6;

            /* "pandas/_libs/tslibs/offsets.pyx":4308
 * 
 *                 dts.year = year_add_months(dts, modby * n - months_since)
 *                 dts.month = month_add_months(dts, modby * n - months_since)             # <<<<<<<<<<<<<<
 *                 dts.day = get_day_of_month(&dts, day_opt)
 * 
 */
            __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(__pyx_v_dts, ((__pyx_v_modby * __pyx_v_n) - __pyx_v_months_since)); if (unlikely(__pyx_t_6 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4308, __pyx_L9_error)
            __pyx_v_dts.month = __pyx_t_6;

            /* "pandas/_libs/tslibs/offsets.pyx":4309
 *                 dts.year = year_add_months(dts, modby * n - months_since)
 *                 dts.month = month_add_months(dts, modby * n - months_since)
 *                 dts.day = get_day_of_month(&dts, day_opt)             # <<<<<<<<<<<<<<
 * 
 *                 res_val = npy_datetimestruct_to_datetime(reso, &dts)
 */
            __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month((&__pyx_v_dts), __pyx_v_day_opt); if (unlikely(__pyx_t_6 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4309, __pyx_L9_error)
            __pyx_v_dts.day = __pyx_t_6;

            /* "pandas/_libs/tslibs/offsets.pyx":4311
 *                 dts.day = get_day_of_month(&dts, day_opt)
 * 
 *                 res_val = npy_datetimestruct_to_datetime(reso, &dts)             # <<<<<<<<<<<<<<
 * 
 *             # Analogous to: out[i] = res_val
 */
            __pyx_v_res_val = npy_datetimestruct_to_datetime(__pyx_v_reso, (&__pyx_v_dts));
          }
          __pyx_L13:;

          /* "pandas/_libs/tslibs/offsets.pyx":4314
 * 
 *             # Analogous to: out[i] = res_val
 *             (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *             cnp.PyArray_MultiIter_NEXT(mi)
 */
          (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

          /* "pandas/_libs/tslibs/offsets.pyx":4316
 *             (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *             cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *     return out
 */
          PyArray_MultiIter_NEXT(__pyx_v_mi);
        }
      }

      /* "pandas/_libs/tslibs/offsets.pyx":4293
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(count):
 *             # Analogous to: val = dtindex[i]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L9_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4318
 *             cnp.PyArray_MultiIter_NEXT(mi)
 * 
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4255
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ndarray shift_quarters(             # <<<<<<<<<<<<<<
 *     ndarray dtindex,
 *     int quarters,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.shift_quarters", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XDECREF((PyObject *)__pyx_v_mi);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_24__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/tslibs/offsets.pyx":4326
 *     ndarray dtindex,  # int64_t, arbitrary ndim
 *     int months,
 *     str day_opt=None,             # <<<<<<<<<<<<<<
 *     NPY_DATETIMEUNIT reso=NPY_DATETIMEUNIT.NPY_FR_ns,
 * ):
 */
  __pyx_t_1 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(__Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self)->__pyx_arg_reso); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, Py_None)) __PYX_ERR(0, 4321, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1)) __PYX_ERR(0, 4321, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 4321, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(0, 4321, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13shift_months(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_12shift_months, "\n    Given an int64-based datetime index, shift all elements\n    specified number of months using DateOffset semantics\n\n    day_opt: {None, 'start', 'end', 'business_start', 'business_end'}\n       * None: day of month\n       * 'start' 1st day of month\n       * 'end' last day of month\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13shift_months = {"shift_months", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13shift_months, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12shift_months};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13shift_months(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_dtindex = 0;
  int __pyx_v_months;
  PyObject *__pyx_v_day_opt = 0;
  NPY_DATETIMEUNIT __pyx_v_reso;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shift_months (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_dtindex,&__pyx_n_s_months,&__pyx_n_s_day_opt_2,&__pyx_n_s_reso,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);

    /* "pandas/_libs/tslibs/offsets.pyx":4326
 *     ndarray dtindex,  # int64_t, arbitrary ndim
 *     int months,
 *     str day_opt=None,             # <<<<<<<<<<<<<<
 *     NPY_DATETIMEUNIT reso=NPY_DATETIMEUNIT.NPY_FR_ns,
 * ):
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject*)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtindex)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4321, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_months)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4321, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("shift_months", 0, 2, 4, 1); __PYX_ERR(0, 4321, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_day_opt_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4321, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_reso);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4321, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "shift_months") < 0)) __PYX_ERR(0, 4321, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_dtindex = ((PyArrayObject *)values[0]);
    __pyx_v_months = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_months == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4325, __pyx_L3_error)
    __pyx_v_day_opt = ((PyObject*)values[2]);
    if (values[3]) {
      __pyx_v_reso = ((NPY_DATETIMEUNIT)__Pyx_PyInt_As_NPY_DATETIMEUNIT(values[3])); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4327, __pyx_L3_error)
    } else {
      __pyx_v_reso = __pyx_dynamic_args->__pyx_arg_reso;
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("shift_months", 0, 2, 4, __pyx_nargs); __PYX_ERR(0, 4321, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.shift_months", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_dtindex), __pyx_ptype_5numpy_ndarray, 1, "dtindex", 0))) __PYX_ERR(0, 4324, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_day_opt), (&PyUnicode_Type), 1, "day_opt", 1))) __PYX_ERR(0, 4326, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_12shift_months(__pyx_self, __pyx_v_dtindex, __pyx_v_months, __pyx_v_day_opt, __pyx_v_reso);

  /* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_12shift_months(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_dtindex, int __pyx_v_months, PyObject *__pyx_v_day_opt, NPY_DATETIMEUNIT __pyx_v_reso) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  npy_datetimestruct __pyx_v_dts;
  int __pyx_v_count;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_months_to_roll;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_res_val;
  PyArrayMultiIterObject *__pyx_v_mi = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  npy_intp __pyx_t_1;
  int __pyx_t_2;
  npy_intp *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  __pyx_t_5numpy_int32_t __pyx_t_12;
  __pyx_t_5numpy_int32_t __pyx_t_13;
  __pyx_t_5numpy_int32_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shift_months", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":4341
 *         Py_ssize_t i
 *         npy_datetimestruct dts
 *         int count = dtindex.size             # <<<<<<<<<<<<<<
 *         ndarray out = cnp.PyArray_EMPTY(dtindex.ndim, dtindex.shape, cnp.NPY_INT64, 0)
 *         int months_to_roll
 */
  __pyx_t_1 = __pyx_f_5numpy_7ndarray_4size_size(__pyx_v_dtindex); if (unlikely(__pyx_t_1 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(0, 4341, __pyx_L1_error)
  __pyx_v_count = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":4342
 *         npy_datetimestruct dts
 *         int count = dtindex.size
 *         ndarray out = cnp.PyArray_EMPTY(dtindex.ndim, dtindex.shape, cnp.NPY_INT64, 0)             # <<<<<<<<<<<<<<
 *         int months_to_roll
 *         int64_t val, res_val
 */
  __pyx_t_2 = __pyx_f_5numpy_7ndarray_4ndim_ndim(__pyx_v_dtindex); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4342, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_5numpy_7ndarray_5shape_shape(__pyx_v_dtindex); if (unlikely(__pyx_t_3 == ((npy_intp *)NULL) && PyErr_Occurred())) __PYX_ERR(0, 4342, __pyx_L1_error)
  __pyx_t_4 = PyArray_EMPTY(__pyx_t_2, __pyx_t_3, NPY_INT64, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 4342, __pyx_L1_error)
  __pyx_v_out = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4346
 *         int64_t val, res_val
 * 
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)             # <<<<<<<<<<<<<<
 * 
 *     if day_opt is not None and day_opt not in {
 */
  __pyx_t_4 = __pyx_f_5numpy_PyArray_MultiIterNew2(((PyObject *)__pyx_v_out), ((PyObject *)__pyx_v_dtindex)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_broadcast))))) __PYX_ERR(0, 4346, __pyx_L1_error)
  __pyx_v_mi = ((PyArrayMultiIterObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4348
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)
 * 
 *     if day_opt is not None and day_opt not in {             # <<<<<<<<<<<<<<
 *             "start", "end", "business_start", "business_end"
 *     }:
 */
  __pyx_t_6 = (__pyx_v_day_opt != ((PyObject*)Py_None));
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_day_opt);
  __pyx_t_7 = __pyx_v_day_opt;
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_n_u_start, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4348, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_n_u_end, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4348, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_n_u_business_start, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4348, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_7, __pyx_n_u_business_end, Py_NE)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 4348, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_8;
  __pyx_L6_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_8 = __pyx_t_6;
  __pyx_t_5 = __pyx_t_8;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4351
 *             "start", "end", "business_start", "business_end"
 *     }:
 *         raise ValueError("day must be None, 'start', 'end', "             # <<<<<<<<<<<<<<
 *                          "'business_start', or 'business_end'")
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4351, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 4351, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":4348
 *         cnp.broadcast mi = cnp.PyArray_MultiIterNew2(out, dtindex)
 * 
 *     if day_opt is not None and day_opt not in {             # <<<<<<<<<<<<<<
 *             "start", "end", "business_start", "business_end"
 *     }:
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4354
 *                          "'business_start', or 'business_end'")
 * 
 *     if day_opt is None:             # <<<<<<<<<<<<<<
 *         # TODO: can we combine this with the non-None case?
 *         with nogil:
 */
  __pyx_t_5 = (__pyx_v_day_opt == ((PyObject*)Py_None));
  if (__pyx_t_5) {

    /* "pandas/_libs/tslibs/offsets.pyx":4356
 *     if day_opt is None:
 *         # TODO: can we combine this with the non-None case?
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/tslibs/offsets.pyx":4357
 *         # TODO: can we combine this with the non-None case?
 *         with nogil:
 *             for i in range(count):             # <<<<<<<<<<<<<<
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 */
          __pyx_t_2 = __pyx_v_count;
          __pyx_t_9 = __pyx_t_2;
          for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
            __pyx_v_i = __pyx_t_10;

            /* "pandas/_libs/tslibs/offsets.pyx":4359
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *                 if val == NPY_NAT:
 */
            __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

            /* "pandas/_libs/tslibs/offsets.pyx":4361
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
            __pyx_t_5 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
            if (__pyx_t_5) {

              /* "pandas/_libs/tslibs/offsets.pyx":4362
 * 
 *                 if val == NPY_NAT:
 *                     res_val = NPY_NAT             # <<<<<<<<<<<<<<
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 */
              __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

              /* "pandas/_libs/tslibs/offsets.pyx":4361
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
              goto __pyx_L16;
            }

            /* "pandas/_libs/tslibs/offsets.pyx":4364
 *                     res_val = NPY_NAT
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                     dts.year = year_add_months(dts, months)
 *                     dts.month = month_add_months(dts, months)
 */
            /*else*/ {
              pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

              /* "pandas/_libs/tslibs/offsets.pyx":4365
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                     dts.year = year_add_months(dts, months)             # <<<<<<<<<<<<<<
 *                     dts.month = month_add_months(dts, months)
 * 
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(__pyx_v_dts, __pyx_v_months); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4365, __pyx_L12_error)
              __pyx_v_dts.year = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4366
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                     dts.year = year_add_months(dts, months)
 *                     dts.month = month_add_months(dts, months)             # <<<<<<<<<<<<<<
 * 
 *                     dts.day = min(dts.day, get_days_in_month(dts.year, dts.month))
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(__pyx_v_dts, __pyx_v_months); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4366, __pyx_L12_error)
              __pyx_v_dts.month = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4368
 *                     dts.month = month_add_months(dts, months)
 * 
 *                     dts.day = min(dts.day, get_days_in_month(dts.year, dts.month))             # <<<<<<<<<<<<<<
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)
 * 
 */
              __pyx_t_12 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_dts.year, __pyx_v_dts.month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4368, __pyx_L12_error)
              __pyx_t_13 = __pyx_v_dts.day;
              __pyx_t_5 = (__pyx_t_12 < __pyx_t_13);
              if (__pyx_t_5) {
                __pyx_t_14 = __pyx_t_12;
              } else {
                __pyx_t_14 = __pyx_t_13;
              }
              __pyx_v_dts.day = __pyx_t_14;

              /* "pandas/_libs/tslibs/offsets.pyx":4369
 * 
 *                     dts.day = min(dts.day, get_days_in_month(dts.year, dts.month))
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)             # <<<<<<<<<<<<<<
 * 
 *                 # Analogous to: out[i] = res_val
 */
              __pyx_v_res_val = npy_datetimestruct_to_datetime(__pyx_v_reso, (&__pyx_v_dts));
            }
            __pyx_L16:;

            /* "pandas/_libs/tslibs/offsets.pyx":4372
 * 
 *                 # Analogous to: out[i] = res_val
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 */
            (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

            /* "pandas/_libs/tslibs/offsets.pyx":4374
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
            PyArray_MultiIter_NEXT(__pyx_v_mi);
          }
        }

        /* "pandas/_libs/tslibs/offsets.pyx":4356
 *     if day_opt is None:
 *         # TODO: can we combine this with the non-None case?
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 *                 # Analogous to: val = i8other[i]
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L13;
          }
          __pyx_L12_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L13:;
        }
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4354
 *                          "'business_start', or 'business_end'")
 * 
 *     if day_opt is None:             # <<<<<<<<<<<<<<
 *         # TODO: can we combine this with the non-None case?
 *         with nogil:
 */
    goto __pyx_L10;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4377
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 * 
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/tslibs/offsets.pyx":4378
 *     else:
 *         with nogil:
 *             for i in range(count):             # <<<<<<<<<<<<<<
 * 
 *                 # Analogous to: val = i8other[i]
 */
          __pyx_t_2 = __pyx_v_count;
          __pyx_t_9 = __pyx_t_2;
          for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
            __pyx_v_i = __pyx_t_10;

            /* "pandas/_libs/tslibs/offsets.pyx":4381
 * 
 *                 # Analogous to: val = i8other[i]
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]             # <<<<<<<<<<<<<<
 * 
 *                 if val == NPY_NAT:
 */
            __pyx_v_val = (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 1))[0]);

            /* "pandas/_libs/tslibs/offsets.pyx":4383
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
            __pyx_t_5 = (__pyx_v_val == __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT);
            if (__pyx_t_5) {

              /* "pandas/_libs/tslibs/offsets.pyx":4384
 * 
 *                 if val == NPY_NAT:
 *                     res_val = NPY_NAT             # <<<<<<<<<<<<<<
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 */
              __pyx_v_res_val = __pyx_v_6pandas_5_libs_6tslibs_7nattype_NPY_NAT;

              /* "pandas/_libs/tslibs/offsets.pyx":4383
 *                 val = (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 1))[0]
 * 
 *                 if val == NPY_NAT:             # <<<<<<<<<<<<<<
 *                     res_val = NPY_NAT
 *                 else:
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/tslibs/offsets.pyx":4386
 *                     res_val = NPY_NAT
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)             # <<<<<<<<<<<<<<
 *                     months_to_roll = months
 * 
 */
            /*else*/ {
              pandas_datetime_to_datetimestruct(__pyx_v_val, __pyx_v_reso, (&__pyx_v_dts));

              /* "pandas/_libs/tslibs/offsets.pyx":4387
 *                 else:
 *                     pandas_datetime_to_datetimestruct(val, reso, &dts)
 *                     months_to_roll = months             # <<<<<<<<<<<<<<
 * 
 *                     months_to_roll = _roll_qtrday(&dts, months_to_roll, 0, day_opt)
 */
              __pyx_v_months_to_roll = __pyx_v_months;

              /* "pandas/_libs/tslibs/offsets.pyx":4389
 *                     months_to_roll = months
 * 
 *                     months_to_roll = _roll_qtrday(&dts, months_to_roll, 0, day_opt)             # <<<<<<<<<<<<<<
 * 
 *                     dts.year = year_add_months(dts, months_to_roll)
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__roll_qtrday((&__pyx_v_dts), __pyx_v_months_to_roll, 0, __pyx_v_day_opt); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4389, __pyx_L18_error)
              __pyx_v_months_to_roll = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4391
 *                     months_to_roll = _roll_qtrday(&dts, months_to_roll, 0, day_opt)
 * 
 *                     dts.year = year_add_months(dts, months_to_roll)             # <<<<<<<<<<<<<<
 *                     dts.month = month_add_months(dts, months_to_roll)
 *                     dts.day = get_day_of_month(&dts, day_opt)
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_year_add_months(__pyx_v_dts, __pyx_v_months_to_roll); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4391, __pyx_L18_error)
              __pyx_v_dts.year = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4392
 * 
 *                     dts.year = year_add_months(dts, months_to_roll)
 *                     dts.month = month_add_months(dts, months_to_roll)             # <<<<<<<<<<<<<<
 *                     dts.day = get_day_of_month(&dts, day_opt)
 * 
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_month_add_months(__pyx_v_dts, __pyx_v_months_to_roll); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4392, __pyx_L18_error)
              __pyx_v_dts.month = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4393
 *                     dts.year = year_add_months(dts, months_to_roll)
 *                     dts.month = month_add_months(dts, months_to_roll)
 *                     dts.day = get_day_of_month(&dts, day_opt)             # <<<<<<<<<<<<<<
 * 
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)
 */
              __pyx_t_11 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month((&__pyx_v_dts), __pyx_v_day_opt); if (unlikely(__pyx_t_11 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4393, __pyx_L18_error)
              __pyx_v_dts.day = __pyx_t_11;

              /* "pandas/_libs/tslibs/offsets.pyx":4395
 *                     dts.day = get_day_of_month(&dts, day_opt)
 * 
 *                     res_val = npy_datetimestruct_to_datetime(reso, &dts)             # <<<<<<<<<<<<<<
 * 
 *                 # Analogous to: out[i] = res_val
 */
              __pyx_v_res_val = npy_datetimestruct_to_datetime(__pyx_v_reso, (&__pyx_v_dts));
            }
            __pyx_L22:;

            /* "pandas/_libs/tslibs/offsets.pyx":4398
 * 
 *                 # Analogous to: out[i] = res_val
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val             # <<<<<<<<<<<<<<
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 */
            (((__pyx_t_5numpy_int64_t *)PyArray_MultiIter_DATA(__pyx_v_mi, 0))[0]) = __pyx_v_res_val;

            /* "pandas/_libs/tslibs/offsets.pyx":4400
 *                 (<int64_t*>cnp.PyArray_MultiIter_DATA(mi, 0))[0] = res_val
 * 
 *                 cnp.PyArray_MultiIter_NEXT(mi)             # <<<<<<<<<<<<<<
 * 
 *     return out
 */
            PyArray_MultiIter_NEXT(__pyx_v_mi);
          }
        }

        /* "pandas/_libs/tslibs/offsets.pyx":4377
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(count):
 * 
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L18_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L19:;
        }
    }
  }
  __pyx_L10:;

  /* "pandas/_libs/tslibs/offsets.pyx":4402
 *                 cnp.PyArray_MultiIter_NEXT(mi)
 * 
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.shift_months", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XDECREF((PyObject *)__pyx_v_mi);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4405
 * 
 * 
 * def shift_month(stamp: datetime, months: int, day_opt: object = None) -> datetime:             # <<<<<<<<<<<<<<
 *     """
 *     Given a datetime (or Timestamp) `stamp`, an integer `months` and an
 */

/* Python wrapper */
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15shift_month(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_14shift_month, "\n    Given a datetime (or Timestamp) `stamp`, an integer `months` and an\n    option `day_opt`, return a new datetimelike that many months later,\n    with day determined by `day_opt` using relativedelta semantics.\n\n    Scalar analogue of shift_months.\n\n    Parameters\n    ----------\n    stamp : datetime or Timestamp\n    months : int\n    day_opt : None, 'start', 'end', 'business_start', 'business_end', or int\n        None: returned datetimelike has the same day as the input, or the\n              last day of the month if the new month is too short\n        'start': returned datetimelike has day=1\n        'end': returned datetimelike has day on the last day of the month\n        'business_start': returned datetimelike has day on the first\n            business day of the month\n        'business_end': returned datetimelike has day on the last\n            business day of the month\n        int: returned datetimelike has day equal to day_opt\n\n    Returns\n    -------\n    shifted : datetime or Timestamp (same as input `stamp`)\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15shift_month = {"shift_month", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15shift_month, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_14shift_month};
static PyDateTime_DateTime *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15shift_month(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_stamp = 0;
  PyObject *__pyx_v_months = 0;
  PyObject *__pyx_v_day_opt = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyDateTime_DateTime *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shift_month (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stamp,&__pyx_n_s_months,&__pyx_n_s_day_opt_2,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stamp)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4405, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_months)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4405, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("shift_month", 0, 2, 3, 1); __PYX_ERR(0, 4405, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_day_opt_2);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4405, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "shift_month") < 0)) __PYX_ERR(0, 4405, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_stamp = ((PyDateTime_DateTime *)values[0]);
    __pyx_v_months = ((PyObject*)values[1]);
    __pyx_v_day_opt = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("shift_month", 0, 2, 3, __pyx_nargs); __PYX_ERR(0, 4405, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.shift_month", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_stamp), __pyx_ptype_7cpython_8datetime_datetime, 0, "stamp", 0))) __PYX_ERR(0, 4405, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_months), (&PyInt_Type), 0, "months", 1))) __PYX_ERR(0, 4405, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_14shift_month(__pyx_self, __pyx_v_stamp, __pyx_v_months, __pyx_v_day_opt);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyDateTime_DateTime *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_14shift_month(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_DateTime *__pyx_v_stamp, PyObject *__pyx_v_months, PyObject *__pyx_v_day_opt) {
  int __pyx_v_year;
  int __pyx_v_month;
  int __pyx_v_day;
  int __pyx_v_days_in_month;
  int __pyx_v_dy;
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __pyx_t_5numpy_int32_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("shift_month", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":4436
 *         int days_in_month, dy
 * 
 *     dy = (stamp.month + months) // 12             # <<<<<<<<<<<<<<
 *     month = (stamp.month + months) % 12
 * 
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_stamp); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4436, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_months); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_FloorDivideObjC(__pyx_t_3, __pyx_int_12, 12, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dy = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":4437
 * 
 *     dy = (stamp.month + months) // 12
 *     month = (stamp.month + months) % 12             # <<<<<<<<<<<<<<
 * 
 *     if month == 0:
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_stamp); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4437, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_months); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_RemainderObjC(__pyx_t_3, __pyx_int_12, 12, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_month = __pyx_t_1;

  /* "pandas/_libs/tslibs/offsets.pyx":4439
 *     month = (stamp.month + months) % 12
 * 
 *     if month == 0:             # <<<<<<<<<<<<<<
 *         month = 12
 *         dy -= 1
 */
  __pyx_t_4 = (__pyx_v_month == 0);
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4440
 * 
 *     if month == 0:
 *         month = 12             # <<<<<<<<<<<<<<
 *         dy -= 1
 *     year = stamp.year + dy
 */
    __pyx_v_month = 12;

    /* "pandas/_libs/tslibs/offsets.pyx":4441
 *     if month == 0:
 *         month = 12
 *         dy -= 1             # <<<<<<<<<<<<<<
 *     year = stamp.year + dy
 * 
 */
    __pyx_v_dy = (__pyx_v_dy - 1);

    /* "pandas/_libs/tslibs/offsets.pyx":4439
 *     month = (stamp.month + months) % 12
 * 
 *     if month == 0:             # <<<<<<<<<<<<<<
 *         month = 12
 *         dy -= 1
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4442
 *         month = 12
 *         dy -= 1
 *     year = stamp.year + dy             # <<<<<<<<<<<<<<
 * 
 *     if day_opt is None:
 */
  __pyx_t_1 = __pyx_f_7cpython_8datetime_8datetime_4year_year(__pyx_v_stamp); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4442, __pyx_L1_error)
  __pyx_v_year = (__pyx_t_1 + __pyx_v_dy);

  /* "pandas/_libs/tslibs/offsets.pyx":4444
 *     year = stamp.year + dy
 * 
 *     if day_opt is None:             # <<<<<<<<<<<<<<
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(stamp.day, days_in_month)
 */
  __pyx_t_4 = (__pyx_v_day_opt == Py_None);
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4445
 * 
 *     if day_opt is None:
 *         days_in_month = get_days_in_month(year, month)             # <<<<<<<<<<<<<<
 *         day = min(stamp.day, days_in_month)
 *     elif day_opt == "start":
 */
    __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_year, __pyx_v_month, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4445, __pyx_L1_error)
    __pyx_v_days_in_month = __pyx_t_5;

    /* "pandas/_libs/tslibs/offsets.pyx":4446
 *     if day_opt is None:
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(stamp.day, days_in_month)             # <<<<<<<<<<<<<<
 *     elif day_opt == "start":
 *         day = 1
 */
    __pyx_t_1 = __pyx_v_days_in_month;
    __pyx_t_6 = __pyx_f_7cpython_8datetime_8datetime_3day_day(__pyx_v_stamp); if (unlikely(__pyx_t_6 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4446, __pyx_L1_error)
    __pyx_t_4 = (__pyx_t_1 < __pyx_t_6);
    if (__pyx_t_4) {
      __pyx_t_7 = __pyx_t_1;
    } else {
      __pyx_t_7 = __pyx_t_6;
    }
    __pyx_v_day = __pyx_t_7;

    /* "pandas/_libs/tslibs/offsets.pyx":4444
 *     year = stamp.year + dy
 * 
 *     if day_opt is None:             # <<<<<<<<<<<<<<
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(stamp.day, days_in_month)
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4447
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(stamp.day, days_in_month)
 *     elif day_opt == "start":             # <<<<<<<<<<<<<<
 *         day = 1
 *     elif day_opt == "end":
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_start, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4447, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4448
 *         day = min(stamp.day, days_in_month)
 *     elif day_opt == "start":
 *         day = 1             # <<<<<<<<<<<<<<
 *     elif day_opt == "end":
 *         day = get_days_in_month(year, month)
 */
    __pyx_v_day = 1;

    /* "pandas/_libs/tslibs/offsets.pyx":4447
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(stamp.day, days_in_month)
 *     elif day_opt == "start":             # <<<<<<<<<<<<<<
 *         day = 1
 *     elif day_opt == "end":
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4449
 *     elif day_opt == "start":
 *         day = 1
 *     elif day_opt == "end":             # <<<<<<<<<<<<<<
 *         day = get_days_in_month(year, month)
 *     elif day_opt == "business_start":
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_end, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4449, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4450
 *         day = 1
 *     elif day_opt == "end":
 *         day = get_days_in_month(year, month)             # <<<<<<<<<<<<<<
 *     elif day_opt == "business_start":
 *         # first business day of month
 */
    __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_year, __pyx_v_month, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4450, __pyx_L1_error)
    __pyx_v_day = __pyx_t_5;

    /* "pandas/_libs/tslibs/offsets.pyx":4449
 *     elif day_opt == "start":
 *         day = 1
 *     elif day_opt == "end":             # <<<<<<<<<<<<<<
 *         day = get_days_in_month(year, month)
 *     elif day_opt == "business_start":
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4451
 *     elif day_opt == "end":
 *         day = get_days_in_month(year, month)
 *     elif day_opt == "business_start":             # <<<<<<<<<<<<<<
 *         # first business day of month
 *         day = get_firstbday(year, month)
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_business_start, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4451, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4453
 *     elif day_opt == "business_start":
 *         # first business day of month
 *         day = get_firstbday(year, month)             # <<<<<<<<<<<<<<
 *     elif day_opt == "business_end":
 *         # last business day of month
 */
    __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_firstbday(__pyx_v_year, __pyx_v_month, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4453, __pyx_L1_error)
    __pyx_v_day = __pyx_t_7;

    /* "pandas/_libs/tslibs/offsets.pyx":4451
 *     elif day_opt == "end":
 *         day = get_days_in_month(year, month)
 *     elif day_opt == "business_start":             # <<<<<<<<<<<<<<
 *         # first business day of month
 *         day = get_firstbday(year, month)
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4454
 *         # first business day of month
 *         day = get_firstbday(year, month)
 *     elif day_opt == "business_end":             # <<<<<<<<<<<<<<
 *         # last business day of month
 *         day = get_lastbday(year, month)
 */
  __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_business_end, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4454, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "pandas/_libs/tslibs/offsets.pyx":4456
 *     elif day_opt == "business_end":
 *         # last business day of month
 *         day = get_lastbday(year, month)             # <<<<<<<<<<<<<<
 *     elif is_integer_object(day_opt):
 *         days_in_month = get_days_in_month(year, month)
 */
    __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_lastbday(__pyx_v_year, __pyx_v_month, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4456, __pyx_L1_error)
    __pyx_v_day = __pyx_t_7;

    /* "pandas/_libs/tslibs/offsets.pyx":4454
 *         # first business day of month
 *         day = get_firstbday(year, month)
 *     elif day_opt == "business_end":             # <<<<<<<<<<<<<<
 *         # last business day of month
 *         day = get_lastbday(year, month)
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4457
 *         # last business day of month
 *         day = get_lastbday(year, month)
 *     elif is_integer_object(day_opt):             # <<<<<<<<<<<<<<
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(day_opt, days_in_month)
 */
  __pyx_t_4 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(__pyx_v_day_opt); if (unlikely(__pyx_t_4 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4457, __pyx_L1_error)
  if (likely(__pyx_t_4)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4458
 *         day = get_lastbday(year, month)
 *     elif is_integer_object(day_opt):
 *         days_in_month = get_days_in_month(year, month)             # <<<<<<<<<<<<<<
 *         day = min(day_opt, days_in_month)
 *     else:
 */
    __pyx_t_5 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_year, __pyx_v_month, 0); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4458, __pyx_L1_error)
    __pyx_v_days_in_month = __pyx_t_5;

    /* "pandas/_libs/tslibs/offsets.pyx":4459
 *     elif is_integer_object(day_opt):
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(day_opt, days_in_month)             # <<<<<<<<<<<<<<
 *     else:
 *         raise ValueError(day_opt)
 */
    __pyx_t_7 = __pyx_v_days_in_month;
    __Pyx_INCREF(__pyx_v_day_opt);
    __pyx_t_2 = __pyx_v_day_opt;
    __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_8, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_4) {
      __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4459, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_3 = __pyx_t_9;
      __pyx_t_9 = 0;
    } else {
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_3 = __pyx_t_2;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4459, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_day = __pyx_t_7;

    /* "pandas/_libs/tslibs/offsets.pyx":4457
 *         # last business day of month
 *         day = get_lastbday(year, month)
 *     elif is_integer_object(day_opt):             # <<<<<<<<<<<<<<
 *         days_in_month = get_days_in_month(year, month)
 *         day = min(day_opt, days_in_month)
 */
    goto __pyx_L4;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4461
 *         day = min(day_opt, days_in_month)
 *     else:
 *         raise ValueError(day_opt)             # <<<<<<<<<<<<<<
 *     return stamp.replace(year=year, month=month, day=day)
 * 
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_v_day_opt); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 4461, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "pandas/_libs/tslibs/offsets.pyx":4462
 *     else:
 *         raise ValueError(day_opt)
 *     return stamp.replace(year=year, month=month, day=day)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_stamp), __pyx_n_s_replace); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_year); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_year, __pyx_t_9) < 0) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_month); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_month, __pyx_t_9) < 0) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_day); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_day, __pyx_t_9) < 0) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 4462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_7cpython_8datetime_datetime))))) __PYX_ERR(0, 4462, __pyx_L1_error)
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_9);
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4405
 * 
 * 
 * def shift_month(stamp: datetime, months: int, day_opt: object = None) -> datetime:             # <<<<<<<<<<<<<<
 *     """
 *     Given a datetime (or Timestamp) `stamp`, an integer `months` and an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.shift_month", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4465
 * 
 * 
 * cdef int get_day_of_month(npy_datetimestruct* dts, str day_opt) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Find the day in `other`'s month that satisfies a DateOffset's is_on_offset
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month(npy_datetimestruct *__pyx_v_dts, PyObject *__pyx_v_day_opt) {
  int __pyx_r;
  int __pyx_t_1;
  __pyx_t_5numpy_int32_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":4497
 *     """
 * 
 *     if day_opt == "start":             # <<<<<<<<<<<<<<
 *         return 1
 *     elif day_opt == "end":
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_start, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4497, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4498
 * 
 *     if day_opt == "start":
 *         return 1             # <<<<<<<<<<<<<<
 *     elif day_opt == "end":
 *         return get_days_in_month(dts.year, dts.month)
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4497
 *     """
 * 
 *     if day_opt == "start":             # <<<<<<<<<<<<<<
 *         return 1
 *     elif day_opt == "end":
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4499
 *     if day_opt == "start":
 *         return 1
 *     elif day_opt == "end":             # <<<<<<<<<<<<<<
 *         return get_days_in_month(dts.year, dts.month)
 *     elif day_opt == "business_start":
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_end, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4499, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4500
 *         return 1
 *     elif day_opt == "end":
 *         return get_days_in_month(dts.year, dts.month)             # <<<<<<<<<<<<<<
 *     elif day_opt == "business_start":
 *         # first business day of month
 */
    __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month(__pyx_v_dts->year, __pyx_v_dts->month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4500, __pyx_L1_error)
    __pyx_r = __pyx_t_2;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4499
 *     if day_opt == "start":
 *         return 1
 *     elif day_opt == "end":             # <<<<<<<<<<<<<<
 *         return get_days_in_month(dts.year, dts.month)
 *     elif day_opt == "business_start":
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4501
 *     elif day_opt == "end":
 *         return get_days_in_month(dts.year, dts.month)
 *     elif day_opt == "business_start":             # <<<<<<<<<<<<<<
 *         # first business day of month
 *         return get_firstbday(dts.year, dts.month)
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_day_opt, __pyx_n_u_business_start, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 4501, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4503
 *     elif day_opt == "business_start":
 *         # first business day of month
 *         return get_firstbday(dts.year, dts.month)             # <<<<<<<<<<<<<<
 *     else:
 *         # i.e. day_opt == "business_end":
 */
    __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_firstbday(__pyx_v_dts->year, __pyx_v_dts->month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4503, __pyx_L1_error)
    __pyx_r = __pyx_t_3;
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/offsets.pyx":4501
 *     elif day_opt == "end":
 *         return get_days_in_month(dts.year, dts.month)
 *     elif day_opt == "business_start":             # <<<<<<<<<<<<<<
 *         # first business day of month
 *         return get_firstbday(dts.year, dts.month)
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4507
 *         # i.e. day_opt == "business_end":
 *         # last business day of month
 *         return get_lastbday(dts.year, dts.month)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_lastbday(__pyx_v_dts->year, __pyx_v_dts->month, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4507, __pyx_L1_error)
    __pyx_r = __pyx_t_3;
    goto __pyx_L0;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4465
 * 
 * 
 * cdef int get_day_of_month(npy_datetimestruct* dts, str day_opt) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Find the day in `other`'s month that satisfies a DateOffset's is_on_offset
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.get_day_of_month", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4510
 * 
 * 
 * cpdef int roll_convention(int other, int n, int compare) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Possibly increment or decrement the number of periods to shift
 */

static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17roll_convention(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static int __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(int __pyx_v_other, int __pyx_v_n, int __pyx_v_compare, CYTHON_UNUSED int __pyx_skip_dispatch) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/tslibs/offsets.pyx":4526
 *     n : int number of periods to increment
 *     """
 *     if n > 0 and other < compare:             # <<<<<<<<<<<<<<
 *         n -= 1
 *     elif n <= 0 and other > compare:
 */
  __pyx_t_2 = (__pyx_v_n > 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_other < __pyx_v_compare);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4527
 *     """
 *     if n > 0 and other < compare:
 *         n -= 1             # <<<<<<<<<<<<<<
 *     elif n <= 0 and other > compare:
 *         # as if rolled forward already
 */
    __pyx_v_n = (__pyx_v_n - 1);

    /* "pandas/_libs/tslibs/offsets.pyx":4526
 *     n : int number of periods to increment
 *     """
 *     if n > 0 and other < compare:             # <<<<<<<<<<<<<<
 *         n -= 1
 *     elif n <= 0 and other > compare:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4528
 *     if n > 0 and other < compare:
 *         n -= 1
 *     elif n <= 0 and other > compare:             # <<<<<<<<<<<<<<
 *         # as if rolled forward already
 *         n += 1
 */
  __pyx_t_2 = (__pyx_v_n <= 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_other > __pyx_v_compare);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4530
 *     elif n <= 0 and other > compare:
 *         # as if rolled forward already
 *         n += 1             # <<<<<<<<<<<<<<
 *     return n
 * 
 */
    __pyx_v_n = (__pyx_v_n + 1);

    /* "pandas/_libs/tslibs/offsets.pyx":4528
 *     if n > 0 and other < compare:
 *         n -= 1
 *     elif n <= 0 and other > compare:             # <<<<<<<<<<<<<<
 *         # as if rolled forward already
 *         n += 1
 */
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":4531
 *         # as if rolled forward already
 *         n += 1
 *     return n             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_n;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4510
 * 
 * 
 * cpdef int roll_convention(int other, int n, int compare) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Possibly increment or decrement the number of periods to shift
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17roll_convention(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_16roll_convention, "\n    Possibly increment or decrement the number of periods to shift\n    based on rollforward/rollbackward conventions.\n\n    Parameters\n    ----------\n    other : int, generally the day component of a datetime\n    n : number of periods to increment, before adjusting for rolling\n    compare : int, generally the day component of a datetime, in the same\n              month as the datetime form which `other` was taken.\n\n    Returns\n    -------\n    n : int number of periods to increment\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17roll_convention = {"roll_convention", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17roll_convention, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_16roll_convention};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17roll_convention(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_other;
  int __pyx_v_n;
  int __pyx_v_compare;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("roll_convention (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,&__pyx_n_s_n,&__pyx_n_s_compare,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_convention", 1, 3, 3, 1); __PYX_ERR(0, 4510, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_compare)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_convention", 1, 3, 3, 2); __PYX_ERR(0, 4510, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "roll_convention") < 0)) __PYX_ERR(0, 4510, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_other = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_other == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
    __pyx_v_n = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_n == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
    __pyx_v_compare = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_compare == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("roll_convention", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 4510, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.roll_convention", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_16roll_convention(__pyx_self, __pyx_v_other, __pyx_v_n, __pyx_v_compare);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_16roll_convention(CYTHON_UNUSED PyObject *__pyx_self, int __pyx_v_other, int __pyx_v_n, int __pyx_v_compare) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("roll_convention", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_roll_convention(__pyx_v_other, __pyx_v_n, __pyx_v_compare, 0); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4510, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.roll_convention", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4534
 * 
 * 
 * def roll_qtrday(other: datetime, n: int, month: int,             # <<<<<<<<<<<<<<
 *                 day_opt: str, modby: int) -> int:
 *     """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19roll_qtrday(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_6tslibs_7offsets_18roll_qtrday, "\n    Possibly increment or decrement the number of periods to shift\n    based on rollforward/rollbackward conventions.\n\n    Parameters\n    ----------\n    other : datetime or Timestamp\n    n : number of periods to increment, before adjusting for rolling\n    month : int reference month giving the first month of the year\n    day_opt : {'start', 'end', 'business_start', 'business_end'}\n        The convention to use in finding the day in a given month against\n        which to compare for rollforward/rollbackward decisions.\n    modby : int 3 for quarters, 12 for years\n\n    Returns\n    -------\n    n : int number of periods to increment\n\n    See Also\n    --------\n    get_day_of_month : Find the day in a month provided an offset.\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19roll_qtrday = {"roll_qtrday", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19roll_qtrday, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_18roll_qtrday};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19roll_qtrday(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyDateTime_DateTime *__pyx_v_other = 0;
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_v_month = 0;
  PyObject *__pyx_v_day_opt = 0;
  PyObject *__pyx_v_modby = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("roll_qtrday (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_other,&__pyx_n_s_n,&__pyx_n_s_month,&__pyx_n_s_day_opt_2,&__pyx_n_s_modby,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_other)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_n)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_qtrday", 1, 5, 5, 1); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_month)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_qtrday", 1, 5, 5, 2); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_day_opt_2)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_qtrday", 1, 5, 5, 3); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_modby)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4534, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("roll_qtrday", 1, 5, 5, 4); __PYX_ERR(0, 4534, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "roll_qtrday") < 0)) __PYX_ERR(0, 4534, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 5)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
      values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
    }
    __pyx_v_other = ((PyDateTime_DateTime *)values[0]);
    __pyx_v_n = ((PyObject*)values[1]);
    __pyx_v_month = ((PyObject*)values[2]);
    __pyx_v_day_opt = ((PyObject*)values[3]);
    __pyx_v_modby = ((PyObject*)values[4]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("roll_qtrday", 1, 5, 5, __pyx_nargs); __PYX_ERR(0, 4534, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.roll_qtrday", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_datetime, 0, "other", 0))) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_n), (&PyInt_Type), 0, "n", 1))) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_month), (&PyInt_Type), 0, "month", 1))) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_day_opt), (&PyUnicode_Type), 0, "day_opt", 1))) __PYX_ERR(0, 4535, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_modby), (&PyInt_Type), 0, "modby", 1))) __PYX_ERR(0, 4535, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_18roll_qtrday(__pyx_self, __pyx_v_other, __pyx_v_n, __pyx_v_month, __pyx_v_day_opt, __pyx_v_modby);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_18roll_qtrday(CYTHON_UNUSED PyObject *__pyx_self, PyDateTime_DateTime *__pyx_v_other, PyObject *__pyx_v_n, PyObject *__pyx_v_month, PyObject *__pyx_v_day_opt, PyObject *__pyx_v_modby) {
  int __pyx_v_months_since;
  npy_datetimestruct __pyx_v_dts;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("roll_qtrday", 1);

  /* "pandas/_libs/tslibs/offsets.pyx":4562
 *         npy_datetimestruct dts
 * 
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:             # <<<<<<<<<<<<<<
 *         raise ValueError(day_opt)
 * 
 */
  __Pyx_INCREF(__pyx_v_day_opt);
  __pyx_t_1 = __pyx_v_day_opt;
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_start, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4562, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_end, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4562, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_business_start, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4562, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_business_end, Py_NE)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4562, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_2;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/tslibs/offsets.pyx":4563
 * 
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:
 *         raise ValueError(day_opt)             # <<<<<<<<<<<<<<
 * 
 *     pydate_to_dtstruct(other, &dts)
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_v_day_opt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 4563, __pyx_L1_error)

    /* "pandas/_libs/tslibs/offsets.pyx":4562
 *         npy_datetimestruct dts
 * 
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:             # <<<<<<<<<<<<<<
 *         raise ValueError(day_opt)
 * 
 */
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4565
 *         raise ValueError(day_opt)
 * 
 *     pydate_to_dtstruct(other, &dts)             # <<<<<<<<<<<<<<
 * 
 *     if modby == 12:
 */
  if (!(likely(__Pyx_TypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_7cpython_8datetime_date)))) __PYX_ERR(0, 4565, __pyx_L1_error)
  __pyx_f_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dtstruct(((PyDateTime_Date *)__pyx_v_other), (&__pyx_v_dts)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 4565, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4567
 *     pydate_to_dtstruct(other, &dts)
 * 
 *     if modby == 12:             # <<<<<<<<<<<<<<
 *         # We care about the month-of-year, not month-of-quarter, so skip mod
 *         months_since = other.month - month
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_modby, __pyx_int_12, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4567, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 4567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "pandas/_libs/tslibs/offsets.pyx":4569
 *     if modby == 12:
 *         # We care about the month-of-year, not month-of-quarter, so skip mod
 *         months_since = other.month - month             # <<<<<<<<<<<<<<
 *     else:
 *         months_since = other.month % modby - month % modby
 */
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyNumber_Subtract(__pyx_t_4, __pyx_v_month); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4569, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_months_since = __pyx_t_5;

    /* "pandas/_libs/tslibs/offsets.pyx":4567
 *     pydate_to_dtstruct(other, &dts)
 * 
 *     if modby == 12:             # <<<<<<<<<<<<<<
 *         # We care about the month-of-year, not month-of-quarter, so skip mod
 *         months_since = other.month - month
 */
    goto __pyx_L8;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4571
 *         months_since = other.month - month
 *     else:
 *         months_since = other.month % modby - month % modby             # <<<<<<<<<<<<<<
 * 
 *     return _roll_qtrday(&dts, n, months_since, day_opt)
 */
  /*else*/ {
    __pyx_t_5 = __pyx_f_7cpython_8datetime_8datetime_5month_month(__pyx_v_other); if (unlikely(__pyx_t_5 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4571, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = PyNumber_Remainder(__pyx_t_6, __pyx_v_modby); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyNumber_Remainder(__pyx_v_month, __pyx_v_modby); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyNumber_Subtract(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4571, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_months_since = __pyx_t_5;
  }
  __pyx_L8:;

  /* "pandas/_libs/tslibs/offsets.pyx":4573
 *         months_since = other.month % modby - month % modby
 * 
 *     return _roll_qtrday(&dts, n, months_since, day_opt)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_n); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4573, __pyx_L1_error)
  __pyx_t_8 = __pyx_f_6pandas_5_libs_6tslibs_7offsets__roll_qtrday((&__pyx_v_dts), __pyx_t_5, __pyx_v_months_since, __pyx_v_day_opt); if (unlikely(__pyx_t_8 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(0, 4573, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 4573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_7)) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_7))) __PYX_ERR(0, 4573, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4534
 * 
 * 
 * def roll_qtrday(other: datetime, n: int, month: int,             # <<<<<<<<<<<<<<
 *                 day_opt: str, modby: int) -> int:
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.roll_qtrday", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/offsets.pyx":4576
 * 
 * 
 * cdef int _roll_qtrday(npy_datetimestruct* dts,             # <<<<<<<<<<<<<<
 *                       int n,
 *                       int months_since,
 */

static int __pyx_f_6pandas_5_libs_6tslibs_7offsets__roll_qtrday(npy_datetimestruct *__pyx_v_dts, int __pyx_v_n, int __pyx_v_months_since, PyObject *__pyx_v_day_opt) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":4584
 *     """
 * 
 *     if n > 0:             # <<<<<<<<<<<<<<
 *         if months_since < 0 or (months_since == 0 and
 *                                 dts.day < get_day_of_month(dts, day_opt)):
 */
  __pyx_t_1 = (__pyx_v_n > 0);
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/offsets.pyx":4585
 * 
 *     if n > 0:
 *         if months_since < 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day < get_day_of_month(dts, day_opt)):
 *             # pretend to roll back if on same month but
 */
    __pyx_t_2 = (__pyx_v_months_since < 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_months_since == 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4586
 *     if n > 0:
 *         if months_since < 0 or (months_since == 0 and
 *                                 dts.day < get_day_of_month(dts, day_opt)):             # <<<<<<<<<<<<<<
 *             # pretend to roll back if on same month but
 *             # before compare_day
 */
    __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month(__pyx_v_dts, __pyx_v_day_opt); if (unlikely(__pyx_t_3 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4586, __pyx_L1_error)
    __pyx_t_2 = (__pyx_v_dts->day < __pyx_t_3);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;

    /* "pandas/_libs/tslibs/offsets.pyx":4585
 * 
 *     if n > 0:
 *         if months_since < 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day < get_day_of_month(dts, day_opt)):
 *             # pretend to roll back if on same month but
 */
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":4589
 *             # pretend to roll back if on same month but
 *             # before compare_day
 *             n -= 1             # <<<<<<<<<<<<<<
 *     else:
 *         if months_since > 0 or (months_since == 0 and
 */
      __pyx_v_n = (__pyx_v_n - 1);

      /* "pandas/_libs/tslibs/offsets.pyx":4585
 * 
 *     if n > 0:
 *         if months_since < 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day < get_day_of_month(dts, day_opt)):
 *             # pretend to roll back if on same month but
 */
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4584
 *     """
 * 
 *     if n > 0:             # <<<<<<<<<<<<<<
 *         if months_since < 0 or (months_since == 0 and
 *                                 dts.day < get_day_of_month(dts, day_opt)):
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/tslibs/offsets.pyx":4591
 *             n -= 1
 *     else:
 *         if months_since > 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day > get_day_of_month(dts, day_opt)):
 *             # make sure to roll forward, so negate
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_months_since > 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_months_since == 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }

    /* "pandas/_libs/tslibs/offsets.pyx":4592
 *     else:
 *         if months_since > 0 or (months_since == 0 and
 *                                 dts.day > get_day_of_month(dts, day_opt)):             # <<<<<<<<<<<<<<
 *             # make sure to roll forward, so negate
 *             n += 1
 */
    __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_7offsets_get_day_of_month(__pyx_v_dts, __pyx_v_day_opt); if (unlikely(__pyx_t_3 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(0, 4592, __pyx_L1_error)
    __pyx_t_2 = (__pyx_v_dts->day > __pyx_t_3);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;

    /* "pandas/_libs/tslibs/offsets.pyx":4591
 *             n -= 1
 *     else:
 *         if months_since > 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day > get_day_of_month(dts, day_opt)):
 *             # make sure to roll forward, so negate
 */
    if (__pyx_t_1) {

      /* "pandas/_libs/tslibs/offsets.pyx":4594
 *                                 dts.day > get_day_of_month(dts, day_opt)):
 *             # make sure to roll forward, so negate
 *             n += 1             # <<<<<<<<<<<<<<
 *     return n
 */
      __pyx_v_n = (__pyx_v_n + 1);

      /* "pandas/_libs/tslibs/offsets.pyx":4591
 *             n -= 1
 *     else:
 *         if months_since > 0 or (months_since == 0 and             # <<<<<<<<<<<<<<
 *                                 dts.day > get_day_of_month(dts, day_opt)):
 *             # make sure to roll forward, so negate
 */
    }
  }
  __pyx_L3:;

  /* "pandas/_libs/tslibs/offsets.pyx":4595
 *             # make sure to roll forward, so negate
 *             n += 1
 *     return n             # <<<<<<<<<<<<<<
 */
  __pyx_r = __pyx_v_n;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/offsets.pyx":4576
 * 
 * 
 * cdef int _roll_qtrday(npy_datetimestruct* dts,             # <<<<<<<<<<<<<<
 *                       int n,
 *                       int months_since,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets._roll_qtrday", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_BaseOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_21__pyx_unpickle_BaseOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_21__pyx_unpickle_BaseOffset = {"__pyx_unpickle_BaseOffset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_21__pyx_unpickle_BaseOffset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_21__pyx_unpickle_BaseOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseOffset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BaseOffset", 1, 3, 3, 1); __PYX_ERR(5, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BaseOffset", 1, 3, 3, 2); __PYX_ERR(5, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_BaseOffset") < 0)) __PYX_ERR(5, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_BaseOffset", 1, 3, 3, __pyx_nargs); __PYX_ERR(5, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_BaseOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_20__pyx_unpickle_BaseOffset(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_20__pyx_unpickle_BaseOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseOffset", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__66, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = BaseOffset.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(5, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = BaseOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(5, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = BaseOffset.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = BaseOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = BaseOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(5, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_BaseOffset__set_state(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = BaseOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_BaseOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_BaseOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_BaseOffset__set_state(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_BaseOffset__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_cache);
  __Pyx_DECREF(__pyx_v___pyx_result->_cache);
  __pyx_v___pyx_result->_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_2 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->n = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->normalize = __pyx_t_3;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 13, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(5, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 > 3);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(5, 13, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_BaseOffset__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_RelativeDeltaOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23__pyx_unpickle_RelativeDeltaOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23__pyx_unpickle_RelativeDeltaOffset = {"__pyx_unpickle_RelativeDeltaOffset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23__pyx_unpickle_RelativeDeltaOffset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23__pyx_unpickle_RelativeDeltaOffset(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_RelativeDeltaOffset (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RelativeDeltaOffset", 1, 3, 3, 1); __PYX_ERR(5, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RelativeDeltaOffset", 1, 3, 3, 2); __PYX_ERR(5, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_RelativeDeltaOffset") < 0)) __PYX_ERR(5, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(5, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RelativeDeltaOffset", 1, 3, 3, __pyx_nargs); __PYX_ERR(5, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_RelativeDeltaOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_6tslibs_7offsets_22__pyx_unpickle_RelativeDeltaOffset(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_6tslibs_7offsets_22__pyx_unpickle_RelativeDeltaOffset(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_RelativeDeltaOffset", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__66, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(5, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(5, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(5, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_RelativeDeltaOffset__set_state(((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 *     __pyx_result = RelativeDeltaOffset.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_RelativeDeltaOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_RelativeDeltaOffset", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_6pandas_5_libs_6tslibs_7offsets___pyx_unpickle_RelativeDeltaOffset__set_state(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_RelativeDeltaOffset__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyDict_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("dict", __pyx_t_1))) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->__pyx_base._cache);
  __Pyx_DECREF(__pyx_v___pyx_result->__pyx_base._cache);
  __pyx_v___pyx_result->__pyx_base._cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_npy_int64(__pyx_t_1); if (unlikely((__pyx_t_2 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->__pyx_base.n = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(5, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->__pyx_base.normalize = __pyx_t_3;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 13, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(5, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 > 3);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(5, 13, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[3])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[3])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_RelativeDeltaOffset__set_state(<RelativeDeltaOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RelativeDeltaOffset__set_state(RelativeDeltaOffset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.tslibs.offsets.__pyx_unpickle_RelativeDeltaOffset__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)o);
  p->_cache = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_cache);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)o;
  if (p->_cache) {
    e = (*v)(p->_cache, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset *)o;
  tmp = ((PyObject*)p->_cache);
  p->_cache = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_3__eq__(o1, o2);
    }
    case Py_NE: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5__ne__(o1, o2);
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static CYTHON_INLINE PyObject *__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_add : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_add);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_add == &__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_11__add__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_add == &__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_13__radd__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_subtract : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_subtract);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_subtract == &__pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_15__sub__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_subtract == &__pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_17__rsub__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_multiply : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_multiply);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_19__mul__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_21__rmul__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_kwds(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4kwds_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4base_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_4name_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset__prefix(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7_prefix_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_nanos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_5nanos_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_n(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1n_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_normalize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9normalize_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset__cache(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_6_cache_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__(self);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BaseOffset[] = {
  {"_params", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_8_params},
  {"__radd__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_13__radd__, METH_O|METH_COEXIST, 0},
  {"__rsub__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_17__rsub__, METH_O|METH_COEXIST, 0},
  {"__rmul__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_21__rmul__, METH_O|METH_COEXIST, 0},
  {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_24copy},
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, METH_NOARGS|METH_COEXIST, 0},
  {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"freqstr", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_30freqstr},
  {"_offset_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"rollback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_38rollback},
  {"rollforward", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_40rollforward},
  {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_44is_on_offset},
  {"_validate_n", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_46_validate_n},
  {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_48__setstate__},
  {"__getstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_50__getstate__},
  {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_52is_anchored},
  {"is_month_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_54is_month_start},
  {"is_month_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_56is_month_end},
  {"is_quarter_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_58is_quarter_start},
  {"is_quarter_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_60is_quarter_end},
  {"is_year_start", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_62is_year_start},
  {"is_year_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_64is_year_end},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BaseOffset[] = {
  {(char *)"kwds", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_kwds, 0, (char *)PyDoc_STR("\n        Return a dict of extra parameters for the offset.\n\n        Examples\n        --------\n        >>> pd.DateOffset(5).kwds\n        {}\n\n        >>> pd.offsets.FY5253Quarter().kwds\n        {'weekday': 0,\n         'startingMonth': 1,\n         'qtr_with_extra_week': 1,\n         'variation': 'nearest'}\n        "), 0},
  {(char *)"base", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_base, 0, (char *)PyDoc_STR("\n        Returns a copy of the calling offset object with n=1 and all other\n        attributes equal.\n        "), 0},
  {(char *)"name", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_name, 0, (char *)PyDoc_STR("\n        Return a string representing the base frequency.\n\n        Examples\n        --------\n        >>> pd.offsets.Hour().name\n        'H'\n\n        >>> pd.offsets.Hour(5).name\n        'H'\n        "), 0},
  {(char *)"_prefix", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset__prefix, 0, (char *)0, 0},
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_rule_code, 0, (char *)0, 0},
  {(char *)"nanos", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_nanos, 0, (char *)0, 0},
  {(char *)"n", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_n, 0, (char *)0, 0},
  {(char *)"normalize", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_normalize, 0, (char *)0, 0},
  {(char *)"_cache", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10BaseOffset__cache, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_repr, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__},
  {Py_nb_add, (void *)__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_nb_subtract, (void *)__pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_nb_multiply, (void *)__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_nb_negative, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_23__neg__},
  {Py_tp_hash, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7__hash__},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Base class for DateOffset methods that are not overridden by subclasses.\n\n    Parameters\n    ----------\n    n : int\n        Number of multiples of the frequency.\n\n    normalize : bool\n        Whether the frequency can align with midnight.\n\n    Examples\n    --------\n    >>> pd.offsets.Hour(5).n\n    5\n    >>> pd.offsets.Hour(5).normalize\n    False\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_richcompare, (void *)__pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset_spec = {
  "pandas._libs.tslibs.offsets.BaseOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset_slots,
};
#else

static PyNumberMethods __pyx_tp_as_number_BaseOffset = {
  __pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*nb_add*/
  __pyx_nb_subtract_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*nb_subtract*/
  __pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_23__neg__, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_bool*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  0, /*nb_index*/
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_matrix_multiply*/
  #endif
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_inplace_matrix_multiply*/
  #endif
};

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BaseOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BaseOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  &__pyx_tp_as_number_BaseOffset, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_7__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Base class for DateOffset methods that are not overridden by subclasses.\n\n    Parameters\n    ----------\n    n : int\n        Number of multiples of the frequency.\n\n    normalize : bool\n        Whether the frequency can align with midnight.\n\n    Examples\n    --------\n    >>> pd.offsets.Hour(5).n\n    5\n    >>> pd.offsets.Hour(5).normalize\n    False\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  __pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset[] = {
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset_spec = {
  "pandas._libs.tslibs.offsets.SingleConstructorOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""SingleConstructorOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Tick;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  return o;
}

static PyObject *__pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_Tick(PyObject *o1, PyObject *o2, int op) {
  switch (op) {
    case Py_EQ: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_13__eq__(o1, o2);
    }
    case Py_NE: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_15__ne__(o1, o2);
    }
    case Py_LT: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_19__lt__(o1, o2);
    }
    case Py_GT: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_23__gt__(o1, o2);
    }
    case Py_LE: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_17__le__(o1, o2);
    }
    case Py_GE: {
      return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_21__ge__(o1, o2);
    }
    default: {
      return __Pyx_NewRef(Py_NotImplemented);
    }
  }
}

static CYTHON_INLINE PyObject *__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_add : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_add);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_add == &__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_33__add__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_add == &__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_35__radd__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_multiply : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_multiply);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_25__mul__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_multiply == &__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_27__rmul__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static CYTHON_INLINE PyObject *__pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick_maybe_call_slot(PyTypeObject* type, PyObject *left, PyObject *right ) {
    binaryfunc slot;
#if CYTHON_USE_TYPE_SLOTS || PY_MAJOR_VERSION < 3 || CYTHON_COMPILING_IN_PYPY
    slot = type->tp_as_number ? type->tp_as_number->nb_true_divide : NULL;
#else
    slot = (binaryfunc) PyType_GetSlot(type, Py_nb_true_divide);
#endif
    return slot ? slot(left, right ) : __Pyx_NewRef(Py_NotImplemented);
}
static PyObject *__pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick(PyObject *left, PyObject *right ) {
    int maybe_self_is_left, maybe_self_is_right = 0;
    maybe_self_is_left = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(left)->tp_as_number && Py_TYPE(left)->tp_as_number->nb_true_divide == &__pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || __Pyx_TypeCheck(left, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_left) {
        PyObject *res;
        res = __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_29__truediv__(left, right);
        if (res != Py_NotImplemented) return res;
        Py_DECREF(res);
    }
    maybe_self_is_right = Py_TYPE(left) == Py_TYPE(right)
#if CYTHON_USE_TYPE_SLOTS
            || (Py_TYPE(right)->tp_as_number && Py_TYPE(right)->tp_as_number->nb_true_divide == &__pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick)
#endif
            || PyType_IsSubtype(Py_TYPE(right), __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);
    if (maybe_self_is_right) {
        return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_31__rtruediv__(right, left);
    }
    return __Pyx_NewRef(Py_NotImplemented);
}



static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Tick_delta(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5delta_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Tick_nanos(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5nanos_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Tick[] = {
  {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__rmul__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_27__rmul__, METH_O|METH_COEXIST, 0},
  {"__rtruediv__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_31__rtruediv__, METH_O|METH_COEXIST, 0},
  {"__radd__", (PyCFunction)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_35__radd__, METH_O|METH_COEXIST, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Tick[] = {
  {(char *)"delta", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Tick_delta, 0, (char *)0, 0},
  {(char *)"nanos", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Tick_nanos, 0, (char *)PyDoc_STR("\n        Return an integer of the total number of nanoseconds.\n\n        Raises\n        ------\n        ValueError\n            If the frequency is non-fixed.\n\n        Examples\n        --------\n        >>> pd.offsets.Hour(5).nanos\n        18000000000000\n        "), 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick_slots[] = {
  {Py_nb_add, (void *)__pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_nb_multiply, (void *)__pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_nb_true_divide, (void *)__pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_tp_hash, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_11__hash__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_richcompare, (void *)__pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Tick},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick_spec = {
  "pandas._libs.tslibs.offsets.Tick",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick_slots,
};
#else

static PyNumberMethods __pyx_tp_as_number_Tick = {
  __pyx_nb_add_6pandas_5_libs_6tslibs_7offsets_Tick, /*nb_add*/
  0, /*nb_subtract*/
  __pyx_nb_multiply_6pandas_5_libs_6tslibs_7offsets_Tick, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_23__neg__, /*nb_negative*/
  #else
  0, /*nb_negative*/
  #endif
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_bool*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3 || (CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03050000)
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  __pyx_nb_true_divide_6pandas_5_libs_6tslibs_7offsets_Tick, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  0, /*nb_index*/
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_matrix_multiply*/
  #endif
  #if PY_VERSION_HEX >= 0x03050000
  0, /*nb_inplace_matrix_multiply*/
  #endif
};

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Tick", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  &__pyx_tp_as_number_Tick, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_11__hash__, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  __pyx_tp_richcompare_6pandas_5_libs_6tslibs_7offsets_Tick, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Tick, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Tick, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Day __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Day;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Day(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Day;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Day_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Day},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Day_spec = {
  "pandas._libs.tslibs.offsets.Day",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Day_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Day = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Day", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Day), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Day, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Hour __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Hour;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Hour(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Hour;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Hour},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour_spec = {
  "pandas._libs.tslibs.offsets.Hour",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Hour", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Hour), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Hour, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Minute __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Minute;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Minute(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Minute;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Minute},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute_spec = {
  "pandas._libs.tslibs.offsets.Minute",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Minute", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Minute), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Minute, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Second __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Second;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Second(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Second;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Second_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Second},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Second_spec = {
  "pandas._libs.tslibs.offsets.Second",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Second_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Second = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Second", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Second), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Second, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Milli __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Milli;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Milli(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Milli;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Milli},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli_spec = {
  "pandas._libs.tslibs.offsets.Milli",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Milli", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Milli), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Milli, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Micro __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Micro;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Micro(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Micro;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Micro},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro_spec = {
  "pandas._libs.tslibs.offsets.Micro",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Micro", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Micro), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Micro, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Nano __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Nano;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Nano(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Tick(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Tick*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Nano;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Nano},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano_spec = {
  "pandas._libs.tslibs.offsets.Nano",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Nano", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Nano), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Tick_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Nano, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset[] = {
  {"__getstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_2__getstate__},
  {"__setstate__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_4__setstate__},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass backed by a dateutil relativedelta object.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset_spec = {
  "pandas._libs.tslibs.offsets.RelativeDeltaOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""RelativeDeltaOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass backed by a dateutil relativedelta object.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  p->_offset = ((PyDateTime_Delta *)Py_None); Py_INCREF(Py_None);
  p->weekmask = Py_None; Py_INCREF(Py_None);
  p->holidays = Py_None; Py_INCREF(Py_None);
  p->calendar = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_offset);
  Py_CLEAR(p->weekmask);
  Py_CLEAR(p->holidays);
  Py_CLEAR(p->calendar);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)o;
  e = __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o, v, a); if (e) return e;
  if (p->_offset) {
    e = (*v)(((PyObject *)p->_offset), a); if (e) return e;
  }
  if (p->weekmask) {
    e = (*v)(p->weekmask, a); if (e) return e;
  }
  if (p->holidays) {
    e = (*v)(p->holidays, a); if (e) return e;
  }
  if (p->calendar) {
    e = (*v)(p->calendar, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *)o;
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o);
  tmp = ((PyObject*)p->_offset);
  p->_offset = ((PyDateTime_Delta *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->weekmask);
  p->weekmask = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->holidays);
  p->holidays = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->calendar);
  p->calendar = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_offset(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_6offset_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__offset(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7_offset_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_weekmask(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8weekmask_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_holidays(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8holidays_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_calendar(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_8calendar_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessMixin[] = {
  {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessMixin[] = {
  {(char *)"offset", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_offset, 0, (char *)PyDoc_STR("\n        Alias for self._offset.\n        "), 0},
  {(char *)"_offset", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__offset, 0, (char *)0, 0},
  {(char *)"weekmask", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_weekmask, 0, (char *)0, 0},
  {(char *)"holidays", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_holidays, 0, (char *)0, 0},
  {(char *)"calendar", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_calendar, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Mixin to business types to provide related functions.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin_spec = {
  "pandas._libs.tslibs.offsets.BusinessMixin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BusinessMixin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Mixin to business types to provide related functions.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessDay __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessDay(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessDay[] = {
  {"_offset_str", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass representing possibly n business days.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of days represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight.\n\n    Examples\n    --------\n    You can use the parameter ``n`` to represent a shift of n business days.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 15)\n    >>> ts.strftime('%a %d %b %Y %H:%M')\n    'Fri 09 Dec 2022 15:00'\n    >>> (ts + pd.offsets.BusinessDay(n=5)).strftime('%a %d %b %Y %H:%M')\n    'Fri 16 Dec 2022 15:00'\n\n    Passing the parameter ``normalize`` equal to True, you shift the start\n    of the next business day to midnight.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 15)\n    >>> ts + pd.offsets.BusinessDay(normalize=True)\n    Timestamp('2022-12-12 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessDay},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessDay},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay_spec = {
  "pandas._libs.tslibs.offsets.BusinessDay",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BusinessDay", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass representing possibly n business days.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of days represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight.\n\n    Examples\n    --------\n    You can use the parameter ``n`` to represent a shift of n business days.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 15)\n    >>> ts.strftime('%a %d %b %Y %H:%M')\n    'Fri 09 Dec 2022 15:00'\n    >>> (ts + pd.offsets.BusinessDay(n=5)).strftime('%a %d %b %Y %H:%M')\n    'Fri 16 Dec 2022 15:00'\n\n    Passing the parameter ``normalize`` equal to True, you shift the start\n    of the next business day to midnight.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 15)\n    >>> ts + pd.offsets.BusinessDay(normalize=True)\n    Timestamp('2022-12-12 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessDay, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessDay, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessHour __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessHour;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessHour(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  p->start = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->end = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessHour(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessHour) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->start);
  Py_CLEAR(p->end);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessHour(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)o;
  e = __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(o, v, a); if (e) return e;
  if (p->start) {
    e = (*v)(p->start, a); if (e) return e;
  }
  if (p->end) {
    e = (*v)(p->end, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessHour(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)o;
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(o);
  tmp = ((PyObject*)p->start);
  p->start = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->end);
  p->end = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_start(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5start_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_end(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3end_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessHour[] = {
  {"_repr_attrs", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_get_business_hours_by_sec", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_6_get_business_hours_by_sec},
  {"_get_closing_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_8_get_closing_time},
  {"next_bday", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_10next_bday},
  {"_next_opening_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_12_next_opening_time},
  {"_prev_opening_time", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_14_prev_opening_time},
  {"rollback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_16rollback},
  {"rollforward", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_18rollforward},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_24_is_on_offset},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessHour[] = {
  {(char *)"start", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_start, 0, (char *)0, 0},
  {(char *)"end", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_end, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass representing possibly n business hours.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of hours represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    start : str, time, or list of str/time, default \"09:00\"\n        Start time of your custom business hour in 24h format.\n    end : str, time, or list of str/time, default: \"17:00\"\n        End time of your custom business hour in 24h format.\n\n    Examples\n    --------\n    You can use the parameter ``n`` to represent a shift of n hours.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 8)\n    >>> ts + pd.offsets.BusinessHour(n=5)\n    Timestamp('2022-12-09 14:00:00')\n\n    You can also change the start and the end of business hours.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.BusinessHour(start=\"11:00\")\n    Timestamp('2022-08-08 11:00:00')\n\n    >>> from datetime import time as dt_time\n    >>> ts = pd.Timestamp(2022, 8, 5, 22)\n    >>> ts + pd.offsets.BusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-08 10:00:00')\n\n    Passing the parameter ``normalize`` equal to True, you shift the start\n    of the next business hour to midnight.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 8)\n    >>> ts + pd.offsets.BusinessHour(normalize=True)\n    Timestamp('2022-12-09 00:00:00')\n\n    You can divide your business day hours into several parts.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.BusinessHour(start=[\"06:00\", \"10:00\", \"15:00\"],\n    ...                                end=[\"08:00\", \"12:00\", \"17:00\"])\n    >>> pd.date_range(dt.datetime(2022, 12, 9), dt.datetime(2022, 12, 13), freq=freq)\n    DatetimeIndex(['2022-12-09 06:00:00', '2022-12-09 07:00:00',\n                   '2022-12-09 10:00:00', '2022-12-09 11:00:00',\n                   '2022-12-09 15:00:00', '2022-12-09 16:00:00',\n                   '2022-12-12 06:00:00', '202""2-12-12 07:00:00',\n                   '2022-12-12 10:00:00', '2022-12-12 11:00:00',\n                   '2022-12-12 15:00:00', '2022-12-12 16:00:00'],\n                   dtype='datetime64[ns]', freq='BH')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour_spec = {
  "pandas._libs.tslibs.offsets.BusinessHour",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BusinessHour", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass representing possibly n business hours.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of hours represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    start : str, time, or list of str/time, default \"09:00\"\n        Start time of your custom business hour in 24h format.\n    end : str, time, or list of str/time, default: \"17:00\"\n        End time of your custom business hour in 24h format.\n\n    Examples\n    --------\n    You can use the parameter ``n`` to represent a shift of n hours.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 8)\n    >>> ts + pd.offsets.BusinessHour(n=5)\n    Timestamp('2022-12-09 14:00:00')\n\n    You can also change the start and the end of business hours.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.BusinessHour(start=\"11:00\")\n    Timestamp('2022-08-08 11:00:00')\n\n    >>> from datetime import time as dt_time\n    >>> ts = pd.Timestamp(2022, 8, 5, 22)\n    >>> ts + pd.offsets.BusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-08 10:00:00')\n\n    Passing the parameter ``normalize`` equal to True, you shift the start\n    of the next business hour to midnight.\n\n    >>> ts = pd.Timestamp(2022, 12, 9, 8)\n    >>> ts + pd.offsets.BusinessHour(normalize=True)\n    Timestamp('2022-12-09 00:00:00')\n\n    You can divide your business day hours into several parts.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.BusinessHour(start=[\"06:00\", \"10:00\", \"15:00\"],\n    ...                                end=[\"08:00\", \"12:00\", \"17:00\"])\n    >>> pd.date_range(dt.datetime(2022, 12, 9), dt.datetime(2022, 12, 13), freq=freq)\n    DatetimeIndex(['2022-12-09 06:00:00', '2022-12-09 07:00:00',\n                   '2022-12-09 10:00:00', '2022-12-09 11:00:00',\n                   '2022-12-09 15:00:00', '2022-12-09 16:00:00',\n                   '2022-12-12 06:00:00', '202""2-12-12 07:00:00',\n                   '2022-12-12 10:00:00', '2022-12-12 11:00:00',\n                   '2022-12-12 15:00:00', '2022-12-12 16:00:00'],\n                   dtype='datetime64[ns]', freq='BH')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_weekday(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_7weekday_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_week(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_4week_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin[] = {
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_rule_code, 0, (char *)0, 0},
  {(char *)"weekday", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_weekday, 0, (char *)0, 0},
  {(char *)"week", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_week, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Mixin for methods common to WeekOfMonth and LastWeekOfMonth.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin_spec = {
  "pandas._libs.tslibs.offsets.WeekOfMonthMixin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""WeekOfMonthMixin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Mixin for methods common to WeekOfMonth and LastWeekOfMonth.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearOffset;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10YearOffset_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10YearOffset_month(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5month_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearOffset[] = {
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearOffset[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10YearOffset_rule_code, 0, (char *)0, 0},
  {(char *)"month", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10YearOffset_month, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset that just needs a month.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearOffset},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearOffset},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset_spec = {
  "pandas._libs.tslibs.offsets.YearOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""YearOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset that just needs a month.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearOffset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearOffset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between the last business day of the year.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BYearEnd\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts - BYearEnd()\n    Timestamp('2019-12-31 05:01:15')\n    >>> ts + BYearEnd()\n    Timestamp('2020-12-31 05:01:15')\n    >>> ts + BYearEnd(3)\n    Timestamp('2022-12-30 05:01:15')\n    >>> ts + BYearEnd(-3)\n    Timestamp('2017-12-29 05:01:15')\n    >>> ts + BYearEnd(month=11)\n    Timestamp('2020-11-30 05:01:15')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd_spec = {
  "pandas._libs.tslibs.offsets.BYearEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BYearEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between the last business day of the year.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BYearEnd\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts - BYearEnd()\n    Timestamp('2019-12-31 05:01:15')\n    >>> ts + BYearEnd()\n    Timestamp('2020-12-31 05:01:15')\n    >>> ts + BYearEnd(3)\n    Timestamp('2022-12-30 05:01:15')\n    >>> ts + BYearEnd(-3)\n    Timestamp('2017-12-29 05:01:15')\n    >>> ts + BYearEnd(month=11)\n    Timestamp('2020-11-30 05:01:15')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BYearBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between the first business day of the year.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BYearBegin\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BYearBegin()\n    Timestamp('2021-01-01 05:01:15')\n    >>> ts - BYearBegin()\n    Timestamp('2020-01-01 05:01:15')\n    >>> ts + BYearBegin(-1)\n    Timestamp('2020-01-01 05:01:15')\n    >>> ts + BYearBegin(2)\n    Timestamp('2022-01-03 05:01:15')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin_spec = {
  "pandas._libs.tslibs.offsets.BYearBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BYearBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BYearBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between the first business day of the year.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BYearBegin\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BYearBegin()\n    Timestamp('2021-01-01 05:01:15')\n    >>> ts - BYearBegin()\n    Timestamp('2020-01-01 05:01:15')\n    >>> ts + BYearBegin(-1)\n    Timestamp('2020-01-01 05:01:15')\n    >>> ts + BYearBegin(2)\n    Timestamp('2022-01-03 05:01:15')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BYearBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearEnd;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_7YearEnd__period_dtype_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_18_period_dtype_code_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearEnd[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearEnd[] = {
  {(char *)"_period_dtype_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_7YearEnd__period_dtype_code, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between calendar year ends.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.YearEnd()\n    Timestamp('2022-12-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearEnd},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearEnd},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd_spec = {
  "pandas._libs.tslibs.offsets.YearEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""YearEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between calendar year ends.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.YearEnd()\n    Timestamp('2022-12-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_YearEnd, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_YearEnd, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_7YearEnd_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_YearOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset of one year at beginning.\n\n    YearBegin goes to the next date which is a start of the year.\n\n    See Also\n    --------\n    :class:`~pandas.tseries.offsets.DateOffset` : Standard kind of date increment.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 12, 1)\n    >>> ts + pd.offsets.YearBegin()\n    Timestamp('2023-01-01 00:00:00')\n\n    >>> ts = pd.Timestamp(2023, 1, 1)\n    >>> ts + pd.offsets.YearBegin()\n    Timestamp('2024-01-01 00:00:00')\n\n    If you want to get the start of the current year:\n\n    >>> ts = pd.Timestamp(2023, 1, 1)\n    >>> pd.offsets.YearBegin().rollback(ts)\n    Timestamp('2023-01-01 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin_spec = {
  "pandas._libs.tslibs.offsets.YearBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""YearBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset of one year at beginning.\n\n    YearBegin goes to the next date which is a start of the year.\n\n    See Also\n    --------\n    :class:`~pandas.tseries.offsets.DateOffset` : Standard kind of date increment.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 12, 1)\n    >>> ts + pd.offsets.YearBegin()\n    Timestamp('2023-01-01 00:00:00')\n\n    >>> ts = pd.Timestamp(2023, 1, 1)\n    >>> ts + pd.offsets.YearBegin()\n    Timestamp('2024-01-01 00:00:00')\n\n    If you want to get the start of the current year:\n\n    >>> ts = pd.Timestamp(2023, 1, 1)\n    >>> pd.offsets.YearBegin().rollback(ts)\n    Timestamp('2023-01-01 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10YearOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_YearBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_startingMonth(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13startingMonth_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterOffset[] = {
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterOffset[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_rule_code, 0, (char *)0, 0},
  {(char *)"startingMonth", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_startingMonth, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterOffset},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterOffset},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset_spec = {
  "pandas._libs.tslibs.offsets.QuarterOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""QuarterOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between the last business day of each Quarter.\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/30/2007, 6/29/2007, ...\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BQuarterEnd\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BQuarterEnd()\n    Timestamp('2020-06-30 05:01:15')\n    >>> ts + BQuarterEnd(2)\n    Timestamp('2020-09-30 05:01:15')\n    >>> ts + BQuarterEnd(1, startingMonth=2)\n    Timestamp('2020-05-29 05:01:15')\n    >>> ts + BQuarterEnd(startingMonth=2)\n    Timestamp('2020-05-29 05:01:15')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd_spec = {
  "pandas._libs.tslibs.offsets.BQuarterEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BQuarterEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between the last business day of each Quarter.\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/30/2007, 6/29/2007, ...\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BQuarterEnd\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BQuarterEnd()\n    Timestamp('2020-06-30 05:01:15')\n    >>> ts + BQuarterEnd(2)\n    Timestamp('2020-09-30 05:01:15')\n    >>> ts + BQuarterEnd(1, startingMonth=2)\n    Timestamp('2020-05-29 05:01:15')\n    >>> ts + BQuarterEnd(startingMonth=2)\n    Timestamp('2020-05-29 05:01:15')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between the first business day of each Quarter.\n\n    startingMonth = 1 corresponds to dates like 1/01/2007, 4/01/2007, ...\n    startingMonth = 2 corresponds to dates like 2/01/2007, 5/01/2007, ...\n    startingMonth = 3 corresponds to dates like 3/01/2007, 6/01/2007, ...\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BQuarterBegin\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BQuarterBegin()\n    Timestamp('2020-06-01 05:01:15')\n    >>> ts + BQuarterBegin(2)\n    Timestamp('2020-09-01 05:01:15')\n    >>> ts + BQuarterBegin(startingMonth=2)\n    Timestamp('2020-08-03 05:01:15')\n    >>> ts + BQuarterBegin(-1)\n    Timestamp('2020-03-02 05:01:15')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin_spec = {
  "pandas._libs.tslibs.offsets.BQuarterBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BQuarterBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between the first business day of each Quarter.\n\n    startingMonth = 1 corresponds to dates like 1/01/2007, 4/01/2007, ...\n    startingMonth = 2 corresponds to dates like 2/01/2007, 5/01/2007, ...\n    startingMonth = 3 corresponds to dates like 3/01/2007, 6/01/2007, ...\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BQuarterBegin\n    >>> ts = pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BQuarterBegin()\n    Timestamp('2020-06-01 05:01:15')\n    >>> ts + BQuarterBegin(2)\n    Timestamp('2020-09-01 05:01:15')\n    >>> ts + BQuarterBegin(startingMonth=2)\n    Timestamp('2020-08-03 05:01:15')\n    >>> ts + BQuarterBegin(-1)\n    Timestamp('2020-03-02 05:01:15')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd__period_dtype_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_18_period_dtype_code_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterEnd[] = {
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterEnd[] = {
  {(char *)"_period_dtype_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd__period_dtype_code, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between Quarter end dates.\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/31/2007, 6/30/2007, ...\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.QuarterEnd()\n    Timestamp('2022-03-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterEnd},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterEnd},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd_spec = {
  "pandas._libs.tslibs.offsets.QuarterEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""QuarterEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between Quarter end dates.\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/31/2007, 6/30/2007, ...\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.QuarterEnd()\n    Timestamp('2022-03-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10QuarterEnd_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_QuarterOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between Quarter start dates.\n\n    startingMonth = 1 corresponds to dates like 1/01/2007, 4/01/2007, ...\n    startingMonth = 2 corresponds to dates like 2/01/2007, 5/01/2007, ...\n    startingMonth = 3 corresponds to dates like 3/01/2007, 6/01/2007, ...\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.QuarterBegin()\n    Timestamp('2022-03-01 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin_spec = {
  "pandas._libs.tslibs.offsets.QuarterBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""QuarterBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between Quarter start dates.\n\n    startingMonth = 1 corresponds to dates like 1/01/2007, 4/01/2007, ...\n    startingMonth = 2 corresponds to dates like 2/01/2007, 5/01/2007, ...\n    startingMonth = 3 corresponds to dates like 3/01/2007, 6/01/2007, ...\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.QuarterBegin()\n    Timestamp('2022-03-01 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthOffset;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_MonthOffset[] = {
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_MonthOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset_spec = {
  "pandas._libs.tslibs.offsets.MonthOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""MonthOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_MonthOffset, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset of one month end.\n\n    MonthEnd goes to the next date which is an end of the month.\n\n    See Also\n    --------\n    :class:`~pandas.tseries.offsets.DateOffset` : Standard kind of date increment.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 30)\n    >>> ts + pd.offsets.MonthEnd()\n    Timestamp('2022-01-31 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> ts + pd.offsets.MonthEnd()\n    Timestamp('2022-02-28 00:00:00')\n\n    If you want to get the end of the current month:\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> pd.offsets.MonthEnd().rollforward(ts)\n    Timestamp('2022-01-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd_spec = {
  "pandas._libs.tslibs.offsets.MonthEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""MonthEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset of one month end.\n\n    MonthEnd goes to the next date which is an end of the month.\n\n    See Also\n    --------\n    :class:`~pandas.tseries.offsets.DateOffset` : Standard kind of date increment.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 30)\n    >>> ts + pd.offsets.MonthEnd()\n    Timestamp('2022-01-31 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> ts + pd.offsets.MonthEnd()\n    Timestamp('2022-02-28 00:00:00')\n\n    If you want to get the end of the current month:\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> pd.offsets.MonthEnd().rollforward(ts)\n    Timestamp('2022-01-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset of one month at beginning.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.MonthBegin()\n    Timestamp('2022-02-01 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin_spec = {
  "pandas._libs.tslibs.offsets.MonthBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""MonthBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset of one month at beginning.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.MonthBegin()\n    Timestamp('2022-02-01 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between the last business day of the month.\n\n    BusinessMonthEnd goes to the next date which is the last business day of the month.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 11, 29)\n    >>> ts + pd.offsets.BMonthEnd()\n    Timestamp('2022-11-30 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 11, 30)\n    >>> ts + pd.offsets.BMonthEnd()\n    Timestamp('2022-12-30 00:00:00')\n\n    If you want to get the end of the current business month:\n\n    >>> ts = pd.Timestamp(2022, 11, 30)\n    >>> pd.offsets.BMonthEnd().rollforward(ts)\n    Timestamp('2022-11-30 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd_spec = {
  "pandas._libs.tslibs.offsets.BusinessMonthEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BusinessMonthEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between the last business day of the month.\n\n    BusinessMonthEnd goes to the next date which is the last business day of the month.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 11, 29)\n    >>> ts + pd.offsets.BMonthEnd()\n    Timestamp('2022-11-30 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 11, 30)\n    >>> ts + pd.offsets.BMonthEnd()\n    Timestamp('2022-12-30 00:00:00')\n\n    If you want to get the end of the current business month:\n\n    >>> ts = pd.Timestamp(2022, 11, 30)\n    >>> pd.offsets.BMonthEnd().rollforward(ts)\n    Timestamp('2022-11-30 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_MonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_MonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset of one month at the first business day.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BMonthBegin\n    >>> ts=pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BMonthBegin()\n    Timestamp('2020-06-01 05:01:15')\n    >>> ts + BMonthBegin(2)\n    Timestamp('2020-07-01 05:01:15')\n    >>> ts + BMonthBegin(-3)\n    Timestamp('2020-03-02 05:01:15')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin_spec = {
  "pandas._libs.tslibs.offsets.BusinessMonthBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""BusinessMonthBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset of one month at the first business day.\n\n    Examples\n    --------\n    >>> from pandas.tseries.offsets import BMonthBegin\n    >>> ts=pd.Timestamp('2020-05-24 05:01:15')\n    >>> ts + BMonthBegin()\n    Timestamp('2020-06-01 05:01:15')\n    >>> ts + BMonthBegin(2)\n    Timestamp('2020-07-01 05:01:15')\n    >>> ts + BMonthBegin(-3)\n    Timestamp('2020-03-02 05:01:15')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_day_of_month(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_12day_of_month_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset[] = {
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_rule_code, 0, (char *)0, 0},
  {(char *)"day_of_month", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_day_of_month, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset_spec = {
  "pandas._libs.tslibs.offsets.SemiMonthOffset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""SemiMonthOffset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd[] = {
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Two DateOffset's per month repeating on the last day of the month & day_of_month.\n\n    Parameters\n    ----------\n    n : int\n    normalize : bool, default False\n    day_of_month : int, {1, 3,...,27}, default 15\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 14)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-01-15 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 15)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-01-31 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-02-15 00:00:00')\n\n    If you want to get the result for the current month:\n\n    >>> ts = pd.Timestamp(2022, 1, 15)\n    >>> pd.offsets.SemiMonthEnd().rollforward(ts)\n    Timestamp('2022-01-15 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd_spec = {
  "pandas._libs.tslibs.offsets.SemiMonthEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""SemiMonthEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Two DateOffset's per month repeating on the last day of the month & day_of_month.\n\n    Parameters\n    ----------\n    n : int\n    normalize : bool, default False\n    day_of_month : int, {1, 3,...,27}, default 15\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 14)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-01-15 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 15)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-01-31 00:00:00')\n\n    >>> ts = pd.Timestamp(2022, 1, 31)\n    >>> ts + pd.offsets.SemiMonthEnd()\n    Timestamp('2022-02-15 00:00:00')\n\n    If you want to get the result for the current month:\n\n    >>> ts = pd.Timestamp(2022, 1, 15)\n    >>> pd.offsets.SemiMonthEnd().rollforward(ts)\n    Timestamp('2022-01-15 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin[] = {
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Two DateOffset's per month repeating on the first day of the month & day_of_month.\n\n    Parameters\n    ----------\n    n : int\n    normalize : bool, default False\n    day_of_month : int, {2, 3,...,27}, default 15\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.SemiMonthBegin()\n    Timestamp('2022-01-15 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin_spec = {
  "pandas._libs.tslibs.offsets.SemiMonthBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""SemiMonthBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Two DateOffset's per month repeating on the first day of the month & day_of_month.\n\n    Parameters\n    ----------\n    n : int\n    normalize : bool, default False\n    day_of_month : int, {2, 3,...,27}, default 15\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.SemiMonthBegin()\n    Timestamp('2022-01-15 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Week __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Week;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Week(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Week;
  p->weekday = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_Week(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_Week) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->weekday);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_Week(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)o;
  e = __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o, v, a); if (e) return e;
  if (p->weekday) {
    e = (*v)(p->weekday, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_Week(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *)o;
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o);
  tmp = ((PyObject*)p->weekday);
  p->weekday = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week_weekday(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7weekday_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week__period_dtype_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_18_period_dtype_code_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Week[] = {
  {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Week[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week_rule_code, 0, (char *)0, 0},
  {(char *)"weekday", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week_weekday, 0, (char *)0, 0},
  {(char *)"_period_dtype_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_4Week__period_dtype_code, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Week_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_Week},
  {Py_tp_doc, (void *)PyDoc_STR("\n    Weekly offset.\n\n    Parameters\n    ----------\n    weekday : int or None, default None\n        Always generate specific day of week.\n        0 for Monday and 6 for Sunday.\n\n    See Also\n    --------\n    pd.tseries.offsets.WeekOfMonth :\n     Describes monthly dates like, the Tuesday of the\n     2nd week of each month.\n\n    Examples\n    --------\n\n    >>> date_object = pd.Timestamp(\"2023-01-13\")\n    >>> date_object\n    Timestamp('2023-01-13 00:00:00')\n\n    >>> date_plus_one_week = date_object + pd.tseries.offsets.Week(n=1)\n    >>> date_plus_one_week\n    Timestamp('2023-01-20 00:00:00')\n\n    >>> date_next_monday = date_object + pd.tseries.offsets.Week(weekday=0)\n    >>> date_next_monday\n    Timestamp('2023-01-16 00:00:00')\n\n    >>> date_next_sunday = date_object + pd.tseries.offsets.Week(weekday=6)\n    >>> date_next_sunday\n    Timestamp('2023-01-15 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_Week},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_Week},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_Week},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Week},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Week},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Week_spec = {
  "pandas._libs.tslibs.offsets.Week",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Week_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Week = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Week", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Weekly offset.\n\n    Parameters\n    ----------\n    weekday : int or None, default None\n        Always generate specific day of week.\n        0 for Monday and 6 for Sunday.\n\n    See Also\n    --------\n    pd.tseries.offsets.WeekOfMonth :\n     Describes monthly dates like, the Tuesday of the\n     2nd week of each month.\n\n    Examples\n    --------\n\n    >>> date_object = pd.Timestamp(\"2023-01-13\")\n    >>> date_object\n    Timestamp('2023-01-13 00:00:00')\n\n    >>> date_plus_one_week = date_object + pd.tseries.offsets.Week(n=1)\n    >>> date_plus_one_week\n    Timestamp('2023-01-20 00:00:00')\n\n    >>> date_next_monday = date_object + pd.tseries.offsets.Week(weekday=0)\n    >>> date_next_monday\n    Timestamp('2023-01-16 00:00:00')\n\n    >>> date_next_sunday = date_object + pd.tseries.offsets.Week(weekday=6)\n    >>> date_next_sunday\n    Timestamp('2023-01-15 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_4Week_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Week, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth[] = {
  {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_4_get_offset_day},
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Describes monthly dates like \"the Tuesday of the 2nd week of each month\".\n\n    Parameters\n    ----------\n    n : int\n    week : int {0, 1, 2, 3, ...}, default 0\n        A specific integer for the week of the month.\n        e.g. 0 is 1st week of month, 1 is the 2nd week, etc.\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.WeekOfMonth()\n    Timestamp('2022-01-03 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth_spec = {
  "pandas._libs.tslibs.offsets.WeekOfMonth",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""WeekOfMonth", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Describes monthly dates like \"the Tuesday of the 2nd week of each month\".\n\n    Parameters\n    ----------\n    n : int\n    week : int {0, 1, 2, 3, ...}, default 0\n        A specific integer for the week of the month.\n        e.g. 0 is 1st week of month, 1 is the 2nd week, etc.\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.WeekOfMonth()\n    Timestamp('2022-01-03 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth[] = {
  {"_get_offset_day", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_4_get_offset_day},
  {"_from_name", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Describes monthly dates in last week of month.\n\n    For example \"the last Tuesday of each month\".\n\n    Parameters\n    ----------\n    n : int, default 1\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.LastWeekOfMonth()\n    Timestamp('2022-01-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth_spec = {
  "pandas._libs.tslibs.offsets.LastWeekOfMonth",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""LastWeekOfMonth", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Describes monthly dates in last week of month.\n\n    For example \"the last Tuesday of each month\".\n\n    Parameters\n    ----------\n    n : int, default 1\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.LastWeekOfMonth()\n    Timestamp('2022-01-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  p->variation = ((PyObject*)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->variation);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_startingMonth(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_13startingMonth_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_weekday(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7weekday_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_variation(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9variation_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin[] = {
  {"is_anchored", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_get_suffix_prefix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_rule_code_suffix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_rule_code, 0, (char *)0, 0},
  {(char *)"startingMonth", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_startingMonth, 0, (char *)0, 0},
  {(char *)"weekday", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_weekday, 0, (char *)0, 0},
  {(char *)"variation", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_variation, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin_spec = {
  "pandas._libs.tslibs.offsets.FY5253Mixin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""FY5253Mixin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253 __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253 *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253[] = {
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_year_end", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_parse_suffix", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_from_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name, METH_VARARGS|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    Describes 52-53 week fiscal year. This is also known as a 4-4-5 calendar.\n\n    It is used by companies that desire that their\n    fiscal year always end on the same day of the week.\n\n    It is a method of managing accounting periods.\n    It is a common calendar structure for some industries,\n    such as retail, manufacturing and parking industry.\n\n    For more information see:\n    https://en.wikipedia.org/wiki/4-4-5_calendar\n\n    The year may either:\n\n    - end on the last X day of the Y month.\n    - end on the last X day closest to the last day of the Y month.\n\n    X is a specific day of the week.\n    Y is a certain month of the year\n\n    Parameters\n    ----------\n    n : int\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    startingMonth : int {1, 2, ... 12}, default 1\n        The month in which the fiscal year ends.\n\n    variation : str, default \"nearest\"\n        Method of employing 4-4-5 calendar.\n\n        There are two options:\n\n        - \"nearest\" means year end is **weekday** closest to last day of month in year.\n        - \"last\" means year end is final **weekday** of the final month in fiscal year.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.FY5253()\n    Timestamp('2022-01-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253_spec = {
  "pandas._libs.tslibs.offsets.FY5253",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253 = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""FY5253", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    Describes 52-53 week fiscal year. This is also known as a 4-4-5 calendar.\n\n    It is used by companies that desire that their\n    fiscal year always end on the same day of the week.\n\n    It is a method of managing accounting periods.\n    It is a common calendar structure for some industries,\n    such as retail, manufacturing and parking industry.\n\n    For more information see:\n    https://en.wikipedia.org/wiki/4-4-5_calendar\n\n    The year may either:\n\n    - end on the last X day of the Y month.\n    - end on the last X day closest to the last day of the Y month.\n\n    X is a specific day of the week.\n    Y is a certain month of the year\n\n    Parameters\n    ----------\n    n : int\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    startingMonth : int {1, 2, ... 12}, default 1\n        The month in which the fiscal year ends.\n\n    variation : str, default \"nearest\"\n        Method of employing 4-4-5 calendar.\n\n        There are two options:\n\n        - \"nearest\" means year end is **weekday** closest to last day of month in year.\n        - \"last\" means year end is final **weekday** of the final month in fiscal year.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.FY5253()\n    Timestamp('2022-01-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
  return o;
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_rule_code(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9rule_code_1__get__(o);
}

static PyObject *__pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_qtr_with_extra_week(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_19qtr_with_extra_week_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter[] = {
  {"_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_rollback_to_year", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_6_rollback_to_year},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_weeks", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"year_has_extra_week", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_from_name", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name, METH_VARARGS|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter[] = {
  {(char *)"rule_code", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_rule_code, 0, (char *)0, 0},
  {(char *)"qtr_with_extra_week", __pyx_getprop_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_qtr_with_extra_week, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset increments between business quarter dates for 52-53 week fiscal year.\n\n    Also known as a 4-4-5 calendar.\n\n    It is used by companies that desire that their\n    fiscal year always end on the same day of the week.\n\n    It is a method of managing accounting periods.\n    It is a common calendar structure for some industries,\n    such as retail, manufacturing and parking industry.\n\n    For more information see:\n    https://en.wikipedia.org/wiki/4-4-5_calendar\n\n    The year may either:\n\n    - end on the last X day of the Y month.\n    - end on the last X day closest to the last day of the Y month.\n\n    X is a specific day of the week.\n    Y is a certain month of the year\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/30/2007, 6/29/2007, ...\n\n    Parameters\n    ----------\n    n : int\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    startingMonth : int {1, 2, ..., 12}, default 1\n        The month in which fiscal years end.\n\n    qtr_with_extra_week : int {1, 2, 3, 4}, default 1\n        The quarter number that has the leap or 14 week when needed.\n\n    variation : str, default \"nearest\"\n        Method of employing 4-4-5 calendar.\n\n        There are two options:\n\n        - \"nearest\" means year end is **weekday** closest to last day of month in year.\n        - \"last\" means year end is final **weekday** of the final month in fiscal year.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.FY5253Quarter()\n    Timestamp('2022-01-31 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter_spec = {
  "pandas._libs.tslibs.offsets.FY5253Quarter",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""FY5253Quarter", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset increments between business quarter dates for 52-53 week fiscal year.\n\n    Also known as a 4-4-5 calendar.\n\n    It is used by companies that desire that their\n    fiscal year always end on the same day of the week.\n\n    It is a method of managing accounting periods.\n    It is a common calendar structure for some industries,\n    such as retail, manufacturing and parking industry.\n\n    For more information see:\n    https://en.wikipedia.org/wiki/4-4-5_calendar\n\n    The year may either:\n\n    - end on the last X day of the Y month.\n    - end on the last X day closest to the last day of the Y month.\n\n    X is a specific day of the week.\n    Y is a certain month of the year\n\n    startingMonth = 1 corresponds to dates like 1/31/2007, 4/30/2007, ...\n    startingMonth = 2 corresponds to dates like 2/28/2007, 5/31/2007, ...\n    startingMonth = 3 corresponds to dates like 3/30/2007, 6/29/2007, ...\n\n    Parameters\n    ----------\n    n : int\n    weekday : int {0, 1, ..., 6}, default 0\n        A specific integer for the day of the week.\n\n        - 0 is Monday\n        - 1 is Tuesday\n        - 2 is Wednesday\n        - 3 is Thursday\n        - 4 is Friday\n        - 5 is Saturday\n        - 6 is Sunday.\n\n    startingMonth : int {1, 2, ..., 12}, default 1\n        The month in which fiscal years end.\n\n    qtr_with_extra_week : int {1, 2, 3, 4}, default 1\n        The quarter number that has the leap or 14 week when needed.\n\n    variation : str, default \"nearest\"\n        Method of employing 4-4-5 calendar.\n\n        There are two options:\n\n        - \"nearest\" means year end is **weekday** closest to last day of month in year.\n        - \"last\" means year end is final **weekday** of the final month in fiscal year.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.FY5253Quarter()\n    Timestamp('2022-01-31 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_Easter __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Easter;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Easter(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BaseOffset(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Easter;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Easter[] = {
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset for the Easter holiday using logic defined in dateutil.\n\n    Right now uses the revised method which is valid in years 1583-4099.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.Easter()\n    Timestamp('2022-04-17 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_Easter},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Easter},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter_spec = {
  "pandas._libs.tslibs.offsets.Easter",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""Easter", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset for the Easter holiday using logic defined in dateutil.\n\n    Right now uses the revised method which is valid in years 1583-4099.\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 1, 1)\n    >>> ts + pd.offsets.Easter()\n    Timestamp('2022-04-17 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BaseOffset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_Easter, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_Easter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessDay(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay[] = {
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_on_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass representing custom business days excluding holidays.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of days represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n    offset : timedelta, default timedelta(0)\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 8, 5)\n    >>> ts + pd.offsets.CustomBusinessDay(1)\n    Timestamp('2022-08-08 00:00:00')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay_spec = {
  "pandas._libs.tslibs.offsets.CustomBusinessDay",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""CustomBusinessDay", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass representing custom business days excluding holidays.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of days represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n    offset : timedelta, default timedelta(0)\n\n    Examples\n    --------\n    >>> ts = pd.Timestamp(2022, 8, 5)\n    >>> ts + pd.offsets.CustomBusinessDay(1)\n    Timestamp('2022-08-08 00:00:00')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessHour(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour[] = {
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass representing possibly n custom business days.\n\n    In CustomBusinessHour we can use custom weekmask, holidays, and calendar.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of hours represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n        Calendar to integrate.\n    start : str, time, or list of str/time, default \"09:00\"\n        Start time of your custom business hour in 24h format.\n    end : str, time, or list of str/time, default: \"17:00\"\n        End time of your custom business hour in 24h format.\n\n    Examples\n    --------\n    In the example below the default parameters give the next business hour.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour()\n    Timestamp('2022-08-08 09:00:00')\n\n    We can also change the start and the end of business hours.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour(start=\"11:00\")\n    Timestamp('2022-08-08 11:00:00')\n\n    >>> from datetime import time as dt_time\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-05 17:00:00')\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 22)\n    >>> ts + pd.offsets.CustomBusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-08 10:00:00')\n\n    You can divide your business day hours into several parts.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.CustomBusinessHour(start=[\"06:00\", \"10:00\", \"15:00\"],\n    ...                                      end=[\"08:00\", \"12:00""\", \"17:00\"])\n    >>> pd.date_range(dt.datetime(2022, 12, 9), dt.datetime(2022, 12, 13), freq=freq)\n    DatetimeIndex(['2022-12-09 06:00:00', '2022-12-09 07:00:00',\n                   '2022-12-09 10:00:00', '2022-12-09 11:00:00',\n                   '2022-12-09 15:00:00', '2022-12-09 16:00:00',\n                   '2022-12-12 06:00:00', '2022-12-12 07:00:00',\n                   '2022-12-12 10:00:00', '2022-12-12 11:00:00',\n                   '2022-12-12 15:00:00', '2022-12-12 16:00:00'],\n                   dtype='datetime64[ns]', freq='CBH')\n\n    Business days can be specified by ``weekmask`` parameter. To convert\n    the returned datetime object to its string representation\n    the function strftime() is used in the next example.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.CustomBusinessHour(weekmask=\"Mon Wed Fri\",\n    ...                                      start=\"10:00\", end=\"13:00\")\n    >>> pd.date_range(dt.datetime(2022, 12, 10), dt.datetime(2022, 12, 18),\n    ...               freq=freq).strftime('%a %d %b %Y %H:%M')\n    Index(['Mon 12 Dec 2022 10:00', 'Mon 12 Dec 2022 11:00',\n           'Mon 12 Dec 2022 12:00', 'Wed 14 Dec 2022 10:00',\n           'Wed 14 Dec 2022 11:00', 'Wed 14 Dec 2022 12:00',\n           'Fri 16 Dec 2022 10:00', 'Fri 16 Dec 2022 11:00',\n           'Fri 16 Dec 2022 12:00'],\n           dtype='object')\n\n    Using NumPy business day calendar you can define custom holidays.\n\n    >>> import datetime as dt\n    >>> bdc = np.busdaycalendar(holidays=['2022-12-12', '2022-12-14'])\n    >>> freq = pd.offsets.CustomBusinessHour(calendar=bdc, start=\"10:00\", end=\"13:00\")\n    >>> pd.date_range(dt.datetime(2022, 12, 10), dt.datetime(2022, 12, 18), freq=freq)\n    DatetimeIndex(['2022-12-13 10:00:00', '2022-12-13 11:00:00',\n                   '2022-12-13 12:00:00', '2022-12-15 10:00:00',\n                   '2022-12-15 11:00:00', '2022-12-15 12:00:00',\n                   '2022-12-16 10:00:00', '2022-12-1""6 11:00:00',\n                   '2022-12-16 12:00:00'],\n                   dtype='datetime64[ns]', freq='CBH')\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessHour},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour_spec = {
  "pandas._libs.tslibs.offsets.CustomBusinessHour",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""CustomBusinessHour", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass representing possibly n custom business days.\n\n    In CustomBusinessHour we can use custom weekmask, holidays, and calendar.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of hours represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n        Calendar to integrate.\n    start : str, time, or list of str/time, default \"09:00\"\n        Start time of your custom business hour in 24h format.\n    end : str, time, or list of str/time, default: \"17:00\"\n        End time of your custom business hour in 24h format.\n\n    Examples\n    --------\n    In the example below the default parameters give the next business hour.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour()\n    Timestamp('2022-08-08 09:00:00')\n\n    We can also change the start and the end of business hours.\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour(start=\"11:00\")\n    Timestamp('2022-08-08 11:00:00')\n\n    >>> from datetime import time as dt_time\n    >>> ts = pd.Timestamp(2022, 8, 5, 16)\n    >>> ts + pd.offsets.CustomBusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-05 17:00:00')\n\n    >>> ts = pd.Timestamp(2022, 8, 5, 22)\n    >>> ts + pd.offsets.CustomBusinessHour(end=dt_time(19, 0))\n    Timestamp('2022-08-08 10:00:00')\n\n    You can divide your business day hours into several parts.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.CustomBusinessHour(start=[\"06:00\", \"10:00\", \"15:00\"],\n    ...                                      end=[\"08:00\", \"12:00""\", \"17:00\"])\n    >>> pd.date_range(dt.datetime(2022, 12, 9), dt.datetime(2022, 12, 13), freq=freq)\n    DatetimeIndex(['2022-12-09 06:00:00', '2022-12-09 07:00:00',\n                   '2022-12-09 10:00:00', '2022-12-09 11:00:00',\n                   '2022-12-09 15:00:00', '2022-12-09 16:00:00',\n                   '2022-12-12 06:00:00', '2022-12-12 07:00:00',\n                   '2022-12-12 10:00:00', '2022-12-12 11:00:00',\n                   '2022-12-12 15:00:00', '2022-12-12 16:00:00'],\n                   dtype='datetime64[ns]', freq='CBH')\n\n    Business days can be specified by ``weekmask`` parameter. To convert\n    the returned datetime object to its string representation\n    the function strftime() is used in the next example.\n\n    >>> import datetime as dt\n    >>> freq = pd.offsets.CustomBusinessHour(weekmask=\"Mon Wed Fri\",\n    ...                                      start=\"10:00\", end=\"13:00\")\n    >>> pd.date_range(dt.datetime(2022, 12, 10), dt.datetime(2022, 12, 18),\n    ...               freq=freq).strftime('%a %d %b %Y %H:%M')\n    Index(['Mon 12 Dec 2022 10:00', 'Mon 12 Dec 2022 11:00',\n           'Mon 12 Dec 2022 12:00', 'Wed 14 Dec 2022 10:00',\n           'Wed 14 Dec 2022 11:00', 'Wed 14 Dec 2022 12:00',\n           'Fri 16 Dec 2022 10:00', 'Fri 16 Dec 2022 11:00',\n           'Fri 16 Dec 2022 12:00'],\n           dtype='object')\n\n    Using NumPy business day calendar you can define custom holidays.\n\n    >>> import datetime as dt\n    >>> bdc = np.busdaycalendar(holidays=['2022-12-12', '2022-12-14'])\n    >>> freq = pd.offsets.CustomBusinessHour(calendar=bdc, start=\"10:00\", end=\"13:00\")\n    >>> pd.date_range(dt.datetime(2022, 12, 10), dt.datetime(2022, 12, 18), freq=freq)\n    DatetimeIndex(['2022-12-13 10:00:00', '2022-12-13 11:00:00',\n                   '2022-12-13 12:00:00', '2022-12-15 10:00:00',\n                   '2022-12-15 11:00:00', '2022-12-15 12:00:00',\n                   '2022-12-16 10:00:00', '2022-12-1""6 11:00:00',\n                   '2022-12-16 12:00:00'],\n                   dtype='datetime64[ns]', freq='CBH')\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessHour, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_18CustomBusinessHour_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth __pyx_vtable_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_BusinessMixin(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  return o;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth[] = {
  {"cbday_roll", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_2cbday_roll},
  {"m_offset", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"month_roll", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_6month_roll},
  {"_apply", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth_slots[] = {
  {Py_tp_doc, (void *)PyDoc_STR("\n    DateOffset subclass representing custom business month(s).\n\n    Increments between beginning/end of month dates.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of months represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n        Calendar to integrate.\n    offset : timedelta, default timedelta(0)\n        Time offset to apply.\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth_spec = {
  "pandas._libs.tslibs.offsets._CustomBusinessMonth",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""_CustomBusinessMonth", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    DateOffset subclass representing custom business month(s).\n\n    Increments between beginning/end of month dates.\n\n    Parameters\n    ----------\n    n : int, default 1\n        The number of months represented.\n    normalize : bool, default False\n        Normalize start/end dates to midnight before generating date range.\n    weekmask : str, Default 'Mon Tue Wed Thu Fri'\n        Weekmask of valid business days, passed to ``numpy.busdaycalendar``.\n    holidays : list\n        List/array of dates to exclude from the set of valid business days,\n        passed to ``numpy.busdaycalendar``.\n    calendar : np.busdaycalendar\n        Calendar to integrate.\n    offset : timedelta, default timedelta(0)\n        Time offset to apply.\n    "), /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd_spec = {
  "pandas._libs.tslibs.offsets.CustomBusinessMonthEnd",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""CustomBusinessMonthEnd", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_7offsets_BusinessMixin*)__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
  return o;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin_slots[] = {
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin_spec = {
  "pandas._libs.tslibs.offsets.CustomBusinessMonthBegin",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""CustomBusinessMonthBegin", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_27__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_pw_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_1__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_func);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)o;
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps *)o;
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct__apply_array_wraps",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct__apply_array_wraps", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_func);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)o;
  if (p->__pyx_v_func) {
    e = (*v)(p->__pyx_v_func, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps *)o;
  tmp = ((PyObject*)p->__pyx_v_func);
  p->__pyx_v_func = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_1_apply_wraps",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_1_apply_wraps", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_kwds_use_relativedelta);
  Py_CLEAR(p->__pyx_v_kwds_use_timedelta);
  Py_CLEAR(p->__pyx_v_nanos);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)o;
  if (p->__pyx_v_kwds_use_relativedelta) {
    e = (*v)(p->__pyx_v_kwds_use_relativedelta, a); if (e) return e;
  }
  if (p->__pyx_v_kwds_use_timedelta) {
    e = (*v)(p->__pyx_v_kwds_use_timedelta, a); if (e) return e;
  }
  if (p->__pyx_v_nanos) {
    e = (*v)(p->__pyx_v_nanos, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset *)o;
  tmp = ((PyObject*)p->__pyx_v_kwds_use_relativedelta);
  p->__pyx_v_kwds_use_relativedelta = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_kwds_use_timedelta);
  p->__pyx_v_kwds_use_timedelta = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_nanos);
  p->__pyx_v_nanos = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_3_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_3_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_4_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_4_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_k);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_5_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_5_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce___slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce___spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_6___reduce__",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce___slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_6___reduce__", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_attr);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_attr) {
    e = (*v)(p->__pyx_v_attr, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_7_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_7_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_en);
  Py_CLEAR(p->__pyx_v_st);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr *)o;
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_en) {
    e = (*v)(p->__pyx_v_en, a); if (e) return e;
  }
  if (p->__pyx_v_st) {
    e = (*v)(p->__pyx_v_st, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_8_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_8_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessHour *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_9__apply",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_9__apply", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr[8];
static int __pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr = 0;

static PyObject *__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  #if CYTHON_COMPILING_IN_CPYTHON
  if (likely((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr > 0) & (int)(t->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr[--__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_en);
  Py_CLEAR(p->__pyx_v_st);
  Py_CLEAR(p->__pyx_t_0);
  #if CYTHON_COMPILING_IN_CPYTHON
  if (((int)(__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr < 8) & (int)(Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr)))) {
    __pyx_freelist_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr[__pyx_freecount_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr++] = ((struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)o);
  } else
  #endif
  {
    #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
    (*Py_TYPE(o)->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
  }
}

static int __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_en) {
    e = (*v)(p->__pyx_v_en, a); if (e) return e;
  }
  if (p->__pyx_v_st) {
    e = (*v)(p->__pyx_v_st, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr_spec = {
  "pandas._libs.tslibs.offsets.__pyx_scope_struct_10_genexpr",
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE,
  __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.tslibs.offsets.""__pyx_scope_struct_10_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_HAVE_FINALIZE, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_02d, __pyx_k_02d, sizeof(__pyx_k_02d), 0, 1, 0, 0},
    {&__pyx_kp_u_09_00, __pyx_k_09_00, sizeof(__pyx_k_09_00), 0, 1, 0, 0},
    {&__pyx_kp_u_17_00, __pyx_k_17_00, sizeof(__pyx_k_17_00), 0, 1, 0, 0},
    {&__pyx_n_u_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 1, 0, 1},
    {&__pyx_n_u_AS, __pyx_k_AS, sizeof(__pyx_k_AS), 0, 1, 0, 1},
    {&__pyx_kp_u_AS_JAN, __pyx_k_AS_JAN, sizeof(__pyx_k_AS_JAN), 0, 1, 0, 0},
    {&__pyx_kp_u_A_DEC, __pyx_k_A_DEC, sizeof(__pyx_k_A_DEC), 0, 1, 0, 0},
    {&__pyx_n_s_ApplyTypeError, __pyx_k_ApplyTypeError, sizeof(__pyx_k_ApplyTypeError), 0, 0, 1, 1},
    {&__pyx_n_s_AssertionError, __pyx_k_AssertionError, sizeof(__pyx_k_AssertionError), 0, 0, 1, 1},
    {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
    {&__pyx_n_u_B, __pyx_k_B, sizeof(__pyx_k_B), 0, 1, 0, 1},
    {&__pyx_n_u_BA, __pyx_k_BA, sizeof(__pyx_k_BA), 0, 1, 0, 1},
    {&__pyx_n_u_BAS, __pyx_k_BAS, sizeof(__pyx_k_BAS), 0, 1, 0, 1},
    {&__pyx_kp_u_BAS_JAN, __pyx_k_BAS_JAN, sizeof(__pyx_k_BAS_JAN), 0, 1, 0, 0},
    {&__pyx_kp_u_BA_DEC, __pyx_k_BA_DEC, sizeof(__pyx_k_BA_DEC), 0, 1, 0, 0},
    {&__pyx_n_s_BDay, __pyx_k_BDay, sizeof(__pyx_k_BDay), 0, 0, 1, 1},
    {&__pyx_n_u_BH, __pyx_k_BH, sizeof(__pyx_k_BH), 0, 1, 0, 1},
    {&__pyx_n_u_BM, __pyx_k_BM, sizeof(__pyx_k_BM), 0, 1, 0, 1},
    {&__pyx_n_u_BMS, __pyx_k_BMS, sizeof(__pyx_k_BMS), 0, 1, 0, 1},
    {&__pyx_n_s_BMonthBegin, __pyx_k_BMonthBegin, sizeof(__pyx_k_BMonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_BMonthEnd, __pyx_k_BMonthEnd, sizeof(__pyx_k_BMonthEnd), 0, 0, 1, 1},
    {&__pyx_n_u_BQ, __pyx_k_BQ, sizeof(__pyx_k_BQ), 0, 1, 0, 1},
    {&__pyx_n_u_BQS, __pyx_k_BQS, sizeof(__pyx_k_BQS), 0, 1, 0, 1},
    {&__pyx_n_s_BQuarterBegin, __pyx_k_BQuarterBegin, sizeof(__pyx_k_BQuarterBegin), 0, 0, 1, 1},
    {&__pyx_n_s_BQuarterEnd, __pyx_k_BQuarterEnd, sizeof(__pyx_k_BQuarterEnd), 0, 0, 1, 1},
    {&__pyx_n_u_BY, __pyx_k_BY, sizeof(__pyx_k_BY), 0, 1, 0, 1},
    {&__pyx_n_u_BYS, __pyx_k_BYS, sizeof(__pyx_k_BYS), 0, 1, 0, 1},
    {&__pyx_n_s_BYearBegin, __pyx_k_BYearBegin, sizeof(__pyx_k_BYearBegin), 0, 0, 1, 1},
    {&__pyx_n_s_BYearEnd, __pyx_k_BYearEnd, sizeof(__pyx_k_BYearEnd), 0, 0, 1, 1},
    {&__pyx_kp_u_Bad_freq_suffix, __pyx_k_Bad_freq_suffix, sizeof(__pyx_k_Bad_freq_suffix), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset, __pyx_k_BaseOffset, sizeof(__pyx_k_BaseOffset), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset___getstate, __pyx_k_BaseOffset___getstate, sizeof(__pyx_k_BaseOffset___getstate), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset___reduce_cython, __pyx_k_BaseOffset___reduce_cython, sizeof(__pyx_k_BaseOffset___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset___setstate, __pyx_k_BaseOffset___setstate, sizeof(__pyx_k_BaseOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset___setstate_cython, __pyx_k_BaseOffset___setstate_cython, sizeof(__pyx_k_BaseOffset___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__apply, __pyx_k_BaseOffset__apply, sizeof(__pyx_k_BaseOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__apply_array, __pyx_k_BaseOffset__apply_array, sizeof(__pyx_k_BaseOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__get_offset_day, __pyx_k_BaseOffset__get_offset_day, sizeof(__pyx_k_BaseOffset__get_offset_day), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__offset_str, __pyx_k_BaseOffset__offset_str, sizeof(__pyx_k_BaseOffset__offset_str), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__params, __pyx_k_BaseOffset__params, sizeof(__pyx_k_BaseOffset__params), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__repr_attrs, __pyx_k_BaseOffset__repr_attrs, sizeof(__pyx_k_BaseOffset__repr_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset__validate_n, __pyx_k_BaseOffset__validate_n, sizeof(__pyx_k_BaseOffset__validate_n), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset_copy, __pyx_k_BaseOffset_copy, sizeof(__pyx_k_BaseOffset_copy), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_copy_line_532, __pyx_k_BaseOffset_copy_line_532, sizeof(__pyx_k_BaseOffset_copy_line_532), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_freqstr, __pyx_k_BaseOffset_freqstr, sizeof(__pyx_k_BaseOffset_freqstr), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_freqstr_line_607, __pyx_k_BaseOffset_freqstr_line_607, sizeof(__pyx_k_BaseOffset_freqstr_line_607), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_anchored, __pyx_k_BaseOffset_is_anchored, sizeof(__pyx_k_BaseOffset_is_anchored), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_anchored_line_790, __pyx_k_BaseOffset_is_anchored_line_790, sizeof(__pyx_k_BaseOffset_is_anchored_line_790), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_month_end, __pyx_k_BaseOffset_is_month_end, sizeof(__pyx_k_BaseOffset_is_month_end), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_month_end_line_820, __pyx_k_BaseOffset_is_month_end_line_820, sizeof(__pyx_k_BaseOffset_is_month_end_line_820), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_month_start, __pyx_k_BaseOffset_is_month_start, sizeof(__pyx_k_BaseOffset_is_month_start), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_month_start_line_8, __pyx_k_BaseOffset_is_month_start_line_8, sizeof(__pyx_k_BaseOffset_is_month_start_line_8), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_on_offset, __pyx_k_BaseOffset_is_on_offset, sizeof(__pyx_k_BaseOffset_is_on_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_on_offset_line_696, __pyx_k_BaseOffset_is_on_offset_line_696, sizeof(__pyx_k_BaseOffset_is_on_offset_line_696), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_quarter_end, __pyx_k_BaseOffset_is_quarter_end, sizeof(__pyx_k_BaseOffset_is_quarter_end), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_quarter_end_line_8, __pyx_k_BaseOffset_is_quarter_end_line_8, sizeof(__pyx_k_BaseOffset_is_quarter_end_line_8), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_quarter_start, __pyx_k_BaseOffset_is_quarter_start, sizeof(__pyx_k_BaseOffset_is_quarter_start), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_quarter_start_line, __pyx_k_BaseOffset_is_quarter_start_line, sizeof(__pyx_k_BaseOffset_is_quarter_start_line), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_year_end, __pyx_k_BaseOffset_is_year_end, sizeof(__pyx_k_BaseOffset_is_year_end), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_year_end_line_872, __pyx_k_BaseOffset_is_year_end_line_872, sizeof(__pyx_k_BaseOffset_is_year_end_line_872), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_is_year_start, __pyx_k_BaseOffset_is_year_start, sizeof(__pyx_k_BaseOffset_is_year_start), 0, 0, 1, 1},
    {&__pyx_kp_u_BaseOffset_is_year_start_line_85, __pyx_k_BaseOffset_is_year_start_line_85, sizeof(__pyx_k_BaseOffset_is_year_start_line_85), 0, 1, 0, 0},
    {&__pyx_kp_u_BaseOffset_kwds___get___line_449, __pyx_k_BaseOffset_kwds___get___line_449, sizeof(__pyx_k_BaseOffset_kwds___get___line_449), 0, 1, 0, 0},
    {&__pyx_kp_u_BaseOffset_name___get___line_584, __pyx_k_BaseOffset_name___get___line_584, sizeof(__pyx_k_BaseOffset_name___get___line_584), 0, 1, 0, 0},
    {&__pyx_n_s_BaseOffset_rollback, __pyx_k_BaseOffset_rollback, sizeof(__pyx_k_BaseOffset_rollback), 0, 0, 1, 1},
    {&__pyx_n_s_BaseOffset_rollforward, __pyx_k_BaseOffset_rollforward, sizeof(__pyx_k_BaseOffset_rollforward), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay, __pyx_k_BusinessDay, sizeof(__pyx_k_BusinessDay), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay___setstate, __pyx_k_BusinessDay___setstate, sizeof(__pyx_k_BusinessDay___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay__apply, __pyx_k_BusinessDay__apply, sizeof(__pyx_k_BusinessDay__apply), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay__apply_array, __pyx_k_BusinessDay__apply_array, sizeof(__pyx_k_BusinessDay__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay__offset_str, __pyx_k_BusinessDay__offset_str, sizeof(__pyx_k_BusinessDay__offset_str), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessDay_is_on_offset, __pyx_k_BusinessDay_is_on_offset, sizeof(__pyx_k_BusinessDay_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour, __pyx_k_BusinessHour, sizeof(__pyx_k_BusinessHour), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour___setstate, __pyx_k_BusinessHour___setstate, sizeof(__pyx_k_BusinessHour___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__apply, __pyx_k_BusinessHour__apply, sizeof(__pyx_k_BusinessHour__apply), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__get_business_hours, __pyx_k_BusinessHour__get_business_hours, sizeof(__pyx_k_BusinessHour__get_business_hours), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__get_closing_time, __pyx_k_BusinessHour__get_closing_time, sizeof(__pyx_k_BusinessHour__get_closing_time), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__is_on_offset, __pyx_k_BusinessHour__is_on_offset, sizeof(__pyx_k_BusinessHour__is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__next_opening_time, __pyx_k_BusinessHour__next_opening_time, sizeof(__pyx_k_BusinessHour__next_opening_time), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__prev_opening_time, __pyx_k_BusinessHour__prev_opening_time, sizeof(__pyx_k_BusinessHour__prev_opening_time), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour__repr_attrs, __pyx_k_BusinessHour__repr_attrs, sizeof(__pyx_k_BusinessHour__repr_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour_is_on_offset, __pyx_k_BusinessHour_is_on_offset, sizeof(__pyx_k_BusinessHour_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour_next_bday, __pyx_k_BusinessHour_next_bday, sizeof(__pyx_k_BusinessHour_next_bday), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour_rollback, __pyx_k_BusinessHour_rollback, sizeof(__pyx_k_BusinessHour_rollback), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessHour_rollforward, __pyx_k_BusinessHour_rollforward, sizeof(__pyx_k_BusinessHour_rollforward), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMixin, __pyx_k_BusinessMixin, sizeof(__pyx_k_BusinessMixin), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMixin___setstate, __pyx_k_BusinessMixin___setstate, sizeof(__pyx_k_BusinessMixin___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMixin__init_custom, __pyx_k_BusinessMixin__init_custom, sizeof(__pyx_k_BusinessMixin__init_custom), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMixin__repr_attrs, __pyx_k_BusinessMixin__repr_attrs, sizeof(__pyx_k_BusinessMixin__repr_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMonthBegin, __pyx_k_BusinessMonthBegin, sizeof(__pyx_k_BusinessMonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_BusinessMonthEnd, __pyx_k_BusinessMonthEnd, sizeof(__pyx_k_BusinessMonthEnd), 0, 0, 1, 1},
    {&__pyx_n_u_BusinessQuarterBegin, __pyx_k_BusinessQuarterBegin, sizeof(__pyx_k_BusinessQuarterBegin), 0, 1, 0, 1},
    {&__pyx_n_u_BusinessQuarterEnd, __pyx_k_BusinessQuarterEnd, sizeof(__pyx_k_BusinessQuarterEnd), 0, 1, 0, 1},
    {&__pyx_n_u_BusinessYearBegin, __pyx_k_BusinessYearBegin, sizeof(__pyx_k_BusinessYearBegin), 0, 1, 0, 1},
    {&__pyx_n_u_BusinessYearEnd, __pyx_k_BusinessYearEnd, sizeof(__pyx_k_BusinessYearEnd), 0, 1, 0, 1},
    {&__pyx_n_u_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 1, 0, 1},
    {&__pyx_n_u_CBH, __pyx_k_CBH, sizeof(__pyx_k_CBH), 0, 1, 0, 1},
    {&__pyx_n_u_CBM, __pyx_k_CBM, sizeof(__pyx_k_CBM), 0, 1, 0, 1},
    {&__pyx_n_u_CBMS, __pyx_k_CBMS, sizeof(__pyx_k_CBMS), 0, 1, 0, 1},
    {&__pyx_n_s_CBMonthBegin, __pyx_k_CBMonthBegin, sizeof(__pyx_k_CBMonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_CBMonthEnd, __pyx_k_CBMonthEnd, sizeof(__pyx_k_CBMonthEnd), 0, 0, 1, 1},
    {&__pyx_n_s_CDay, __pyx_k_CDay, sizeof(__pyx_k_CDay), 0, 0, 1, 1},
    {&__pyx_kp_u_Cannot_add, __pyx_k_Cannot_add, sizeof(__pyx_k_Cannot_add), 0, 1, 0, 0},
    {&__pyx_kp_u_Cannot_subtract_datetime_from_of, __pyx_k_Cannot_subtract_datetime_from_of, sizeof(__pyx_k_Cannot_subtract_datetime_from_of), 0, 1, 0, 0},
    {&__pyx_kp_u_Could_not_convert_to_integer_off, __pyx_k_Could_not_convert_to_integer_off, sizeof(__pyx_k_Could_not_convert_to_integer_off), 0, 1, 0, 0},
    {&__pyx_n_s_CustomBusinessDay, __pyx_k_CustomBusinessDay, sizeof(__pyx_k_CustomBusinessDay), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessDay___setstate, __pyx_k_CustomBusinessDay___setstate, sizeof(__pyx_k_CustomBusinessDay___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessDay__apply, __pyx_k_CustomBusinessDay__apply, sizeof(__pyx_k_CustomBusinessDay__apply), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessDay_is_on_offset, __pyx_k_CustomBusinessDay_is_on_offset, sizeof(__pyx_k_CustomBusinessDay_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessHour, __pyx_k_CustomBusinessHour, sizeof(__pyx_k_CustomBusinessHour), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonth, __pyx_k_CustomBusinessMonth, sizeof(__pyx_k_CustomBusinessMonth), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonthBegin, __pyx_k_CustomBusinessMonthBegin, sizeof(__pyx_k_CustomBusinessMonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonthEnd, __pyx_k_CustomBusinessMonthEnd, sizeof(__pyx_k_CustomBusinessMonthEnd), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonth__apply, __pyx_k_CustomBusinessMonth__apply, sizeof(__pyx_k_CustomBusinessMonth__apply), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonth_cbday_roll, __pyx_k_CustomBusinessMonth_cbday_roll, sizeof(__pyx_k_CustomBusinessMonth_cbday_roll), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonth_m_offset, __pyx_k_CustomBusinessMonth_m_offset, sizeof(__pyx_k_CustomBusinessMonth_m_offset), 0, 0, 1, 1},
    {&__pyx_n_s_CustomBusinessMonth_month_roll, __pyx_k_CustomBusinessMonth_month_roll, sizeof(__pyx_k_CustomBusinessMonth_month_roll), 0, 0, 1, 1},
    {&__pyx_n_u_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 1, 0, 1},
    {&__pyx_n_s_DateOffset, __pyx_k_DateOffset, sizeof(__pyx_k_DateOffset), 0, 0, 1, 1},
    {&__pyx_n_s_DateOffset___setattr, __pyx_k_DateOffset___setattr, sizeof(__pyx_k_DateOffset___setattr), 0, 0, 1, 1},
    {&__pyx_kp_u_DateOffset_objects_are_immutable, __pyx_k_DateOffset_objects_are_immutable, sizeof(__pyx_k_DateOffset_objects_are_immutable), 0, 1, 0, 0},
    {&__pyx_kp_u_DateOffset_subclass, __pyx_k_DateOffset_subclass, sizeof(__pyx_k_DateOffset_subclass), 0, 1, 0, 0},
    {&__pyx_kp_u_DateOffset_with_relativedelta_ke, __pyx_k_DateOffset_with_relativedelta_ke, sizeof(__pyx_k_DateOffset_with_relativedelta_ke), 0, 1, 0, 0},
    {&__pyx_n_s_Day, __pyx_k_Day, sizeof(__pyx_k_Day), 0, 0, 1, 1},
    {&__pyx_kp_u_Day_must_be_0_day_6_got, __pyx_k_Day_must_be_0_day_6_got, sizeof(__pyx_k_Day_must_be_0_day_6_got), 0, 1, 0, 0},
    {&__pyx_n_s_Easter, __pyx_k_Easter, sizeof(__pyx_k_Easter), 0, 0, 1, 1},
    {&__pyx_n_s_Easter___setstate, __pyx_k_Easter___setstate, sizeof(__pyx_k_Easter___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_Easter__apply, __pyx_k_Easter__apply, sizeof(__pyx_k_Easter__apply), 0, 0, 1, 1},
    {&__pyx_n_s_Easter_is_on_offset, __pyx_k_Easter_is_on_offset, sizeof(__pyx_k_Easter_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253, __pyx_k_FY5253, sizeof(__pyx_k_FY5253), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Mixin, __pyx_k_FY5253Mixin, sizeof(__pyx_k_FY5253Mixin), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Mixin___setstate, __pyx_k_FY5253Mixin___setstate, sizeof(__pyx_k_FY5253Mixin___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Mixin__get_suffix_prefix, __pyx_k_FY5253Mixin__get_suffix_prefix, sizeof(__pyx_k_FY5253Mixin__get_suffix_prefix), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Mixin_get_rule_code_suffix, __pyx_k_FY5253Mixin_get_rule_code_suffix, sizeof(__pyx_k_FY5253Mixin_get_rule_code_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Mixin_is_anchored, __pyx_k_FY5253Mixin_is_anchored, sizeof(__pyx_k_FY5253Mixin_is_anchored), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter, __pyx_k_FY5253Quarter, sizeof(__pyx_k_FY5253Quarter), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter___setstate, __pyx_k_FY5253Quarter___setstate, sizeof(__pyx_k_FY5253Quarter___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter__apply, __pyx_k_FY5253Quarter__apply, sizeof(__pyx_k_FY5253Quarter__apply), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter__from_name, __pyx_k_FY5253Quarter__from_name, sizeof(__pyx_k_FY5253Quarter__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter__offset, __pyx_k_FY5253Quarter__offset, sizeof(__pyx_k_FY5253Quarter__offset), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter__rollback_to_year, __pyx_k_FY5253Quarter__rollback_to_year, sizeof(__pyx_k_FY5253Quarter__rollback_to_year), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter_get_weeks, __pyx_k_FY5253Quarter_get_weeks, sizeof(__pyx_k_FY5253Quarter_get_weeks), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter_is_on_offset, __pyx_k_FY5253Quarter_is_on_offset, sizeof(__pyx_k_FY5253Quarter_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253Quarter_year_has_extra_wee, __pyx_k_FY5253Quarter_year_has_extra_wee, sizeof(__pyx_k_FY5253Quarter_year_has_extra_wee), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253__apply, __pyx_k_FY5253__apply, sizeof(__pyx_k_FY5253__apply), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253__from_name, __pyx_k_FY5253__from_name, sizeof(__pyx_k_FY5253__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253__parse_suffix, __pyx_k_FY5253__parse_suffix, sizeof(__pyx_k_FY5253__parse_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253_get_year_end, __pyx_k_FY5253_get_year_end, sizeof(__pyx_k_FY5253_get_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_FY5253_is_on_offset, __pyx_k_FY5253_is_on_offset, sizeof(__pyx_k_FY5253_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_u_H, __pyx_k_H, sizeof(__pyx_k_H), 0, 1, 0, 1},
    {&__pyx_kp_u_H_M, __pyx_k_H_M, sizeof(__pyx_k_H_M), 0, 1, 0, 0},
    {&__pyx_n_s_Hour, __pyx_k_Hour, sizeof(__pyx_k_Hour), 0, 0, 1, 1},
    {&__pyx_n_s_INVALID_FREQ_ERR_MSG, __pyx_k_INVALID_FREQ_ERR_MSG, sizeof(__pyx_k_INVALID_FREQ_ERR_MSG), 0, 0, 1, 1},
    {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_kp_u_Invalid_argument_s_or_bad_combin, __pyx_k_Invalid_argument_s_or_bad_combin, sizeof(__pyx_k_Invalid_argument_s_or_bad_combin), 0, 1, 0, 0},
    {&__pyx_kp_u_Invalid_frequency_0, __pyx_k_Invalid_frequency_0, sizeof(__pyx_k_Invalid_frequency_0), 0, 1, 0, 0},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_u_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 1, 0, 1},
    {&__pyx_n_u_LWOM, __pyx_k_LWOM, sizeof(__pyx_k_LWOM), 0, 1, 0, 1},
    {&__pyx_n_s_LastWeekOfMonth, __pyx_k_LastWeekOfMonth, sizeof(__pyx_k_LastWeekOfMonth), 0, 0, 1, 1},
    {&__pyx_n_s_LastWeekOfMonth___setstate, __pyx_k_LastWeekOfMonth___setstate, sizeof(__pyx_k_LastWeekOfMonth___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_LastWeekOfMonth__from_name, __pyx_k_LastWeekOfMonth__from_name, sizeof(__pyx_k_LastWeekOfMonth__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_LastWeekOfMonth__get_offset_day, __pyx_k_LastWeekOfMonth__get_offset_day, sizeof(__pyx_k_LastWeekOfMonth__get_offset_day), 0, 0, 1, 1},
    {&__pyx_n_u_M, __pyx_k_M, sizeof(__pyx_k_M), 0, 1, 0, 1},
    {&__pyx_n_s_MONTH_ALIASES, __pyx_k_MONTH_ALIASES, sizeof(__pyx_k_MONTH_ALIASES), 0, 0, 1, 1},
    {&__pyx_n_s_MONTH_TO_CAL_NUM, __pyx_k_MONTH_TO_CAL_NUM, sizeof(__pyx_k_MONTH_TO_CAL_NUM), 0, 0, 1, 1},
    {&__pyx_n_u_MS, __pyx_k_MS, sizeof(__pyx_k_MS), 0, 1, 0, 1},
    {&__pyx_kp_s_Metaclass_that_allows_us_to_pre, __pyx_k_Metaclass_that_allows_us_to_pre, sizeof(__pyx_k_Metaclass_that_allows_us_to_pre), 0, 0, 1, 0},
    {&__pyx_n_s_Micro, __pyx_k_Micro, sizeof(__pyx_k_Micro), 0, 0, 1, 1},
    {&__pyx_n_s_Milli, __pyx_k_Milli, sizeof(__pyx_k_Milli), 0, 0, 1, 1},
    {&__pyx_n_u_Min, __pyx_k_Min, sizeof(__pyx_k_Min), 0, 1, 0, 1},
    {&__pyx_n_s_Minute, __pyx_k_Minute, sizeof(__pyx_k_Minute), 0, 0, 1, 1},
    {&__pyx_kp_u_Mon_Tue_Wed_Thu_Fri, __pyx_k_Mon_Tue_Wed_Thu_Fri, sizeof(__pyx_k_Mon_Tue_Wed_Thu_Fri), 0, 1, 0, 0},
    {&__pyx_n_s_MonthBegin, __pyx_k_MonthBegin, sizeof(__pyx_k_MonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_MonthEnd, __pyx_k_MonthEnd, sizeof(__pyx_k_MonthEnd), 0, 0, 1, 1},
    {&__pyx_n_s_MonthOffset, __pyx_k_MonthOffset, sizeof(__pyx_k_MonthOffset), 0, 0, 1, 1},
    {&__pyx_n_s_MonthOffset___setstate, __pyx_k_MonthOffset___setstate, sizeof(__pyx_k_MonthOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_MonthOffset__apply, __pyx_k_MonthOffset__apply, sizeof(__pyx_k_MonthOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_MonthOffset__apply_array, __pyx_k_MonthOffset__apply_array, sizeof(__pyx_k_MonthOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_MonthOffset_is_on_offset, __pyx_k_MonthOffset_is_on_offset, sizeof(__pyx_k_MonthOffset_is_on_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_Month_must_go_from_1_to_12, __pyx_k_Month_must_go_from_1_to_12, sizeof(__pyx_k_Month_must_go_from_1_to_12), 0, 1, 0, 0},
    {&__pyx_kp_u_Must_include_at_least_1_end_time, __pyx_k_Must_include_at_least_1_end_time, sizeof(__pyx_k_Must_include_at_least_1_end_time), 0, 1, 0, 0},
    {&__pyx_kp_u_Must_include_at_least_1_start_ti, __pyx_k_Must_include_at_least_1_start_ti, sizeof(__pyx_k_Must_include_at_least_1_start_ti), 0, 1, 0, 0},
    {&__pyx_n_u_N, __pyx_k_N, sizeof(__pyx_k_N), 0, 1, 0, 1},
    {&__pyx_kp_u_N_cannot_be_0, __pyx_k_N_cannot_be_0, sizeof(__pyx_k_N_cannot_be_0), 0, 1, 0, 0},
    {&__pyx_n_s_Nano, __pyx_k_Nano, sizeof(__pyx_k_Nano), 0, 0, 1, 1},
    {&__pyx_kp_u_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 1, 0, 0},
    {&__pyx_n_s_NotImplemented, __pyx_k_NotImplemented, sizeof(__pyx_k_NotImplemented), 0, 0, 1, 1},
    {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
    {&__pyx_n_s_OffsetMeta, __pyx_k_OffsetMeta, sizeof(__pyx_k_OffsetMeta), 0, 0, 1, 1},
    {&__pyx_n_s_OffsetMeta___instancecheck, __pyx_k_OffsetMeta___instancecheck, sizeof(__pyx_k_OffsetMeta___instancecheck), 0, 0, 1, 1},
    {&__pyx_n_s_OffsetMeta___subclasscheck, __pyx_k_OffsetMeta___subclasscheck, sizeof(__pyx_k_OffsetMeta___subclasscheck), 0, 0, 1, 1},
    {&__pyx_kp_u_Only_know_how_to_combine_busines, __pyx_k_Only_know_how_to_combine_busines, sizeof(__pyx_k_Only_know_how_to_combine_busines), 0, 1, 0, 0},
    {&__pyx_kp_u_Only_know_how_to_combine_trading, __pyx_k_Only_know_how_to_combine_trading, sizeof(__pyx_k_Only_know_how_to_combine_trading), 0, 1, 0, 0},
    {&__pyx_n_s_OverflowError, __pyx_k_OverflowError, sizeof(__pyx_k_OverflowError), 0, 0, 1, 1},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_kp_u_Prefix, __pyx_k_Prefix, sizeof(__pyx_k_Prefix), 0, 1, 0, 0},
    {&__pyx_kp_u_Prefix_not_defined, __pyx_k_Prefix_not_defined, sizeof(__pyx_k_Prefix_not_defined), 0, 1, 0, 0},
    {&__pyx_n_u_Q, __pyx_k_Q, sizeof(__pyx_k_Q), 0, 1, 0, 1},
    {&__pyx_n_u_QS, __pyx_k_QS, sizeof(__pyx_k_QS), 0, 1, 0, 1},
    {&__pyx_kp_u_Q_DEC, __pyx_k_Q_DEC, sizeof(__pyx_k_Q_DEC), 0, 1, 0, 0},
    {&__pyx_n_s_QuarterBegin, __pyx_k_QuarterBegin, sizeof(__pyx_k_QuarterBegin), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterEnd, __pyx_k_QuarterEnd, sizeof(__pyx_k_QuarterEnd), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset, __pyx_k_QuarterOffset, sizeof(__pyx_k_QuarterOffset), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset___setstate, __pyx_k_QuarterOffset___setstate, sizeof(__pyx_k_QuarterOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset__apply, __pyx_k_QuarterOffset__apply, sizeof(__pyx_k_QuarterOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset__apply_array, __pyx_k_QuarterOffset__apply_array, sizeof(__pyx_k_QuarterOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset__from_name, __pyx_k_QuarterOffset__from_name, sizeof(__pyx_k_QuarterOffset__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset_is_anchored, __pyx_k_QuarterOffset_is_anchored, sizeof(__pyx_k_QuarterOffset_is_anchored), 0, 0, 1, 1},
    {&__pyx_n_s_QuarterOffset_is_on_offset, __pyx_k_QuarterOffset_is_on_offset, sizeof(__pyx_k_QuarterOffset_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_u_RE, __pyx_k_RE, sizeof(__pyx_k_RE), 0, 1, 0, 1},
    {&__pyx_n_u_REQ, __pyx_k_REQ, sizeof(__pyx_k_REQ), 0, 1, 0, 1},
    {&__pyx_n_s_RelativeDeltaOffset, __pyx_k_RelativeDeltaOffset, sizeof(__pyx_k_RelativeDeltaOffset), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset___getstate, __pyx_k_RelativeDeltaOffset___getstate, sizeof(__pyx_k_RelativeDeltaOffset___getstate), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset___reduce_cyt, __pyx_k_RelativeDeltaOffset___reduce_cyt, sizeof(__pyx_k_RelativeDeltaOffset___reduce_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset___setstate, __pyx_k_RelativeDeltaOffset___setstate, sizeof(__pyx_k_RelativeDeltaOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset___setstate_c, __pyx_k_RelativeDeltaOffset___setstate_c, sizeof(__pyx_k_RelativeDeltaOffset___setstate_c), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset__apply, __pyx_k_RelativeDeltaOffset__apply, sizeof(__pyx_k_RelativeDeltaOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset__apply_array, __pyx_k_RelativeDeltaOffset__apply_array, sizeof(__pyx_k_RelativeDeltaOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_RelativeDeltaOffset_is_on_offset, __pyx_k_RelativeDeltaOffset_is_on_offset, sizeof(__pyx_k_RelativeDeltaOffset_is_on_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_Return_DateOffset_object_from_s, __pyx_k_Return_DateOffset_object_from_s, sizeof(__pyx_k_Return_DateOffset_object_from_s), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_a_copy_of_the_frequency, __pyx_k_Return_a_copy_of_the_frequency, sizeof(__pyx_k_Return_a_copy_of_the_frequency), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_a_dict_of_extra_paramete, __pyx_k_Return_a_dict_of_extra_paramete, sizeof(__pyx_k_Return_a_dict_of_extra_paramete), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_a_string_representing_th, __pyx_k_Return_a_string_representing_th, sizeof(__pyx_k_Return_a_string_representing_th), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_a_string_representing_th_2, __pyx_k_Return_a_string_representing_th_2, sizeof(__pyx_k_Return_a_string_representing_th_2), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_an_integer_of_the_total, __pyx_k_Return_an_integer_of_the_total, sizeof(__pyx_k_Return_an_integer_of_the_total), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest, __pyx_k_Return_boolean_whether_a_timest, sizeof(__pyx_k_Return_boolean_whether_a_timest), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_2, __pyx_k_Return_boolean_whether_a_timest_2, sizeof(__pyx_k_Return_boolean_whether_a_timest_2), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_3, __pyx_k_Return_boolean_whether_a_timest_3, sizeof(__pyx_k_Return_boolean_whether_a_timest_3), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_4, __pyx_k_Return_boolean_whether_a_timest_4, sizeof(__pyx_k_Return_boolean_whether_a_timest_4), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_5, __pyx_k_Return_boolean_whether_a_timest_5, sizeof(__pyx_k_Return_boolean_whether_a_timest_5), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_6, __pyx_k_Return_boolean_whether_a_timest_6, sizeof(__pyx_k_Return_boolean_whether_a_timest_6), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_a_timest_7, __pyx_k_Return_boolean_whether_a_timest_7, sizeof(__pyx_k_Return_boolean_whether_a_timest_7), 0, 1, 0, 0},
    {&__pyx_kp_u_Return_boolean_whether_the_freq, __pyx_k_Return_boolean_whether_the_freq, sizeof(__pyx_k_Return_boolean_whether_the_freq), 0, 1, 0, 0},
    {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
    {&__pyx_n_u_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 1, 0, 1},
    {&__pyx_n_u_SM, __pyx_k_SM, sizeof(__pyx_k_SM), 0, 1, 0, 1},
    {&__pyx_n_u_SMS, __pyx_k_SMS, sizeof(__pyx_k_SMS), 0, 1, 0, 1},
    {&__pyx_n_s_Second, __pyx_k_Second, sizeof(__pyx_k_Second), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthBegin, __pyx_k_SemiMonthBegin, sizeof(__pyx_k_SemiMonthBegin), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthBegin_is_on_offset, __pyx_k_SemiMonthBegin_is_on_offset, sizeof(__pyx_k_SemiMonthBegin_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthEnd, __pyx_k_SemiMonthEnd, sizeof(__pyx_k_SemiMonthEnd), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthEnd_is_on_offset, __pyx_k_SemiMonthEnd_is_on_offset, sizeof(__pyx_k_SemiMonthEnd_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthOffset, __pyx_k_SemiMonthOffset, sizeof(__pyx_k_SemiMonthOffset), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthOffset___setstate, __pyx_k_SemiMonthOffset___setstate, sizeof(__pyx_k_SemiMonthOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthOffset__apply, __pyx_k_SemiMonthOffset__apply, sizeof(__pyx_k_SemiMonthOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthOffset__apply_array, __pyx_k_SemiMonthOffset__apply_array, sizeof(__pyx_k_SemiMonthOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_SemiMonthOffset__from_name, __pyx_k_SemiMonthOffset__from_name, sizeof(__pyx_k_SemiMonthOffset__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_SingleConstructorOffset, __pyx_k_SingleConstructorOffset, sizeof(__pyx_k_SingleConstructorOffset), 0, 0, 1, 1},
    {&__pyx_n_s_SingleConstructorOffset___reduce, __pyx_k_SingleConstructorOffset___reduce, sizeof(__pyx_k_SingleConstructorOffset___reduce), 0, 0, 1, 1},
    {&__pyx_n_s_SingleConstructorOffset__from_na, __pyx_k_SingleConstructorOffset__from_na, sizeof(__pyx_k_SingleConstructorOffset__from_na), 0, 0, 1, 1},
    {&__pyx_kp_s_Standard_kind_of_date_increment, __pyx_k_Standard_kind_of_date_increment, sizeof(__pyx_k_Standard_kind_of_date_increment), 0, 0, 1, 0},
    {&__pyx_n_u_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 1, 0, 1},
    {&__pyx_n_s_Tick, __pyx_k_Tick, sizeof(__pyx_k_Tick), 0, 0, 1, 1},
    {&__pyx_n_s_Tick___setstate, __pyx_k_Tick___setstate, sizeof(__pyx_k_Tick___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_Tick__apply, __pyx_k_Tick__apply, sizeof(__pyx_k_Tick__apply), 0, 0, 1, 1},
    {&__pyx_n_s_Tick__next_higher_resolution, __pyx_k_Tick__next_higher_resolution, sizeof(__pyx_k_Tick__next_higher_resolution), 0, 0, 1, 1},
    {&__pyx_n_s_Tick__repr_attrs, __pyx_k_Tick__repr_attrs, sizeof(__pyx_k_Tick__repr_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_Tick_is_anchored, __pyx_k_Tick_is_anchored, sizeof(__pyx_k_Tick_is_anchored), 0, 0, 1, 1},
    {&__pyx_n_s_Tick_is_on_offset, __pyx_k_Tick_is_on_offset, sizeof(__pyx_k_Tick_is_on_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_Tick_nanos___get___line_953, __pyx_k_Tick_nanos___get___line_953, sizeof(__pyx_k_Tick_nanos___get___line_953), 0, 1, 0, 0},
    {&__pyx_kp_u_Tick_offset_with_normalize_True, __pyx_k_Tick_offset_with_normalize_True, sizeof(__pyx_k_Tick_offset_with_normalize_True), 0, 1, 0, 0},
    {&__pyx_kp_u_Time_zones_are_not_available_fro, __pyx_k_Time_zones_are_not_available_fro, sizeof(__pyx_k_Time_zones_are_not_available_fro), 0, 1, 0, 0},
    {&__pyx_n_s_Timedelta, __pyx_k_Timedelta, sizeof(__pyx_k_Timedelta), 0, 0, 1, 1},
    {&__pyx_n_s_Timestamp, __pyx_k_Timestamp, sizeof(__pyx_k_Timestamp), 0, 0, 1, 1},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_u_U, __pyx_k_U, sizeof(__pyx_k_U), 0, 1, 0, 1},
    {&__pyx_kp_u_Unable_to_parse_varion_code, __pyx_k_Unable_to_parse_varion_code, sizeof(__pyx_k_Unable_to_parse_varion_code), 0, 1, 0, 0},
    {&__pyx_kp_u_Unexpected_key__offset, __pyx_k_Unexpected_key__offset, sizeof(__pyx_k_Unexpected_key__offset), 0, 1, 0, 0},
    {&__pyx_kp_u_Unhandled_type, __pyx_k_Unhandled_type, sizeof(__pyx_k_Unhandled_type), 0, 1, 0, 0},
    {&__pyx_kp_u_Using_DateOffset_to_replace_mill, __pyx_k_Using_DateOffset_to_replace_mill, sizeof(__pyx_k_Using_DateOffset_to_replace_mill), 0, 1, 0, 0},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_u_W, __pyx_k_W, sizeof(__pyx_k_W), 0, 1, 0, 1},
    {&__pyx_n_u_WOM, __pyx_k_WOM, sizeof(__pyx_k_WOM), 0, 1, 0, 1},
    {&__pyx_kp_u_W_SUN, __pyx_k_W_SUN, sizeof(__pyx_k_W_SUN), 0, 1, 0, 0},
    {&__pyx_n_s_Week, __pyx_k_Week, sizeof(__pyx_k_Week), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonth, __pyx_k_WeekOfMonth, sizeof(__pyx_k_WeekOfMonth), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonthMixin, __pyx_k_WeekOfMonthMixin, sizeof(__pyx_k_WeekOfMonthMixin), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonthMixin__apply, __pyx_k_WeekOfMonthMixin__apply, sizeof(__pyx_k_WeekOfMonthMixin__apply), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonthMixin_is_on_offset, __pyx_k_WeekOfMonthMixin_is_on_offset, sizeof(__pyx_k_WeekOfMonthMixin_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonth___setstate, __pyx_k_WeekOfMonth___setstate, sizeof(__pyx_k_WeekOfMonth___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonth__from_name, __pyx_k_WeekOfMonth__from_name, sizeof(__pyx_k_WeekOfMonth__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_WeekOfMonth__get_offset_day, __pyx_k_WeekOfMonth__get_offset_day, sizeof(__pyx_k_WeekOfMonth__get_offset_day), 0, 0, 1, 1},
    {&__pyx_n_s_Week___setstate, __pyx_k_Week___setstate, sizeof(__pyx_k_Week___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_Week__apply, __pyx_k_Week__apply, sizeof(__pyx_k_Week__apply), 0, 0, 1, 1},
    {&__pyx_n_s_Week__apply_array, __pyx_k_Week__apply_array, sizeof(__pyx_k_Week__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_Week__from_name, __pyx_k_Week__from_name, sizeof(__pyx_k_Week__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_Week_is_anchored, __pyx_k_Week_is_anchored, sizeof(__pyx_k_Week_is_anchored), 0, 0, 1, 1},
    {&__pyx_n_s_Week_is_on_offset, __pyx_k_Week_is_on_offset, sizeof(__pyx_k_Week_is_on_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_Week_must_be_0_week_3_got, __pyx_k_Week_must_be_0_week_3_got, sizeof(__pyx_k_Week_must_be_0_week_3_got), 0, 1, 0, 0},
    {&__pyx_n_u_Y, __pyx_k_Y, sizeof(__pyx_k_Y), 0, 1, 0, 1},
    {&__pyx_n_u_YS, __pyx_k_YS, sizeof(__pyx_k_YS), 0, 1, 0, 1},
    {&__pyx_n_s_YearBegin, __pyx_k_YearBegin, sizeof(__pyx_k_YearBegin), 0, 0, 1, 1},
    {&__pyx_n_s_YearEnd, __pyx_k_YearEnd, sizeof(__pyx_k_YearEnd), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset, __pyx_k_YearOffset, sizeof(__pyx_k_YearOffset), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset___setstate, __pyx_k_YearOffset___setstate, sizeof(__pyx_k_YearOffset___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset__apply, __pyx_k_YearOffset__apply, sizeof(__pyx_k_YearOffset__apply), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset__apply_array, __pyx_k_YearOffset__apply_array, sizeof(__pyx_k_YearOffset__apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset__from_name, __pyx_k_YearOffset__from_name, sizeof(__pyx_k_YearOffset__from_name), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset__get_offset_day, __pyx_k_YearOffset__get_offset_day, sizeof(__pyx_k_YearOffset__get_offset_day), 0, 0, 1, 1},
    {&__pyx_n_s_YearOffset_is_on_offset, __pyx_k_YearOffset_is_on_offset, sizeof(__pyx_k_YearOffset_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_u__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 1, 0, 1},
    {&__pyx_kp_u__15, __pyx_k__15, sizeof(__pyx_k__15), 0, 1, 0, 0},
    {&__pyx_kp_u__16, __pyx_k__16, sizeof(__pyx_k__16), 0, 1, 0, 0},
    {&__pyx_kp_u__17, __pyx_k__17, sizeof(__pyx_k__17), 0, 1, 0, 0},
    {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
    {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
    {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
    {&__pyx_kp_u__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 1, 0, 0},
    {&__pyx_n_s__284, __pyx_k__284, sizeof(__pyx_k__284), 0, 0, 1, 1},
    {&__pyx_kp_u__37, __pyx_k__37, sizeof(__pyx_k__37), 0, 1, 0, 0},
    {&__pyx_kp_u__38, __pyx_k__38, sizeof(__pyx_k__38), 0, 1, 0, 0},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_kp_u__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 1, 0, 0},
    {&__pyx_kp_u__47, __pyx_k__47, sizeof(__pyx_k__47), 0, 1, 0, 0},
    {&__pyx_n_s__67, __pyx_k__67, sizeof(__pyx_k__67), 0, 0, 1, 1},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
    {&__pyx_n_s_adjust_dst, __pyx_k_adjust_dst, sizeof(__pyx_k_adjust_dst), 0, 0, 1, 1},
    {&__pyx_n_s_all_paras, __pyx_k_all_paras, sizeof(__pyx_k_all_paras), 0, 0, 1, 1},
    {&__pyx_n_s_anchor, __pyx_k_anchor, sizeof(__pyx_k_anchor), 0, 0, 1, 1},
    {&__pyx_n_s_anchor_dom, __pyx_k_anchor_dom, sizeof(__pyx_k_anchor_dom), 0, 0, 1, 1},
    {&__pyx_kp_u_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 1, 0, 0},
    {&__pyx_n_s_apply, __pyx_k_apply, sizeof(__pyx_k_apply), 0, 0, 1, 1},
    {&__pyx_n_s_apply_array, __pyx_k_apply_array, sizeof(__pyx_k_apply_array), 0, 0, 1, 1},
    {&__pyx_n_s_apply_array_wraps, __pyx_k_apply_array_wraps, sizeof(__pyx_k_apply_array_wraps), 0, 0, 1, 1},
    {&__pyx_n_s_apply_array_wraps_locals_wrapper, __pyx_k_apply_array_wraps_locals_wrapper, sizeof(__pyx_k_apply_array_wraps_locals_wrapper), 0, 0, 1, 1},
    {&__pyx_n_s_apply_locals_genexpr, __pyx_k_apply_locals_genexpr, sizeof(__pyx_k_apply_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_apply_wrapper_core, __pyx_k_apply_wrapper_core, sizeof(__pyx_k_apply_wrapper_core), 0, 0, 1, 1},
    {&__pyx_n_s_apply_wraps, __pyx_k_apply_wraps, sizeof(__pyx_k_apply_wraps), 0, 0, 1, 1},
    {&__pyx_n_s_apply_wraps_locals_wrapper, __pyx_k_apply_wraps_locals_wrapper, sizeof(__pyx_k_apply_wraps_locals_wrapper), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_argsort, __pyx_k_argsort, sizeof(__pyx_k_argsort), 0, 0, 1, 1},
    {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
    {&__pyx_n_s_array_priority, __pyx_k_array_priority, sizeof(__pyx_k_array_priority), 0, 0, 1, 1},
    {&__pyx_n_s_as_unit, __pyx_k_as_unit, sizeof(__pyx_k_as_unit), 0, 0, 1, 1},
    {&__pyx_n_s_asarray, __pyx_k_asarray, sizeof(__pyx_k_asarray), 0, 0, 1, 1},
    {&__pyx_n_s_astype, __pyx_k_astype, sizeof(__pyx_k_astype), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_attr, __pyx_k_attr, sizeof(__pyx_k_attr), 0, 0, 1, 1},
    {&__pyx_n_s_attributes, __pyx_k_attributes, sizeof(__pyx_k_attributes), 0, 0, 1, 1},
    {&__pyx_n_s_attrs, __pyx_k_attrs, sizeof(__pyx_k_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 0, 1, 1},
    {&__pyx_n_u_backward, __pyx_k_backward, sizeof(__pyx_k_backward), 0, 1, 0, 1},
    {&__pyx_n_s_bd, __pyx_k_bd, sizeof(__pyx_k_bd), 0, 0, 1, 1},
    {&__pyx_n_s_bhour, __pyx_k_bhour, sizeof(__pyx_k_bhour), 0, 0, 1, 1},
    {&__pyx_n_s_bhour_remain, __pyx_k_bhour_remain, sizeof(__pyx_k_bhour_remain), 0, 0, 1, 1},
    {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
    {&__pyx_n_s_busday_offset, __pyx_k_busday_offset, sizeof(__pyx_k_busday_offset), 0, 0, 1, 1},
    {&__pyx_n_s_busdaycal, __pyx_k_busdaycal, sizeof(__pyx_k_busdaycal), 0, 0, 1, 1},
    {&__pyx_n_s_busdaycalendar, __pyx_k_busdaycalendar, sizeof(__pyx_k_busdaycalendar), 0, 0, 1, 1},
    {&__pyx_n_u_business_end, __pyx_k_business_end, sizeof(__pyx_k_business_end), 0, 1, 0, 1},
    {&__pyx_n_u_business_start, __pyx_k_business_start, sizeof(__pyx_k_business_start), 0, 1, 0, 1},
    {&__pyx_n_s_businesshours, __pyx_k_businesshours, sizeof(__pyx_k_businesshours), 0, 0, 1, 1},
    {&__pyx_n_u_cache, __pyx_k_cache, sizeof(__pyx_k_cache), 0, 1, 0, 1},
    {&__pyx_n_s_cache_readonly, __pyx_k_cache_readonly, sizeof(__pyx_k_cache_readonly), 0, 0, 1, 1},
    {&__pyx_n_s_calendar, __pyx_k_calendar, sizeof(__pyx_k_calendar), 0, 0, 1, 1},
    {&__pyx_n_u_calendar, __pyx_k_calendar, sizeof(__pyx_k_calendar), 0, 1, 0, 1},
    {&__pyx_n_s_cbday, __pyx_k_cbday, sizeof(__pyx_k_cbday), 0, 0, 1, 1},
    {&__pyx_n_s_cbday_kwds, __pyx_k_cbday_kwds, sizeof(__pyx_k_cbday_kwds), 0, 0, 1, 1},
    {&__pyx_n_s_cbday_roll, __pyx_k_cbday_roll, sizeof(__pyx_k_cbday_roll), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_cls, __pyx_k_cls, sizeof(__pyx_k_cls), 0, 0, 1, 1},
    {&__pyx_n_s_code, __pyx_k_code, sizeof(__pyx_k_code), 0, 0, 1, 1},
    {&__pyx_n_s_combine, __pyx_k_combine, sizeof(__pyx_k_combine), 0, 0, 1, 1},
    {&__pyx_n_s_compare, __pyx_k_compare, sizeof(__pyx_k_compare), 0, 0, 1, 1},
    {&__pyx_n_s_compare_date, __pyx_k_compare_date, sizeof(__pyx_k_compare_date), 0, 0, 1, 1},
    {&__pyx_n_s_compare_day, __pyx_k_compare_day, sizeof(__pyx_k_compare_day), 0, 0, 1, 1},
    {&__pyx_n_s_compile, __pyx_k_compile, sizeof(__pyx_k_compile), 0, 0, 1, 1},
    {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_creso, __pyx_k_creso, sizeof(__pyx_k_creso), 0, 0, 1, 1},
    {&__pyx_n_s_cur_month_offset_date, __pyx_k_cur_month_offset_date, sizeof(__pyx_k_cur_month_offset_date), 0, 0, 1, 1},
    {&__pyx_n_s_cur_year, __pyx_k_cur_year, sizeof(__pyx_k_cur_year), 0, 0, 1, 1},
    {&__pyx_n_s_current, __pyx_k_current, sizeof(__pyx_k_current), 0, 0, 1, 1},
    {&__pyx_n_s_current_easter, __pyx_k_current_easter, sizeof(__pyx_k_current_easter), 0, 0, 1, 1},
    {&__pyx_n_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 1},
    {&__pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z, __pyx_k_d_d_d_s_A_Za_z_dA_Za_z, sizeof(__pyx_k_d_d_d_s_A_Za_z_dA_Za_z), 0, 1, 0, 0},
    {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
    {&__pyx_n_s_date_in, __pyx_k_date_in, sizeof(__pyx_k_date_in), 0, 0, 1, 1},
    {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
    {&__pyx_n_s_datetime64, __pyx_k_datetime64, sizeof(__pyx_k_datetime64), 0, 0, 1, 1},
    {&__pyx_kp_u_datetime64_D, __pyx_k_datetime64_D, sizeof(__pyx_k_datetime64_D), 0, 1, 0, 0},
    {&__pyx_n_s_dateutil_easter, __pyx_k_dateutil_easter, sizeof(__pyx_k_dateutil_easter), 0, 0, 1, 1},
    {&__pyx_n_s_dateutil_relativedelta, __pyx_k_dateutil_relativedelta, sizeof(__pyx_k_dateutil_relativedelta), 0, 0, 1, 1},
    {&__pyx_n_s_day, __pyx_k_day, sizeof(__pyx_k_day), 0, 0, 1, 1},
    {&__pyx_n_u_day, __pyx_k_day, sizeof(__pyx_k_day), 0, 1, 0, 1},
    {&__pyx_n_s_day64, __pyx_k_day64, sizeof(__pyx_k_day64), 0, 0, 1, 1},
    {&__pyx_kp_u_day_must_be_None_start_end_busin, __pyx_k_day_must_be_None_start_end_busin, sizeof(__pyx_k_day_must_be_None_start_end_busin), 0, 1, 0, 0},
    {&__pyx_n_s_day_of_month, __pyx_k_day_of_month, sizeof(__pyx_k_day_of_month), 0, 0, 1, 1},
    {&__pyx_n_u_day_of_month, __pyx_k_day_of_month, sizeof(__pyx_k_day_of_month), 0, 1, 0, 1},
    {&__pyx_kp_u_day_of_month_27_got, __pyx_k_day_of_month_27_got, sizeof(__pyx_k_day_of_month_27_got), 0, 1, 0, 0},
    {&__pyx_kp_u_day_of_month_must_be, __pyx_k_day_of_month_must_be, sizeof(__pyx_k_day_of_month_must_be), 0, 1, 0, 0},
    {&__pyx_n_s_day_opt, __pyx_k_day_opt, sizeof(__pyx_k_day_opt), 0, 0, 1, 1},
    {&__pyx_n_s_day_opt_2, __pyx_k_day_opt_2, sizeof(__pyx_k_day_opt_2), 0, 0, 1, 1},
    {&__pyx_n_s_days, __pyx_k_days, sizeof(__pyx_k_days), 0, 0, 1, 1},
    {&__pyx_n_u_days, __pyx_k_days, sizeof(__pyx_k_days), 0, 1, 0, 1},
    {&__pyx_n_s_days_forward, __pyx_k_days_forward, sizeof(__pyx_k_days_forward), 0, 0, 1, 1},
    {&__pyx_n_s_days_in_month, __pyx_k_days_in_month, sizeof(__pyx_k_days_in_month), 0, 0, 1, 1},
    {&__pyx_n_s_default_day_of_month, __pyx_k_default_day_of_month, sizeof(__pyx_k_default_day_of_month), 0, 0, 1, 1},
    {&__pyx_n_s_default_month, __pyx_k_default_month, sizeof(__pyx_k_default_month), 0, 0, 1, 1},
    {&__pyx_n_s_default_starting_month, __pyx_k_default_starting_month, sizeof(__pyx_k_default_starting_month), 0, 0, 1, 1},
    {&__pyx_n_s_delta, __pyx_k_delta, sizeof(__pyx_k_delta), 0, 0, 1, 1},
    {&__pyx_n_s_delta_to_tick, __pyx_k_delta_to_tick, sizeof(__pyx_k_delta_to_tick), 0, 0, 1, 1},
    {&__pyx_n_s_determine_offset_locals_genexpr, __pyx_k_determine_offset_locals_genexpr, sizeof(__pyx_k_determine_offset_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_u_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 1, 0, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_n_s_dim, __pyx_k_dim, sizeof(__pyx_k_dim), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
    {&__pyx_kp_u_does_not_have_a_vectorized_impl, __pyx_k_does_not_have_a_vectorized_impl, sizeof(__pyx_k_does_not_have_a_vectorized_impl), 0, 1, 0, 0},
    {&__pyx_n_s_dont_uppercase, __pyx_k_dont_uppercase, sizeof(__pyx_k_dont_uppercase), 0, 0, 1, 1},
    {&__pyx_n_s_dt, __pyx_k_dt, sizeof(__pyx_k_dt), 0, 0, 1, 1},
    {&__pyx_n_s_dt64other, __pyx_k_dt64other, sizeof(__pyx_k_dt64other), 0, 0, 1, 1},
    {&__pyx_n_s_dt_date, __pyx_k_dt_date, sizeof(__pyx_k_dt_date), 0, 0, 1, 1},
    {&__pyx_n_s_dtarr, __pyx_k_dtarr, sizeof(__pyx_k_dtarr), 0, 0, 1, 1},
    {&__pyx_n_s_dtindex, __pyx_k_dtindex, sizeof(__pyx_k_dtindex), 0, 0, 1, 1},
    {&__pyx_n_s_dts, __pyx_k_dts, sizeof(__pyx_k_dts), 0, 0, 1, 1},
    {&__pyx_n_s_dtstart, __pyx_k_dtstart, sizeof(__pyx_k_dtstart), 0, 0, 1, 1},
    {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
    {&__pyx_n_s_dy, __pyx_k_dy, sizeof(__pyx_k_dy), 0, 0, 1, 1},
    {&__pyx_n_s_earliest_start, __pyx_k_earliest_start, sizeof(__pyx_k_earliest_start), 0, 0, 1, 1},
    {&__pyx_n_s_easter, __pyx_k_easter, sizeof(__pyx_k_easter), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
    {&__pyx_n_u_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 1, 0, 1},
    {&__pyx_n_s_endswith, __pyx_k_endswith, sizeof(__pyx_k_endswith), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_err, __pyx_k_err, sizeof(__pyx_k_err), 0, 0, 1, 1},
    {&__pyx_n_s_exclude, __pyx_k_exclude, sizeof(__pyx_k_exclude), 0, 0, 1, 1},
    {&__pyx_n_s_fabs, __pyx_k_fabs, sizeof(__pyx_k_fabs), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_u_forward, __pyx_k_forward, sizeof(__pyx_k_forward), 0, 1, 0, 1},
    {&__pyx_n_s_freq, __pyx_k_freq, sizeof(__pyx_k_freq), 0, 0, 1, 1},
    {&__pyx_n_s_freqstr, __pyx_k_freqstr, sizeof(__pyx_k_freqstr), 0, 0, 1, 1},
    {&__pyx_n_s_from_name, __pyx_k_from_name, sizeof(__pyx_k_from_name), 0, 0, 1, 1},
    {&__pyx_n_s_from_name_starting_month, __pyx_k_from_name_starting_month, sizeof(__pyx_k_from_name_starting_month), 0, 0, 1, 1},
    {&__pyx_n_s_fstr, __pyx_k_fstr, sizeof(__pyx_k_fstr), 0, 0, 1, 1},
    {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_ge, __pyx_k_ge, sizeof(__pyx_k_ge), 0, 0, 1, 1},
    {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_get_2, __pyx_k_get_2, sizeof(__pyx_k_get_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_business_hours_by_sec, __pyx_k_get_business_hours_by_sec, sizeof(__pyx_k_get_business_hours_by_sec), 0, 0, 1, 1},
    {&__pyx_n_s_get_closing_time, __pyx_k_get_closing_time, sizeof(__pyx_k_get_closing_time), 0, 0, 1, 1},
    {&__pyx_n_s_get_offset, __pyx_k_get_offset, sizeof(__pyx_k_get_offset), 0, 0, 1, 1},
    {&__pyx_n_s_get_offset_day, __pyx_k_get_offset_day, sizeof(__pyx_k_get_offset_day), 0, 0, 1, 1},
    {&__pyx_n_s_get_rule_code_suffix, __pyx_k_get_rule_code_suffix, sizeof(__pyx_k_get_rule_code_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_get_str, __pyx_k_get_str, sizeof(__pyx_k_get_str), 0, 0, 1, 1},
    {&__pyx_n_s_get_suffix_prefix, __pyx_k_get_suffix_prefix, sizeof(__pyx_k_get_suffix_prefix), 0, 0, 1, 1},
    {&__pyx_n_s_get_weeks, __pyx_k_get_weeks, sizeof(__pyx_k_get_weeks), 0, 0, 1, 1},
    {&__pyx_n_s_get_year_end, __pyx_k_get_year_end, sizeof(__pyx_k_get_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_gt, __pyx_k_gt, sizeof(__pyx_k_gt), 0, 0, 1, 1},
    {&__pyx_n_u_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 1, 0, 1},
    {&__pyx_n_s_holidays, __pyx_k_holidays, sizeof(__pyx_k_holidays), 0, 0, 1, 1},
    {&__pyx_n_u_holidays, __pyx_k_holidays, sizeof(__pyx_k_holidays), 0, 1, 0, 1},
    {&__pyx_n_s_hour, __pyx_k_hour, sizeof(__pyx_k_hour), 0, 0, 1, 1},
    {&__pyx_n_u_hour, __pyx_k_hour, sizeof(__pyx_k_hour), 0, 1, 0, 1},
    {&__pyx_n_s_hours, __pyx_k_hours, sizeof(__pyx_k_hours), 0, 0, 1, 1},
    {&__pyx_n_u_hours, __pyx_k_hours, sizeof(__pyx_k_hours), 0, 1, 0, 1},
    {&__pyx_n_s_hrs, __pyx_k_hrs, sizeof(__pyx_k_hrs), 0, 0, 1, 1},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_u_i8, __pyx_k_i8, sizeof(__pyx_k_i8), 0, 1, 0, 1},
    {&__pyx_n_s_i8other, __pyx_k_i8other, sizeof(__pyx_k_i8other), 0, 0, 1, 1},
    {&__pyx_kp_u_implemented_by_subclasses, __pyx_k_implemented_by_subclasses, sizeof(__pyx_k_implemented_by_subclasses), 0, 1, 0, 0},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_u_inc, __pyx_k_inc, sizeof(__pyx_k_inc), 0, 1, 0, 1},
    {&__pyx_n_s_inc_2, __pyx_k_inc_2, sizeof(__pyx_k_inc_2), 0, 0, 1, 1},
    {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
    {&__pyx_n_s_init_custom, __pyx_k_init_custom, sizeof(__pyx_k_init_custom), 0, 0, 1, 1},
    {&__pyx_n_s_init_subclass, __pyx_k_init_subclass, sizeof(__pyx_k_init_subclass), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_instancecheck, __pyx_k_instancecheck, sizeof(__pyx_k_instancecheck), 0, 0, 1, 1},
    {&__pyx_n_s_int, __pyx_k_int, sizeof(__pyx_k_int), 0, 0, 1, 1},
    {&__pyx_n_s_int_to_weekday, __pyx_k_int_to_weekday, sizeof(__pyx_k_int_to_weekday), 0, 0, 1, 1},
    {&__pyx_kp_u_invalid_starting_and_ending_time, __pyx_k_invalid_starting_and_ending_time, sizeof(__pyx_k_invalid_starting_and_ending_time), 0, 1, 0, 0},
    {&__pyx_kp_u_is_a_non_fixed_frequency, __pyx_k_is_a_non_fixed_frequency, sizeof(__pyx_k_is_a_non_fixed_frequency), 0, 1, 0, 0},
    {&__pyx_n_s_is_anchored, __pyx_k_is_anchored, sizeof(__pyx_k_is_anchored), 0, 0, 1, 1},
    {&__pyx_n_s_is_busday, __pyx_k_is_busday, sizeof(__pyx_k_is_busday), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_month_end, __pyx_k_is_month_end, sizeof(__pyx_k_is_month_end), 0, 0, 1, 1},
    {&__pyx_n_u_is_month_end, __pyx_k_is_month_end, sizeof(__pyx_k_is_month_end), 0, 1, 0, 1},
    {&__pyx_n_s_is_month_start, __pyx_k_is_month_start, sizeof(__pyx_k_is_month_start), 0, 0, 1, 1},
    {&__pyx_n_u_is_month_start, __pyx_k_is_month_start, sizeof(__pyx_k_is_month_start), 0, 1, 0, 1},
    {&__pyx_kp_u_is_not_a_valid_variation, __pyx_k_is_not_a_valid_variation, sizeof(__pyx_k_is_not_a_valid_variation), 0, 1, 0, 0},
    {&__pyx_n_s_is_on_offset, __pyx_k_is_on_offset, sizeof(__pyx_k_is_on_offset), 0, 0, 1, 1},
    {&__pyx_n_s_is_on_offset_2, __pyx_k_is_on_offset_2, sizeof(__pyx_k_is_on_offset_2), 0, 0, 1, 1},
    {&__pyx_n_s_is_quarter_end, __pyx_k_is_quarter_end, sizeof(__pyx_k_is_quarter_end), 0, 0, 1, 1},
    {&__pyx_n_u_is_quarter_end, __pyx_k_is_quarter_end, sizeof(__pyx_k_is_quarter_end), 0, 1, 0, 1},
    {&__pyx_n_s_is_quarter_start, __pyx_k_is_quarter_start, sizeof(__pyx_k_is_quarter_start), 0, 0, 1, 1},
    {&__pyx_n_u_is_quarter_start, __pyx_k_is_quarter_start, sizeof(__pyx_k_is_quarter_start), 0, 1, 0, 1},
    {&__pyx_n_s_is_same_sign, __pyx_k_is_same_sign, sizeof(__pyx_k_is_same_sign), 0, 0, 1, 1},
    {&__pyx_n_s_is_start, __pyx_k_is_start, sizeof(__pyx_k_is_start), 0, 0, 1, 1},
    {&__pyx_n_s_is_year_end, __pyx_k_is_year_end, sizeof(__pyx_k_is_year_end), 0, 0, 1, 1},
    {&__pyx_n_u_is_year_end, __pyx_k_is_year_end, sizeof(__pyx_k_is_year_end), 0, 1, 0, 1},
    {&__pyx_n_s_is_year_start, __pyx_k_is_year_start, sizeof(__pyx_k_is_year_start), 0, 0, 1, 1},
    {&__pyx_n_u_is_year_start, __pyx_k_is_year_start, sizeof(__pyx_k_is_year_start), 0, 1, 0, 1},
    {&__pyx_n_s_isclose, __pyx_k_isclose, sizeof(__pyx_k_isclose), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_isspace, __pyx_k_isspace, sizeof(__pyx_k_isspace), 0, 0, 1, 1},
    {&__pyx_n_s_issubset, __pyx_k_issubset, sizeof(__pyx_k_issubset), 0, 0, 1, 1},
    {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
    {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_klass, __pyx_k_klass, sizeof(__pyx_k_klass), 0, 0, 1, 1},
    {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
    {&__pyx_n_s_kwd, __pyx_k_kwd, sizeof(__pyx_k_kwd), 0, 0, 1, 1},
    {&__pyx_n_s_kwds, __pyx_k_kwds, sizeof(__pyx_k_kwds), 0, 0, 1, 1},
    {&__pyx_n_u_kwds, __pyx_k_kwds, sizeof(__pyx_k_kwds), 0, 1, 0, 1},
    {&__pyx_n_u_last, __pyx_k_last, sizeof(__pyx_k_last), 0, 1, 0, 1},
    {&__pyx_kp_u_last_element_must_be_blank, __pyx_k_last_element_must_be_blank, sizeof(__pyx_k_last_element_must_be_blank), 0, 1, 0, 0},
    {&__pyx_n_s_latest_start, __pyx_k_latest_start, sizeof(__pyx_k_latest_start), 0, 0, 1, 1},
    {&__pyx_n_s_le, __pyx_k_le, sizeof(__pyx_k_le), 0, 0, 1, 1},
    {&__pyx_n_s_lite_rule_alias, __pyx_k_lite_rule_alias, sizeof(__pyx_k_lite_rule_alias), 0, 0, 1, 1},
    {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
    {&__pyx_n_s_lt, __pyx_k_lt, sizeof(__pyx_k_lt), 0, 0, 1, 1},
    {&__pyx_n_u_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 1, 0, 1},
    {&__pyx_n_s_m_offset, __pyx_k_m_offset, sizeof(__pyx_k_m_offset), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_mend, __pyx_k_mend, sizeof(__pyx_k_mend), 0, 0, 1, 1},
    {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
    {&__pyx_n_s_mi, __pyx_k_mi, sizeof(__pyx_k_mi), 0, 0, 1, 1},
    {&__pyx_n_s_microsecond, __pyx_k_microsecond, sizeof(__pyx_k_microsecond), 0, 0, 1, 1},
    {&__pyx_n_u_microsecond, __pyx_k_microsecond, sizeof(__pyx_k_microsecond), 0, 1, 0, 1},
    {&__pyx_n_s_microseconds, __pyx_k_microseconds, sizeof(__pyx_k_microseconds), 0, 0, 1, 1},
    {&__pyx_n_u_microseconds, __pyx_k_microseconds, sizeof(__pyx_k_microseconds), 0, 1, 0, 1},
    {&__pyx_n_u_millisecond, __pyx_k_millisecond, sizeof(__pyx_k_millisecond), 0, 1, 0, 1},
    {&__pyx_n_u_milliseconds, __pyx_k_milliseconds, sizeof(__pyx_k_milliseconds), 0, 1, 0, 1},
    {&__pyx_n_u_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 1, 0, 1},
    {&__pyx_n_s_min_day_of_month, __pyx_k_min_day_of_month, sizeof(__pyx_k_min_day_of_month), 0, 0, 1, 1},
    {&__pyx_n_s_minute, __pyx_k_minute, sizeof(__pyx_k_minute), 0, 0, 1, 1},
    {&__pyx_n_u_minute, __pyx_k_minute, sizeof(__pyx_k_minute), 0, 1, 0, 1},
    {&__pyx_n_s_minutes, __pyx_k_minutes, sizeof(__pyx_k_minutes), 0, 0, 1, 1},
    {&__pyx_n_u_minutes, __pyx_k_minutes, sizeof(__pyx_k_minutes), 0, 1, 0, 1},
    {&__pyx_n_s_mod_month, __pyx_k_mod_month, sizeof(__pyx_k_mod_month), 0, 0, 1, 1},
    {&__pyx_n_s_modby, __pyx_k_modby, sizeof(__pyx_k_modby), 0, 0, 1, 1},
    {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
    {&__pyx_n_s_moff, __pyx_k_moff, sizeof(__pyx_k_moff), 0, 0, 1, 1},
    {&__pyx_n_s_month, __pyx_k_month, sizeof(__pyx_k_month), 0, 0, 1, 1},
    {&__pyx_n_u_month, __pyx_k_month, sizeof(__pyx_k_month), 0, 1, 0, 1},
    {&__pyx_n_s_month_roll, __pyx_k_month_roll, sizeof(__pyx_k_month_roll), 0, 0, 1, 1},
    {&__pyx_n_s_months, __pyx_k_months, sizeof(__pyx_k_months), 0, 0, 1, 1},
    {&__pyx_n_u_months, __pyx_k_months, sizeof(__pyx_k_months), 0, 1, 0, 1},
    {&__pyx_n_s_months_since, __pyx_k_months_since, sizeof(__pyx_k_months_since), 0, 0, 1, 1},
    {&__pyx_n_s_months_to_roll, __pyx_k_months_to_roll, sizeof(__pyx_k_months_to_roll), 0, 0, 1, 1},
    {&__pyx_n_s_mro_entries, __pyx_k_mro_entries, sizeof(__pyx_k_mro_entries), 0, 0, 1, 1},
    {&__pyx_n_u_ms, __pyx_k_ms, sizeof(__pyx_k_ms), 0, 1, 0, 1},
    {&__pyx_n_s_mstart, __pyx_k_mstart, sizeof(__pyx_k_mstart), 0, 0, 1, 1},
    {&__pyx_n_s_mts, __pyx_k_mts, sizeof(__pyx_k_mts), 0, 0, 1, 1},
    {&__pyx_n_s_mul, __pyx_k_mul, sizeof(__pyx_k_mul), 0, 0, 1, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_n_u_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 1, 0, 1},
    {&__pyx_kp_u_n_argument_must_be_an_integer_g, __pyx_k_n_argument_must_be_an_integer_g, sizeof(__pyx_k_n_argument_must_be_an_integer_g), 0, 1, 0, 0},
    {&__pyx_n_s_nadj, __pyx_k_nadj, sizeof(__pyx_k_nadj), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_u_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 1, 0, 1},
    {&__pyx_n_s_nano, __pyx_k_nano, sizeof(__pyx_k_nano), 0, 0, 1, 1},
    {&__pyx_n_s_nanos, __pyx_k_nanos, sizeof(__pyx_k_nanos), 0, 0, 1, 1},
    {&__pyx_n_s_nanos_inc, __pyx_k_nanos_inc, sizeof(__pyx_k_nanos_inc), 0, 0, 1, 1},
    {&__pyx_n_s_nanosecond, __pyx_k_nanosecond, sizeof(__pyx_k_nanosecond), 0, 0, 1, 1},
    {&__pyx_n_u_nanosecond, __pyx_k_nanosecond, sizeof(__pyx_k_nanosecond), 0, 1, 0, 1},
    {&__pyx_n_s_nanoseconds, __pyx_k_nanoseconds, sizeof(__pyx_k_nanoseconds), 0, 0, 1, 1},
    {&__pyx_n_u_nanoseconds, __pyx_k_nanoseconds, sizeof(__pyx_k_nanoseconds), 0, 1, 0, 1},
    {&__pyx_n_s_nb_offset, __pyx_k_nb_offset, sizeof(__pyx_k_nb_offset), 0, 0, 1, 1},
    {&__pyx_n_s_ndarray, __pyx_k_ndarray, sizeof(__pyx_k_ndarray), 0, 0, 1, 1},
    {&__pyx_n_s_ndim, __pyx_k_ndim, sizeof(__pyx_k_ndim), 0, 0, 1, 1},
    {&__pyx_n_u_nearest, __pyx_k_nearest, sizeof(__pyx_k_nearest), 0, 1, 0, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_new_2, __pyx_k_new_2, sizeof(__pyx_k_new_2), 0, 0, 1, 1},
    {&__pyx_n_s_next_bday, __pyx_k_next_bday, sizeof(__pyx_k_next_bday), 0, 0, 1, 1},
    {&__pyx_n_u_next_bday, __pyx_k_next_bday, sizeof(__pyx_k_next_bday), 0, 1, 0, 1},
    {&__pyx_n_s_next_higher_resolution, __pyx_k_next_higher_resolution, sizeof(__pyx_k_next_higher_resolution), 0, 0, 1, 1},
    {&__pyx_n_s_next_opening_time, __pyx_k_next_opening_time, sizeof(__pyx_k_next_opening_time), 0, 0, 1, 1},
    {&__pyx_n_s_next_year, __pyx_k_next_year, sizeof(__pyx_k_next_year), 0, 0, 1, 1},
    {&__pyx_n_s_next_year_end, __pyx_k_next_year_end, sizeof(__pyx_k_next_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_nint, __pyx_k_nint, sizeof(__pyx_k_nint), 0, 0, 1, 1},
    {&__pyx_n_s_norm, __pyx_k_norm, sizeof(__pyx_k_norm), 0, 0, 1, 1},
    {&__pyx_n_s_normalize, __pyx_k_normalize, sizeof(__pyx_k_normalize), 0, 0, 1, 1},
    {&__pyx_n_u_normalize, __pyx_k_normalize, sizeof(__pyx_k_normalize), 0, 1, 0, 1},
    {&__pyx_n_s_normalize_i8_timestamps, __pyx_k_normalize_i8_timestamps, sizeof(__pyx_k_normalize_i8_timestamps), 0, 0, 1, 1},
    {&__pyx_kp_u_not_able_to_be_applied_vectoriz, __pyx_k_not_able_to_be_applied_vectoriz, sizeof(__pyx_k_not_able_to_be_applied_vectoriz), 0, 1, 0, 0},
    {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
    {&__pyx_n_s_np_dt, __pyx_k_np_dt, sizeof(__pyx_k_np_dt), 0, 0, 1, 1},
    {&__pyx_n_s_np_incr_dt, __pyx_k_np_incr_dt, sizeof(__pyx_k_np_incr_dt), 0, 0, 1, 1},
    {&__pyx_kp_s_np_ndarray, __pyx_k_np_ndarray, sizeof(__pyx_k_np_ndarray), 0, 0, 1, 0},
    {&__pyx_n_u_ns, __pyx_k_ns, sizeof(__pyx_k_ns), 0, 1, 0, 1},
    {&__pyx_n_s_num_nano, __pyx_k_num_nano, sizeof(__pyx_k_num_nano), 0, 0, 1, 1},
    {&__pyx_n_s_num_qtrs, __pyx_k_num_qtrs, sizeof(__pyx_k_num_qtrs), 0, 0, 1, 1},
    {&__pyx_kp_u_number_of_starting_time_and_endi, __pyx_k_number_of_starting_time_and_endi, sizeof(__pyx_k_number_of_starting_time_and_endi), 0, 1, 0, 0},
    {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
    {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
    {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_off_str, __pyx_k_off_str, sizeof(__pyx_k_off_str), 0, 0, 1, 1},
    {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
    {&__pyx_n_u_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 1, 0, 1},
    {&__pyx_n_s_offset_2, __pyx_k_offset_2, sizeof(__pyx_k_offset_2), 0, 0, 1, 1},
    {&__pyx_n_u_offset_2, __pyx_k_offset_2, sizeof(__pyx_k_offset_2), 0, 1, 0, 1},
    {&__pyx_kp_u_offset_3, __pyx_k_offset_3, sizeof(__pyx_k_offset_3), 0, 1, 0, 0},
    {&__pyx_n_s_offset_map, __pyx_k_offset_map, sizeof(__pyx_k_offset_map), 0, 0, 1, 1},
    {&__pyx_n_s_offset_str, __pyx_k_offset_str, sizeof(__pyx_k_offset_str), 0, 0, 1, 1},
    {&__pyx_n_s_offset_str_locals_get_str, __pyx_k_offset_str_locals_get_str, sizeof(__pyx_k_offset_str_locals_get_str), 0, 0, 1, 1},
    {&__pyx_n_s_op, __pyx_k_op, sizeof(__pyx_k_op), 0, 0, 1, 1},
    {&__pyx_n_s_opattern, __pyx_k_opattern, sizeof(__pyx_k_opattern), 0, 0, 1, 1},
    {&__pyx_n_s_other, __pyx_k_other, sizeof(__pyx_k_other), 0, 0, 1, 1},
    {&__pyx_n_s_otherDay, __pyx_k_otherDay, sizeof(__pyx_k_otherDay), 0, 0, 1, 1},
    {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
    {&__pyx_n_s_outputName, __pyx_k_outputName, sizeof(__pyx_k_outputName), 0, 0, 1, 1},
    {&__pyx_n_s_output_name, __pyx_k_output_name, sizeof(__pyx_k_output_name), 0, 0, 1, 1},
    {&__pyx_n_u_output_name, __pyx_k_output_name, sizeof(__pyx_k_output_name), 0, 1, 0, 1},
    {&__pyx_n_s_pandas__libs_properties, __pyx_k_pandas__libs_properties, sizeof(__pyx_k_pandas__libs_properties), 0, 0, 1, 1},
    {&__pyx_n_s_pandas__libs_tslibs_ccalendar, __pyx_k_pandas__libs_tslibs_ccalendar, sizeof(__pyx_k_pandas__libs_tslibs_ccalendar), 0, 0, 1, 1},
    {&__pyx_n_s_pandas__libs_tslibs_offsets, __pyx_k_pandas__libs_tslibs_offsets, sizeof(__pyx_k_pandas__libs_tslibs_offsets), 0, 0, 1, 1},
    {&__pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_k_pandas__libs_tslibs_offsets_pyx, sizeof(__pyx_k_pandas__libs_tslibs_offsets_pyx), 0, 0, 1, 0},
    {&__pyx_n_s_params, __pyx_k_params, sizeof(__pyx_k_params), 0, 0, 1, 1},
    {&__pyx_n_s_params_2, __pyx_k_params_2, sizeof(__pyx_k_params_2), 0, 0, 1, 1},
    {&__pyx_n_s_parse_suffix, __pyx_k_parse_suffix, sizeof(__pyx_k_parse_suffix), 0, 0, 1, 1},
    {&__pyx_kp_u_pass_as_a_string_instead, __pyx_k_pass_as_a_string_instead, sizeof(__pyx_k_pass_as_a_string_instead), 0, 1, 0, 0},
    {&__pyx_n_s_period_dtype_code, __pyx_k_period_dtype_code, sizeof(__pyx_k_period_dtype_code), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
    {&__pyx_n_s_prefix, __pyx_k_prefix, sizeof(__pyx_k_prefix), 0, 0, 1, 1},
    {&__pyx_n_s_prefix_2, __pyx_k_prefix_2, sizeof(__pyx_k_prefix_2), 0, 0, 1, 1},
    {&__pyx_n_s_prefix_mapping, __pyx_k_prefix_mapping, sizeof(__pyx_k_prefix_mapping), 0, 0, 1, 1},
    {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
    {&__pyx_n_s_prev_open, __pyx_k_prev_open, sizeof(__pyx_k_prev_open), 0, 0, 1, 1},
    {&__pyx_n_s_prev_opening_time, __pyx_k_prev_opening_time, sizeof(__pyx_k_prev_opening_time), 0, 0, 1, 1},
    {&__pyx_n_s_prev_year, __pyx_k_prev_year, sizeof(__pyx_k_prev_year), 0, 0, 1, 1},
    {&__pyx_n_s_prev_year_end, __pyx_k_prev_year_end, sizeof(__pyx_k_prev_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_BaseOffset, __pyx_k_pyx_unpickle_BaseOffset, sizeof(__pyx_k_pyx_unpickle_BaseOffset), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_RelativeDeltaOffs, __pyx_k_pyx_unpickle_RelativeDeltaOffs, sizeof(__pyx_k_pyx_unpickle_RelativeDeltaOffs), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_qlen, __pyx_k_qlen, sizeof(__pyx_k_qlen), 0, 0, 1, 1},
    {&__pyx_n_s_qtr_len, __pyx_k_qtr_len, sizeof(__pyx_k_qtr_len), 0, 0, 1, 1},
    {&__pyx_n_s_qtr_lens, __pyx_k_qtr_lens, sizeof(__pyx_k_qtr_lens), 0, 0, 1, 1},
    {&__pyx_n_s_qtr_with_extra_week, __pyx_k_qtr_with_extra_week, sizeof(__pyx_k_qtr_with_extra_week), 0, 0, 1, 1},
    {&__pyx_n_u_qtr_with_extra_week, __pyx_k_qtr_with_extra_week, sizeof(__pyx_k_qtr_with_extra_week), 0, 1, 0, 1},
    {&__pyx_n_s_qtrs, __pyx_k_qtrs, sizeof(__pyx_k_qtrs), 0, 0, 1, 1},
    {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
    {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce___locals_genexpr, __pyx_k_reduce___locals_genexpr, sizeof(__pyx_k_reduce___locals_genexpr), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_relativedelta, __pyx_k_relativedelta, sizeof(__pyx_k_relativedelta), 0, 0, 1, 1},
    {&__pyx_n_s_relativedelta_fast, __pyx_k_relativedelta_fast, sizeof(__pyx_k_relativedelta_fast), 0, 0, 1, 1},
    {&__pyx_n_s_relativedelta_kwds, __pyx_k_relativedelta_kwds, sizeof(__pyx_k_relativedelta_kwds), 0, 0, 1, 1},
    {&__pyx_n_s_rem_nano, __pyx_k_rem_nano, sizeof(__pyx_k_rem_nano), 0, 0, 1, 1},
    {&__pyx_n_s_remain, __pyx_k_remain, sizeof(__pyx_k_remain), 0, 0, 1, 1},
    {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
    {&__pyx_n_s_repr_attrs, __pyx_k_repr_attrs, sizeof(__pyx_k_repr_attrs), 0, 0, 1, 1},
    {&__pyx_n_s_repr_attrs_locals_genexpr, __pyx_k_repr_attrs_locals_genexpr, sizeof(__pyx_k_repr_attrs_locals_genexpr), 0, 0, 1, 1},
    {&__pyx_kp_u_requires_a_suffix, __pyx_k_requires_a_suffix, sizeof(__pyx_k_requires_a_suffix), 0, 1, 0, 0},
    {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
    {&__pyx_n_s_res_val, __pyx_k_res_val, sizeof(__pyx_k_res_val), 0, 0, 1, 1},
    {&__pyx_n_s_reso, __pyx_k_reso, sizeof(__pyx_k_reso), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_result2, __pyx_k_result2, sizeof(__pyx_k_result2), 0, 0, 1, 1},
    {&__pyx_n_s_ret, __pyx_k_ret, sizeof(__pyx_k_ret), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_reversed, __pyx_k_reversed, sizeof(__pyx_k_reversed), 0, 0, 1, 1},
    {&__pyx_n_s_roll, __pyx_k_roll, sizeof(__pyx_k_roll), 0, 0, 1, 1},
    {&__pyx_n_s_roll_convention, __pyx_k_roll_convention, sizeof(__pyx_k_roll_convention), 0, 0, 1, 1},
    {&__pyx_n_s_roll_func, __pyx_k_roll_func, sizeof(__pyx_k_roll_func), 0, 0, 1, 1},
    {&__pyx_n_s_roll_qtrday, __pyx_k_roll_qtrday, sizeof(__pyx_k_roll_qtrday), 0, 0, 1, 1},
    {&__pyx_n_s_rollback, __pyx_k_rollback, sizeof(__pyx_k_rollback), 0, 0, 1, 1},
    {&__pyx_n_s_rollback_to_year, __pyx_k_rollback_to_year, sizeof(__pyx_k_rollback_to_year), 0, 0, 1, 1},
    {&__pyx_n_s_rollforward, __pyx_k_rollforward, sizeof(__pyx_k_rollforward), 0, 0, 1, 1},
    {&__pyx_n_s_rtruediv, __pyx_k_rtruediv, sizeof(__pyx_k_rtruediv), 0, 0, 1, 1},
    {&__pyx_n_s_rule_code, __pyx_k_rule_code, sizeof(__pyx_k_rule_code), 0, 0, 1, 1},
    {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
    {&__pyx_n_u_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 1, 0, 1},
    {&__pyx_n_s_second, __pyx_k_second, sizeof(__pyx_k_second), 0, 0, 1, 1},
    {&__pyx_n_u_second, __pyx_k_second, sizeof(__pyx_k_second), 0, 1, 0, 1},
    {&__pyx_n_s_seconds, __pyx_k_seconds, sizeof(__pyx_k_seconds), 0, 0, 1, 1},
    {&__pyx_n_u_seconds, __pyx_k_seconds, sizeof(__pyx_k_seconds), 0, 1, 0, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
    {&__pyx_kp_u_separator_must_be_spaces, __pyx_k_separator_must_be_spaces, sizeof(__pyx_k_separator_must_be_spaces), 0, 1, 0, 0},
    {&__pyx_n_s_set_name, __pyx_k_set_name, sizeof(__pyx_k_set_name), 0, 0, 1, 1},
    {&__pyx_n_s_setattr, __pyx_k_setattr, sizeof(__pyx_k_setattr), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_shift_days, __pyx_k_shift_days, sizeof(__pyx_k_shift_days), 0, 0, 1, 1},
    {&__pyx_n_s_shift_month, __pyx_k_shift_month, sizeof(__pyx_k_shift_month), 0, 0, 1, 1},
    {&__pyx_n_s_shift_months, __pyx_k_shift_months, sizeof(__pyx_k_shift_months), 0, 0, 1, 1},
    {&__pyx_n_s_shifted, __pyx_k_shifted, sizeof(__pyx_k_shifted), 0, 0, 1, 1},
    {&__pyx_n_s_sign, __pyx_k_sign, sizeof(__pyx_k_sign), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_s_skip_bd, __pyx_k_skip_bd, sizeof(__pyx_k_skip_bd), 0, 0, 1, 1},
    {&__pyx_n_s_span, __pyx_k_span, sizeof(__pyx_k_span), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_st, __pyx_k_st, sizeof(__pyx_k_st), 0, 0, 1, 1},
    {&__pyx_n_s_stamp, __pyx_k_stamp, sizeof(__pyx_k_stamp), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_u_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 1, 0, 1},
    {&__pyx_n_s_startingMonth, __pyx_k_startingMonth, sizeof(__pyx_k_startingMonth), 0, 0, 1, 1},
    {&__pyx_n_u_startingMonth, __pyx_k_startingMonth, sizeof(__pyx_k_startingMonth), 0, 1, 0, 1},
    {&__pyx_n_s_startingMonth_code, __pyx_k_startingMonth_code, sizeof(__pyx_k_startingMonth_code), 0, 0, 1, 1},
    {&__pyx_n_s_startswith, __pyx_k_startswith, sizeof(__pyx_k_startswith), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_staticmethod, __pyx_k_staticmethod, sizeof(__pyx_k_staticmethod), 0, 0, 1, 1},
    {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_strptime, __pyx_k_strptime, sizeof(__pyx_k_strptime), 0, 0, 1, 1},
    {&__pyx_n_s_subclasscheck, __pyx_k_subclasscheck, sizeof(__pyx_k_subclasscheck), 0, 0, 1, 1},
    {&__pyx_n_s_suffix, __pyx_k_suffix, sizeof(__pyx_k_suffix), 0, 0, 1, 1},
    {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
    {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
    {&__pyx_n_s_target_date, __pyx_k_target_date, sizeof(__pyx_k_target_date), 0, 0, 1, 1},
    {&__pyx_n_s_td, __pyx_k_td, sizeof(__pyx_k_td), 0, 0, 1, 1},
    {&__pyx_n_s_td64, __pyx_k_td64, sizeof(__pyx_k_td64), 0, 0, 1, 1},
    {&__pyx_n_s_td64_unit, __pyx_k_td64_unit, sizeof(__pyx_k_td64_unit), 0, 0, 1, 1},
    {&__pyx_n_s_td_nano, __pyx_k_td_nano, sizeof(__pyx_k_td_nano), 0, 0, 1, 1},
    {&__pyx_n_s_tdelta, __pyx_k_tdelta, sizeof(__pyx_k_tdelta), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_kp_u_the_add_operation_between, __pyx_k_the_add_operation_between, sizeof(__pyx_k_the_add_operation_between), 0, 1, 0, 0},
    {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
    {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
    {&__pyx_kp_u_time_data_must_be_specified_only, __pyx_k_time_data_must_be_specified_only, sizeof(__pyx_k_time_data_must_be_specified_only), 0, 1, 0, 0},
    {&__pyx_kp_u_time_data_must_be_string_or_date, __pyx_k_time_data_must_be_string_or_date, sizeof(__pyx_k_time_data_must_be_string_or_date), 0, 1, 0, 0},
    {&__pyx_kp_u_time_data_must_match_H_M_format, __pyx_k_time_data_must_match_H_M_format, sizeof(__pyx_k_time_data_must_match_H_M_format), 0, 1, 0, 0},
    {&__pyx_n_s_timedelta, __pyx_k_timedelta, sizeof(__pyx_k_timedelta), 0, 0, 1, 1},
    {&__pyx_n_s_timedelta64, __pyx_k_timedelta64, sizeof(__pyx_k_timedelta64), 0, 0, 1, 1},
    {&__pyx_n_s_timedelta_kwds, __pyx_k_timedelta_kwds, sizeof(__pyx_k_timedelta_kwds), 0, 0, 1, 1},
    {&__pyx_n_s_timedeltas, __pyx_k_timedeltas, sizeof(__pyx_k_timedeltas), 0, 0, 1, 1},
    {&__pyx_n_s_timestamps, __pyx_k_timestamps, sizeof(__pyx_k_timestamps), 0, 0, 1, 1},
    {&__pyx_n_s_tm_hour, __pyx_k_tm_hour, sizeof(__pyx_k_tm_hour), 0, 0, 1, 1},
    {&__pyx_n_s_tm_min, __pyx_k_tm_min, sizeof(__pyx_k_tm_min), 0, 0, 1, 1},
    {&__pyx_kp_u_to, __pyx_k_to, sizeof(__pyx_k_to), 0, 1, 0, 0},
    {&__pyx_n_s_to_day, __pyx_k_to_day, sizeof(__pyx_k_to_day), 0, 0, 1, 1},
    {&__pyx_n_s_to_offset, __pyx_k_to_offset, sizeof(__pyx_k_to_offset), 0, 0, 1, 1},
    {&__pyx_kp_u_to_offset_does_not_support_tuple, __pyx_k_to_offset_does_not_support_tuple, sizeof(__pyx_k_to_offset_does_not_support_tuple), 0, 1, 0, 0},
    {&__pyx_kp_u_to_offset_line_4102, __pyx_k_to_offset_line_4102, sizeof(__pyx_k_to_offset_line_4102), 0, 1, 0, 0},
    {&__pyx_n_s_to_pydatetime, __pyx_k_to_pydatetime, sizeof(__pyx_k_to_pydatetime), 0, 0, 1, 1},
    {&__pyx_n_s_to_pytimedelta, __pyx_k_to_pytimedelta, sizeof(__pyx_k_to_pytimedelta), 0, 0, 1, 1},
    {&__pyx_n_s_tolist, __pyx_k_tolist, sizeof(__pyx_k_tolist), 0, 0, 1, 1},
    {&__pyx_n_s_total_seconds, __pyx_k_total_seconds, sizeof(__pyx_k_total_seconds), 0, 0, 1, 1},
    {&__pyx_n_s_truediv, __pyx_k_truediv, sizeof(__pyx_k_truediv), 0, 0, 1, 1},
    {&__pyx_n_s_ts, __pyx_k_ts, sizeof(__pyx_k_ts), 0, 0, 1, 1},
    {&__pyx_n_s_tup, __pyx_k_tup, sizeof(__pyx_k_tup), 0, 0, 1, 1},
    {&__pyx_n_s_tz, __pyx_k_tz, sizeof(__pyx_k_tz), 0, 0, 1, 1},
    {&__pyx_n_s_tz_localize, __pyx_k_tz_localize, sizeof(__pyx_k_tz_localize), 0, 0, 1, 1},
    {&__pyx_n_s_tzinfo, __pyx_k_tzinfo, sizeof(__pyx_k_tzinfo), 0, 0, 1, 1},
    {&__pyx_n_u_tzinfo, __pyx_k_tzinfo, sizeof(__pyx_k_tzinfo), 0, 1, 0, 1},
    {&__pyx_n_u_undefined, __pyx_k_undefined, sizeof(__pyx_k_undefined), 0, 1, 0, 1},
    {&__pyx_n_s_unit, __pyx_k_unit, sizeof(__pyx_k_unit), 0, 0, 1, 1},
    {&__pyx_n_s_until, __pyx_k_until, sizeof(__pyx_k_until), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
    {&__pyx_n_u_us, __pyx_k_us, sizeof(__pyx_k_us), 0, 1, 0, 1},
    {&__pyx_n_s_use_relativedelta, __pyx_k_use_relativedelta, sizeof(__pyx_k_use_relativedelta), 0, 0, 1, 1},
    {&__pyx_n_u_use_relativedelta, __pyx_k_use_relativedelta, sizeof(__pyx_k_use_relativedelta), 0, 1, 0, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
    {&__pyx_n_s_validate_n, __pyx_k_validate_n, sizeof(__pyx_k_validate_n), 0, 0, 1, 1},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_n_s_value_2, __pyx_k_value_2, sizeof(__pyx_k_value_2), 0, 0, 1, 1},
    {&__pyx_n_s_variation, __pyx_k_variation, sizeof(__pyx_k_variation), 0, 0, 1, 1},
    {&__pyx_n_u_variation, __pyx_k_variation, sizeof(__pyx_k_variation), 0, 1, 0, 1},
    {&__pyx_n_s_varion_code, __pyx_k_varion_code, sizeof(__pyx_k_varion_code), 0, 0, 1, 1},
    {&__pyx_n_s_vectorized, __pyx_k_vectorized, sizeof(__pyx_k_vectorized), 0, 0, 1, 1},
    {&__pyx_n_s_view, __pyx_k_view, sizeof(__pyx_k_view), 0, 0, 1, 1},
    {&__pyx_n_s_wday, __pyx_k_wday, sizeof(__pyx_k_wday), 0, 0, 1, 1},
    {&__pyx_n_s_week, __pyx_k_week, sizeof(__pyx_k_week), 0, 0, 1, 1},
    {&__pyx_n_u_week, __pyx_k_week, sizeof(__pyx_k_week), 0, 1, 0, 1},
    {&__pyx_n_s_weekday, __pyx_k_weekday, sizeof(__pyx_k_weekday), 0, 0, 1, 1},
    {&__pyx_n_u_weekday, __pyx_k_weekday, sizeof(__pyx_k_weekday), 0, 1, 0, 1},
    {&__pyx_n_s_weekday_code, __pyx_k_weekday_code, sizeof(__pyx_k_weekday_code), 0, 0, 1, 1},
    {&__pyx_n_s_weekday_to_int, __pyx_k_weekday_to_int, sizeof(__pyx_k_weekday_to_int), 0, 0, 1, 1},
    {&__pyx_n_s_weekmask, __pyx_k_weekmask, sizeof(__pyx_k_weekmask), 0, 0, 1, 1},
    {&__pyx_n_u_weekmask, __pyx_k_weekmask, sizeof(__pyx_k_weekmask), 0, 1, 0, 1},
    {&__pyx_n_s_weeks, __pyx_k_weeks, sizeof(__pyx_k_weeks), 0, 0, 1, 1},
    {&__pyx_n_u_weeks, __pyx_k_weeks, sizeof(__pyx_k_weeks), 0, 1, 0, 1},
    {&__pyx_n_s_weeks_in_year, __pyx_k_weeks_in_year, sizeof(__pyx_k_weeks_in_year), 0, 0, 1, 1},
    {&__pyx_kp_u_will_overflow, __pyx_k_will_overflow, sizeof(__pyx_k_will_overflow), 0, 1, 0, 0},
    {&__pyx_n_s_wkday_diff, __pyx_k_wkday_diff, sizeof(__pyx_k_wkday_diff), 0, 0, 1, 1},
    {&__pyx_n_s_wrapper, __pyx_k_wrapper, sizeof(__pyx_k_wrapper), 0, 0, 1, 1},
    {&__pyx_n_s_year, __pyx_k_year, sizeof(__pyx_k_year), 0, 0, 1, 1},
    {&__pyx_n_u_year, __pyx_k_year, sizeof(__pyx_k_year), 0, 1, 0, 1},
    {&__pyx_n_s_year_end, __pyx_k_year_end, sizeof(__pyx_k_year_end), 0, 0, 1, 1},
    {&__pyx_n_s_year_has_extra_week, __pyx_k_year_has_extra_week, sizeof(__pyx_k_year_has_extra_week), 0, 0, 1, 1},
    {&__pyx_n_s_years, __pyx_k_years, sizeof(__pyx_k_years), 0, 0, 1, 1},
    {&__pyx_n_u_years, __pyx_k_years, sizeof(__pyx_k_years), 0, 1, 0, 1},
    {&__pyx_n_s_zero, __pyx_k_zero, sizeof(__pyx_k_zero), 0, 0, 1, 1},
    {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 358, __pyx_L1_error)
  __pyx_builtin_staticmethod = __Pyx_GetBuiltinName(__pyx_n_s_staticmethod); if (!__pyx_builtin_staticmethod) __PYX_ERR(0, 733, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 242, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 283, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(0, 310, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 484, __pyx_L1_error)
  __pyx_builtin_NotImplemented = __Pyx_GetBuiltinName(__pyx_n_s_NotImplemented); if (!__pyx_builtin_NotImplemented) __PYX_ERR(0, 490, __pyx_L1_error)
  __pyx_builtin_OverflowError = __Pyx_GetBuiltinName(__pyx_n_s_OverflowError); if (!__pyx_builtin_OverflowError) __PYX_ERR(0, 1057, __pyx_L1_error)
  __pyx_builtin_AssertionError = __Pyx_GetBuiltinName(__pyx_n_s_AssertionError); if (!__pyx_builtin_AssertionError) __PYX_ERR(0, 1205, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 1232, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(0, 1823, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) __PYX_ERR(0, 1827, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 1857, __pyx_L1_error)
  __pyx_builtin_reversed = __Pyx_GetBuiltinName(__pyx_n_s_reversed); if (!__pyx_builtin_reversed) __PYX_ERR(0, 1941, __pyx_L1_error)
  __pyx_builtin_sum = __Pyx_GetBuiltinName(__pyx_n_s_sum); if (!__pyx_builtin_sum) __PYX_ERR(0, 2022, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(0, 4093, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(1, 984, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(2, 308, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":984
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple_)) __PYX_ERR(1, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":990
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(1, 990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "cpython/datetime.pxd":308
 * cdef inline object timezone_new(object offset, object name=None):
 *     if PY_VERSION_HEX < 0x030700b1:
 *         raise RuntimeError('Time zones are not available from the C-API.')             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_Time_zones_are_not_available_fro); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(2, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "pandas/_libs/tslibs/offsets.pyx":124
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 *     def wrapper(self, other) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         # other is a DatetimeArray
 *         result = apply_wrapper_core(func, self, other)
 */
  __pyx_tuple__5 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_result); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__5, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_wrapper, 124, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 124, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":139
 *     # not play nicely with cython class methods
 * 
 *     def wrapper(self, other):             # <<<<<<<<<<<<<<
 * 
 *         if other is NaT:
 */
  __pyx_tuple__7 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_tz, __pyx_n_s_nano, __pyx_n_s_result, __pyx_n_s_result2, __pyx_n_s_res, __pyx_n_s_value_2); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);
  __pyx_codeobj__8 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__7, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_wrapper, 139, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__8)) __PYX_ERR(0, 139, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":284
 *             return dt_time(hour=t.tm_hour, minute=t.tm_min)
 *         except ValueError:
 *             raise ValueError("time data must match '%H:%M' format")             # <<<<<<<<<<<<<<
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_time_data_must_match_H_M_format); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "pandas/_libs/tslibs/offsets.pyx":287
 *     elif isinstance(t_input, dt_time):
 *         if t_input.second != 0 or t_input.microsecond != 0:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "time data must be specified only with hour and minute")
 *         return t_input
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_time_data_must_be_specified_only); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "pandas/_libs/tslibs/offsets.pyx":291
 *         return t_input
 *     else:
 *         raise ValueError("time data must be string or datetime.time")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_time_data_must_be_string_or_date); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "pandas/_libs/tslibs/offsets.pyx":310
 * 
 *     if "millisecond" in kwds:
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             "Using DateOffset to replace `millisecond` component in "
 *             "datetime object is not supported. Use "
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Using_DateOffset_to_replace_mill); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "pandas/_libs/tslibs/offsets.pyx":497
 *     def __sub__(self, other):
 *         if PyDateTime_Check(other):
 *             raise TypeError("Cannot subtract datetime from offset.")             # <<<<<<<<<<<<<<
 *         elif type(other) == type(self):
 *             return type(self)(self.n - other.n, normalize=self.normalize,
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Cannot_subtract_datetime_from_of); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "pandas/_libs/tslibs/offsets.pyx":601
 *     @property
 *     def _prefix(self) -> str:
 *         raise NotImplementedError("Prefix not defined")             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_u_Prefix_not_defined); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "pandas/_libs/tslibs/offsets.pyx":651
 * 
 *     def _apply(self, other):
 *         raise NotImplementedError("implemented by subclasses")             # <<<<<<<<<<<<<<
 * 
 *     @apply_array_wraps
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_u_implemented_by_subclasses); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "pandas/_libs/tslibs/offsets.pyx":671
 *         dt = Timestamp(dt)
 *         if not self.is_on_offset(dt):
 *             dt = dt - type(self)(1, normalize=self.normalize, **self.kwds)             # <<<<<<<<<<<<<<
 *         return dt
 * 
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "pandas/_libs/tslibs/offsets.pyx":782
 *         state.pop("calendar", None)
 *         if "kwds" in state:
 *             state["kwds"].pop("calendar", None)             # <<<<<<<<<<<<<<
 * 
 *         return state
 */
  __pyx_tuple__25 = PyTuple_Pack(2, __pyx_n_u_calendar, Py_None); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "pandas/_libs/tslibs/offsets.pyx":922
 *         if normalize:
 *             # GH#21427
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "Tick offset with `normalize=True` are not allowed."
 *             )
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u_Tick_offset_with_normalize_True); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "pandas/_libs/tslibs/offsets.pyx":941
 *         if type(self) is Micro:
 *             return Nano(self.n * 1000)
 *         raise ValueError("Could not convert to integer offset at any resolution")             # <<<<<<<<<<<<<<
 * 
 *     # --------------------------------------------------------------------
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_Could_not_convert_to_integer_off); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "pandas/_libs/tslibs/offsets.pyx":1205
 *             # Older (<0.22.0) versions have offset attribute instead of _offset
 *             if "_offset" in state:  # pragma: no cover
 *                 raise AssertionError("Unexpected key `_offset`")             # <<<<<<<<<<<<<<
 *             state["_offset"] = state.pop("offset")
 *             state["kwds"]["offset"] = state["_offset"]
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_u_Unexpected_key__offset); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(0, 1205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "pandas/_libs/tslibs/offsets.pyx":1264
 *         if self._use_relativedelta and set(kwds).issubset(relativedelta_fast):
 * 
 *             months = (kwds.get("years", 0) * 12 + kwds.get("months", 0)) * self.n             # <<<<<<<<<<<<<<
 *             if months:
 *                 shifted = shift_months(dt64other.view("i8"), months, reso=reso)
 */
  __pyx_tuple__29 = PyTuple_Pack(2, __pyx_n_u_years, __pyx_int_0); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_tuple__30 = PyTuple_Pack(2, __pyx_n_u_months, __pyx_int_0); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "pandas/_libs/tslibs/offsets.pyx":1269
 *                 dt64other = shifted.view(dtarr.dtype)
 * 
 *             weeks = kwds.get("weeks", 0) * self.n             # <<<<<<<<<<<<<<
 *             if weeks:
 *                 delta = Timedelta(days=7 * weeks)
 */
  __pyx_tuple__31 = PyTuple_Pack(2, __pyx_n_u_weeks, __pyx_int_0); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "pandas/_libs/tslibs/offsets.pyx":1432
 *     """
 *     def __setattr__(self, name, value):
 *         raise AttributeError("DateOffset objects are immutable.")             # <<<<<<<<<<<<<<
 * 
 * # --------------------------------------------------------------------
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_u_DateOffset_objects_are_immutable); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "pandas/_libs/tslibs/offsets.pyx":1547
 * 
 *     def _offset_str(self) -> str:
 *         def get_str(td):             # <<<<<<<<<<<<<<
 *             off_str = ""
 *             if td.days > 0:
 */
  __pyx_tuple__34 = PyTuple_Pack(5, __pyx_n_s_td, __pyx_n_s_off_str, __pyx_n_s_s, __pyx_n_s_hrs, __pyx_n_s_mts); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 1547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_str, 1547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 1547, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1568
 * 
 *         if PyDelta_Check(self.offset):
 *             zero = timedelta(0, 0, 0)             # <<<<<<<<<<<<<<
 *             if self.offset >= zero:
 *                 off_str = "+" + get_str(self.offset)
 */
  __pyx_tuple__36 = PyTuple_Pack(3, __pyx_int_0, __pyx_int_0, __pyx_int_0); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 1568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "pandas/_libs/tslibs/offsets.pyx":1771
 *             start = [start]
 *         if not len(start):
 *             raise ValueError("Must include at least 1 start time")             # <<<<<<<<<<<<<<
 * 
 *         if np.ndim(end) == 0:
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_u_Must_include_at_least_1_start_ti); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 1771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "pandas/_libs/tslibs/offsets.pyx":1777
 *             end = [end]
 *         if not len(end):
 *             raise ValueError("Must include at least 1 end time")             # <<<<<<<<<<<<<<
 * 
 *         start = np.array([_validate_business_time(x) for x in start])
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_kp_u_Must_include_at_least_1_end_time); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(0, 1777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "pandas/_libs/tslibs/offsets.pyx":1784
 *         # Validation of input
 *         if len(start) != len(end):
 *             raise ValueError("number of starting time and ending time must be the same")             # <<<<<<<<<<<<<<
 *         num_openings = len(start)
 * 
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_kp_u_number_of_starting_time_and_endi); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 1784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "pandas/_libs/tslibs/offsets.pyx":1801
 *             )
 *         if total_secs != 24 * 60 * 60:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "invalid starting and ending time(s): "
 *                 "opening hours should not touch or overlap with "
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_kp_u_invalid_starting_and_ending_time); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 1801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "pandas/_libs/tslibs/offsets.pyx":1819
 * 
 *         state.pop("kwds", {})
 *         state.pop("next_bday", None)             # <<<<<<<<<<<<<<
 *         BusinessMixin.__setstate__(self, state)
 * 
 */
  __pyx_tuple__45 = PyTuple_Pack(2, __pyx_n_u_next_bday, Py_None); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 1819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "pandas/_libs/tslibs/offsets.pyx":2055
 * 
 *         if n >= 0:
 *             while bhour_remain != timedelta(0):             # <<<<<<<<<<<<<<
 *                 # business hour left in this business time interval
 *                 bhour = (
 */
  __pyx_tuple__48 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 2055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "pandas/_libs/tslibs/offsets.pyx":2188
 * 
 *         if month < 1 or month > 12:
 *             raise ValueError("Month must go from 1 to 12")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_kp_u_Month_must_go_from_1_to_12); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "pandas/_libs/tslibs/offsets.pyx":2549
 * 
 *     cpdef __setstate__(self, state):
 *         state.pop("_use_relativedelta", False)             # <<<<<<<<<<<<<<
 *         state.pop("offset", None)
 *         state.pop("_offset", None)
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_n_u_use_relativedelta, Py_False); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 2549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "pandas/_libs/tslibs/offsets.pyx":2550
 *     cpdef __setstate__(self, state):
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)             # <<<<<<<<<<<<<<
 *         state.pop("_offset", None)
 *         state.pop("kwds", {})
 */
  __pyx_tuple__51 = PyTuple_Pack(2, __pyx_n_u_offset_2, Py_None); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(0, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "pandas/_libs/tslibs/offsets.pyx":2551
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 *         state.pop("_offset", None)             # <<<<<<<<<<<<<<
 *         state.pop("kwds", {})
 * 
 */
  __pyx_tuple__52 = PyTuple_Pack(2, __pyx_n_u_offset, Py_None); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "pandas/_libs/tslibs/offsets.pyx":3092
 *         # only one digit weeks (1 --> week 0, 2 --> week 1, etc.)
 *         week = int(suffix[0]) - 1
 *         weekday = weekday_to_int[suffix[1:]]             # <<<<<<<<<<<<<<
 *         return cls(week=week, weekday=weekday)
 * 
 */
  __pyx_slice__53 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__53)) __PYX_ERR(0, 3092, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__53);
  __Pyx_GIVEREF(__pyx_slice__53);

  /* "pandas/_libs/tslibs/offsets.pyx":3131
 * 
 *         if self.n == 0:
 *             raise ValueError("N cannot be 0")             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_kp_u_N_cannot_be_0); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 3131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "pandas/_libs/tslibs/offsets.pyx":3325
 *                 norm.year == prev_year.year
 *                 and norm < prev_year
 *                 and prev_year - norm <= timedelta(6)             # <<<<<<<<<<<<<<
 *             ):
 *                 # GH#14774, error when next_year.year == cur_year.year
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_int_6); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 3325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "pandas/_libs/tslibs/offsets.pyx":4165
 *             if split[-1] != "" and not split[-1].isspace():
 *                 # the last element must be blank
 *                 raise ValueError("last element must be blank")             # <<<<<<<<<<<<<<
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_last_element_must_be_blank); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 4165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "pandas/_libs/tslibs/offsets.pyx":4167
 *                 raise ValueError("last element must be blank")
 * 
 *             tups = zip(split[0::4], split[1::4], split[2::4])             # <<<<<<<<<<<<<<
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():
 */
  __pyx_slice__60 = PySlice_New(__pyx_int_0, Py_None, __pyx_int_4); if (unlikely(!__pyx_slice__60)) __PYX_ERR(0, 4167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__60);
  __Pyx_GIVEREF(__pyx_slice__60);
  __pyx_slice__61 = PySlice_New(__pyx_int_1, Py_None, __pyx_int_4); if (unlikely(!__pyx_slice__61)) __PYX_ERR(0, 4167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__61);
  __Pyx_GIVEREF(__pyx_slice__61);
  __pyx_slice__62 = PySlice_New(__pyx_int_2, Py_None, __pyx_int_4); if (unlikely(!__pyx_slice__62)) __PYX_ERR(0, 4167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__62);
  __Pyx_GIVEREF(__pyx_slice__62);

  /* "pandas/_libs/tslibs/offsets.pyx":4170
 *             for n, (sep, stride, name) in enumerate(tups):
 *                 if sep != "" and not sep.isspace():
 *                     raise ValueError("separator must be spaces")             # <<<<<<<<<<<<<<
 *                 prefix = _lite_rule_alias.get(name) or name
 *                 if stride_sign is None:
 */
  __pyx_tuple__63 = PyTuple_Pack(1, __pyx_kp_u_separator_must_be_spaces); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(0, 4170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "pandas/_libs/tslibs/offsets.pyx":4281
 *     """
 *     if day_opt not in ["start", "end", "business_start", "business_end"]:
 *         raise ValueError("day must be None, 'start', 'end', "             # <<<<<<<<<<<<<<
 *                          "'business_start', or 'business_end'")
 * 
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_u_day_must_be_None_start_end_busin); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 4281, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xa31c5ed, 0xcbadb40, 0x0a5792c):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xa31c5ed, 0xcbadb40, 0x0a5792c) = (_cache, n, normalize))" % __pyx_checksum
 */
  __pyx_tuple__66 = PyTuple_Pack(3, __pyx_int_171034093, __pyx_int_213572416, __pyx_int_10844460); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(5, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "pandas/_libs/tslibs/offsets.pyx":108
 * 
 * 
 * def apply_wrapper_core(func, self, other) -> ndarray:             # <<<<<<<<<<<<<<
 *     result = func(self, other)
 *     result = np.asarray(result)
 */
  __pyx_tuple__68 = PyTuple_Pack(6, __pyx_n_s_func, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_result, __pyx_n_s_normalize_i8_timestamps, __pyx_n_s_reso); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__68, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_wrapper_core, 108, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(0, 108, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
  __pyx_tuple__70 = PyTuple_Pack(3, __pyx_n_s_func, __pyx_n_s_wrapper, __pyx_n_s_wrapper); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);
  __pyx_codeobj__71 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__70, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array_wraps, 121, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__71)) __PYX_ERR(0, 121, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__70, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_wraps, 135, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) __PYX_ERR(0, 135, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":358
 * 
 * 
 * class ApplyTypeError(TypeError):             # <<<<<<<<<<<<<<
 *     # sentinel class for catching the apply error to return NotImplemented
 *     pass
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_builtin_TypeError); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_tuple__74 = PyTuple_Pack(1, __pyx_builtin_TypeError); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "pandas/_libs/tslibs/offsets.pyx":425
 *         return hash(self._params)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _params(self):
 *         """
 */
  __pyx_tuple__75 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_d, __pyx_n_s_all_paras, __pyx_n_s_attr, __pyx_n_s_exclude, __pyx_n_s_attrs, __pyx_n_s_params_2, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__75, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_params, 425, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) __PYX_ERR(0, 425, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":532
 *         return self * -1
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_copy, 532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) __PYX_ERR(0, 532, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":567
 *         return out
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 */
  __pyx_tuple__79 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_exclude, __pyx_n_s_attrs, __pyx_n_s_attr, __pyx_n_s_value_2, __pyx_n_s_out); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__79, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_repr_attrs, 567, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) __PYX_ERR(0, 567, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":607
 *         return self._prefix
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def freqstr(self) -> str:
 *         """
 */
  __pyx_tuple__81 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_code, __pyx_n_s_fstr); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);
  __pyx_codeobj__82 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__81, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_freqstr, 607, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__82)) __PYX_ERR(0, 607, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":645
 *         return fstr
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_codeobj__83 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_offset_str, 645, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__83)) __PYX_ERR(0, 645, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":650
 *     # ------------------------------------------------------------------
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("implemented by subclasses")
 * 
 */
  __pyx_tuple__84 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_other); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);
  __pyx_codeobj__85 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 650, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__85)) __PYX_ERR(0, 650, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":653
 *         raise NotImplementedError("implemented by subclasses")
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(
 */
  __pyx_tuple__86 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_dtarr); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);
  __pyx_codeobj__87 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__86, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__87)) __PYX_ERR(0, 653, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":660
 *         )
 * 
 *     def rollback(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date backward to next offset only if not on offset.
 */
  __pyx_tuple__88 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__88)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__88);
  __Pyx_GIVEREF(__pyx_tuple__88);
  __pyx_codeobj__89 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_rollback, 660, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__89)) __PYX_ERR(0, 660, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":674
 *         return dt
 * 
 *     def rollforward(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date forward to next offset only if not on offset.
 */
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_rollforward, 674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) __PYX_ERR(0, 674, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":688
 *         return dt
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # subclass must implement `_day_opt`; calling from the base class
 *         # will implicitly assume day_opt = "business_end", see get_day_of_month.
 */
  __pyx_tuple__91 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_dts); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_offset_day, 688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) __PYX_ERR(0, 688, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":696
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp intersects with this frequency.
 */
  __pyx_tuple__93 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_a, __pyx_n_s_b); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 696, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) __PYX_ERR(0, 696, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":733
 *     # Staticmethod so we can call from Tick.__init__, will be unnecessary
 *     #  once BaseOffset is a cdef class and is inherited by Tick
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _validate_n(n) -> int:
 *         """
 */
  __pyx_tuple__95 = PyTuple_Pack(2, __pyx_n_s_n, __pyx_n_s_nint); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_validate_n, 733, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) __PYX_ERR(0, 733, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":761
 *         return nint
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */
  __pyx_tuple__97 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_state); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 761, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) __PYX_ERR(0, 761, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":770
 *         # At this point we expect state to be empty
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */
  __pyx_codeobj__99 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_getstate, 770, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__99)) __PYX_ERR(0, 770, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":790
 *         raise ValueError(f"{self} is a non-fixed frequency")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         # TODO: Does this make sense for the general case?  It would help
 *         # if there were a canonical docstring for what is_anchored means.
 */
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_anchored, 790, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) __PYX_ERR(0, 790, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":807
 *     # ------------------------------------------------------------------
 * 
 *     def is_month_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month start.
 */
  __pyx_tuple__101 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_ts); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);
  __pyx_codeobj__102 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_month_start, 807, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__102)) __PYX_ERR(0, 807, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":820
 *         return ts._get_start_end_field("is_month_start", self)
 * 
 *     def is_month_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month end.
 */
  __pyx_codeobj__103 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_month_end, 820, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__103)) __PYX_ERR(0, 820, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":833
 *         return ts._get_start_end_field("is_month_end", self)
 * 
 *     def is_quarter_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter start.
 */
  __pyx_codeobj__104 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_quarter_start, 833, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__104)) __PYX_ERR(0, 833, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":846
 *         return ts._get_start_end_field("is_quarter_start", self)
 * 
 *     def is_quarter_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter end.
 */
  __pyx_codeobj__105 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_quarter_end, 846, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__105)) __PYX_ERR(0, 846, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":859
 *         return ts._get_start_end_field("is_quarter_end", self)
 * 
 *     def is_year_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year start.
 */
  __pyx_codeobj__106 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_year_start, 859, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__106)) __PYX_ERR(0, 859, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":872
 *         return ts._get_start_end_field("is_year_start", self)
 * 
 *     def is_year_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year end.
 */
  __pyx_codeobj__107 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__101, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_year_end, 872, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__107)) __PYX_ERR(0, 872, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__108 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);
  __pyx_codeobj__109 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__108, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__109)) __PYX_ERR(5, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)
 */
  __pyx_tuple__110 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);
  __pyx_codeobj__111 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__110, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__111)) __PYX_ERR(5, 16, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":887
 * 
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 */
  __pyx_tuple__112 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_suffix); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);
  __pyx_codeobj__113 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 887, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__113)) __PYX_ERR(0, 887, __pyx_L1_error)
  __pyx_tuple__114 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__114)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__114);
  __Pyx_GIVEREF(__pyx_tuple__114);

  /* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */
  __pyx_tuple__115 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_tup, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);
  __pyx_codeobj__116 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_reduce, 894, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__116)) __PYX_ERR(0, 894, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":928
 *     # Note: Without making this cpdef, we get AttributeError when calling
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):             # <<<<<<<<<<<<<<
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 */
  __pyx_codeobj__117 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_next_higher_resolution, 928, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__117)) __PYX_ERR(0, 928, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":945
 *     # --------------------------------------------------------------------
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         # Since cdef classes have no __dict__, we need to override
 *         return ""
 */
  __pyx_codeobj__118 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_repr_attrs, 945, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__118)) __PYX_ERR(0, 945, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":970
 *         return self.n * self._nanos_inc
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  __pyx_codeobj__119 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 970, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__119)) __PYX_ERR(0, 970, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":973
 *         return True
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
  __pyx_codeobj__120 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_anchored, 973, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__120)) __PYX_ERR(0, 973, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1065
 *         return self.__add__(other)
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):
 */
  __pyx_codeobj__121 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 1065, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__121)) __PYX_ERR(0, 1065, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1084
 *     # Pickle Methods
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state["n"]
 *         self.normalize = False
 */
  __pyx_codeobj__122 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 1084, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__122)) __PYX_ERR(0, 1084, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1145
 * 
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:             # <<<<<<<<<<<<<<
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 */
  __pyx_tuple__123 = PyTuple_Pack(3, __pyx_n_s_delta, __pyx_n_s_seconds, __pyx_n_s_nanos); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_delta_to_tick, 1145, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(0, 1145, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1186
 *             object.__setattr__(self, key, val)
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */
  __pyx_codeobj__125 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_getstate, 1186, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__125)) __PYX_ERR(0, 1186, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1197
 *         return state
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 1197, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(0, 1197, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1215
 *         self.__dict__.update(state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:
 */
  __pyx_tuple__127 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_tzinfo, __pyx_n_s_td_nano, __pyx_n_s_i); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);
  __pyx_codeobj__128 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__127, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 1215, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__128)) __PYX_ERR(0, 1215, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1246
 *             return other + timedelta(self.n)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_tuple__129 = PyTuple_Pack(17, __pyx_n_s_self, __pyx_n_s_dtarr, __pyx_n_s_reso, __pyx_n_s_dt64other, __pyx_n_s_kwds, __pyx_n_s_relativedelta_fast, __pyx_n_s_months, __pyx_n_s_shifted, __pyx_n_s_weeks, __pyx_n_s_delta, __pyx_n_s_td, __pyx_n_s_timedelta_kwds, __pyx_n_s_num_nano, __pyx_n_s_rem_nano, __pyx_n_s_kwd, __pyx_n_s_k, __pyx_n_s_v); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);
  __pyx_codeobj__130 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 17, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__129, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 1246, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__130)) __PYX_ERR(0, 1246, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1304
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 1304, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(0, 1304, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_codeobj__132 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__108, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__132)) __PYX_ERR(5, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)
 */
  __pyx_codeobj__133 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__110, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__133)) __PYX_ERR(5, 16, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1316
 *     """
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __instancecheck__(cls, obj) -> bool:
 *         return isinstance(obj, BaseOffset)
 */
  __pyx_tuple__134 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);
  __pyx_codeobj__135 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__134, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_instancecheck, 1316, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__135)) __PYX_ERR(0, 1316, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1320
 *         return isinstance(obj, BaseOffset)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __subclasscheck__(cls, obj) -> bool:
 *         return issubclass(obj, BaseOffset)
 */
  __pyx_codeobj__136 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__134, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_subclasscheck, 1320, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__136)) __PYX_ERR(0, 1320, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1431
 *     Timestamp('2017-01-01 08:10:11')
 *     """
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         raise AttributeError("DateOffset objects are immutable.")
 * 
 */
  __pyx_tuple__137 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_name_2, __pyx_n_s_value_2); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 1431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__137, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setattr, 1431, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(0, 1431, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1451
 *         self._offset = offset
 * 
 *     cpdef _init_custom(self, weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *         """
 *         Additional __init__ for Custom subclasses.
 */
  __pyx_tuple__139 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_weekmask, __pyx_n_s_holidays, __pyx_n_s_calendar); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);
  __pyx_codeobj__140 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__139, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_init_custom, 1451, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__140)) __PYX_ERR(0, 1451, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1473
 *         return self._offset
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.offset:
 *             attrs = [f"offset={repr(self.offset)}"]
 */
  __pyx_tuple__141 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_attrs, __pyx_n_s_out); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);
  __pyx_codeobj__142 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__141, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_repr_attrs, 1473, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__142)) __PYX_ERR(0, 1473, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1483
 *         return out
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:
 */
  __pyx_codeobj__143 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 1483, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__143)) __PYX_ERR(0, 1483, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1537
 *     _attributes = tuple(["n", "normalize", "offset"])
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__144 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 1537, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__144)) __PYX_ERR(0, 1537, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1546
 *         self._cache = state.pop("_cache", {})
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         def get_str(td):
 *             off_str = ""
 */
  __pyx_tuple__145 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_get_str, __pyx_n_s_get_str, __pyx_n_s_zero, __pyx_n_s_off_str); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);
  __pyx_codeobj__146 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__145, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_offset_str, 1546, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__146)) __PYX_ERR(0, 1546, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1577
 *             return "+" + repr(self.offset)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):
 */
  __pyx_tuple__147 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_n, __pyx_n_s_wday, __pyx_n_s_weeks, __pyx_n_s_days, __pyx_n_s_result, __pyx_n_s_td); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);
  __pyx_codeobj__148 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__147, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 1577, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__148)) __PYX_ERR(0, 1577, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1681
 *         return days
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")
 */
  __pyx_tuple__149 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_dtarr, __pyx_n_s_i8other, __pyx_n_s_reso, __pyx_n_s_res); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);
  __pyx_codeobj__150 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__149, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 1681, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__150)) __PYX_ERR(0, 1681, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1691
 *         return res
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__151 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 1691, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__151)) __PYX_ERR(0, 1691, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1810
 *         self.end = end
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 */
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 1810, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(0, 1810, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1822
 *         BusinessMixin.__setstate__(self, state)
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 */
  __pyx_tuple__153 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_out, __pyx_n_s_hours, __pyx_n_s_attrs, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_repr_attrs, 1822, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(0, 1822, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1833
 *         return out
 * 
 *     def _get_business_hours_by_sec(self, start, end):             # <<<<<<<<<<<<<<
 *         """
 *         Return business hours in a day by seconds.
 */
  __pyx_tuple__155 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_start, __pyx_n_s_end, __pyx_n_s_dtstart, __pyx_n_s_day, __pyx_n_s_until); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);
  __pyx_codeobj__156 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__155, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_business_hours_by_sec, 1833, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__156)) __PYX_ERR(0, 1833, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1843
 *         return int((until - dtstart).total_seconds())
 * 
 *     def _get_closing_time(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Get the closing time of a business hour interval by its opening time.
 */
  __pyx_tuple__157 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_i, __pyx_n_s_st); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 1843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);
  __pyx_codeobj__158 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__157, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_closing_time, 1843, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__158)) __PYX_ERR(0, 1843, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1864
 *         assert False
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def next_bday(self):
 *         """
 */
  __pyx_tuple__159 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_nb_offset); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__159, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_next_bday, 1864, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(0, 1864, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1884
 *             return BusinessDay(n=nb_offset)
 * 
 *     def _next_opening_time(self, other, sign=1):             # <<<<<<<<<<<<<<
 *         """
 *         If self.n and sign have the same sign, return the earliest opening time
 */
  __pyx_tuple__161 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_sign, __pyx_n_s_earliest_start, __pyx_n_s_latest_start, __pyx_n_s_is_same_sign, __pyx_n_s_hour, __pyx_n_s_minute, __pyx_n_s_st); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 1884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__161, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_next_opening_time, 1884, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(0, 1884, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1948
 *         return datetime(other.year, other.month, other.day, hour, minute)
 * 
 *     def _prev_opening_time(self, other: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         If n is positive, return the latest opening time earlier than or equal
 */
  __pyx_codeobj__163 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__84, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_prev_opening_time, 1948, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__163)) __PYX_ERR(0, 1948, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1967
 *         return self._next_opening_time(other, sign=-1)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollback(self, dt: datetime) -> datetime:
 *         """
 */
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_rollback, 1967, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(0, 1967, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1980
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollforward(self, dt: datetime) -> datetime:
 *         """
 */
  __pyx_codeobj__165 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_rollforward, 1980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__165)) __PYX_ERR(0, 1980, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */
  __pyx_tuple__166 = PyTuple_Pack(14, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_nanosecond, __pyx_n_s_n, __pyx_n_s_businesshours, __pyx_n_s_bd, __pyx_n_s_r, __pyx_n_s_skip_bd, __pyx_n_s_prev_open, __pyx_n_s_remain, __pyx_n_s_bhour_remain, __pyx_n_s_bhour, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__166)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__166);
  __Pyx_GIVEREF(__pyx_tuple__166);
  __pyx_codeobj__167 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 14, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__166, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 1992, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__167)) __PYX_ERR(0, 1992, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2091
 *         return other
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__168 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2091, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__168)) __PYX_ERR(0, 2091, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2103
 *         return self._is_on_offset(dt)
 * 
 *     def _is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Slight speedups using calculated values.
 */
  __pyx_tuple__169 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_op, __pyx_n_s_span, __pyx_n_s_businesshours, __pyx_n_s_i, __pyx_n_s_st); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);
  __pyx_codeobj__170 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset_2, 2103, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__170)) __PYX_ERR(0, 2103, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2141
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */
  __pyx_tuple__171 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_compare_day, __pyx_n_s_months, __pyx_n_s_shifted, __pyx_n_s_to_day); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);
  __pyx_codeobj__172 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__171, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2141, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__172)) __PYX_ERR(0, 2141, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2152
 *         return _shift_day(shifted, to_day - shifted.day)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__173 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__173)) __PYX_ERR(0, 2152, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2190
 *             raise ValueError("Month must go from 1 to 12")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")
 */
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 2190, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(0, 2190, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2196
 *         self._cache = {}
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */
  __pyx_tuple__175 = PyTuple_Pack(3, __pyx_n_s_cls, __pyx_n_s_suffix, __pyx_n_s_kwargs); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 2196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(0, 2196, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2208
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__177 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__177)) __PYX_ERR(0, 2208, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2213
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # override BaseOffset method to use self.month instead of other.month
 *         cdef:
 */
  __pyx_codeobj__178 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_offset_day, 2213, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__178)) __PYX_ERR(0, 2213, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2221
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 */
  __pyx_tuple__179 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_years, __pyx_n_s_months); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);
  __pyx_codeobj__180 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__179, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__180)) __PYX_ERR(0, 2221, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2227
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_tuple__181 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_dtarr, __pyx_n_s_reso, __pyx_n_s_shifted); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);
  __pyx_codeobj__182 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 2227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__182)) __PYX_ERR(0, 2227, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2366
 *         self.startingMonth = startingMonth
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")
 */
  __pyx_codeobj__183 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 2366, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__183)) __PYX_ERR(0, 2366, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2371
 *         self.normalize = state.pop("normalize")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */
  __pyx_codeobj__184 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 2371, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__184)) __PYX_ERR(0, 2371, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2386
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.startingMonth is not None
 * 
 */
  __pyx_codeobj__185 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_anchored, 2386, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__185)) __PYX_ERR(0, 2386, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2389
 *         return self.n == 1 and self.startingMonth is not None
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_tuple__186 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_mod_month); if (unlikely(!__pyx_tuple__186)) __PYX_ERR(0, 2389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__186);
  __Pyx_GIVEREF(__pyx_tuple__186);
  __pyx_codeobj__187 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__186, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2389, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__187)) __PYX_ERR(0, 2389, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2395
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # months_since: find the calendar quarter containing other.month,
 */
  __pyx_tuple__188 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_months_since, __pyx_n_s_qtrs, __pyx_n_s_months); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);
  __pyx_codeobj__189 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2395, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__189)) __PYX_ERR(0, 2395, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2409
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_codeobj__190 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 2409, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__190)) __PYX_ERR(0, 2409, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2531
 * 
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__191 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2531, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__191)) __PYX_ERR(0, 2531, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2536
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */
  __pyx_tuple__192 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_compare_day, __pyx_n_s_n); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);
  __pyx_codeobj__193 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__193)) __PYX_ERR(0, 2536, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2542
 *         return shift_month(other, n, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_codeobj__194 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 2542, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__194)) __PYX_ERR(0, 2542, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2548
 *         return shifted
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 */
  __pyx_codeobj__195 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 2548, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__195)) __PYX_ERR(0, 2548, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2672
 *             )
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__196 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 2672, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__196)) __PYX_ERR(0, 2672, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2677
 *         self.day_of_month = state.pop("day_of_month")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)
 */
  __pyx_codeobj__197 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 2677, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__197)) __PYX_ERR(0, 2677, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2686
 *         return self._prefix + suffix
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         is_start = isinstance(self, SemiMonthBegin)
 */
  __pyx_tuple__198 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_is_start, __pyx_n_s_n, __pyx_n_s_days_in_month, __pyx_n_s_months, __pyx_n_s_to_day); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);
  __pyx_codeobj__199 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__198, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2686, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__199)) __PYX_ERR(0, 2686, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2713
 *         return shift_month(other, months, to_day)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 */
  __pyx_tuple__200 = PyTuple_Pack(19, __pyx_n_s_self, __pyx_n_s_dtarr, __pyx_n_s_i8other, __pyx_n_s_i, __pyx_n_s_count, __pyx_n_s_val, __pyx_n_s_res_val, __pyx_n_s_out, __pyx_n_s_dts, __pyx_n_s_months, __pyx_n_s_to_day, __pyx_n_s_nadj, __pyx_n_s_n, __pyx_n_s_days_in_month, __pyx_n_s_day, __pyx_n_s_anchor_dom, __pyx_n_s_is_start, __pyx_n_s_reso, __pyx_n_s_mi); if (unlikely(!__pyx_tuple__200)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__200);
  __Pyx_GIVEREF(__pyx_tuple__200);
  __pyx_codeobj__201 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 19, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__200, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 2713, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__201)) __PYX_ERR(0, 2713, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2816
 *     _min_day_of_month = 1
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_tuple__202 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_days_in_month); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);
  __pyx_codeobj__203 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__202, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2816, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__203)) __PYX_ERR(0, 2816, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2842
 *     _prefix = "SMS"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 2842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(0, 2842, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2906
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 2906, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(0, 2906, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2912
 *         self._cache = state.pop("_cache", {})
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.weekday is not None
 * 
 */
  __pyx_codeobj__206 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_anchored, 2912, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__206)) __PYX_ERR(0, 2912, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2915
 *         return self.n == 1 and self.weekday is not None
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.weekday is None:
 */
  __pyx_tuple__207 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_k, __pyx_n_s_otherDay); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__207, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 2915, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(0, 2915, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":2934
 *         return other + timedelta(weeks=k)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:
 */
  __pyx_tuple__209 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_dtarr, __pyx_n_s_td, __pyx_n_s_td64, __pyx_n_s_reso, __pyx_n_s_i8other); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__209, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply_array, 2934, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(0, 2934, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3000
 *         return out
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__211 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 3000, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__211)) __PYX_ERR(0, 3000, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3015
 *         return self._prefix + suffix
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_tuple__212 = PyTuple_Pack(3, __pyx_n_s_cls, __pyx_n_s_suffix, __pyx_n_s_weekday); if (unlikely(!__pyx_tuple__212)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__212);
  __Pyx_GIVEREF(__pyx_tuple__212);
  __pyx_codeobj__213 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__212, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 3015, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__213)) __PYX_ERR(0, 3015, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3062
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3062, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(0, 3062, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3068
 *         self.week = state.pop("week")
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */
  __pyx_tuple__215 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_mstart, __pyx_n_s_wday, __pyx_n_s_shift_days); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__215, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_offset_day, 3068, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(0, 3068, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3086
 *         return 1 + shift_days + self.week * 7
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_tuple__217 = PyTuple_Pack(4, __pyx_n_s_cls, __pyx_n_s_suffix, __pyx_n_s_week, __pyx_n_s_weekday); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__217, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 3086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(0, 3086, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3133
 *             raise ValueError("N cannot be 0")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__219 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__219)) __PYX_ERR(0, 3133, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3139
 *         self.week = -1
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */
  __pyx_tuple__220 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_dim, __pyx_n_s_mend, __pyx_n_s_wday, __pyx_n_s_shift_days); if (unlikely(!__pyx_tuple__220)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__220);
  __Pyx_GIVEREF(__pyx_tuple__220);
  __pyx_codeobj__221 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__220, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_offset_day, 3139, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__221)) __PYX_ERR(0, 3139, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3158
 *         return dim - shift_days
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__212, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 3158, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(0, 3158, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3189
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3189, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(0, 3189, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3195
 *         self.variation = state.pop("variation")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return (
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None
 */
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_anchored, 3195, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(0, 3195, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3209
 *         return f"{prefix}-{suffix}"
 * 
 *     def _get_suffix_prefix(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.variation == "nearest":
 *             return "N"
 */
  __pyx_codeobj__225 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_suffix_prefix, 3209, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__225)) __PYX_ERR(0, 3209, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3215
 *             return "L"
 * 
 *     def get_rule_code_suffix(self) -> str:             # <<<<<<<<<<<<<<
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]
 */
  __pyx_tuple__226 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_prefix_2, __pyx_n_s_month, __pyx_n_s_weekday); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);
  __pyx_codeobj__227 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__226, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_rule_code_suffix, 3215, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__227)) __PYX_ERR(0, 3215, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3279
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_tuple__228 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_year_end); if (unlikely(!__pyx_tuple__228)) __PYX_ERR(0, 3279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__228);
  __Pyx_GIVEREF(__pyx_tuple__228);
  __pyx_codeobj__229 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__228, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 3279, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__229)) __PYX_ERR(0, 3279, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3291
 *             return year_end == dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         norm = Timestamp(other).normalize()
 */
  __pyx_tuple__230 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_norm, __pyx_n_s_n, __pyx_n_s_prev_year, __pyx_n_s_cur_year, __pyx_n_s_next_year, __pyx_n_s_shifted, __pyx_n_s_result); if (unlikely(!__pyx_tuple__230)) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__230);
  __Pyx_GIVEREF(__pyx_tuple__230);
  __pyx_codeobj__231 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__230, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 3291, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__231)) __PYX_ERR(0, 3291, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3347
 *         return result
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         assert dt.tzinfo is None
 * 
 */
  __pyx_tuple__232 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_dim, __pyx_n_s_target_date, __pyx_n_s_wkday_diff, __pyx_n_s_days_forward); if (unlikely(!__pyx_tuple__232)) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__232);
  __Pyx_GIVEREF(__pyx_tuple__232);
  __pyx_codeobj__233 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__232, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_year_end, 3347, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__233)) __PYX_ERR(0, 3347, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3373
 *                 return target_date + timedelta(days_forward - 7)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":
 */
  __pyx_tuple__234 = PyTuple_Pack(7, __pyx_n_s_cls, __pyx_n_s_varion_code, __pyx_n_s_startingMonth_code, __pyx_n_s_weekday_code, __pyx_n_s_variation, __pyx_n_s_startingMonth, __pyx_n_s_weekday); if (unlikely(!__pyx_tuple__234)) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__234);
  __Pyx_GIVEREF(__pyx_tuple__234);
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__234, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_parse_suffix, 3373, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(0, 3373, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3391
 *         }
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(**cls._parse_suffix(*args))
 */
  __pyx_tuple__236 = PyTuple_Pack(2, __pyx_n_s_cls, __pyx_n_s_args); if (unlikely(!__pyx_tuple__236)) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__236);
  __Pyx_GIVEREF(__pyx_tuple__236);
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__236, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 3391, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(0, 3391, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3488
 *         self.qtr_with_extra_week = qtr_with_extra_week
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         FY5253Mixin.__setstate__(self, state)
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 */
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(0, 3488, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3492
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _offset(self):
 *         return FY5253(
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_offset, 3492, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(0, 3492, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3500
 *         )
 * 
 *     def _rollback_to_year(self, other: datetime):             # <<<<<<<<<<<<<<
 *         """
 *         Roll `other` back to the most recent date that was on a fiscal year
 */
  __pyx_tuple__240 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_num_qtrs, __pyx_n_s_norm, __pyx_n_s_start, __pyx_n_s_qtr_lens, __pyx_n_s_end, __pyx_n_s_tdelta, __pyx_n_s_qlen); if (unlikely(!__pyx_tuple__240)) __PYX_ERR(0, 3500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__240);
  __Pyx_GIVEREF(__pyx_tuple__240);
  __pyx_codeobj__241 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__240, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_rollback_to_year, 3500, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__241)) __PYX_ERR(0, 3500, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3549
 *         return start, num_qtrs, tdelta
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # Note: self.n == 0 is not allowed.
 */
  __pyx_tuple__242 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_n, __pyx_n_s_prev_year_end, __pyx_n_s_num_qtrs, __pyx_n_s_tdelta, __pyx_n_s_res, __pyx_n_s_years, __pyx_n_s_qtr_lens, __pyx_n_s_weeks); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);
  __pyx_codeobj__243 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__242, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 3549, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__243)) __PYX_ERR(0, 3549, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3578
 *         return res
 * 
 *     def get_weeks(self, dt: datetime):             # <<<<<<<<<<<<<<
 *         ret = [13] * 4
 * 
 */
  __pyx_tuple__244 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_ret, __pyx_n_s_year_has_extra_week); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);
  __pyx_codeobj__245 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__244, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_weeks, 3578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__245)) __PYX_ERR(0, 3578, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3588
 *         return ret
 * 
 *     def year_has_extra_week(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         # Avoid round-down errors --> normalize to get
 *         # e.g. '370D' instead of '360D23H'
 */
  __pyx_tuple__246 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_norm, __pyx_n_s_next_year_end, __pyx_n_s_prev_year_end, __pyx_n_s_weeks_in_year); if (unlikely(!__pyx_tuple__246)) __PYX_ERR(0, 3588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__246);
  __Pyx_GIVEREF(__pyx_tuple__246);
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__246, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_year_has_extra_week, 3588, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(0, 3588, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3599
 *         return weeks_in_year == 53
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_tuple__248 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_next_year_end, __pyx_n_s_qtr_lens, __pyx_n_s_current, __pyx_n_s_qtr_len); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__248, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 3599, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(0, 3599, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3622
 *         return f"{suffix}-{qtr}"
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(
 */
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__236, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_from_name, 3622, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(0, 3622, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3642
 *     """
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(0, 3642, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3646
 *         self.normalize = state.pop("normalize")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)
 */
  __pyx_tuple__252 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_current_easter, __pyx_n_s_n, __pyx_n_s_new_2); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__252, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 3646, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(0, 3646, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3675
 *         return new
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__88, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 3675, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(0, 3675, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3729
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")
 */
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_setstate, 3729, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(0, 3729, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3734
 *         BusinessDay.__setstate__(self, state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.n <= 0:
 */
  __pyx_tuple__256 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_roll, __pyx_n_s_date_in, __pyx_n_s_np_dt, __pyx_n_s_np_incr_dt, __pyx_n_s_dt_date, __pyx_n_s_result, __pyx_n_s_td); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__256, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 3734, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(0, 3734, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3765
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_tuple__258 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_dt, __pyx_n_s_day64); if (unlikely(!__pyx_tuple__258)) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__258);
  __Pyx_GIVEREF(__pyx_tuple__258);
  __pyx_codeobj__259 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__258, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_is_on_offset, 3765, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__259)) __PYX_ERR(0, 3765, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3923
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def cbday_roll(self):
 *         """
 */
  __pyx_tuple__260 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_cbday_kwds, __pyx_n_s_cbday, __pyx_n_s_roll_func); if (unlikely(!__pyx_tuple__260)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__260);
  __Pyx_GIVEREF(__pyx_tuple__260);
  __pyx_codeobj__261 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__260, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_cbday_roll, 3923, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__261)) __PYX_ERR(0, 3923, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3941
 *         return roll_func
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):
 */
  __pyx_tuple__262 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_moff); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);
  __pyx_codeobj__263 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__262, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_m_offset, 3941, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__263)) __PYX_ERR(0, 3941, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3951
 *         return moff
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def month_roll(self):
 *         """
 */
  __pyx_tuple__264 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_roll_func); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);
  __pyx_codeobj__265 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__264, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_month_roll, 3951, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__265)) __PYX_ERR(0, 3951, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3964
 *         return roll_func
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # First move to month offset
 */
  __pyx_tuple__266 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_other, __pyx_n_s_cur_month_offset_date, __pyx_n_s_compare_date, __pyx_n_s_n, __pyx_n_s_new_2, __pyx_n_s_result); if (unlikely(!__pyx_tuple__266)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__266);
  __Pyx_GIVEREF(__pyx_tuple__266);
  __pyx_codeobj__267 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__266, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_apply, 3964, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__267)) __PYX_ERR(0, 3964, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4037
 * 
 * # hack to handle WOM-1MON
 * opattern = re.compile(             # <<<<<<<<<<<<<<
 *     r"([+\-]?\d*|[+\-]?\d*\.\d*)\s*([A-Za-z]+([\-][\dA-Za-z\-]+)?)"
 * )
 */
  __pyx_tuple__268 = PyTuple_Pack(1, __pyx_kp_u_d_d_d_s_A_Za_z_dA_Za_z); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(0, 4037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);

  /* "pandas/_libs/tslibs/offsets.pyx":4071
 * 
 * # TODO: better name?
 * def _get_offset(name: str) -> BaseOffset:             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object associated with rule name.
 */
  __pyx_tuple__269 = PyTuple_Pack(5, __pyx_n_s_name_2, __pyx_n_s_split, __pyx_n_s_klass, __pyx_n_s_offset_2, __pyx_n_s_err); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_get_offset, 4071, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 4071, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4102
 * 
 * 
 * cpdef to_offset(freq):             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object from string or datetime.timedelta object.
 */
  __pyx_tuple__271 = PyTuple_Pack(1, __pyx_n_s_freq); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_to_offset, 4102, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 4102, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */
  __pyx_tuple__273 = PyTuple_Pack(12, __pyx_n_s_dtindex, __pyx_n_s_months, __pyx_n_s_day_opt_2, __pyx_n_s_reso, __pyx_n_s_i, __pyx_n_s_dts, __pyx_n_s_count, __pyx_n_s_out, __pyx_n_s_months_to_roll, __pyx_n_s_val, __pyx_n_s_res_val, __pyx_n_s_mi); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__273, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_shift_months, 4321, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(0, 4321, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4405
 * 
 * 
 * def shift_month(stamp: datetime, months: int, day_opt: object = None) -> datetime:             # <<<<<<<<<<<<<<
 *     """
 *     Given a datetime (or Timestamp) `stamp`, an integer `months` and an
 */
  __pyx_tuple__275 = PyTuple_Pack(8, __pyx_n_s_stamp, __pyx_n_s_months, __pyx_n_s_day_opt_2, __pyx_n_s_year, __pyx_n_s_month, __pyx_n_s_day, __pyx_n_s_days_in_month, __pyx_n_s_dy); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__275, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_shift_month, 4405, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(0, 4405, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4510
 * 
 * 
 * cpdef int roll_convention(int other, int n, int compare) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Possibly increment or decrement the number of periods to shift
 */
  __pyx_tuple__277 = PyTuple_Pack(3, __pyx_n_s_other, __pyx_n_s_n, __pyx_n_s_compare); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__277, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_roll_convention, 4510, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(0, 4510, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4534
 * 
 * 
 * def roll_qtrday(other: datetime, n: int, month: int,             # <<<<<<<<<<<<<<
 *                 day_opt: str, modby: int) -> int:
 *     """
 */
  __pyx_tuple__279 = PyTuple_Pack(7, __pyx_n_s_other, __pyx_n_s_n, __pyx_n_s_month, __pyx_n_s_day_opt_2, __pyx_n_s_modby, __pyx_n_s_months_since, __pyx_n_s_dts); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_tslibs_offsets_pyx, __pyx_n_s_roll_qtrday, 4534, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(0, 4534, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_BaseOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__281 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_BaseOffset, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(5, 1, __pyx_L1_error)
  __pyx_codeobj__283 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_RelativeDeltaOffs, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__283)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_get.method_name = &__pyx_n_s_get;
  __pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_pop.method_name = &__pyx_n_s_pop;
  __pyx_umethod_PyUnicode_Type_lower.type = (PyObject*)&PyUnicode_Type;
  __pyx_umethod_PyUnicode_Type_lower.method_name = &__pyx_n_s_lower;
  __pyx_umethod_PyUnicode_Type_upper.type = (PyObject*)&PyUnicode_Type;
  __pyx_umethod_PyUnicode_Type_upper.method_name = &__pyx_n_s_upper;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_13 = PyInt_FromLong(13); if (unlikely(!__pyx_int_13)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_14 = PyInt_FromLong(14); if (unlikely(!__pyx_int_14)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_27 = PyInt_FromLong(27); if (unlikely(!__pyx_int_27)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_52 = PyInt_FromLong(52); if (unlikely(!__pyx_int_52)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_53 = PyInt_FromLong(53); if (unlikely(!__pyx_int_53)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_60 = PyInt_FromLong(60); if (unlikely(!__pyx_int_60)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000 = PyInt_FromLong(1000); if (unlikely(!__pyx_int_1000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2014 = PyInt_FromLong(2014); if (unlikely(!__pyx_int_2014)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3600 = PyInt_FromLong(3600); if (unlikely(!__pyx_int_3600)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_86400 = PyInt_FromLong(86400L); if (unlikely(!__pyx_int_86400)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000000 = PyInt_FromLong(1000000L); if (unlikely(!__pyx_int_1000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10844460 = PyInt_FromLong(10844460L); if (unlikely(!__pyx_int_10844460)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_171034093 = PyInt_FromLong(171034093L); if (unlikely(!__pyx_int_171034093)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_213572416 = PyInt_FromLong(213572416L); if (unlikely(!__pyx_int_213572416)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1000000000 = PyInt_FromLong(1000000000L); if (unlikely(!__pyx_int_1000000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_60000000000 = PyInt_FromString((char *)"60000000000", 0, 0); if (unlikely(!__pyx_int_60000000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3600000000000 = PyInt_FromString((char *)"3600000000000", 0, 0); if (unlikely(!__pyx_int_3600000000000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0x4e94914f0000 = PyInt_FromString((char *)"0x4e94914f0000", 0, 0); if (unlikely(!__pyx_int_0x4e94914f0000)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  if (__Pyx_ExportFunction("to_offset", (void (*)(void))__pyx_f_6pandas_5_libs_6tslibs_7offsets_to_offset, "PyObject *(PyObject *, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("is_offset_object", (void (*)(void))__pyx_f_6pandas_5_libs_6tslibs_7offsets_is_offset_object, "int (PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ExportFunction("is_tick_object", (void (*)(void))__pyx_f_6pandas_5_libs_6tslibs_7offsets_is_tick_object, "int (PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset)) __PYX_ERR(0, 366, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset) < 0) __PYX_ERR(0, 366, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset) < 0) __PYX_ERR(0, 366, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BaseOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset) < 0) __PYX_ERR(0, 366, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset) < 0) __PYX_ERR(0, 366, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 886, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset)) __PYX_ERR(0, 886, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset) < 0) __PYX_ERR(0, 886, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset) < 0) __PYX_ERR(0, 886, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SingleConstructorOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset) < 0) __PYX_ERR(0, 886, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Tick;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Tick._next_higher_resolution = (struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Tick *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Tick__next_higher_resolution;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 909, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick)) __PYX_ERR(0, 909, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick) < 0) __PYX_ERR(0, 909, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick) < 0) __PYX_ERR(0, 909, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick) < 0) __PYX_ERR(0, 909, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick) < 0) __PYX_ERR(0, 909, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Tick, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick) < 0) __PYX_ERR(0, 909, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Day = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Day;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Day.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1089, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day)) __PYX_ERR(0, 1089, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Day;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Day) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Day, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day) < 0) __PYX_ERR(0, 1089, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Hour = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Hour;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Hour.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour)) __PYX_ERR(0, 1097, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Hour;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Hour) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Hour, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Minute = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Minute;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Minute.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute)) __PYX_ERR(0, 1105, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute) < 0) __PYX_ERR(0, 1105, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Minute;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute) < 0) __PYX_ERR(0, 1105, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Minute) < 0) __PYX_ERR(0, 1105, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute) < 0) __PYX_ERR(0, 1105, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Minute, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute) < 0) __PYX_ERR(0, 1105, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Second = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Second;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Second.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second)) __PYX_ERR(0, 1113, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second) < 0) __PYX_ERR(0, 1113, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Second;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second) < 0) __PYX_ERR(0, 1113, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Second) < 0) __PYX_ERR(0, 1113, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second) < 0) __PYX_ERR(0, 1113, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Second, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second) < 0) __PYX_ERR(0, 1113, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Milli = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Milli;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Milli.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli)) __PYX_ERR(0, 1121, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli) < 0) __PYX_ERR(0, 1121, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Milli;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli) < 0) __PYX_ERR(0, 1121, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Milli) < 0) __PYX_ERR(0, 1121, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli) < 0) __PYX_ERR(0, 1121, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Milli, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli) < 0) __PYX_ERR(0, 1121, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Micro = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Micro;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Micro.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro)) __PYX_ERR(0, 1129, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro) < 0) __PYX_ERR(0, 1129, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Micro;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro) < 0) __PYX_ERR(0, 1129, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Micro) < 0) __PYX_ERR(0, 1129, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro) < 0) __PYX_ERR(0, 1129, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Micro, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro) < 0) __PYX_ERR(0, 1129, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Nano = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Nano;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Nano.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Tick;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano)) __PYX_ERR(0, 1137, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Nano;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Nano) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Nano, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano) < 0) __PYX_ERR(0, 1137, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset)) __PYX_ERR(0, 1170, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_RelativeDeltaOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset) < 0) __PYX_ERR(0, 1170, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMixin._init_custom = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin__init_custom;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMixin.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin)) __PYX_ERR(0, 1437, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BusinessMixin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessDay = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay.__pyx_base.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay___setstate__;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay._shift_bdays = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *, PyArrayObject *, struct __pyx_opt_args_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays *__pyx_optional_args))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__shift_bdays;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessDay._adjust_ndays = (int (*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessDay *, int, int))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11BusinessDay__adjust_ndays;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay)) __PYX_ERR(0, 1505, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay) < 0) __PYX_ERR(0, 1505, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay) < 0) __PYX_ERR(0, 1505, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessDay) < 0) __PYX_ERR(0, 1505, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay) < 0) __PYX_ERR(0, 1505, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BusinessDay, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay) < 0) __PYX_ERR(0, 1505, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessHour = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessHour.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessHour.__pyx_base.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_12BusinessHour___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour)) __PYX_ERR(0, 1697, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessHour) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BusinessHour, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour) < 0) __PYX_ERR(0, 1697, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin)) __PYX_ERR(0, 2126, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin) < 0) __PYX_ERR(0, 2126, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin) < 0) __PYX_ERR(0, 2126, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_WeekOfMonthMixin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin) < 0) __PYX_ERR(0, 2126, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearOffset.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_YearOffset *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_10YearOffset___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset)) __PYX_ERR(0, 2169, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_YearOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset) < 0) __PYX_ERR(0, 2169, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd)) __PYX_ERR(0, 2236, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd) < 0) __PYX_ERR(0, 2236, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd) < 0) __PYX_ERR(0, 2236, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearEnd) < 0) __PYX_ERR(0, 2236, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd) < 0) __PYX_ERR(0, 2236, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BYearEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd) < 0) __PYX_ERR(0, 2236, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BYearBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin)) __PYX_ERR(0, 2262, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin) < 0) __PYX_ERR(0, 2262, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BYearBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin) < 0) __PYX_ERR(0, 2262, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BYearBegin) < 0) __PYX_ERR(0, 2262, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin) < 0) __PYX_ERR(0, 2262, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BYearBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin) < 0) __PYX_ERR(0, 2262, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd)) __PYX_ERR(0, 2286, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd) < 0) __PYX_ERR(0, 2286, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd) < 0) __PYX_ERR(0, 2286, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearEnd) < 0) __PYX_ERR(0, 2286, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd) < 0) __PYX_ERR(0, 2286, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_YearEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd) < 0) __PYX_ERR(0, 2286, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_YearBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin)) __PYX_ERR(0, 2311, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin) < 0) __PYX_ERR(0, 2311, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_YearBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin) < 0) __PYX_ERR(0, 2311, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_YearBegin) < 0) __PYX_ERR(0, 2311, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin) < 0) __PYX_ERR(0, 2311, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_YearBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin) < 0) __PYX_ERR(0, 2311, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterOffset.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_QuarterOffset *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset)) __PYX_ERR(0, 2346, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset) < 0) __PYX_ERR(0, 2346, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset) < 0) __PYX_ERR(0, 2346, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset) < 0) __PYX_ERR(0, 2346, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset) < 0) __PYX_ERR(0, 2346, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_QuarterOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset) < 0) __PYX_ERR(0, 2346, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd)) __PYX_ERR(0, 2423, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BQuarterEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd) < 0) __PYX_ERR(0, 2423, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin)) __PYX_ERR(0, 2451, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin) < 0) __PYX_ERR(0, 2451, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin) < 0) __PYX_ERR(0, 2451, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin) < 0) __PYX_ERR(0, 2451, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin) < 0) __PYX_ERR(0, 2451, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BQuarterBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin) < 0) __PYX_ERR(0, 2451, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd)) __PYX_ERR(0, 2479, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd) < 0) __PYX_ERR(0, 2479, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd) < 0) __PYX_ERR(0, 2479, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterEnd) < 0) __PYX_ERR(0, 2479, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd) < 0) __PYX_ERR(0, 2479, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_QuarterEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd) < 0) __PYX_ERR(0, 2479, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_QuarterBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin)) __PYX_ERR(0, 2507, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin) < 0) __PYX_ERR(0, 2507, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_QuarterBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin) < 0) __PYX_ERR(0, 2507, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_QuarterBegin) < 0) __PYX_ERR(0, 2507, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin) < 0) __PYX_ERR(0, 2507, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_QuarterBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin) < 0) __PYX_ERR(0, 2507, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthOffset.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_MonthOffset *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11MonthOffset___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset)) __PYX_ERR(0, 2530, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset) < 0) __PYX_ERR(0, 2530, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset) < 0) __PYX_ERR(0, 2530, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset) < 0) __PYX_ERR(0, 2530, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset) < 0) __PYX_ERR(0, 2530, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_MonthOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset) < 0) __PYX_ERR(0, 2530, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd)) __PYX_ERR(0, 2557, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthEnd) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_MonthEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd) < 0) __PYX_ERR(0, 2557, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_MonthBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin)) __PYX_ERR(0, 2588, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_MonthBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthBegin) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_MonthBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin) < 0) __PYX_ERR(0, 2588, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd)) __PYX_ERR(0, 2602, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BusinessMonthEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd) < 0) __PYX_ERR(0, 2602, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin)) __PYX_ERR(0, 2628, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin) < 0) __PYX_ERR(0, 2628, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin) < 0) __PYX_ERR(0, 2628, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin) < 0) __PYX_ERR(0, 2628, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin) < 0) __PYX_ERR(0, 2628, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_BusinessMonthBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin) < 0) __PYX_ERR(0, 2628, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset)) __PYX_ERR(0, 2650, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset) < 0) __PYX_ERR(0, 2650, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset) < 0) __PYX_ERR(0, 2650, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset) < 0) __PYX_ERR(0, 2650, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset) < 0) __PYX_ERR(0, 2650, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SemiMonthOffset, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset) < 0) __PYX_ERR(0, 2650, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd)) __PYX_ERR(0, 2783, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SemiMonthEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd) < 0) __PYX_ERR(0, 2783, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin)) __PYX_ERR(0, 2823, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_SemiMonthBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin) < 0) __PYX_ERR(0, 2823, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Week = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Week;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Week.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week___setstate__;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Week._end_apply_index = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Week *, PyArrayObject *, NPY_DATETIMEUNIT))__pyx_f_6pandas_5_libs_6tslibs_7offsets_4Week__end_apply_index;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week)) __PYX_ERR(0, 2852, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Week;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Week) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Week, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week) < 0) __PYX_ERR(0, 2852, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth)) __PYX_ERR(0, 3024, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth) < 0) __PYX_ERR(0, 3024, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth) < 0) __PYX_ERR(0, 3024, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth) < 0) __PYX_ERR(0, 3024, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth) < 0) __PYX_ERR(0, 3024, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_WeekOfMonth, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth) < 0) __PYX_ERR(0, 3024, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3096, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth)) __PYX_ERR(0, 3096, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth) < 0) __PYX_ERR(0, 3096, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth) < 0) __PYX_ERR(0, 3096, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth) < 0) __PYX_ERR(0, 3096, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth) < 0) __PYX_ERR(0, 3096, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_LastWeekOfMonth, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth) < 0) __PYX_ERR(0, 3096, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin)) __PYX_ERR(0, 3169, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FY5253Mixin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin) < 0) __PYX_ERR(0, 3169, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253 = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253 = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253)) __PYX_ERR(0, 3222, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253 = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FY5253, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253) < 0) __PYX_ERR(0, 3222, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter.__pyx_base.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter)) __PYX_ERR(0, 3396, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter) < 0) __PYX_ERR(0, 3396, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter) < 0) __PYX_ERR(0, 3396, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter) < 0) __PYX_ERR(0, 3396, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter) < 0) __PYX_ERR(0, 3396, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FY5253Quarter, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter) < 0) __PYX_ERR(0, 3396, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Easter = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Easter;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_Easter.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_Easter *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_6Easter___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter)) __PYX_ERR(0, 3629, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter) < 0) __PYX_ERR(0, 3629, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_Easter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter) < 0) __PYX_ERR(0, 3629, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_Easter) < 0) __PYX_ERR(0, 3629, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter) < 0) __PYX_ERR(0, 3629, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Easter, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter) < 0) __PYX_ERR(0, 3629, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay.__pyx_base.__pyx_base.__pyx___setstate__ = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_6tslibs_7offsets_BusinessMixin *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay___setstate__;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay)) __PYX_ERR(0, 3685, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CustomBusinessDay, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay) < 0) __PYX_ERR(0, 3685, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3772, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour)) __PYX_ERR(0, 3772, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour) < 0) __PYX_ERR(0, 3772, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour) < 0) __PYX_ERR(0, 3772, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour) < 0) __PYX_ERR(0, 3772, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour) < 0) __PYX_ERR(0, 3772, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CustomBusinessHour, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour) < 0) __PYX_ERR(0, 3772, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth)) __PYX_ERR(0, 3884, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth) < 0) __PYX_ERR(0, 3884, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth = &__pyx_type_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth) < 0) __PYX_ERR(0, 3884, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth) < 0) __PYX_ERR(0, 3884, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth) < 0) __PYX_ERR(0, 3884, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CustomBusinessMonth, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth) < 0) __PYX_ERR(0, 3884, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd)) __PYX_ERR(0, 3981, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CustomBusinessMonthEnd, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd) < 0) __PYX_ERR(0, 3981, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin = &__pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
  __pyx_vtable_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin.__pyx_base = *__pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin)) __PYX_ERR(0, 3985, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin = &__pyx_type_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin->tp_base = __pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin, __pyx_vtabptr_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CustomBusinessMonthBegin, (PyObject *) __pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin) < 0) __PYX_ERR(0, 3985, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps)) __PYX_ERR(0, 121, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps) < 0) __PYX_ERR(0, 121, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps) < 0) __PYX_ERR(0, 121, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct__apply_array_wraps->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps)) __PYX_ERR(0, 135, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_1_apply_wraps->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset)) __PYX_ERR(0, 304, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset) < 0) __PYX_ERR(0, 304, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset) < 0) __PYX_ERR(0, 304, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_2___pyx_f_6pandas_5_libs_6tslibs_7offsets__determine_offset->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr)) __PYX_ERR(0, 320, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 320, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr) < 0) __PYX_ERR(0, 320, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_3_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr)) __PYX_ERR(0, 337, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr) < 0) __PYX_ERR(0, 337, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_4_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr)) __PYX_ERR(0, 347, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr) < 0) __PYX_ERR(0, 347, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr) < 0) __PYX_ERR(0, 347, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_5_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce___spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__)) __PYX_ERR(0, 894, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce___spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__) < 0) __PYX_ERR(0, 894, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__ = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__) < 0) __PYX_ERR(0, 894, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_6___reduce__->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr)) __PYX_ERR(0, 900, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr) < 0) __PYX_ERR(0, 900, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr) < 0) __PYX_ERR(0, 900, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_7_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr)) __PYX_ERR(0, 1826, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr) < 0) __PYX_ERR(0, 1826, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_8_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply)) __PYX_ERR(0, 1992, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_9__apply->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr)) __PYX_ERR(0, 2023, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr_spec, __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr) < 0) __PYX_ERR(0, 2023, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr = &__pyx_type_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr) < 0) __PYX_ERR(0, 2023, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr->tp_dictoffset && __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_6tslibs_7offsets___pyx_scope_struct_10_genexpr->tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_8(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArray_Descr),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(1, 202, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(1, 225, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayMultiIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(1, 229, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(1, 238, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_generic) __PYX_ERR(1, 809, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "number", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_number) __PYX_ERR(1, 811, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_integer) __PYX_ERR(1, 813, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(1, 815, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(1, 817, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(1, 819, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_floating) __PYX_ERR(1, 821, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(1, 823, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(1, 825, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "character", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_character) __PYX_ERR(1, 827, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyUFuncObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(1, 866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("datetime"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType_3_0_8(__pyx_t_1, "datetime", "date", sizeof(PyDateTime_Date), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyDateTime_Date),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_8datetime_date) __PYX_ERR(2, 70, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType_3_0_8(__pyx_t_1, "datetime", "time", sizeof(PyDateTime_Time), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyDateTime_Time),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_8datetime_time) __PYX_ERR(2, 83, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType_3_0_8(__pyx_t_1, "datetime", "datetime", sizeof(PyDateTime_DateTime), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyDateTime_DateTime),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_8datetime_datetime) __PYX_ERR(2, 109, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType_3_0_8(__pyx_t_1, "datetime", "timedelta", sizeof(PyDateTime_Delta), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyDateTime_Delta),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_8datetime_timedelta) __PYX_ERR(2, 147, __pyx_L1_error)
  __pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType_3_0_8(__pyx_t_1, "datetime", "tzinfo", sizeof(PyDateTime_TZInfo), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyDateTime_TZInfo),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_8datetime_tzinfo) __PYX_ERR(2, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.base"); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.base", "ABCTimestamp", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_4base_ABCTimestamp), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_4base_ABCTimestamp),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_4base_ABCTimestamp) __PYX_ERR(7, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.timestamps"); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.timestamps", "_Timestamp", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_10timestamps__Timestamp),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp) __PYX_ERR(8, 22, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_10timestamps__Timestamp = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timestamps__Timestamp*)__Pyx_GetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_10timestamps__Timestamp); if (unlikely(!__pyx_vtabptr_6pandas_5_libs_6tslibs_10timestamps__Timestamp)) __PYX_ERR(8, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.conversion"); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.conversion", "_TSObject", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_10conversion__TSObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_10conversion__TSObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject) __PYX_ERR(9, 19, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_10conversion__TSObject = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10conversion__TSObject*)__Pyx_GetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_10conversion__TSObject); if (unlikely(!__pyx_vtabptr_6pandas_5_libs_6tslibs_10conversion__TSObject)) __PYX_ERR(9, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.dtypes"); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.dtypes", "PeriodDtypeBase", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase) __PYX_ERR(10, 102, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase*)__Pyx_GetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase); if (unlikely(!__pyx_vtabptr_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeBase)) __PYX_ERR(10, 102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.nattype"); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.nattype", "_NaT", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_7nattype__NaT) __PYX_ERR(11, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.timedeltas"); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.tslibs.timedeltas", "_Timedelta", sizeof(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_6tslibs_10timedeltas__Timedelta),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta) __PYX_ERR(12, 15, __pyx_L1_error)
  __pyx_vtabptr_6pandas_5_libs_6tslibs_10timedeltas__Timedelta = (struct __pyx_vtabstruct_6pandas_5_libs_6tslibs_10timedeltas__Timedelta*)__Pyx_GetVtable(__pyx_ptype_6pandas_5_libs_6tslibs_10timedeltas__Timedelta); if (unlikely(!__pyx_vtabptr_6pandas_5_libs_6tslibs_10timedeltas__Timedelta)) __PYX_ERR(12, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.ccalendar"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "c_MONTH_NUMBERS", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_c_MONTH_NUMBERS, "PyObject *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "month_offset", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_9ccalendar_month_offset, "__pyx_t_5numpy_int32_t *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.timezones"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "utc_stdlib", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_9timezones_utc_stdlib, "PyDateTime_TZInfo *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.dtypes"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "attrname_to_abbrevs", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_abbrevs, "PyObject *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "npy_unit_to_attrname", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_npy_unit_to_attrname, "PyObject *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "attrname_to_npy_unit", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_6dtypes_attrname_to_npy_unit, "PyObject *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.nattype"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "NPY_NAT", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_7nattype_NPY_NAT, "__pyx_t_5numpy_int64_t") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "c_nat_strings", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_nat_strings, "PyObject *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "c_NaT", (void **)&__pyx_vp_6pandas_5_libs_6tslibs_7nattype_c_NaT, "struct __pyx_obj_6pandas_5_libs_6tslibs_7nattype__NaT *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.ccalendar"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "dayofweek", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_dayofweek, "int (int, int, int)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "get_days_in_month", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_days_in_month, "__pyx_t_5numpy_int32_t (int, Py_ssize_t, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "get_lastbday", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_lastbday, "int (int, int, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "get_firstbday", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_9ccalendar_get_firstbday, "int (int, int, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.np_datetime"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "pydate_to_dtstruct", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_11np_datetime_pydate_to_dtstruct, "void (PyDateTime_Date *, npy_datetimestruct *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "get_unit_from_dtype", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_11np_datetime_get_unit_from_dtype, "NPY_DATETIMEUNIT (PyArray_Descr *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.timezones"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "tz_compare", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_9timezones_tz_compare, "int (PyDateTime_TZInfo *, PyDateTime_TZInfo *, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.conversion"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "localize_pydatetime", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_10conversion_localize_pydatetime, "PyDateTime_DateTime *(PyDateTime_DateTime *, PyDateTime_TZInfo *, int __pyx_skip_dispatch)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.dtypes"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "periods_per_day", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_6dtypes_periods_per_day, "__pyx_t_5numpy_int64_t (int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_6tslibs_6dtypes_periods_per_day *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.tslibs.timedeltas"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "delta_to_nanoseconds", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds, "__pyx_t_5numpy_int64_t (PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_6tslibs_10timedeltas_delta_to_nanoseconds *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "is_any_td_scalar", (void (**)(void))&__pyx_f_6pandas_5_libs_6tslibs_10timedeltas_is_any_td_scalar, "int (PyObject *)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_offsets(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_offsets},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "offsets",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initoffsets(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initoffsets(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_offsets(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_offsets(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_offsets(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'offsets' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("offsets", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "offsets" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_offsets(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_pandas___libs__tslibs__offsets) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "pandas._libs.tslibs.offsets")) {
      if (unlikely((PyDict_SetItemString(modules, "pandas._libs.tslibs.offsets", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  if (unlikely((__Pyx_modinit_function_export_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "pandas/_libs/tslibs/offsets.pyx":1
 * import re             # <<<<<<<<<<<<<<
 * import time
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_re, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":2
 * import re
 * import time             # <<<<<<<<<<<<<<
 * 
 * cimport cython
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_time, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_2) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":16
 * )
 * 
 * import_datetime()             # <<<<<<<<<<<<<<
 * 
 * from dateutil.easter import easter
 */
  __pyx_f_7cpython_8datetime_import_datetime(); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 16, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":18
 * import_datetime()
 * 
 * from dateutil.easter import easter             # <<<<<<<<<<<<<<
 * from dateutil.relativedelta import relativedelta
 * import numpy as np
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_easter);
  __Pyx_GIVEREF(__pyx_n_s_easter);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_easter)) __PYX_ERR(0, 18, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_dateutil_easter, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_easter); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_easter, __pyx_t_2) < 0) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":19
 * 
 * from dateutil.easter import easter
 * from dateutil.relativedelta import relativedelta             # <<<<<<<<<<<<<<
 * import numpy as np
 * 
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_relativedelta);
  __Pyx_GIVEREF(__pyx_n_s_relativedelta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_relativedelta)) __PYX_ERR(0, 19, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_dateutil_relativedelta, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_relativedelta); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_relativedelta, __pyx_t_3) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":20
 * from dateutil.easter import easter
 * from dateutil.relativedelta import relativedelta
 * import numpy as np             # <<<<<<<<<<<<<<
 * 
 * cimport numpy as cnp
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_numpy, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_2) < 0) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":28
 * )
 * 
 * cnp.import_array()             # <<<<<<<<<<<<<<
 * 
 * # TODO: formalize having _libs.properties "above" tslibs in the dependency structure
 */
  __pyx_t_4 = __pyx_f_5numpy_import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(0, 28, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":32
 * # TODO: formalize having _libs.properties "above" tslibs in the dependency structure
 * 
 * from pandas._libs.properties import cache_readonly             # <<<<<<<<<<<<<<
 * 
 * from pandas._libs.tslibs cimport util
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_cache_readonly);
  __Pyx_GIVEREF(__pyx_n_s_cache_readonly);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_cache_readonly)) __PYX_ERR(0, 32, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pandas__libs_properties, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cache_readonly, __pyx_t_2) < 0) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":42
 * 
 * from pandas._libs.tslibs.ccalendar import (
 *     MONTH_ALIASES,             # <<<<<<<<<<<<<<
 *     MONTH_TO_CAL_NUM,
 *     int_to_weekday,
 */
  __pyx_t_3 = PyList_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_MONTH_ALIASES);
  __Pyx_GIVEREF(__pyx_n_s_MONTH_ALIASES);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_MONTH_ALIASES)) __PYX_ERR(0, 42, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_MONTH_TO_CAL_NUM);
  __Pyx_GIVEREF(__pyx_n_s_MONTH_TO_CAL_NUM);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_MONTH_TO_CAL_NUM)) __PYX_ERR(0, 42, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_int_to_weekday);
  __Pyx_GIVEREF(__pyx_n_s_int_to_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_int_to_weekday)) __PYX_ERR(0, 42, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_weekday_to_int);
  __Pyx_GIVEREF(__pyx_n_s_weekday_to_int);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 3, __pyx_n_s_weekday_to_int)) __PYX_ERR(0, 42, __pyx_L1_error);

  /* "pandas/_libs/tslibs/offsets.pyx":41
 * )
 * 
 * from pandas._libs.tslibs.ccalendar import (             # <<<<<<<<<<<<<<
 *     MONTH_ALIASES,
 *     MONTH_TO_CAL_NUM,
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pandas__libs_tslibs_ccalendar, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MONTH_ALIASES); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MONTH_ALIASES, __pyx_t_3) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_MONTH_TO_CAL_NUM); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MONTH_TO_CAL_NUM, __pyx_t_3) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_int_to_weekday); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_int_to_weekday, __pyx_t_3) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_weekday_to_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_weekday_to_int, __pyx_t_3) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":76
 * )
 * 
 * from .timedeltas import Timedelta             # <<<<<<<<<<<<<<
 * 
 * from .timestamps cimport _Timestamp
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Timedelta);
  __Pyx_GIVEREF(__pyx_n_s_Timedelta);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Timedelta)) __PYX_ERR(0, 76, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_timedeltas, __pyx_t_2, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_Timedelta); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Timedelta, __pyx_t_2) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":80
 * from .timestamps cimport _Timestamp
 * 
 * from .timestamps import Timestamp             # <<<<<<<<<<<<<<
 * 
 * # ---------------------------------------------------------------------
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_Timestamp);
  __Pyx_GIVEREF(__pyx_n_s_Timestamp);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_Timestamp)) __PYX_ERR(0, 80, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_timestamps, __pyx_t_3, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Timestamp); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Timestamp, __pyx_t_3) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":108
 * 
 * 
 * def apply_wrapper_core(func, self, other) -> ndarray:             # <<<<<<<<<<<<<<
 *     result = func(self, other)
 *     result = np.asarray(result)
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(0, 108, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_1apply_wrapper_core, 0, __pyx_n_s_apply_wrapper_core, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__69)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_apply_wrapper_core, __pyx_t_3) < 0) __PYX_ERR(0, 108, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":121
 * 
 * 
 * def apply_array_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_3apply_array_wraps, 0, __pyx_n_s_apply_array_wraps, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__71)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_apply_array_wraps, __pyx_t_3) < 0) __PYX_ERR(0, 121, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":135
 * 
 * 
 * def apply_wraps(func):             # <<<<<<<<<<<<<<
 *     # Note: normally we would use `@functools.wraps(func)`, but this does
 *     # not play nicely with cython class methods
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_5apply_wraps, 0, __pyx_n_s_apply_wraps, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_apply_wraps, __pyx_t_3) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":297
 * # Constructor Helpers
 * 
 * _relativedelta_kwds = {"years", "months", "weeks", "days", "year", "month",             # <<<<<<<<<<<<<<
 *                        "day", "weekday", "hour", "minute", "second",
 *                        "microsecond", "millisecond", "nanosecond",
 */
  __pyx_t_3 = PySet_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PySet_Add(__pyx_t_3, __pyx_n_u_years) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_months) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_weeks) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_days) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_year) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_month) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_day) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_weekday) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_hour) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_minute) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_second) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_microsecond) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_millisecond) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_nanosecond) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_nanoseconds) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_hours) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_minutes) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_seconds) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_milliseconds) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PySet_Add(__pyx_t_3, __pyx_n_u_microseconds) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_relativedelta_kwds, __pyx_t_3) < 0) __PYX_ERR(0, 297, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":358
 * 
 * 
 * class ApplyTypeError(TypeError):             # <<<<<<<<<<<<<<
 *     # sentinel class for catching the apply error to return NotImplemented
 *     pass
 */
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_tuple__74); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_ApplyTypeError, __pyx_n_s_ApplyTypeError, (PyObject *) NULL, __pyx_n_s_pandas__libs_tslibs_offsets, (PyObject *) NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__pyx_t_3 != __pyx_tuple__74) {
    if (unlikely((PyDict_SetItemString(__pyx_t_5, "__orig_bases__", __pyx_tuple__74) < 0))) __PYX_ERR(0, 358, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_ApplyTypeError, __pyx_t_3, __pyx_t_5, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ApplyTypeError, __pyx_t_6) < 0) __PYX_ERR(0, 358, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":386
 *     """
 *     # ensure that reversed-ops with numpy scalars return NotImplemented
 *     __array_priority__ = 1000             # <<<<<<<<<<<<<<
 * 
 *     _day_opt = None
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_array_priority, __pyx_int_1000) < 0) __PYX_ERR(0, 386, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":388
 *     __array_priority__ = 1000
 * 
 *     _day_opt = None             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize"])
 *     _use_relativedelta = False
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_day_opt, Py_None) < 0) __PYX_ERR(0, 388, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":389
 * 
 *     _day_opt = None
 *     _attributes = tuple(["n", "normalize"])             # <<<<<<<<<<<<<<
 *     _use_relativedelta = False
 *     _adjust_dst = True
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_n)) __PYX_ERR(0, 389, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 389, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":390
 *     _day_opt = None
 *     _attributes = tuple(["n", "normalize"])
 *     _use_relativedelta = False             # <<<<<<<<<<<<<<
 *     _adjust_dst = True
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_use_relativedelta, Py_False) < 0) __PYX_ERR(0, 390, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":391
 *     _attributes = tuple(["n", "normalize"])
 *     _use_relativedelta = False
 *     _adjust_dst = True             # <<<<<<<<<<<<<<
 * 
 *     # cdef readonly:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_adjust_dst, Py_True) < 0) __PYX_ERR(0, 391, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":425
 *         return hash(self._params)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _params(self):
 *         """
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_9_params, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__params, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__76)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_params, __pyx_t_2) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_params); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_params, __pyx_t_2) < 0) __PYX_ERR(0, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":532
 *         return self * -1
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         # Note: we are deferring directly to __mul__ instead of __rmul__, as
 *         # that allows us to use methods that can go in a `cdef class`
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_25copy, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_copy, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__78)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_copy, __pyx_t_2) < 0) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":567
 *         return out
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         exclude = {"n", "inc", "normalize"}
 *         attrs = []
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 567, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_29_repr_attrs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__repr_attrs, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__80)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_repr_attrs, __pyx_t_3) < 0) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":607
 *         return self._prefix
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def freqstr(self) -> str:
 *         """
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 607, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_31freqstr, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_freqstr, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__82)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_freqstr, __pyx_t_2) < 0) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_freqstr); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_freqstr, __pyx_t_2) < 0) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":645
 *         return fstr
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         return ""
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 645, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_33_offset_str, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__offset_str, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__83)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_offset_str, __pyx_t_3) < 0) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":650
 *     # ------------------------------------------------------------------
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("implemented by subclasses")
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_35_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__85)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_apply, __pyx_t_3) < 0) __PYX_ERR(0, 650, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":653
 *         raise NotImplementedError("implemented by subclasses")
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         raise NotImplementedError(
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_37_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__87)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_apply_array, __pyx_t_3) < 0) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_apply_array, __pyx_t_3) < 0) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":660
 *         )
 * 
 *     def rollback(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date backward to next offset only if not on offset.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_39rollback, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_rollback, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__89)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_rollback, __pyx_t_2) < 0) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":674
 *         return dt
 * 
 *     def rollforward(self, dt) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Roll provided date forward to next offset only if not on offset.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 674, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_41rollforward, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_rollforward, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_rollforward, __pyx_t_3) < 0) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":688
 *         return dt
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # subclass must implement `_day_opt`; calling from the base class
 *         # will implicitly assume day_opt = "business_end", see get_day_of_month.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_43_get_offset_day, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__get_offset_day, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__92)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_get_offset_day, __pyx_t_2) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":696
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp intersects with this frequency.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 696, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 696, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_45is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__94)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_on_offset, __pyx_t_3) < 0) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":733
 *     # Staticmethod so we can call from Tick.__init__, will be unnecessary
 *     #  once BaseOffset is a cdef class and is inherited by Tick
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     def _validate_n(n) -> int:
 *         """
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 733, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_47_validate_n, __Pyx_CYFUNCTION_STATICMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset__validate_n, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__96)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_validate_n, __pyx_t_2) < 0) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_validate_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_staticmethod, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_validate_n, __pyx_t_3) < 0) __PYX_ERR(0, 733, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":761
 *         return nint
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_49__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__98)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_setstate, __pyx_t_3) < 0) __PYX_ERR(0, 761, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":770
 *         # At this point we expect state to be empty
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_51__getstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset___getstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__99)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_getstate, __pyx_t_3) < 0) __PYX_ERR(0, 770, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":790
 *         raise ValueError(f"{self} is a non-fixed frequency")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         # TODO: Does this make sense for the general case?  It would help
 *         # if there were a canonical docstring for what is_anchored means.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 790, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_53is_anchored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_anchored, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__100)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_anchored, __pyx_t_2) < 0) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":807
 *     # ------------------------------------------------------------------
 * 
 *     def is_month_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month start.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_55is_month_start, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_month_start, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__102)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_month_start, __pyx_t_2) < 0) __PYX_ERR(0, 807, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":820
 *         return ts._get_start_end_field("is_month_start", self)
 * 
 *     def is_month_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the month end.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_57is_month_end, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_month_end, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__103)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_month_end, __pyx_t_2) < 0) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":833
 *         return ts._get_start_end_field("is_month_end", self)
 * 
 *     def is_quarter_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter start.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_59is_quarter_start, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_quarter_start, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__104)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_quarter_start, __pyx_t_2) < 0) __PYX_ERR(0, 833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":846
 *         return ts._get_start_end_field("is_quarter_start", self)
 * 
 *     def is_quarter_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the quarter end.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_61is_quarter_end, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_quarter_end, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__105)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_quarter_end, __pyx_t_2) < 0) __PYX_ERR(0, 846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":859
 *         return ts._get_start_end_field("is_quarter_end", self)
 * 
 *     def is_year_start(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year start.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_63is_year_start, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_year_start, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__106)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_year_start, __pyx_t_2) < 0) __PYX_ERR(0, 859, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":872
 *         return ts._get_start_end_field("is_year_start", self)
 * 
 *     def is_year_end(self, _Timestamp ts):             # <<<<<<<<<<<<<<
 *         """
 *         Return boolean whether a timestamp occurs on the year end.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_65is_year_end, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset_is_year_end, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__107)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_is_year_end, __pyx_t_2) < 0) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_67__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset___reduce_cython, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__109)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_BaseOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_BaseOffset__set_state(self, __pyx_state)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10BaseOffset_69__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BaseOffset___setstate_cython, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__111)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":887
 * 
 * cdef class SingleConstructorOffset(BaseOffset):
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         # default _from_name calls cls with no args
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_1_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SingleConstructorOffset__from_na, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__113)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset, __pyx_n_s_from_name, __pyx_t_3) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":894
 *         return cls()
 * 
 *     def __reduce__(self):             # <<<<<<<<<<<<<<
 *         # This __reduce__ implementation is for all BaseOffset subclasses
 *         #  except for RelativeDeltaOffset
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23SingleConstructorOffset_3__reduce__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SingleConstructorOffset___reduce, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__116)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset, __pyx_n_s_reduce, __pyx_t_3) < 0) __PYX_ERR(0, 894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SingleConstructorOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":910
 * 
 * cdef class Tick(SingleConstructorOffset):
 *     _adjust_dst = False             # <<<<<<<<<<<<<<
 *     _prefix = "undefined"
 *     _td64_unit = "undefined"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_adjust_dst, Py_False) < 0) __PYX_ERR(0, 910, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":911
 * cdef class Tick(SingleConstructorOffset):
 *     _adjust_dst = False
 *     _prefix = "undefined"             # <<<<<<<<<<<<<<
 *     _td64_unit = "undefined"
 *     _attributes = tuple(["n", "normalize"])
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_prefix, __pyx_n_u_undefined) < 0) __PYX_ERR(0, 911, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":912
 *     _adjust_dst = False
 *     _prefix = "undefined"
 *     _td64_unit = "undefined"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_td64_unit, __pyx_n_u_undefined) < 0) __PYX_ERR(0, 912, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":913
 *     _prefix = "undefined"
 *     _td64_unit = "undefined"
 *     _attributes = tuple(["n", "normalize"])             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False):
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_n)) __PYX_ERR(0, 913, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 913, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 913, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":928
 *     # Note: Without making this cpdef, we get AttributeError when calling
 *     #  from __mul__
 *     cpdef Tick _next_higher_resolution(Tick self):             # <<<<<<<<<<<<<<
 *         if type(self) is Day:
 *             return Hour(self.n * 24)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_3_next_higher_resolution, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick__next_higher_resolution, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__117)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_next_higher_resolution, __pyx_t_2) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":945
 *     # --------------------------------------------------------------------
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         # Since cdef classes have no __dict__, we need to override
 *         return ""
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 945, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_5_repr_attrs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick__repr_attrs, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__118)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_repr_attrs, __pyx_t_3) < 0) __PYX_ERR(0, 945, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":970
 *         return self.n * self._nanos_inc
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 970, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 970, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_7is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__119)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":973
 *         return True
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 973, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_9is_anchored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick_is_anchored, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__120)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_is_anchored, __pyx_t_3) < 0) __PYX_ERR(0, 973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":1065
 *         return self.__add__(other)
 * 
 *     def _apply(self, other):             # <<<<<<<<<<<<<<
 *         # Timestamp can handle tz and nano sec, thus no need to use apply_wraps
 *         if isinstance(other, _Timestamp):
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_37_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__121)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_apply, __pyx_t_3) < 0) __PYX_ERR(0, 1065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":1084
 *     # Pickle Methods
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state["n"]
 *         self.normalize = False
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Tick_39__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Tick___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__122)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick, __pyx_n_s_setstate, __pyx_t_3) < 0) __PYX_ERR(0, 1084, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Tick);

  /* "pandas/_libs/tslibs/offsets.pyx":1090
 * 
 * cdef class Day(Tick):
 *     _nanos_inc = 24 * 3600 * 1_000_000_000             # <<<<<<<<<<<<<<
 *     _prefix = "D"
 *     _td64_unit = "D"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_n_s_nanos_inc, __pyx_int_0x4e94914f0000) < 0) __PYX_ERR(0, 1090, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);

  /* "pandas/_libs/tslibs/offsets.pyx":1091
 * cdef class Day(Tick):
 *     _nanos_inc = 24 * 3600 * 1_000_000_000
 *     _prefix = "D"             # <<<<<<<<<<<<<<
 *     _td64_unit = "D"
 *     _period_dtype_code = PeriodDtypeCode.D
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_n_s_prefix, __pyx_n_u_D) < 0) __PYX_ERR(0, 1091, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);

  /* "pandas/_libs/tslibs/offsets.pyx":1092
 *     _nanos_inc = 24 * 3600 * 1_000_000_000
 *     _prefix = "D"
 *     _td64_unit = "D"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.D
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_D
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_n_s_td64_unit, __pyx_n_u_D) < 0) __PYX_ERR(0, 1092, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);

  /* "pandas/_libs/tslibs/offsets.pyx":1093
 *     _prefix = "D"
 *     _td64_unit = "D"
 *     _period_dtype_code = PeriodDtypeCode.D             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_D
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_D); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1093, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);

  /* "pandas/_libs/tslibs/offsets.pyx":1094
 *     _td64_unit = "D"
 *     _period_dtype_code = PeriodDtypeCode.D
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_D             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_D); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1094, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);

  /* "pandas/_libs/tslibs/offsets.pyx":1098
 * 
 * cdef class Hour(Tick):
 *     _nanos_inc = 3600 * 1_000_000_000             # <<<<<<<<<<<<<<
 *     _prefix = "H"
 *     _td64_unit = "h"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_n_s_nanos_inc, __pyx_int_3600000000000) < 0) __PYX_ERR(0, 1098, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);

  /* "pandas/_libs/tslibs/offsets.pyx":1099
 * cdef class Hour(Tick):
 *     _nanos_inc = 3600 * 1_000_000_000
 *     _prefix = "H"             # <<<<<<<<<<<<<<
 *     _td64_unit = "h"
 *     _period_dtype_code = PeriodDtypeCode.H
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_n_s_prefix, __pyx_n_u_H) < 0) __PYX_ERR(0, 1099, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);

  /* "pandas/_libs/tslibs/offsets.pyx":1100
 *     _nanos_inc = 3600 * 1_000_000_000
 *     _prefix = "H"
 *     _td64_unit = "h"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.H
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_h
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_n_s_td64_unit, __pyx_n_u_h) < 0) __PYX_ERR(0, 1100, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);

  /* "pandas/_libs/tslibs/offsets.pyx":1101
 *     _prefix = "H"
 *     _td64_unit = "h"
 *     _period_dtype_code = PeriodDtypeCode.H             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_h
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_H); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);

  /* "pandas/_libs/tslibs/offsets.pyx":1102
 *     _td64_unit = "h"
 *     _period_dtype_code = PeriodDtypeCode.H
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_h             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);

  /* "pandas/_libs/tslibs/offsets.pyx":1106
 * 
 * cdef class Minute(Tick):
 *     _nanos_inc = 60 * 1_000_000_000             # <<<<<<<<<<<<<<
 *     _prefix = "T"
 *     _td64_unit = "m"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_n_s_nanos_inc, __pyx_int_60000000000) < 0) __PYX_ERR(0, 1106, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);

  /* "pandas/_libs/tslibs/offsets.pyx":1107
 * cdef class Minute(Tick):
 *     _nanos_inc = 60 * 1_000_000_000
 *     _prefix = "T"             # <<<<<<<<<<<<<<
 *     _td64_unit = "m"
 *     _period_dtype_code = PeriodDtypeCode.T
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_n_s_prefix, __pyx_n_u_T) < 0) __PYX_ERR(0, 1107, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);

  /* "pandas/_libs/tslibs/offsets.pyx":1108
 *     _nanos_inc = 60 * 1_000_000_000
 *     _prefix = "T"
 *     _td64_unit = "m"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.T
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_m
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_n_s_td64_unit, __pyx_n_u_m) < 0) __PYX_ERR(0, 1108, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);

  /* "pandas/_libs/tslibs/offsets.pyx":1109
 *     _prefix = "T"
 *     _td64_unit = "m"
 *     _period_dtype_code = PeriodDtypeCode.T             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_m
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_T); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1109, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);

  /* "pandas/_libs/tslibs/offsets.pyx":1110
 *     _td64_unit = "m"
 *     _period_dtype_code = PeriodDtypeCode.T
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_m             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_m); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);

  /* "pandas/_libs/tslibs/offsets.pyx":1114
 * 
 * cdef class Second(Tick):
 *     _nanos_inc = 1_000_000_000             # <<<<<<<<<<<<<<
 *     _prefix = "S"
 *     _td64_unit = "s"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_n_s_nanos_inc, __pyx_int_1000000000) < 0) __PYX_ERR(0, 1114, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);

  /* "pandas/_libs/tslibs/offsets.pyx":1115
 * cdef class Second(Tick):
 *     _nanos_inc = 1_000_000_000
 *     _prefix = "S"             # <<<<<<<<<<<<<<
 *     _td64_unit = "s"
 *     _period_dtype_code = PeriodDtypeCode.S
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_n_s_prefix, __pyx_n_u_S) < 0) __PYX_ERR(0, 1115, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);

  /* "pandas/_libs/tslibs/offsets.pyx":1116
 *     _nanos_inc = 1_000_000_000
 *     _prefix = "S"
 *     _td64_unit = "s"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.S
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_s
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_n_s_td64_unit, __pyx_n_u_s) < 0) __PYX_ERR(0, 1116, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);

  /* "pandas/_libs/tslibs/offsets.pyx":1117
 *     _prefix = "S"
 *     _td64_unit = "s"
 *     _period_dtype_code = PeriodDtypeCode.S             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_s
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_S); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);

  /* "pandas/_libs/tslibs/offsets.pyx":1118
 *     _td64_unit = "s"
 *     _period_dtype_code = PeriodDtypeCode.S
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_s             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);

  /* "pandas/_libs/tslibs/offsets.pyx":1122
 * 
 * cdef class Milli(Tick):
 *     _nanos_inc = 1_000_000             # <<<<<<<<<<<<<<
 *     _prefix = "L"
 *     _td64_unit = "ms"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_n_s_nanos_inc, __pyx_int_1000000) < 0) __PYX_ERR(0, 1122, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);

  /* "pandas/_libs/tslibs/offsets.pyx":1123
 * cdef class Milli(Tick):
 *     _nanos_inc = 1_000_000
 *     _prefix = "L"             # <<<<<<<<<<<<<<
 *     _td64_unit = "ms"
 *     _period_dtype_code = PeriodDtypeCode.L
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_n_s_prefix, __pyx_n_u_L) < 0) __PYX_ERR(0, 1123, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);

  /* "pandas/_libs/tslibs/offsets.pyx":1124
 *     _nanos_inc = 1_000_000
 *     _prefix = "L"
 *     _td64_unit = "ms"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.L
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ms
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_n_s_td64_unit, __pyx_n_u_ms) < 0) __PYX_ERR(0, 1124, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);

  /* "pandas/_libs/tslibs/offsets.pyx":1125
 *     _prefix = "L"
 *     _td64_unit = "ms"
 *     _period_dtype_code = PeriodDtypeCode.L             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ms
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_L); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);

  /* "pandas/_libs/tslibs/offsets.pyx":1126
 *     _td64_unit = "ms"
 *     _period_dtype_code = PeriodDtypeCode.L
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ms             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_ms); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);

  /* "pandas/_libs/tslibs/offsets.pyx":1130
 * 
 * cdef class Micro(Tick):
 *     _nanos_inc = 1000             # <<<<<<<<<<<<<<
 *     _prefix = "U"
 *     _td64_unit = "us"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_n_s_nanos_inc, __pyx_int_1000) < 0) __PYX_ERR(0, 1130, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);

  /* "pandas/_libs/tslibs/offsets.pyx":1131
 * cdef class Micro(Tick):
 *     _nanos_inc = 1000
 *     _prefix = "U"             # <<<<<<<<<<<<<<
 *     _td64_unit = "us"
 *     _period_dtype_code = PeriodDtypeCode.U
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_n_s_prefix, __pyx_n_u_U) < 0) __PYX_ERR(0, 1131, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);

  /* "pandas/_libs/tslibs/offsets.pyx":1132
 *     _nanos_inc = 1000
 *     _prefix = "U"
 *     _td64_unit = "us"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.U
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_us
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_n_s_td64_unit, __pyx_n_u_us) < 0) __PYX_ERR(0, 1132, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);

  /* "pandas/_libs/tslibs/offsets.pyx":1133
 *     _prefix = "U"
 *     _td64_unit = "us"
 *     _period_dtype_code = PeriodDtypeCode.U             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_us
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_U); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);

  /* "pandas/_libs/tslibs/offsets.pyx":1134
 *     _td64_unit = "us"
 *     _period_dtype_code = PeriodDtypeCode.U
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_us             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_us); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);

  /* "pandas/_libs/tslibs/offsets.pyx":1138
 * 
 * cdef class Nano(Tick):
 *     _nanos_inc = 1             # <<<<<<<<<<<<<<
 *     _prefix = "N"
 *     _td64_unit = "ns"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_n_s_nanos_inc, __pyx_int_1) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);

  /* "pandas/_libs/tslibs/offsets.pyx":1139
 * cdef class Nano(Tick):
 *     _nanos_inc = 1
 *     _prefix = "N"             # <<<<<<<<<<<<<<
 *     _td64_unit = "ns"
 *     _period_dtype_code = PeriodDtypeCode.N
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_n_s_prefix, __pyx_n_u_N) < 0) __PYX_ERR(0, 1139, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);

  /* "pandas/_libs/tslibs/offsets.pyx":1140
 *     _nanos_inc = 1
 *     _prefix = "N"
 *     _td64_unit = "ns"             # <<<<<<<<<<<<<<
 *     _period_dtype_code = PeriodDtypeCode.N
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ns
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_n_s_td64_unit, __pyx_n_u_ns) < 0) __PYX_ERR(0, 1140, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);

  /* "pandas/_libs/tslibs/offsets.pyx":1141
 *     _prefix = "N"
 *     _td64_unit = "ns"
 *     _period_dtype_code = PeriodDtypeCode.N             # <<<<<<<<<<<<<<
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ns
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_N); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_n_s_period_dtype_code, __pyx_t_3) < 0) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);

  /* "pandas/_libs/tslibs/offsets.pyx":1142
 *     _td64_unit = "ns"
 *     _period_dtype_code = PeriodDtypeCode.N
 *     _creso = NPY_DATETIMEUNIT.NPY_FR_ns             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_FR_ns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano, __pyx_n_s_creso, __pyx_t_3) < 0) __PYX_ERR(0, 1142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);

  /* "pandas/_libs/tslibs/offsets.pyx":1145
 * 
 * 
 * def delta_to_tick(delta: timedelta) -> Tick:             # <<<<<<<<<<<<<<
 *     if delta.microseconds == 0 and getattr(delta, "nanoseconds", 0) == 0:
 *         # nanoseconds only for pd.Timedelta
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_delta, __pyx_n_s_timedelta) < 0) __PYX_ERR(0, 1145, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_Tick) < 0) __PYX_ERR(0, 1145, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_7delta_to_tick, 0, __pyx_n_s_delta_to_tick, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_delta_to_tick, __pyx_t_2) < 0) __PYX_ERR(0, 1145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1174
 *     DateOffset subclass backed by a dateutil relativedelta object.
 *     """
 *     _attributes = tuple(["n", "normalize"] + list(_relativedelta_kwds))             # <<<<<<<<<<<<<<
 *     _adjust_dst = False
 * 
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 1174, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 1174, __pyx_L1_error);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_relativedelta_kwds); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PySequence_ListKeepNew(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_AsTuple(((PyObject*)__pyx_t_3)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_attributes, __pyx_t_5) < 0) __PYX_ERR(0, 1174, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1175
 *     """
 *     _attributes = tuple(["n", "normalize"] + list(_relativedelta_kwds))
 *     _adjust_dst = False             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, **kwds):
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_adjust_dst, Py_False) < 0) __PYX_ERR(0, 1175, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1186
 *             object.__setattr__(self, key, val)
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         """
 *         Return a pickleable state
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_3__getstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset___getstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__125)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_getstate, __pyx_t_5) < 0) __PYX_ERR(0, 1186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1197
 *         return state
 * 
 *     def __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         """
 *         Reconstruct an instance from a pickled state
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_5__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__126)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_setstate, __pyx_t_5) < 0) __PYX_ERR(0, 1197, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1215
 *         self.__dict__.update(state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         if self._use_relativedelta:
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_7_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__128)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_3, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply, __pyx_t_3) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply, __pyx_t_3) < 0) __PYX_ERR(0, 1215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1246
 *             return other + timedelta(self.n)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_9_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__130)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply_array, __pyx_t_3) < 0) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_apply_array, __pyx_t_3) < 0) __PYX_ERR(0, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1304
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1304, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 1304, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_11is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_is_on_offset, __pyx_t_5) < 0) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_13__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset___reduce_cyt, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__132)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RelativeDeltaOffset, (type(self), 0xa31c5ed, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RelativeDeltaOffset__set_state(self, __pyx_state)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19RelativeDeltaOffset_15__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_RelativeDeltaOffset___setstate_c, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__133)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(5, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":1310
 * 
 * 
 * class OffsetMeta(type):             # <<<<<<<<<<<<<<
 *     """
 *     Metaclass that allows us to pretend that all BaseOffset subclasses
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF((PyObject *)(&PyType_Type));
  __Pyx_GIVEREF((PyObject *)(&PyType_Type));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)(&PyType_Type)))) __PYX_ERR(0, 1310, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PEP560_update_bases(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_OffsetMeta, __pyx_n_s_OffsetMeta, (PyObject *) NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_kp_s_Metaclass_that_allows_us_to_pre); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__pyx_t_3 != __pyx_t_5) {
    if (unlikely((PyDict_SetItemString(__pyx_t_6, "__orig_bases__", __pyx_t_5) < 0))) __PYX_ERR(0, 1310, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1316
 *     """
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __instancecheck__(cls, obj) -> bool:
 *         return isinstance(obj, BaseOffset)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 1316, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_1__instancecheck__, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_OffsetMeta___instancecheck, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__135)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_Method_ClassMethod(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_instancecheck, __pyx_t_5) < 0) __PYX_ERR(0, 1316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1320
 *         return isinstance(obj, BaseOffset)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def __subclasscheck__(cls, obj) -> bool:
 *         return issubclass(obj, BaseOffset)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 1320, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10OffsetMeta_3__subclasscheck__, __Pyx_CYFUNCTION_CLASSMETHOD, __pyx_n_s_OffsetMeta___subclasscheck, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__136)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_Method_ClassMethod(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_subclasscheck, __pyx_t_5) < 0) __PYX_ERR(0, 1320, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1310
 * 
 * 
 * class OffsetMeta(type):             # <<<<<<<<<<<<<<
 *     """
 *     Metaclass that allows us to pretend that all BaseOffset subclasses
 */
  __pyx_t_5 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_OffsetMeta, __pyx_t_3, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OffsetMeta, __pyx_t_5) < 0) __PYX_ERR(0, 1310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1326
 * 
 * # TODO: figure out a way to use a metaclass with a cdef class
 * class DateOffset(RelativeDeltaOffset, metaclass=OffsetMeta):             # <<<<<<<<<<<<<<
 *     """
 *     Standard kind of date increment used for a date range.
 */
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_RelativeDeltaOffset))) __PYX_ERR(0, 1326, __pyx_L1_error);
  __pyx_t_2 = __Pyx_PEP560_update_bases(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_OffsetMeta); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_Py3MetaclassPrepare(__pyx_t_5, __pyx_t_2, __pyx_n_s_DateOffset, __pyx_n_s_DateOffset, __pyx_t_6, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_kp_s_Standard_kind_of_date_increment); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__pyx_t_2 != __pyx_t_3) {
    if (unlikely((PyDict_SetItemString(__pyx_t_7, "__orig_bases__", __pyx_t_3) < 0))) __PYX_ERR(0, 1326, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1431
 *     Timestamp('2017-01-01 08:10:11')
 *     """
 *     def __setattr__(self, name, value):             # <<<<<<<<<<<<<<
 *         raise AttributeError("DateOffset objects are immutable.")
 * 
 */
  __pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10DateOffset_1__setattr__, 0, __pyx_n_s_DateOffset___setattr, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__138)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_7, __pyx_n_s_setattr, __pyx_t_3) < 0) __PYX_ERR(0, 1431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1326
 * 
 * # TODO: figure out a way to use a metaclass with a cdef class
 * class DateOffset(RelativeDeltaOffset, metaclass=OffsetMeta):             # <<<<<<<<<<<<<<
 *     """
 *     Standard kind of date increment used for a date range.
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(__pyx_t_5, __pyx_n_s_DateOffset, __pyx_t_2, __pyx_t_7, __pyx_t_6, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DateOffset, __pyx_t_3) < 0) __PYX_ERR(0, 1326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1447
 *         object weekmask, holidays, calendar
 * 
 *     def __init__(self, n=1, normalize=False, offset=timedelta(0)):             # <<<<<<<<<<<<<<
 *         BaseOffset.__init__(self, n, normalize)
 *         self._offset = offset
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_k__33 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1451
 *         self._offset = offset
 * 
 *     cpdef _init_custom(self, weekmask, holidays, calendar):             # <<<<<<<<<<<<<<
 *         """
 *         Additional __init__ for Custom subclasses.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_3_init_custom, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessMixin__init_custom, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__140)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, __pyx_n_s_init_custom, __pyx_t_2) < 0) __PYX_ERR(0, 1451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);

  /* "pandas/_libs/tslibs/offsets.pyx":1473
 *         return self._offset
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.offset:
 *             attrs = [f"offset={repr(self.offset)}"]
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 1473, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_5_repr_attrs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessMixin__repr_attrs, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__142)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, __pyx_n_s_repr_attrs, __pyx_t_6) < 0) __PYX_ERR(0, 1473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);

  /* "pandas/_libs/tslibs/offsets.pyx":1483
 *         return out
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         # We need to use a cdef/cpdef method to set the readonly _offset attribute
 *         if "_offset" in state:
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13BusinessMixin_7__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessMixin___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__143)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 1483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMixin);

  /* "pandas/_libs/tslibs/offsets.pyx":1533
 *     Timestamp('2022-12-12 00:00:00')
 *     """
 *     _period_dtype_code = PeriodDtypeCode.B             # <<<<<<<<<<<<<<
 *     _prefix = "B"
 *     _attributes = tuple(["n", "normalize", "offset"])
 */
  __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_B); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_period_dtype_code, __pyx_t_6) < 0) __PYX_ERR(0, 1533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1534
 *     """
 *     _period_dtype_code = PeriodDtypeCode.B
 *     _prefix = "B"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "offset"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_prefix, __pyx_n_u_B) < 0) __PYX_ERR(0, 1534, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1535
 *     _period_dtype_code = PeriodDtypeCode.B
 *     _prefix = "B"
 *     _attributes = tuple(["n", "normalize", "offset"])             # <<<<<<<<<<<<<<
 * 
 *     cpdef __setstate__(self, state):
 */
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 1535, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 1535, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_offset_2);
  __Pyx_GIVEREF(__pyx_n_u_offset_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_offset_2)) __PYX_ERR(0, 1535, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 1535, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1537
 *     _attributes = tuple(["n", "normalize", "offset"])
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_1__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessDay___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__144)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1546
 *         self._cache = state.pop("_cache", {})
 * 
 *     def _offset_str(self) -> str:             # <<<<<<<<<<<<<<
 *         def get_str(td):
 *             off_str = ""
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 1546, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_3_offset_str, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessDay__offset_str, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__146)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_offset_str, __pyx_t_6) < 0) __PYX_ERR(0, 1546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1577
 *             return "+" + repr(self.offset)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if PyDateTime_Check(other):
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_5_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessDay__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__148)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1607
 *         self,
 *         ndarray i8other,
 *         NPY_DATETIMEUNIT reso=NPY_DATETIMEUNIT.NPY_FR_ns,             # <<<<<<<<<<<<<<
 *     ):
 *         """
 */
  __pyx_k__39 = NPY_FR_ns;

  /* "pandas/_libs/tslibs/offsets.pyx":1681
 *         return days
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         i8other = dtarr.view("i8")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_7_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessDay__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__150)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 1681, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1691
 *         return res
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1691, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 1691, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11BusinessDay_9is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessDay_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__151)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 1691, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":1753
 *     """
 * 
 *     _prefix = "BH"             # <<<<<<<<<<<<<<
 *     _anchor = 0
 *     _attributes = tuple(["n", "normalize", "start", "end", "offset"])
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_prefix, __pyx_n_u_BH) < 0) __PYX_ERR(0, 1753, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1754
 * 
 *     _prefix = "BH"
 *     _anchor = 0             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "start", "end", "offset"])
 *     _adjust_dst = False
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_anchor, __pyx_int_0) < 0) __PYX_ERR(0, 1754, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1755
 *     _prefix = "BH"
 *     _anchor = 0
 *     _attributes = tuple(["n", "normalize", "start", "end", "offset"])             # <<<<<<<<<<<<<<
 *     _adjust_dst = False
 * 
 */
  __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 1755, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 1755, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_start);
  __Pyx_GIVEREF(__pyx_n_u_start);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_start)) __PYX_ERR(0, 1755, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_end);
  __Pyx_GIVEREF(__pyx_n_u_end);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_end)) __PYX_ERR(0, 1755, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_offset_2);
  __Pyx_GIVEREF(__pyx_n_u_offset_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_offset_2)) __PYX_ERR(0, 1755, __pyx_L1_error);
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 1755, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1756
 *     _anchor = 0
 *     _attributes = tuple(["n", "normalize", "start", "end", "offset"])
 *     _adjust_dst = False             # <<<<<<<<<<<<<<
 * 
 *     cdef readonly:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_adjust_dst, Py_False) < 0) __PYX_ERR(0, 1756, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1762
 * 
 *     def __init__(
 *             self, n=1, normalize=False, start="09:00", end="17:00", offset=timedelta(0)             # <<<<<<<<<<<<<<
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)
 */
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1762, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_k__40 = __pyx_t_6;
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1810
 *         self.end = end
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         start = state.pop("start")
 *         start = (start,) if np.ndim(start) == 0 else tuple(start)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__152)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 1810, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1822
 *         BusinessMixin.__setstate__(self, state)
 * 
 *     def _repr_attrs(self) -> str:             # <<<<<<<<<<<<<<
 *         out = super()._repr_attrs()
 *         # Use python string formatting to be faster than strftime
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 1822, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_5_repr_attrs, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__repr_attrs, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__154)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_repr_attrs, __pyx_t_2) < 0) __PYX_ERR(0, 1822, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1833
 *         return out
 * 
 *     def _get_business_hours_by_sec(self, start, end):             # <<<<<<<<<<<<<<
 *         """
 *         Return business hours in a day by seconds.
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_7_get_business_hours_by_sec, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__get_business_hours, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__156)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_get_business_hours_by_sec, __pyx_t_2) < 0) __PYX_ERR(0, 1833, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1843
 *         return int((until - dtstart).total_seconds())
 * 
 *     def _get_closing_time(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         Get the closing time of a business hour interval by its opening time.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1843, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1843, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_9_get_closing_time, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__get_closing_time, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__158)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_get_closing_time, __pyx_t_6) < 0) __PYX_ERR(0, 1843, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1864
 *         assert False
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def next_bday(self):
 *         """
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_11next_bday, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour_next_bday, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__160)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_next_bday, __pyx_t_6) < 0) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_next_bday); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1864, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_next_bday, __pyx_t_6) < 0) __PYX_ERR(0, 1864, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1884
 *             return BusinessDay(n=nb_offset)
 * 
 *     def _next_opening_time(self, other, sign=1):             # <<<<<<<<<<<<<<
 *         """
 *         If self.n and sign have the same sign, return the earliest opening time
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_13_next_opening_time, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__next_opening_time, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__162)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__24);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_next_opening_time, __pyx_t_6) < 0) __PYX_ERR(0, 1884, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1948
 *         return datetime(other.year, other.month, other.day, hour, minute)
 * 
 *     def _prev_opening_time(self, other: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         """
 *         If n is positive, return the latest opening time earlier than or equal
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1948, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1948, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_15_prev_opening_time, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__prev_opening_time, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__163)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1948, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_prev_opening_time, __pyx_t_2) < 0) __PYX_ERR(0, 1948, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1967
 *         return self._next_opening_time(other, sign=-1)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollback(self, dt: datetime) -> datetime:
 *         """
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1967, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1967, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_17rollback, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour_rollback, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__164)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollback, __pyx_t_6) < 0) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollback); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1967, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollback, __pyx_t_6) < 0) __PYX_ERR(0, 1967, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1980
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def rollforward(self, dt: datetime) -> datetime:
 *         """
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1980, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1980, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_19rollforward, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour_rollforward, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__165)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollforward, __pyx_t_2) < 0) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollforward); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_rollforward, __pyx_t_2) < 0) __PYX_ERR(0, 1980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":1992
 *         return dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # used for detecting edge condition
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_21_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__167)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 1992, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":2091
 *         return other
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2091, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2091, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_23is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__168)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 2091, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":2103
 *         return self._is_on_offset(dt)
 * 
 *     def _is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         """
 *         Slight speedups using calculated values.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2103, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2103, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12BusinessHour_25_is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_BusinessHour__is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__170)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour, __pyx_n_s_is_on_offset_2, __pyx_t_6) < 0) __PYX_ERR(0, 2103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":2141
 *             raise ValueError(f"Day must be 0<=day<=6, got {weekday}")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2141, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2141, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_3_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_WeekOfMonthMixin__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__172)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);

  /* "pandas/_libs/tslibs/offsets.pyx":2152
 *         return _shift_day(shifted, to_day - shifted.day)
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2152, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2152, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_16WeekOfMonthMixin_5is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_WeekOfMonthMixin_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__173)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin, __pyx_n_s_is_on_offset, __pyx_t_6) < 0) __PYX_ERR(0, 2152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonthMixin);

  /* "pandas/_libs/tslibs/offsets.pyx":2173
 *     DateOffset that just needs a month.
 *     """
 *     _attributes = tuple(["n", "normalize", "month"])             # <<<<<<<<<<<<<<
 * 
 *     # FIXME(cython#4446): python annotation here gives compile-time errors
 */
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 2173, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 2173, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_month);
  __Pyx_GIVEREF(__pyx_n_u_month);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_month)) __PYX_ERR(0, 2173, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 2173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2190
 *             raise ValueError("Month must go from 1 to 12")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.month = state.pop("month")
 *         self.n = state.pop("n")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__174)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 2190, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2196
 *         self._cache = {}
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_5_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__176)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 2196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2208
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2208, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2208, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_7is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__177)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 2208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2213
 *         return dt.month == self.month and dt.day == self._get_offset_day(dt)
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         # override BaseOffset method to use self.month instead of other.month
 *         cdef:
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2213, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 2213, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_9_get_offset_day, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset__get_offset_day, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__178)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_get_offset_day, __pyx_t_6) < 0) __PYX_ERR(0, 2213, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2221
 *         return get_day_of_month(&dts, self._day_opt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         years = roll_qtrday(other, self.n, self.month, self._day_opt, modby=12)
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2221, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2221, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_11_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__180)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2227
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_10YearOffset_13_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_YearOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__182)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply_array, __pyx_t_2) < 0) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset, __pyx_n_s_apply_array, __pyx_t_2) < 0) __PYX_ERR(0, 2227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2256
 *     """
 * 
 *     _outputName = "BusinessYearEnd"             # <<<<<<<<<<<<<<
 *     _default_month = 12
 *     _prefix = "BA"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd, __pyx_n_s_outputName, __pyx_n_u_BusinessYearEnd) < 0) __PYX_ERR(0, 2256, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2257
 * 
 *     _outputName = "BusinessYearEnd"
 *     _default_month = 12             # <<<<<<<<<<<<<<
 *     _prefix = "BA"
 *     _day_opt = "business_end"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd, __pyx_n_s_default_month, __pyx_int_12) < 0) __PYX_ERR(0, 2257, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2258
 *     _outputName = "BusinessYearEnd"
 *     _default_month = 12
 *     _prefix = "BA"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd, __pyx_n_s_prefix, __pyx_n_u_BA) < 0) __PYX_ERR(0, 2258, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2259
 *     _default_month = 12
 *     _prefix = "BA"
 *     _day_opt = "business_end"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd, __pyx_n_s_day_opt, __pyx_n_u_business_end) < 0) __PYX_ERR(0, 2259, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2280
 *     """
 * 
 *     _outputName = "BusinessYearBegin"             # <<<<<<<<<<<<<<
 *     _default_month = 1
 *     _prefix = "BAS"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin, __pyx_n_s_outputName, __pyx_n_u_BusinessYearBegin) < 0) __PYX_ERR(0, 2280, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2281
 * 
 *     _outputName = "BusinessYearBegin"
 *     _default_month = 1             # <<<<<<<<<<<<<<
 *     _prefix = "BAS"
 *     _day_opt = "business_start"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin, __pyx_n_s_default_month, __pyx_int_1) < 0) __PYX_ERR(0, 2281, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2282
 *     _outputName = "BusinessYearBegin"
 *     _default_month = 1
 *     _prefix = "BAS"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin, __pyx_n_s_prefix, __pyx_n_u_BAS) < 0) __PYX_ERR(0, 2282, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2283
 *     _default_month = 1
 *     _prefix = "BAS"
 *     _day_opt = "business_start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin, __pyx_n_s_day_opt, __pyx_n_u_business_start) < 0) __PYX_ERR(0, 2283, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2297
 *     """
 * 
 *     _default_month = 12             # <<<<<<<<<<<<<<
 *     _prefix = "A"
 *     _day_opt = "end"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd, __pyx_n_s_default_month, __pyx_int_12) < 0) __PYX_ERR(0, 2297, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2298
 * 
 *     _default_month = 12
 *     _prefix = "A"             # <<<<<<<<<<<<<<
 *     _day_opt = "end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd, __pyx_n_s_prefix, __pyx_n_u_A) < 0) __PYX_ERR(0, 2298, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2299
 *     _default_month = 12
 *     _prefix = "A"
 *     _day_opt = "end"             # <<<<<<<<<<<<<<
 * 
 *     cdef readonly:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd, __pyx_n_s_day_opt, __pyx_n_u_end) < 0) __PYX_ERR(0, 2299, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2338
 *     """
 * 
 *     _default_month = 1             # <<<<<<<<<<<<<<
 *     _prefix = "AS"
 *     _day_opt = "start"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin, __pyx_n_s_default_month, __pyx_int_1) < 0) __PYX_ERR(0, 2338, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2339
 * 
 *     _default_month = 1
 *     _prefix = "AS"             # <<<<<<<<<<<<<<
 *     _day_opt = "start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin, __pyx_n_s_prefix, __pyx_n_u_AS) < 0) __PYX_ERR(0, 2339, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2340
 *     _default_month = 1
 *     _prefix = "AS"
 *     _day_opt = "start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin, __pyx_n_s_day_opt, __pyx_n_u_start) < 0) __PYX_ERR(0, 2340, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2347
 * 
 * cdef class QuarterOffset(SingleConstructorOffset):
 *     _attributes = tuple(["n", "normalize", "startingMonth"])             # <<<<<<<<<<<<<<
 *     # TODO: Consider combining QuarterOffset and YearOffset __init__ at some
 *     #       point.  Also apply_index, is_on_offset, rule_code if
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 2347, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 2347, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_startingMonth);
  __Pyx_GIVEREF(__pyx_n_u_startingMonth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_startingMonth)) __PYX_ERR(0, 2347, __pyx_L1_error);
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 2347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2366
 *         self.startingMonth = startingMonth
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.startingMonth = state.pop("startingMonth")
 *         self.n = state.pop("n")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__183)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 2366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2371
 *         self.normalize = state.pop("normalize")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         kwargs = {}
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_5_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__184)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  __Pyx_GetNameInClass(__pyx_t_6, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_from_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 2371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2386
 *         return f"{self._prefix}-{month}"
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.startingMonth is not None
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_7is_anchored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset_is_anchored, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__185)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_is_anchored, __pyx_t_6) < 0) __PYX_ERR(0, 2386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2389
 *         return self.n == 1 and self.startingMonth is not None
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2389, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2389, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_9is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__187)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 2389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2395
 *         return mod_month == 0 and dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # months_since: find the calendar quarter containing other.month,
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2395, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2395, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_11_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__189)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2409
 *         return shift_month(other, months, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13QuarterOffset_13_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_QuarterOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__190)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2409, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2444
 *     Timestamp('2020-05-29 05:01:15')
 *     """
 *     _output_name = "BusinessQuarterEnd"             # <<<<<<<<<<<<<<
 *     _default_starting_month = 3
 *     _from_name_starting_month = 12
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_n_s_output_name, __pyx_n_u_BusinessQuarterEnd) < 0) __PYX_ERR(0, 2444, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2445
 *     """
 *     _output_name = "BusinessQuarterEnd"
 *     _default_starting_month = 3             # <<<<<<<<<<<<<<
 *     _from_name_starting_month = 12
 *     _prefix = "BQ"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_n_s_default_starting_month, __pyx_int_3) < 0) __PYX_ERR(0, 2445, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2446
 *     _output_name = "BusinessQuarterEnd"
 *     _default_starting_month = 3
 *     _from_name_starting_month = 12             # <<<<<<<<<<<<<<
 *     _prefix = "BQ"
 *     _day_opt = "business_end"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_n_s_from_name_starting_month, __pyx_int_12) < 0) __PYX_ERR(0, 2446, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2447
 *     _default_starting_month = 3
 *     _from_name_starting_month = 12
 *     _prefix = "BQ"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_n_s_prefix, __pyx_n_u_BQ) < 0) __PYX_ERR(0, 2447, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2448
 *     _from_name_starting_month = 12
 *     _prefix = "BQ"
 *     _day_opt = "business_end"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd, __pyx_n_s_day_opt, __pyx_n_u_business_end) < 0) __PYX_ERR(0, 2448, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2472
 *     Timestamp('2020-03-02 05:01:15')
 *     """
 *     _output_name = "BusinessQuarterBegin"             # <<<<<<<<<<<<<<
 *     _default_starting_month = 3
 *     _from_name_starting_month = 1
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_n_s_output_name, __pyx_n_u_BusinessQuarterBegin) < 0) __PYX_ERR(0, 2472, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2473
 *     """
 *     _output_name = "BusinessQuarterBegin"
 *     _default_starting_month = 3             # <<<<<<<<<<<<<<
 *     _from_name_starting_month = 1
 *     _prefix = "BQS"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_n_s_default_starting_month, __pyx_int_3) < 0) __PYX_ERR(0, 2473, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2474
 *     _output_name = "BusinessQuarterBegin"
 *     _default_starting_month = 3
 *     _from_name_starting_month = 1             # <<<<<<<<<<<<<<
 *     _prefix = "BQS"
 *     _day_opt = "business_start"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_n_s_from_name_starting_month, __pyx_int_1) < 0) __PYX_ERR(0, 2474, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2475
 *     _default_starting_month = 3
 *     _from_name_starting_month = 1
 *     _prefix = "BQS"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_n_s_prefix, __pyx_n_u_BQS) < 0) __PYX_ERR(0, 2475, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2476
 *     _from_name_starting_month = 1
 *     _prefix = "BQS"
 *     _day_opt = "business_start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin, __pyx_n_s_day_opt, __pyx_n_u_business_start) < 0) __PYX_ERR(0, 2476, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2493
 *     Timestamp('2022-03-31 00:00:00')
 *     """
 *     _default_starting_month = 3             # <<<<<<<<<<<<<<
 *     _prefix = "Q"
 *     _day_opt = "end"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, __pyx_n_s_default_starting_month, __pyx_int_3) < 0) __PYX_ERR(0, 2493, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2494
 *     """
 *     _default_starting_month = 3
 *     _prefix = "Q"             # <<<<<<<<<<<<<<
 *     _day_opt = "end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, __pyx_n_s_prefix, __pyx_n_u_Q) < 0) __PYX_ERR(0, 2494, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2495
 *     _default_starting_month = 3
 *     _prefix = "Q"
 *     _day_opt = "end"             # <<<<<<<<<<<<<<
 * 
 *     cdef readonly:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd, __pyx_n_s_day_opt, __pyx_n_u_end) < 0) __PYX_ERR(0, 2495, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2521
 *     Timestamp('2022-03-01 00:00:00')
 *     """
 *     _default_starting_month = 3             # <<<<<<<<<<<<<<
 *     _from_name_starting_month = 1
 *     _prefix = "QS"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, __pyx_n_s_default_starting_month, __pyx_int_3) < 0) __PYX_ERR(0, 2521, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2522
 *     """
 *     _default_starting_month = 3
 *     _from_name_starting_month = 1             # <<<<<<<<<<<<<<
 *     _prefix = "QS"
 *     _day_opt = "start"
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, __pyx_n_s_from_name_starting_month, __pyx_int_1) < 0) __PYX_ERR(0, 2522, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2523
 *     _default_starting_month = 3
 *     _from_name_starting_month = 1
 *     _prefix = "QS"             # <<<<<<<<<<<<<<
 *     _day_opt = "start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, __pyx_n_s_prefix, __pyx_n_u_QS) < 0) __PYX_ERR(0, 2523, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2524
 *     _from_name_starting_month = 1
 *     _prefix = "QS"
 *     _day_opt = "start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin, __pyx_n_s_day_opt, __pyx_n_u_start) < 0) __PYX_ERR(0, 2524, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2531
 * 
 * cdef class MonthOffset(SingleConstructorOffset):
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2531, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2531, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_1is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_MonthOffset_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__191)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 2531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2536
 *         return dt.day == self._get_offset_day(dt)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         compare_day = self._get_offset_day(other)
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_3_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_MonthOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__193)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2536, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2542
 *         return shift_month(other, n, self._day_opt)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         reso = get_unit_from_dtype(dtarr.dtype)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_5_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_MonthOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__194)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2548
 *         return shifted
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         state.pop("_use_relativedelta", False)
 *         state.pop("offset", None)
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11MonthOffset_7__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_MonthOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__195)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 2548, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2583
 *     Timestamp('2022-01-31 00:00:00')
 *     """
 *     _period_dtype_code = PeriodDtypeCode.M             # <<<<<<<<<<<<<<
 *     _prefix = "M"
 *     _day_opt = "end"
 */
  __pyx_t_6 = __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(__pyx_e_6pandas_5_libs_6tslibs_6dtypes_M); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd, __pyx_n_s_period_dtype_code, __pyx_t_6) < 0) __PYX_ERR(0, 2583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2584
 *     """
 *     _period_dtype_code = PeriodDtypeCode.M
 *     _prefix = "M"             # <<<<<<<<<<<<<<
 *     _day_opt = "end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd, __pyx_n_s_prefix, __pyx_n_u_M) < 0) __PYX_ERR(0, 2584, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2585
 *     _period_dtype_code = PeriodDtypeCode.M
 *     _prefix = "M"
 *     _day_opt = "end"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd, __pyx_n_s_day_opt, __pyx_n_u_end) < 0) __PYX_ERR(0, 2585, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2598
 *     Timestamp('2022-02-01 00:00:00')
 *     """
 *     _prefix = "MS"             # <<<<<<<<<<<<<<
 *     _day_opt = "start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin, __pyx_n_s_prefix, __pyx_n_u_MS) < 0) __PYX_ERR(0, 2598, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2599
 *     """
 *     _prefix = "MS"
 *     _day_opt = "start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin, __pyx_n_s_day_opt, __pyx_n_u_start) < 0) __PYX_ERR(0, 2599, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2624
 *     Timestamp('2022-11-30 00:00:00')
 *     """
 *     _prefix = "BM"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_end"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd, __pyx_n_s_prefix, __pyx_n_u_BM) < 0) __PYX_ERR(0, 2624, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2625
 *     """
 *     _prefix = "BM"
 *     _day_opt = "business_end"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd, __pyx_n_s_day_opt, __pyx_n_u_business_end) < 0) __PYX_ERR(0, 2625, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2643
 *     Timestamp('2020-03-02 05:01:15')
 *     """
 *     _prefix = "BMS"             # <<<<<<<<<<<<<<
 *     _day_opt = "business_start"
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin, __pyx_n_s_prefix, __pyx_n_u_BMS) < 0) __PYX_ERR(0, 2643, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2644
 *     """
 *     _prefix = "BMS"
 *     _day_opt = "business_start"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin, __pyx_n_s_day_opt, __pyx_n_u_business_start) < 0) __PYX_ERR(0, 2644, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2651
 * 
 * cdef class SemiMonthOffset(SingleConstructorOffset):
 *     _default_day_of_month = 15             # <<<<<<<<<<<<<<
 *     _min_day_of_month = 2
 *     _attributes = tuple(["n", "normalize", "day_of_month"])
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_default_day_of_month, __pyx_int_15) < 0) __PYX_ERR(0, 2651, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2652
 * cdef class SemiMonthOffset(SingleConstructorOffset):
 *     _default_day_of_month = 15
 *     _min_day_of_month = 2             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "day_of_month"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_min_day_of_month, __pyx_int_2) < 0) __PYX_ERR(0, 2652, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2653
 *     _default_day_of_month = 15
 *     _min_day_of_month = 2
 *     _attributes = tuple(["n", "normalize", "day_of_month"])             # <<<<<<<<<<<<<<
 * 
 *     cdef readonly:
 */
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 2653, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 2653, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_day_of_month);
  __Pyx_GIVEREF(__pyx_n_u_day_of_month);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_day_of_month)) __PYX_ERR(0, 2653, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2672
 *             )
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthOffset___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__196)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 2672, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2677
 *         self.day_of_month = state.pop("day_of_month")
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         return cls(day_of_month=suffix)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_5_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthOffset__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__197)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 2677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 2677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2686
 *         return self._prefix + suffix
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         is_start = isinstance(self, SemiMonthBegin)
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_7_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthOffset__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__199)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 2686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2713
 *         return shift_month(other, months, to_day)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     @cython.boundscheck(False)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15SemiMonthOffset_9_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthOffset__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__201)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply_array, __pyx_t_2) < 0) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset, __pyx_n_s_apply_array, __pyx_t_2) < 0) __PYX_ERR(0, 2713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthOffset);

  /* "pandas/_libs/tslibs/offsets.pyx":2813
 *     Timestamp('2022-01-15 00:00:00')
 *     """
 *     _prefix = "SM"             # <<<<<<<<<<<<<<
 *     _min_day_of_month = 1
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, __pyx_n_s_prefix, __pyx_n_u_SM) < 0) __PYX_ERR(0, 2813, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2814
 *     """
 *     _prefix = "SM"
 *     _min_day_of_month = 1             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, __pyx_n_s_min_day_of_month, __pyx_int_1) < 0) __PYX_ERR(0, 2814, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2816
 *     _min_day_of_month = 1
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_12SemiMonthEnd_1is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthEnd_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__203)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd, __pyx_n_s_is_on_offset, __pyx_t_6) < 0) __PYX_ERR(0, 2816, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":2840
 *     """
 * 
 *     _prefix = "SMS"             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin, __pyx_n_s_prefix, __pyx_n_u_SMS) < 0) __PYX_ERR(0, 2840, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2842
 *     _prefix = "SMS"
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 2842, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2842, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_14SemiMonthBegin_1is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_SemiMonthBegin_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 2842, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":2888
 *     """
 * 
 *     _inc = timedelta(weeks=1)             # <<<<<<<<<<<<<<
 *     _prefix = "W"
 *     _attributes = tuple(["n", "normalize", "weekday"])
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_weeks, __pyx_int_1) < 0) __PYX_ERR(0, 2888, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_inc_2, __pyx_t_6) < 0) __PYX_ERR(0, 2888, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2889
 * 
 *     _inc = timedelta(weeks=1)
 *     _prefix = "W"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "weekday"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_prefix, __pyx_n_u_W) < 0) __PYX_ERR(0, 2889, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2890
 *     _inc = timedelta(weeks=1)
 *     _prefix = "W"
 *     _attributes = tuple(["n", "normalize", "weekday"])             # <<<<<<<<<<<<<<
 * 
 *     cdef readonly:
 */
  __pyx_t_6 = PyList_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 2890, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 2890, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekday);
  __Pyx_GIVEREF(__pyx_n_u_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_weekday)) __PYX_ERR(0, 2890, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 2890, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2906
 *             self._period_dtype_code = PeriodDtypeCode.W_SUN + (weekday + 1) % 7
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2906, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 2906, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2912
 *         self._cache = state.pop("_cache", {})
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return self.n == 1 and self.weekday is not None
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 2912, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_5is_anchored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week_is_anchored, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__206)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_is_anchored, __pyx_t_6) < 0) __PYX_ERR(0, 2912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2915
 *         return self.n == 1 and self.weekday is not None
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.weekday is None:
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_7_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__208)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":2934
 *         return other + timedelta(weeks=k)
 * 
 *     @apply_array_wraps             # <<<<<<<<<<<<<<
 *     def _apply_array(self, dtarr):
 *         if self.weekday is None:
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_9_apply_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week__apply_array, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__210)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_array_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply_array); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 2934, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_apply_array, __pyx_t_6) < 0) __PYX_ERR(0, 2934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":3000
 *         return out
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3000, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3000, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_11is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__211)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 3000, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":3015
 *         return self._prefix + suffix
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_4Week_13_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Week__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__213)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 3015, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);

  /* "pandas/_libs/tslibs/offsets.pyx":3052
 *     """
 * 
 *     _prefix = "WOM"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "week", "weekday"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_prefix, __pyx_n_u_WOM) < 0) __PYX_ERR(0, 3052, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3053
 * 
 *     _prefix = "WOM"
 *     _attributes = tuple(["n", "normalize", "week", "weekday"])             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, week=0, weekday=0):
 */
  __pyx_t_6 = PyList_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 3053, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3053, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_week);
  __Pyx_GIVEREF(__pyx_n_u_week);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_week)) __PYX_ERR(0, 3053, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekday);
  __Pyx_GIVEREF(__pyx_n_u_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 3, __pyx_n_u_weekday)) __PYX_ERR(0, 3053, __pyx_L1_error);
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3053, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 3053, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3062
 *             raise ValueError(f"Week must be 0<=week<=3, got {self.week}")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_WeekOfMonth___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 3062, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3068
 *         self.week = state.pop("week")
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_5_get_offset_day, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_WeekOfMonth__get_offset_day, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__216)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_get_offset_day, __pyx_t_6) < 0) __PYX_ERR(0, 3068, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3086
 *         return 1 + shift_days + self.week * 7
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11WeekOfMonth_7_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_WeekOfMonth__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__218)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
  __Pyx_GetNameInClass(__pyx_t_6, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_from_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 3086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3123
 *     """
 * 
 *     _prefix = "LWOM"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "weekday"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_prefix, __pyx_n_u_LWOM) < 0) __PYX_ERR(0, 3123, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3124
 * 
 *     _prefix = "LWOM"
 *     _attributes = tuple(["n", "normalize", "weekday"])             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, n=1, normalize=False, weekday=0):
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 3124, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3124, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekday);
  __Pyx_GIVEREF(__pyx_n_u_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_weekday)) __PYX_ERR(0, 3124, __pyx_L1_error);
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 3124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3133
 *             raise ValueError("N cannot be 0")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_LastWeekOfMonth___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__219)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 3133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3139
 *         self.week = -1
 * 
 *     def _get_offset_day(self, other: datetime) -> int:             # <<<<<<<<<<<<<<
 *         """
 *         Find the day in the same month as other that has the same
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3139, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 3139, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_5_get_offset_day, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_LastWeekOfMonth__get_offset_day, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__221)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_get_offset_day, __pyx_t_2) < 0) __PYX_ERR(0, 3139, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3158
 *         return dim - shift_days
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, suffix=None):
 *         if not suffix:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15LastWeekOfMonth_7_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_LastWeekOfMonth__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 3158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_LastWeekOfMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3189
 *             raise ValueError(f"{self.variation} is not a valid variation")
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Mixin___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 3189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);

  /* "pandas/_libs/tslibs/offsets.pyx":3195
 *         self.variation = state.pop("variation")
 * 
 *     def is_anchored(self) -> bool:             # <<<<<<<<<<<<<<
 *         return (
 *             self.n == 1 and self.startingMonth is not None and self.weekday is not None
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3195, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_5is_anchored, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Mixin_is_anchored, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, __pyx_n_s_is_anchored, __pyx_t_2) < 0) __PYX_ERR(0, 3195, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);

  /* "pandas/_libs/tslibs/offsets.pyx":3209
 *         return f"{prefix}-{suffix}"
 * 
 *     def _get_suffix_prefix(self) -> str:             # <<<<<<<<<<<<<<
 *         if self.variation == "nearest":
 *             return "N"
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 3209, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_7_get_suffix_prefix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Mixin__get_suffix_prefix, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__225)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, __pyx_n_s_get_suffix_prefix, __pyx_t_6) < 0) __PYX_ERR(0, 3209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);

  /* "pandas/_libs/tslibs/offsets.pyx":3215
 *             return "L"
 * 
 *     def get_rule_code_suffix(self) -> str:             # <<<<<<<<<<<<<<
 *         prefix = self._get_suffix_prefix()
 *         month = MONTH_ALIASES[self.startingMonth]
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_str) < 0) __PYX_ERR(0, 3215, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11FY5253Mixin_9get_rule_code_suffix, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Mixin_get_rule_code_suffix, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__227)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin, __pyx_n_s_get_rule_code_suffix, __pyx_t_2) < 0) __PYX_ERR(0, 3215, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Mixin);

  /* "pandas/_libs/tslibs/offsets.pyx":3276
 *     """
 * 
 *     _prefix = "RE"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_prefix, __pyx_n_u_RE) < 0) __PYX_ERR(0, 3276, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3277
 * 
 *     _prefix = "RE"
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])             # <<<<<<<<<<<<<<
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:
 */
  __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 3277, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3277, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekday);
  __Pyx_GIVEREF(__pyx_n_u_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_weekday)) __PYX_ERR(0, 3277, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_startingMonth);
  __Pyx_GIVEREF(__pyx_n_u_startingMonth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_startingMonth)) __PYX_ERR(0, 3277, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_variation);
  __Pyx_GIVEREF(__pyx_n_u_variation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_variation)) __PYX_ERR(0, 3277, __pyx_L1_error);
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 3277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3279
 *     _attributes = tuple(["n", "normalize", "weekday", "startingMonth", "variation"])
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3279, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3279, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_1is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__229)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 3279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3291
 *             return year_end == dt
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         norm = Timestamp(other).normalize()
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3291, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3291, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_3_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__231)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 3291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3347
 *         return result
 * 
 *     def get_year_end(self, dt: datetime) -> datetime:             # <<<<<<<<<<<<<<
 *         assert dt.tzinfo is None
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3347, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3347, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_5get_year_end, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253_get_year_end, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__233)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_get_year_end, __pyx_t_2) < 0) __PYX_ERR(0, 3347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3373
 *                 return target_date + timedelta(days_forward - 7)
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _parse_suffix(cls, varion_code, startingMonth_code, weekday_code):
 *         if varion_code == "N":
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_7_parse_suffix, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253__parse_suffix, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_parse_suffix, __pyx_t_2) < 0) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_parse_suffix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_parse_suffix, __pyx_t_6) < 0) __PYX_ERR(0, 3373, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3391
 *         }
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(**cls._parse_suffix(*args))
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6FY5253_9_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
  __Pyx_GetNameInClass(__pyx_t_6, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_from_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 3391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);

  /* "pandas/_libs/tslibs/offsets.pyx":3459
 *     """
 * 
 *     _prefix = "REQ"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(
 *         [
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_prefix, __pyx_n_u_REQ) < 0) __PYX_ERR(0, 3459, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3461
 *     _prefix = "REQ"
 *     _attributes = tuple(
 *         [             # <<<<<<<<<<<<<<
 *             "n",
 *             "normalize",
 */
  __pyx_t_2 = PyList_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 3461, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3461, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekday);
  __Pyx_GIVEREF(__pyx_n_u_weekday);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_weekday)) __PYX_ERR(0, 3461, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_startingMonth);
  __Pyx_GIVEREF(__pyx_n_u_startingMonth);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_startingMonth)) __PYX_ERR(0, 3461, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_qtr_with_extra_week);
  __Pyx_GIVEREF(__pyx_n_u_qtr_with_extra_week);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_qtr_with_extra_week)) __PYX_ERR(0, 3461, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_variation);
  __Pyx_GIVEREF(__pyx_n_u_variation);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_u_variation)) __PYX_ERR(0, 3461, __pyx_L1_error);

  /* "pandas/_libs/tslibs/offsets.pyx":3460
 * 
 *     _prefix = "REQ"
 *     _attributes = tuple(             # <<<<<<<<<<<<<<
 *         [
 *             "n",
 */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 3460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3488
 *         self.qtr_with_extra_week = qtr_with_extra_week
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         FY5253Mixin.__setstate__(self, state)
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 3488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3492
 *         self.qtr_with_extra_week = state.pop("qtr_with_extra_week")
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def _offset(self):
 *         return FY5253(
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_5_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter__offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3500
 *         )
 * 
 *     def _rollback_to_year(self, other: datetime):             # <<<<<<<<<<<<<<
 *         """
 *         Roll `other` back to the most recent date that was on a fiscal year
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3500, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_7_rollback_to_year, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter__rollback_to_year, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__241)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_rollback_to_year, __pyx_t_2) < 0) __PYX_ERR(0, 3500, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3549
 *         return start, num_qtrs, tdelta
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # Note: self.n == 0 is not allowed.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3549, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3549, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_9_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__243)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_apply, __pyx_t_6) < 0) __PYX_ERR(0, 3549, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3578
 *         return res
 * 
 *     def get_weeks(self, dt: datetime):             # <<<<<<<<<<<<<<
 *         ret = [13] * 4
 * 
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3578, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_11get_weeks, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter_get_weeks, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__245)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_get_weeks, __pyx_t_2) < 0) __PYX_ERR(0, 3578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3588
 *         return ret
 * 
 *     def year_has_extra_week(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         # Avoid round-down errors --> normalize to get
 *         # e.g. '370D' instead of '360D23H'
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3588, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3588, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_13year_has_extra_week, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter_year_has_extra_wee, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_year_has_extra_week, __pyx_t_6) < 0) __PYX_ERR(0, 3588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3599
 *         return weeks_in_year == 53
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3599, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3599, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_15is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_is_on_offset, __pyx_t_2) < 0) __PYX_ERR(0, 3599, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3622
 *         return f"{suffix}-{qtr}"
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def _from_name(cls, *args):
 *         return cls(
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13FY5253Quarter_17_from_name, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_FY5253Quarter__from_name, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__250)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_from_name, __pyx_t_2) < 0) __PYX_ERR(0, 3622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
  __Pyx_GetNameInClass(__pyx_t_2, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_from_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Method_ClassMethod(__pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter, __pyx_n_s_from_name, __pyx_t_6) < 0) __PYX_ERR(0, 3622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);

  /* "pandas/_libs/tslibs/offsets.pyx":3642
 *     """
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.n = state.pop("n")
 *         self.normalize = state.pop("normalize")
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_1__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Easter___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_n_s_setstate, __pyx_t_6) < 0) __PYX_ERR(0, 3642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);

  /* "pandas/_libs/tslibs/offsets.pyx":3646
 *         self.normalize = state.pop("normalize")
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         current_easter = easter(other.year)
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3646, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3646, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_3_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Easter__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3646, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);

  /* "pandas/_libs/tslibs/offsets.pyx":3675
 *         return new
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3675, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3675, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_6Easter_5is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Easter_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__254)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter, __pyx_n_s_is_on_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Easter);

  /* "pandas/_libs/tslibs/offsets.pyx":3710
 *     """
 * 
 *     _prefix = "C"             # <<<<<<<<<<<<<<
 *     _attributes = tuple(
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "offset"]
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_prefix, __pyx_n_u_C) < 0) __PYX_ERR(0, 3710, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3712
 *     _prefix = "C"
 *     _attributes = tuple(
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "offset"]             # <<<<<<<<<<<<<<
 *     )
 * 
 */
  __pyx_t_6 = PyList_New(6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 3712, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3712, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekmask);
  __Pyx_GIVEREF(__pyx_n_u_weekmask);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_weekmask)) __PYX_ERR(0, 3712, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_holidays);
  __Pyx_GIVEREF(__pyx_n_u_holidays);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 3, __pyx_n_u_holidays)) __PYX_ERR(0, 3712, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_calendar);
  __Pyx_GIVEREF(__pyx_n_u_calendar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 4, __pyx_n_u_calendar)) __PYX_ERR(0, 3712, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_offset_2);
  __Pyx_GIVEREF(__pyx_n_u_offset_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 5, __pyx_n_u_offset_2)) __PYX_ERR(0, 3712, __pyx_L1_error);

  /* "pandas/_libs/tslibs/offsets.pyx":3711
 * 
 *     _prefix = "C"
 *     _attributes = tuple(             # <<<<<<<<<<<<<<
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "offset"]
 *     )
 */
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 3711, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3715
 *     )
 * 
 *     _apply_array = BaseOffset._apply_array             # <<<<<<<<<<<<<<
 * 
 *     def __init__(
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BaseOffset), __pyx_n_s_apply_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_apply_array, __pyx_t_2) < 0) __PYX_ERR(0, 3715, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3724
 *         holidays=None,
 *         calendar=None,
 *         offset=timedelta(0),             # <<<<<<<<<<<<<<
 *     ):
 *         BusinessDay.__init__(self, n, normalize, offset)
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_k__56 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3729
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     cpdef __setstate__(self, state):             # <<<<<<<<<<<<<<
 *         self.holidays = state.pop("holidays")
 *         self.weekmask = state.pop("weekmask")
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_3__setstate__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessDay___setstate, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_setstate, __pyx_t_2) < 0) __PYX_ERR(0, 3729, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3734
 *         BusinessDay.__setstate__(self, state)
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other):
 *         if self.n <= 0:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_5_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessDay__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3765
 *             )
 * 
 *     def is_on_offset(self, dt: datetime) -> bool:             # <<<<<<<<<<<<<<
 *         if self.normalize and not _is_normalized(dt):
 *             return False
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dt, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3765, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_bool) < 0) __PYX_ERR(0, 3765, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17CustomBusinessDay_7is_on_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessDay_is_on_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__259)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay, __pyx_n_s_is_on_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3765, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);

  /* "pandas/_libs/tslibs/offsets.pyx":3863
 *     """
 * 
 *     _prefix = "CBH"             # <<<<<<<<<<<<<<
 *     _anchor = 0
 *     _attributes = tuple(
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, __pyx_n_s_prefix, __pyx_n_u_CBH) < 0) __PYX_ERR(0, 3863, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":3864
 * 
 *     _prefix = "CBH"
 *     _anchor = 0             # <<<<<<<<<<<<<<
 *     _attributes = tuple(
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "start", "end", "offset"]
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, __pyx_n_s_anchor, __pyx_int_0) < 0) __PYX_ERR(0, 3864, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":3866
 *     _anchor = 0
 *     _attributes = tuple(
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "start", "end", "offset"]             # <<<<<<<<<<<<<<
 *     )
 * 
 */
  __pyx_t_6 = PyList_New(8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 0, __pyx_n_u_n)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekmask);
  __Pyx_GIVEREF(__pyx_n_u_weekmask);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 2, __pyx_n_u_weekmask)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_holidays);
  __Pyx_GIVEREF(__pyx_n_u_holidays);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 3, __pyx_n_u_holidays)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_calendar);
  __Pyx_GIVEREF(__pyx_n_u_calendar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 4, __pyx_n_u_calendar)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_start);
  __Pyx_GIVEREF(__pyx_n_u_start);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 5, __pyx_n_u_start)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_end);
  __Pyx_GIVEREF(__pyx_n_u_end);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 6, __pyx_n_u_end)) __PYX_ERR(0, 3866, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_offset_2);
  __Pyx_GIVEREF(__pyx_n_u_offset_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_6, 7, __pyx_n_u_offset_2)) __PYX_ERR(0, 3866, __pyx_L1_error);

  /* "pandas/_libs/tslibs/offsets.pyx":3865
 *     _prefix = "CBH"
 *     _anchor = 0
 *     _attributes = tuple(             # <<<<<<<<<<<<<<
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "start", "end", "offset"]
 *     )
 */
  __pyx_t_2 = PyList_AsTuple(((PyObject*)__pyx_t_6)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour, __pyx_n_s_attributes, __pyx_t_2) < 0) __PYX_ERR(0, 3865, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);

  /* "pandas/_libs/tslibs/offsets.pyx":3878
 *         start="09:00",
 *         end="17:00",
 *         offset=timedelta(0),             # <<<<<<<<<<<<<<
 *     ):
 *         BusinessHour.__init__(self, n, normalize, start=start, end=end, offset=offset)
 */
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_k__57 = __pyx_t_2;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3908
 * 
 *     _attributes = tuple(
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "offset"]             # <<<<<<<<<<<<<<
 *     )
 * 
 */
  __pyx_t_2 = PyList_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3908, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_n);
  __Pyx_GIVEREF(__pyx_n_u_n);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_n)) __PYX_ERR(0, 3908, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_normalize);
  __Pyx_GIVEREF(__pyx_n_u_normalize);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_normalize)) __PYX_ERR(0, 3908, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_weekmask);
  __Pyx_GIVEREF(__pyx_n_u_weekmask);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_weekmask)) __PYX_ERR(0, 3908, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_holidays);
  __Pyx_GIVEREF(__pyx_n_u_holidays);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_holidays)) __PYX_ERR(0, 3908, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_calendar);
  __Pyx_GIVEREF(__pyx_n_u_calendar);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_calendar)) __PYX_ERR(0, 3908, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_u_offset_2);
  __Pyx_GIVEREF(__pyx_n_u_offset_2);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_u_offset_2)) __PYX_ERR(0, 3908, __pyx_L1_error);

  /* "pandas/_libs/tslibs/offsets.pyx":3907
 *     """
 * 
 *     _attributes = tuple(             # <<<<<<<<<<<<<<
 *         ["n", "normalize", "weekmask", "holidays", "calendar", "offset"]
 *     )
 */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3907, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_attributes, __pyx_t_6) < 0) __PYX_ERR(0, 3907, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3918
 *         holidays=None,
 *         calendar=None,
 *         offset=timedelta(0),             # <<<<<<<<<<<<<<
 *     ):
 *         BusinessMixin.__init__(self, n, normalize, offset)
 */
  __pyx_t_6 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_7cpython_8datetime_timedelta), __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3918, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_k__58 = __pyx_t_6;
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":3923
 *         self._init_custom(weekmask, holidays, calendar)
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def cbday_roll(self):
 *         """
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_3cbday_roll, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessMonth_cbday_roll, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__261)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_cbday_roll, __pyx_t_6) < 0) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_cbday_roll); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_cbday_roll, __pyx_t_6) < 0) __PYX_ERR(0, 3923, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3941
 *         return roll_func
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def m_offset(self):
 *         if self._prefix.endswith("S"):
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_5m_offset, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessMonth_m_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__263)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_m_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_m_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3941, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_m_offset, __pyx_t_6) < 0) __PYX_ERR(0, 3941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3951
 *         return moff
 * 
 *     @cache_readonly             # <<<<<<<<<<<<<<
 *     def month_roll(self):
 *         """
 */
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_7month_roll, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessMonth_month_roll, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__265)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_month_roll, __pyx_t_6) < 0) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_cache_readonly); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_month_roll); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3951, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_month_roll, __pyx_t_6) < 0) __PYX_ERR(0, 3951, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3964
 *         return roll_func
 * 
 *     @apply_wraps             # <<<<<<<<<<<<<<
 *     def _apply(self, other: datetime) -> datetime:
 *         # First move to month offset
 */
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3964, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 3964, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_20_CustomBusinessMonth_9_apply, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CustomBusinessMonth__apply, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__267)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_apply_wraps); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetNameInClass(__pyx_t_5, (PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_apply); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth, __pyx_n_s_apply, __pyx_t_2) < 0) __PYX_ERR(0, 3964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets__CustomBusinessMonth);

  /* "pandas/_libs/tslibs/offsets.pyx":3982
 * 
 * cdef class CustomBusinessMonthEnd(_CustomBusinessMonth):
 *     _prefix = "CBM"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd, __pyx_n_s_prefix, __pyx_n_u_CBM) < 0) __PYX_ERR(0, 3982, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);

  /* "pandas/_libs/tslibs/offsets.pyx":3986
 * 
 * cdef class CustomBusinessMonthBegin(_CustomBusinessMonth):
 *     _prefix = "CBMS"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin, __pyx_n_s_prefix, __pyx_n_u_CBMS) < 0) __PYX_ERR(0, 3986, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);

  /* "pandas/_libs/tslibs/offsets.pyx":3989
 * 
 * 
 * BDay = BusinessDay             # <<<<<<<<<<<<<<
 * BMonthEnd = BusinessMonthEnd
 * BMonthBegin = BusinessMonthBegin
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BDay, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay)) < 0) __PYX_ERR(0, 3989, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3990
 * 
 * BDay = BusinessDay
 * BMonthEnd = BusinessMonthEnd             # <<<<<<<<<<<<<<
 * BMonthBegin = BusinessMonthBegin
 * CBMonthEnd = CustomBusinessMonthEnd
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BMonthEnd, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd)) < 0) __PYX_ERR(0, 3990, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3991
 * BDay = BusinessDay
 * BMonthEnd = BusinessMonthEnd
 * BMonthBegin = BusinessMonthBegin             # <<<<<<<<<<<<<<
 * CBMonthEnd = CustomBusinessMonthEnd
 * CBMonthBegin = CustomBusinessMonthBegin
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BMonthBegin, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin)) < 0) __PYX_ERR(0, 3991, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3992
 * BMonthEnd = BusinessMonthEnd
 * BMonthBegin = BusinessMonthBegin
 * CBMonthEnd = CustomBusinessMonthEnd             # <<<<<<<<<<<<<<
 * CBMonthBegin = CustomBusinessMonthBegin
 * CDay = CustomBusinessDay
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CBMonthEnd, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd)) < 0) __PYX_ERR(0, 3992, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3993
 * BMonthBegin = BusinessMonthBegin
 * CBMonthEnd = CustomBusinessMonthEnd
 * CBMonthBegin = CustomBusinessMonthBegin             # <<<<<<<<<<<<<<
 * CDay = CustomBusinessDay
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CBMonthBegin, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin)) < 0) __PYX_ERR(0, 3993, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3994
 * CBMonthEnd = CustomBusinessMonthEnd
 * CBMonthBegin = CustomBusinessMonthBegin
 * CDay = CustomBusinessDay             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CDay, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay)) < 0) __PYX_ERR(0, 3994, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":3999
 * # to_offset helpers
 * 
 * prefix_mapping = {             # <<<<<<<<<<<<<<
 *     offset._prefix: offset
 *     for offset in [
 */
  { /* enter inner scope */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3999, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "pandas/_libs/tslibs/offsets.pyx":4001
 * prefix_mapping = {
 *     offset._prefix: offset
 *     for offset in [             # <<<<<<<<<<<<<<
 *         YearBegin,  # 'AS'
 *         YearEnd,  # 'A'
 */
    __pyx_t_6 = PyTuple_New(31); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4001, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_YearEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BYearEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 4, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessDay))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 5, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 6, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessMonthEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 7, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 8, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BQuarterBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 9, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_BusinessHour))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 10, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessDay))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 11, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 12, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessMonthBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 13, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_CustomBusinessHour))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 14, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 15, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_MonthBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 16, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Nano))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 17, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 18, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_SemiMonthBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 19, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Week))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 20, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Second))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 21, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Minute))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 22, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Micro))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 23, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterEnd))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 24, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_QuarterBegin))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 25, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Milli))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 26, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Hour))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 27, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_Day))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 28, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_WeekOfMonth))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 29, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __Pyx_INCREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
    __Pyx_GIVEREF((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 30, ((PyObject *)__pyx_ptype_6pandas_5_libs_6tslibs_7offsets_FY5253Quarter))) __PYX_ERR(0, 4001, __pyx_L4_error);
    __pyx_t_5 = __pyx_t_6; __Pyx_INCREF(__pyx_t_5);
    __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    for (;;) {
      if (__pyx_t_8 >= 31) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_6); __pyx_t_8++; if (unlikely((0 < 0))) __PYX_ERR(0, 4001, __pyx_L4_error)
      #else
      __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4001, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_XGOTREF(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset);
      __Pyx_DECREF_SET(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset, ((PyObject *)__pyx_t_6));
      __Pyx_GIVEREF((PyObject *)__pyx_t_6);
      __pyx_t_6 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":4000
 * 
 * prefix_mapping = {
 *     offset._prefix: offset             # <<<<<<<<<<<<<<
 *     for offset in [
 *         YearBegin,  # 'AS'
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset, __pyx_n_s_prefix); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 4000, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(PyDict_SetItem(__pyx_t_2, (PyObject*)__pyx_t_6, (PyObject*)__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset))) __PYX_ERR(0, 4000, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pandas/_libs/tslibs/offsets.pyx":4001
 * prefix_mapping = {
 *     offset._prefix: offset
 *     for offset in [             # <<<<<<<<<<<<<<
 *         YearBegin,  # 'AS'
 *         YearEnd,  # 'A'
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset);
    __Pyx_DECREF_SET(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset, Py_None);
    goto __pyx_L8_exit_scope;
    __pyx_L4_error:;
    __Pyx_GOTREF(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset);
    __Pyx_DECREF_SET(__pyx_9genexpr16__pyx_v_6pandas_5_libs_6tslibs_7offsets_offset, Py_None);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_prefix_mapping, __pyx_t_2) < 0) __PYX_ERR(0, 3999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4037
 * 
 * # hack to handle WOM-1MON
 * opattern = re.compile(             # <<<<<<<<<<<<<<
 *     r"([+\-]?\d*|[+\-]?\d*\.\d*)\s*([A-Za-z]+([\-][\dA-Za-z\-]+)?)"
 * )
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_compile); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__268, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_opattern, __pyx_t_2) < 0) __PYX_ERR(0, 4037, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4042
 * 
 * _lite_rule_alias = {
 *     "W": "W-SUN",             # <<<<<<<<<<<<<<
 *     "Q": "Q-DEC",
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(15); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_W, __pyx_kp_u_W_SUN) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_Q, __pyx_kp_u_Q_DEC) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_A, __pyx_kp_u_A_DEC) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_Y, __pyx_kp_u_A_DEC) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_AS, __pyx_kp_u_AS_JAN) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_YS, __pyx_kp_u_AS_JAN) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_BA, __pyx_kp_u_BA_DEC) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_BY, __pyx_kp_u_BA_DEC) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_BAS, __pyx_kp_u_BAS_JAN) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_BYS, __pyx_kp_u_BAS_JAN) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_Min, __pyx_n_u_T) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_min, __pyx_n_u_T) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ms, __pyx_n_u_L) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_us, __pyx_n_u_U) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_u_ns, __pyx_n_u_N) < 0) __PYX_ERR(0, 4042, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lite_rule_alias, __pyx_t_2) < 0) __PYX_ERR(0, 4041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4061
 * }
 * 
 * _dont_uppercase = {"MS", "ms"}             # <<<<<<<<<<<<<<
 * 
 * INVALID_FREQ_ERR_MSG = "Invalid frequency: {0}"
 */
  __pyx_t_2 = PySet_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4061, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PySet_Add(__pyx_t_2, __pyx_n_u_MS) < 0) __PYX_ERR(0, 4061, __pyx_L1_error)
  if (PySet_Add(__pyx_t_2, __pyx_n_u_ms) < 0) __PYX_ERR(0, 4061, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dont_uppercase, __pyx_t_2) < 0) __PYX_ERR(0, 4061, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4063
 * _dont_uppercase = {"MS", "ms"}
 * 
 * INVALID_FREQ_ERR_MSG = "Invalid frequency: {0}"             # <<<<<<<<<<<<<<
 * 
 * # TODO: still needed?
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_INVALID_FREQ_ERR_MSG, __pyx_kp_u_Invalid_frequency_0) < 0) __PYX_ERR(0, 4063, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4067
 * # TODO: still needed?
 * # cache of previously seen offsets
 * _offset_map = {}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_offset_map, __pyx_t_2) < 0) __PYX_ERR(0, 4067, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4071
 * 
 * # TODO: better name?
 * def _get_offset(name: str) -> BaseOffset:             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object associated with rule name.
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_name_2, __pyx_n_s_str) < 0) __PYX_ERR(0, 4071, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_BaseOffset) < 0) __PYX_ERR(0, 4071, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_9_get_offset, 0, __pyx_n_s_get_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_offset, __pyx_t_5) < 0) __PYX_ERR(0, 4071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4102
 * 
 * 
 * cpdef to_offset(freq):             # <<<<<<<<<<<<<<
 *     """
 *     Return DateOffset object from string or datetime.timedelta object.
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_11to_offset, 0, __pyx_n_s_to_offset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_to_offset, __pyx_t_5) < 0) __PYX_ERR(0, 4102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4261
 *     str day_opt,
 *     int modby=3,
 *     NPY_DATETIMEUNIT reso=NPY_DATETIMEUNIT.NPY_FR_ns,             # <<<<<<<<<<<<<<
 * ):
 *     """
 */
  __pyx_k__64 = NPY_FR_ns;

  /* "pandas/_libs/tslibs/offsets.pyx":4321
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def shift_months(
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_13shift_months, 0, __pyx_n_s_shift_months, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_5, sizeof(__pyx_defaults), 0)) __PYX_ERR(0, 4321, __pyx_L1_error)

  /* "pandas/_libs/tslibs/offsets.pyx":4327
 *     int months,
 *     str day_opt=None,
 *     NPY_DATETIMEUNIT reso=NPY_DATETIMEUNIT.NPY_FR_ns,             # <<<<<<<<<<<<<<
 * ):
 *     """
 */
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_5)->__pyx_arg_reso = NPY_FR_ns;
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_5, __pyx_pf_6pandas_5_libs_6tslibs_7offsets_24__defaults__);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_shift_months, __pyx_t_5) < 0) __PYX_ERR(0, 4321, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4405
 * 
 * 
 * def shift_month(stamp: datetime, months: int, day_opt: object = None) -> datetime:             # <<<<<<<<<<<<<<
 *     """
 *     Given a datetime (or Timestamp) `stamp`, an integer `months` and an
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_stamp, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 4405, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_months, __pyx_n_s_int) < 0) __PYX_ERR(0, 4405, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_day_opt_2, __pyx_n_s_object) < 0) __PYX_ERR(0, 4405, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 4405, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_15shift_month, 0, __pyx_n_s_shift_month, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__114);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_shift_month, __pyx_t_2) < 0) __PYX_ERR(0, 4405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4510
 * 
 * 
 * cpdef int roll_convention(int other, int n, int compare) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Possibly increment or decrement the number of periods to shift
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_17roll_convention, 0, __pyx_n_s_roll_convention, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_roll_convention, __pyx_t_2) < 0) __PYX_ERR(0, 4510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":4534
 * 
 * 
 * def roll_qtrday(other: datetime, n: int, month: int,             # <<<<<<<<<<<<<<
 *                 day_opt: str, modby: int) -> int:
 *     """
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_other, __pyx_n_s_datetime) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_n, __pyx_n_s_int) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_month, __pyx_n_s_int) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_day_opt_2, __pyx_n_s_str) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_modby, __pyx_n_s_int) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_19roll_qtrday, 0, __pyx_n_s_roll_qtrday, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_roll_qtrday, __pyx_t_5) < 0) __PYX_ERR(0, 4534, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_BaseOffset(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_21__pyx_unpickle_BaseOffset, 0, __pyx_n_s_pyx_unpickle_BaseOffset, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_BaseOffset, __pyx_t_5) < 0) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":11
 *         __pyx_unpickle_BaseOffset__set_state(<BaseOffset> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_BaseOffset__set_state(BaseOffset __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._cache = __pyx_state[0]; __pyx_result.n = __pyx_state[1]; __pyx_result.normalize = __pyx_state[2]
 *     if len(__pyx_state) > 3 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_6tslibs_7offsets_23__pyx_unpickle_RelativeDeltaOffset, 0, __pyx_n_s_pyx_unpickle_RelativeDeltaOffs, NULL, __pyx_n_s_pandas__libs_tslibs_offsets, __pyx_d, ((PyObject *)__pyx_codeobj__283)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_RelativeDeltaOffs, __pyx_t_5) < 0) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/tslibs/offsets.pyx":1
 * import re             # <<<<<<<<<<<<<<
 * import time
 * 
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(14); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_kwds___get___line_449, __pyx_kp_u_Return_a_dict_of_extra_paramete) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_copy_line_532, __pyx_kp_u_Return_a_copy_of_the_frequency) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_name___get___line_584, __pyx_kp_u_Return_a_string_representing_th) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_freqstr_line_607, __pyx_kp_u_Return_a_string_representing_th_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_on_offset_line_696, __pyx_kp_u_Return_boolean_whether_a_timest) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_anchored_line_790, __pyx_kp_u_Return_boolean_whether_the_freq) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_month_start_line_8, __pyx_kp_u_Return_boolean_whether_a_timest_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_month_end_line_820, __pyx_kp_u_Return_boolean_whether_a_timest_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_quarter_start_line, __pyx_kp_u_Return_boolean_whether_a_timest_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_quarter_end_line_8, __pyx_kp_u_Return_boolean_whether_a_timest_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_year_start_line_85, __pyx_kp_u_Return_boolean_whether_a_timest_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_BaseOffset_is_year_end_line_872, __pyx_kp_u_Return_boolean_whether_a_timest_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Tick_nanos___get___line_953, __pyx_kp_u_Return_an_integer_of_the_total) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_to_offset_line_4102, __pyx_kp_u_Return_DateOffset_object_from_s) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init pandas._libs.tslibs.offsets", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pandas._libs.tslibs.offsets");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* ErrOccurredWithGIL */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void) {
  int err;
  #ifdef WITH_THREAD
  PyGILState_STATE _save = PyGILState_Ensure();
  #endif
  err = !!PyErr_Occurred();
  #ifdef WITH_THREAD
  PyGILState_Release(_save);
  #endif
  return err;
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            if (__Pyx_PyLong_IsZero(op1) == 1) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                Py_RETURN_FALSE;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__4);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseClosureNameError */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* pyfrozenset_new */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if ((PY_VERSION_HEX >= 0x031000A1) || likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* PySetContains */
static int __Pyx_PySet_ContainsUnhashable(PyObject *set, PyObject *key) {
    int result = -1;
    if (PySet_Check(key) && PyErr_ExceptionMatches(PyExc_TypeError)) {
        PyObject *tmpkey;
        PyErr_Clear();
        tmpkey = __Pyx_PyFrozenSet_New(key);
        if (tmpkey != NULL) {
            result = PySet_Contains(set, tmpkey);
            Py_DECREF(tmpkey);
        }
    }
    return result;
}
static CYTHON_INLINE int __Pyx_PySet_ContainsTF(PyObject* key, PyObject* set, int eq) {
    int result = PySet_Contains(set, key);
    if (unlikely(result < 0)) {
        result = __Pyx_PySet_ContainsUnhashable(set, key);
    }
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc;
    __Pyx_PyThreadState_declare
    #ifdef __Pyx_StopAsyncIteration_USED
    int is_async_stopiteration = 0;
    #endif
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    cur_exc = PyErr_Occurred();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        #ifdef __Pyx_StopAsyncIteration_USED
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, __Pyx_PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else
        #endif
            return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(val);
    Py_XDECREF(tb);
    PyErr_SetString(PyExc_RuntimeError,
        #ifdef __Pyx_StopAsyncIteration_USED
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        #endif
        "generator raised StopIteration");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                lla = a;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* UnpackUnboundCMethod */
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod1 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* py_dict_pop */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B3 & PY_VERSION_HEX < 0x030d0000
    if ((1)) {
        return _PyDict_Pop(d, key, default_value);
    } else
#endif
    if (default_value) {
        return __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_pop, d, key, default_value);
    } else {
        return __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_pop, d, key);
    }
}

/* dict_getitem_default */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* MergeKeywords */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError))) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* py_abs */
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject *__Pyx_PyLong_AbsNeg(PyObject *n) {
#if PY_VERSION_HEX >= 0x030C00A7
    if (likely(__Pyx_PyLong_IsCompact(n))) {
        return PyLong_FromSize_t(__Pyx_PyLong_CompactValueUnsigned(n));
    }
#else
    if (likely(Py_SIZE(n) == -1)) {
        return PyLong_FromUnsignedLong(__Pyx_PyLong_Digits(n)[0]);
    }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    {
        PyObject *copy = _PyLong_Copy((PyLongObject*)n);
        if (likely(copy)) {
            #if PY_VERSION_HEX >= 0x030C00A7
            ((PyLongObject*)copy)->long_value.lv_tag = ((PyLongObject*)copy)->long_value.lv_tag & ~_PyLong_SIGN_MASK;
            #else
            __Pyx_SET_SIZE(copy, -Py_SIZE(copy));
            #endif
        }
        return copy;
    }
#else
    return PyNumber_Negative(n);
#endif
}
#endif

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
static int
__Pyx_unicode_modifiable(PyObject *unicode)
{
    if (Py_REFCNT(unicode) != 1)
        return 0;
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = a % b;
            x += ((x != 0) & ((x ^ b) < 0)) * b;
            return PyInt_FromLong(x);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_remainder(op1, op2);
            }
        }
                x = a % b;
                x += ((x != 0) & ((x ^ b) < 0)) * b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla % llb;
                llx += ((llx != 0) & ((llx ^ llb) < 0)) * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceRemainder : PyNumber_Remainder)(op1, op2);
}
#endif

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_TrueDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        
            if (8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53))) {
                return PyFloat_FromDouble((double)a / (double)b);
            }
            return PyInt_Type.tp_as_number->nb_true_divide(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT && 1 * PyLong_SHIFT < 53) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT && 2 * PyLong_SHIFT < 53) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT && 3 * PyLong_SHIFT < 53) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            }
        }
                if ((8 * sizeof(long) <= 53 || likely(labs(a) <= ((PY_LONG_LONG)1 << 53)))
                        || __Pyx_PyLong_DigitCount(op1) <= 52 / PyLong_SHIFT) {
                    return PyFloat_FromDouble((double)a / (double)b);
                }
                return PyLong_Type.tp_as_number->nb_true_divide(op1, op2);
            return PyLong_FromLong(x);
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("divide", return NULL)
            result = ((double)a) / (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceTrueDivide : PyNumber_TrueDivide)(op1, op2);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            if (unlikely(b == -1 && ((unsigned long)a) == 0-(unsigned long)a))
                return PyInt_Type.tp_as_number->nb_floor_divide(op1, op2);
            else {
                long q, r;
                q = a / b;
                r = a - q*b;
                q -= ((r != 0) & ((r ^ b) < 0));
                x = q;
            }
            return PyInt_FromLong(x);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_floor_divide(op1, op2);
            }
        }
                {
                    long q, r;
                    q = a / b;
                    r = a - q*b;
                    q -= ((r != 0) & ((r ^ b) < 0));
                    x = q;
                }
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                {
                    PY_LONG_LONG q, r;
                    q = lla / llb;
                    r = lla - q*llb;
                    q -= ((r != 0) & ((r ^ llb) < 0));
                    llx = q;
                }
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceFloorDivide : PyNumber_FloorDivide)(op1, op2);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long b = PyInt_AS_LONG(op2);
        
#ifdef HAVE_LONG_LONG
            if (sizeof(PY_LONG_LONG) > sizeof(long)) {
                PY_LONG_LONG result = (PY_LONG_LONG)a * (PY_LONG_LONG)b;
                return (result >= LONG_MIN && result <= LONG_MAX) ?
                    PyInt_FromLong((long)result) : PyLong_FromLongLong(result);
            }
#endif
#if CYTHON_USE_TYPE_SLOTS
            return PyInt_Type.tp_as_number->nb_multiply(op1, op2);
#else
            return PyNumber_Multiply(op1, op2);
#endif
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op2))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op2))) {
            b = __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
            }
        }
                CYTHON_UNUSED_VAR(a);
                CYTHON_UNUSED_VAR(b);
                #ifdef HAVE_LONG_LONG
                llb = b;
                goto long_long;
                #else
                return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
                #endif
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla * llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double b = __pyx_PyFloat_AsDouble(op2);
#else
        double b = PyFloat_AS_DOUBLE(op2);
#endif
            double result;
            
            PyFPE_START_PROTECT("multiply", return NULL)
            result = ((double)a) * (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#endif

/* DivInt[long] */
static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return __Pyx_NewRef(op2);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectFormat */
#if CYTHON_USE_UNICODE_WRITER
static PyObject* __Pyx_PyObject_Format(PyObject* obj, PyObject* format_spec) {
    int ret;
    _PyUnicodeWriter writer;
    if (likely(PyFloat_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyFloat_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else if (likely(PyLong_CheckExact(obj))) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x03040000
        _PyUnicodeWriter_Init(&writer, 0);
#else
        _PyUnicodeWriter_Init(&writer);
#endif
        ret = _PyLong_FormatAdvancedWriter(
            &writer,
            obj,
            format_spec, 0, PyUnicode_GET_LENGTH(format_spec));
    } else {
        return PyObject_Format(obj, format_spec);
    }
    if (unlikely(ret == -1)) {
        _PyUnicodeWriter_Dealloc(&writer);
        return NULL;
    }
    return _PyUnicodeWriter_Finish(&writer);
}
#endif

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_long(long value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(long)*3+2];
    char *dpos, *end = digits + sizeof(long)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    long remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (long) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (long) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (long) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* ModInt[long] */
static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
        
            x = (long)((unsigned long)a - (unsigned long)b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op1))) {
            return PyLong_FromLong(-intval);
        }
        if (likely(__Pyx_PyLong_IsCompact(op1))) {
            a = __Pyx_PyLong_CompactValue(op1);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op1);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op1);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
            double result;
            
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op2))) {
        const long a = intval;
        long x;
        long b = PyInt_AS_LONG(op2);
        
            x = (long)((unsigned long)a + (unsigned long)b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        const long a = intval;
        long b, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG lla = intval;
        PY_LONG_LONG llb, llx;
#endif
        if (unlikely(__Pyx_PyLong_IsZero(op2))) {
            return __Pyx_NewRef(op1);
        }
        if (likely(__Pyx_PyLong_IsCompact(op2))) {
            b = __Pyx_PyLong_CompactValue(op2);
        } else {
            const digit* digits = __Pyx_PyLong_Digits(op2);
            const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(op2);
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    #ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    #endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        const long a = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double b = __pyx_PyFloat_AsDouble(op2);
#else
        double b = PyFloat_AS_DOUBLE(op2);
#endif
            double result;
            
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, int wraparound) {
    __Pyx_TypeName obj_type_name;
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#else
    CYTHON_UNUSED_VAR(wraparound);
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is unsliceable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
bad:
    return NULL;
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
    if (is_list || !PyMapping_Check(o))
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* SliceTupleAndList */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_crop_slice(Py_ssize_t* _start, Py_ssize_t* _stop, Py_ssize_t* _length) {
    Py_ssize_t start = *_start, stop = *_stop, length = *_length;
    if (start < 0) {
        start += length;
        if (start < 0)
            start = 0;
    }
    if (stop < 0)
        stop += length;
    else if (stop > length)
        stop = length;
    *_length = stop - start;
    *_start = start;
    *_stop = stop;
}
static CYTHON_INLINE PyObject* __Pyx_PyList_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyList_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    if (length <= 0) {
        return PyList_New(0);
    }
    return __Pyx_PyList_FromArray(((PyListObject*)src)->ob_item + start, length);
}
static CYTHON_INLINE PyObject* __Pyx_PyTuple_GetSlice(
            PyObject* src, Py_ssize_t start, Py_ssize_t stop) {
    Py_ssize_t length = PyTuple_GET_SIZE(src);
    __Pyx_crop_slice(&start, &stop, &length);
    return __Pyx_PyTuple_FromArray(((PyTupleObject*)src)->ob_item + start, length);
}
#endif

/* CallUnboundCMethod0 */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* pybytes_as_double */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj) {
    PyObject *float_value;
#if PY_MAJOR_VERSION >= 3
    float_value = PyFloat_FromString(obj);
#else
    float_value = PyFloat_FromString(obj, 0);
#endif
    if (likely(float_value)) {
#if CYTHON_ASSUME_SAFE_MACROS
        double value = PyFloat_AS_DOUBLE(float_value);
#else
        double value = PyFloat_AsDouble(float_value);
#endif
        Py_DECREF(float_value);
        return value;
    }
    return (double)-1;
}
static const char* __Pyx__PyBytes_AsDouble_Copy(const char* start, char* buffer, Py_ssize_t length) {
    int last_was_punctuation = 1;
    Py_ssize_t i;
    for (i=0; i < length; i++) {
        char chr = start[i];
        int is_punctuation = (chr == '_') | (chr == '.') | (chr == 'e') | (chr == 'E');
        *buffer = chr;
        buffer += (chr != '_');
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyBytes_AsDouble_inf_nan(const char* start, Py_ssize_t length) {
    int matches = 1;
    char sign = start[0];
    int is_signed = (sign == '+') | (sign == '-');
    start += is_signed;
    length -= is_signed;
    switch (start[0]) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            matches &= (start[1] == 'a' || start[1] == 'A');
            matches &= (start[2] == 'n' || start[2] == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            matches &= (start[1] == 'n' || start[1] == 'N');
            matches &= (start[2] == 'f' || start[2] == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            matches &= (start[3] == 'i' || start[3] == 'I');
            matches &= (start[4] == 'n' || start[4] == 'N');
            matches &= (start[5] == 'i' || start[5] == 'I');
            matches &= (start[6] == 't' || start[6] == 'T');
            matches &= (start[7] == 'y' || start[7] == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static CYTHON_INLINE int __Pyx__PyBytes_AsDouble_IsSpace(char ch) {
    return (ch == 0x20) | !((ch < 0x9) | (ch > 0xd));
}
CYTHON_UNUSED static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length) {
    double value;
    Py_ssize_t i, digits;
    const char *last = start + length;
    char *end;
    while (__Pyx__PyBytes_AsDouble_IsSpace(*start))
        start++;
    while (start < last - 1 && __Pyx__PyBytes_AsDouble_IsSpace(last[-1]))
        last--;
    length = last - start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyBytes_AsDouble_inf_nan(start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    digits = 0;
    for (i=0; i < length; digits += start[i++] != '_');
    if (likely(digits == length)) {
        value = PyOS_string_to_double(start, &end, NULL);
    } else if (digits < 40) {
        char number[40];
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((digits + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}

/* pynumber_float */
static CYTHON_INLINE PyObject* __Pyx__PyNumber_Float(PyObject* obj) {
    double val;
    if (PyLong_CheckExact(obj)) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (likely(__Pyx_PyLong_IsCompact(obj))) {
            val = (double) __Pyx_PyLong_CompactValue(obj);
            goto no_error;
        }
#endif
        val = PyLong_AsDouble(obj);
    } else if (PyUnicode_CheckExact(obj)) {
        val = __Pyx_PyUnicode_AsDouble(obj);
    } else if (PyBytes_CheckExact(obj)) {
        val = __Pyx_PyBytes_AsDouble(obj);
    } else if (PyByteArray_CheckExact(obj)) {
        val = __Pyx_PyByteArray_AsDouble(obj);
    } else {
        return PyNumber_Float(obj);
    }
    if (unlikely(val == -1 && PyErr_Occurred())) {
        return NULL;
    }
#if CYTHON_USE_PYLONG_INTERNALS
no_error:
#endif
    return PyFloat_FromDouble(val);
}

/* ModInt[__pyx_t_5numpy_int32_t] */
static CYTHON_INLINE __pyx_t_5numpy_int32_t __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_5numpy_int32_t a, __pyx_t_5numpy_int32_t b) {
    __pyx_t_5numpy_int32_t r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !(CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY)
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_0_8
#define __PYX_HAVE_RT_ImportType_3_0_8
static PyTypeObject *__Pyx_ImportType_3_0_8(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_8 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_8 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_8 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__67;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* Py3UpdateBases */
static PyObject*
__Pyx_PEP560_update_bases(PyObject *bases)
{
    Py_ssize_t i, j, size_bases;
    PyObject *base, *meth, *new_base, *result, *new_bases = NULL;
    size_bases = PyTuple_GET_SIZE(bases);
    for (i = 0; i < size_bases; i++) {
        base  = PyTuple_GET_ITEM(bases, i);
        if (PyType_Check(base)) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        meth = __Pyx_PyObject_GetAttrStrNoError(base, __pyx_n_s_mro_entries);
        if (!meth && PyErr_Occurred()) {
            goto error;
        }
        if (!meth) {
            if (new_bases) {
                if (PyList_Append(new_bases, base) < 0) {
                    goto error;
                }
            }
            continue;
        }
        new_base = __Pyx_PyObject_CallOneArg(meth, bases);
        Py_DECREF(meth);
        if (!new_base) {
            goto error;
        }
        if (!PyTuple_Check(new_base)) {
            PyErr_SetString(PyExc_TypeError,
                            "__mro_entries__ must return a tuple");
            Py_DECREF(new_base);
            goto error;
        }
        if (!new_bases) {
            if (!(new_bases = PyList_New(i))) {
                goto error;
            }
            for (j = 0; j < i; j++) {
                base = PyTuple_GET_ITEM(bases, j);
                PyList_SET_ITEM(new_bases, j, base);
                Py_INCREF(base);
            }
        }
        j = PyList_GET_SIZE(new_bases);
        if (PyList_SetSlice(new_bases, j, j, new_base) < 0) {
            goto error;
        }
        Py_DECREF(new_base);
    }
    if (!new_bases) {
        Py_INCREF(bases);
        return bases;
    }
    result = PyList_AsTuple(new_bases);
    Py_DECREF(new_bases);
    return result;
error:
    Py_XDECREF(new_bases);
    return NULL;
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases;
#if CYTHON_ASSUME_SAFE_MACROS
    nbases = PyTuple_GET_SIZE(bases);
#else
    nbases = PyTuple_Size(bases);
    if (nbases < 0) return NULL;
#endif
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
#if CYTHON_ASSUME_SAFE_MACROS
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *tmp = PyTuple_GetItem(bases, i);
        if (!tmp) return NULL;
#endif
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* PyObjectCall2Args */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectLookupSpecial */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx__PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name, int with_error) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return with_error ? __Pyx_PyObject_GetAttrStr(obj, attr_name) : __Pyx_PyObject_GetAttrStrNoError(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else if (with_error) {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#endif

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStrNoError(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs[3] = {NULL, name, bases};
            ns = __Pyx_PyObject_FastCallDict(prep, pargs+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, mkw);
            Py_DECREF(prep);
        } else {
            if (unlikely(PyErr_Occurred()))
                return NULL;
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
#if PY_VERSION_HEX >= 0x03030000
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
#else
    CYTHON_MAYBE_UNUSED_VAR(qualname);
#endif
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
static int __Pyx_SetNamesPEP487(PyObject *type_obj) {
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *names_to_set, *key, *value, *set_name, *tmp;
    Py_ssize_t i = 0;
#if CYTHON_USE_TYPE_SLOTS
    names_to_set = PyDict_Copy(type->tp_dict);
#else
    {
        PyObject *d = PyObject_GetAttr(type_obj, __pyx_n_s_dict);
        names_to_set = NULL;
        if (likely(d)) {
            PyObject *names_to_set = PyDict_New();
            int ret = likely(names_to_set) ? PyDict_Update(names_to_set, d) : -1;
            Py_DECREF(d);
            if (unlikely(ret < 0))
                Py_CLEAR(names_to_set);
        }
    }
#endif
    if (unlikely(names_to_set == NULL))
        goto bad;
    while (PyDict_Next(names_to_set, &i, &key, &value)) {
        set_name = __Pyx_PyObject_LookupSpecialNoError(value, __pyx_n_s_set_name);
        if (unlikely(set_name != NULL)) {
            tmp = __Pyx_PyObject_Call2Args(set_name, type_obj, key);
            Py_DECREF(set_name);
            if (unlikely(tmp == NULL)) {
                __Pyx_TypeName value_type_name =
                    __Pyx_PyType_GetName(Py_TYPE(value));
                __Pyx_TypeName type_name = __Pyx_PyType_GetName(type);
                PyErr_Format(PyExc_RuntimeError,
#if PY_MAJOR_VERSION >= 3
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %R " "in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name, key, type_name);
#else
                    "Error calling __set_name__ on '" __Pyx_FMT_TYPENAME "' instance %.100s in '" __Pyx_FMT_TYPENAME "'",
                    value_type_name,
                    PyString_Check(key) ? PyString_AS_STRING(key) : "?",
                    type_name);
#endif
                goto bad;
            } else {
                Py_DECREF(tmp);
            }
        }
        else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
    Py_DECREF(names_to_set);
    return 0;
bad:
    Py_XDECREF(names_to_set);
    return -1;
}
static PyObject *__Pyx_InitSubclassPEP487(PyObject *type_obj, PyObject *mkw) {
#if CYTHON_USE_TYPE_SLOTS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyTypeObject *type = (PyTypeObject*) type_obj;
    PyObject *mro = type->tp_mro;
    Py_ssize_t i, nbases;
    if (unlikely(!mro)) goto done;
    (void) &__Pyx_GetBuiltinName;
    Py_INCREF(mro);
    nbases = PyTuple_GET_SIZE(mro);
    assert(PyTuple_GET_ITEM(mro, 0) == type_obj);
    for (i = 1; i < nbases-1; i++) {
        PyObject *base, *dict, *meth;
        base = PyTuple_GET_ITEM(mro, i);
        dict = ((PyTypeObject *)base)->tp_dict;
        meth = __Pyx_PyDict_GetItemStrWithError(dict, __pyx_n_s_init_subclass);
        if (unlikely(meth)) {
            descrgetfunc f = Py_TYPE(meth)->tp_descr_get;
            PyObject *res;
            Py_INCREF(meth);
            if (likely(f)) {
                res = f(meth, NULL, type_obj);
                Py_DECREF(meth);
                if (unlikely(!res)) goto bad;
                meth = res;
            }
            res = __Pyx_PyObject_FastCallDict(meth, NULL, 0, mkw);
            Py_DECREF(meth);
            if (unlikely(!res)) goto bad;
            Py_DECREF(res);
            goto done;
        } else if (unlikely(PyErr_Occurred())) {
            goto bad;
        }
    }
done:
    Py_XDECREF(mro);
    return type_obj;
bad:
    Py_XDECREF(mro);
    Py_DECREF(type_obj);
    return NULL;
#else
    PyObject *super_type, *super, *func, *res;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    super_type = __Pyx_GetBuiltinName(__pyx_n_s_super);
#else
    super_type = (PyObject*) &PySuper_Type;
    (void) &__Pyx_GetBuiltinName;
#endif
    super = likely(super_type) ? __Pyx_PyObject_Call2Args(super_type, type_obj, type_obj) : NULL;
#if CYTHON_COMPILING_IN_PYPY && !defined(PySuper_Type)
    Py_XDECREF(super_type);
#endif
    if (unlikely(!super)) {
        Py_CLEAR(type_obj);
        goto done;
    }
    func = __Pyx_PyObject_GetAttrStrNoError(super, __pyx_n_s_init_subclass);
    Py_DECREF(super);
    if (likely(!func)) {
        if (unlikely(PyErr_Occurred()))
            Py_CLEAR(type_obj);
        goto done;
    }
    res = __Pyx_PyObject_FastCallDict(func, NULL, 0, mkw);
    Py_DECREF(func);
    if (unlikely(!res))
        Py_CLEAR(type_obj);
    Py_XDECREF(res);
done:
    return type_obj;
#endif
}
#endif
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result;
    PyObject *owned_metaclass = NULL;
    PyObject *margs[4] = {NULL, name, bases, dict};
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    result = __Pyx_PyObject_FastCallDict(metaclass, margs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET,
#if PY_VERSION_HEX < 0x030600A4
        (metaclass == (PyObject*)&PyType_Type) ? NULL : mkw
#else
        mkw
#endif
    );
    Py_XDECREF(owned_metaclass);
#if PY_VERSION_HEX < 0x030600A4 && CYTHON_PEP487_INIT_SUBCLASS
    if (likely(result) && likely(PyType_Check(result))) {
        if (unlikely(__Pyx_SetNamesPEP487(result) < 0)) {
            Py_CLEAR(result);
        } else {
            result = __Pyx_InitSubclassPEP487(result, mkw);
        }
    }
#else
    (void) &__Pyx_GetBuiltinName;
#endif
    return result;
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_n_s_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    #if PY_MAJOR_VERSION == 2
    static PyTypeObject *methoddescr_type = NULL;
    if (unlikely(methoddescr_type == NULL)) {
       PyObject *meth = PyObject_GetAttrString((PyObject*)&PyList_Type, "append");
       if (unlikely(!meth)) return NULL;
       methoddescr_type = Py_TYPE(meth);
       Py_DECREF(meth);
    }
    #else
    PyTypeObject *methoddescr_type = &PyMethodDescr_Type;
    #endif
    if (__Pyx_TypeCheck(method, methoddescr_type))
#endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        #if PY_VERSION_HEX < 0x03020000
        PyTypeObject *d_type = descr->d_type;
        #else
        PyTypeObject *d_type = descr->d_common.d_type;
        #endif
        return PyDescr_NewClassMethod(d_type, descr->d_method);
    }
#endif
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* Declarations */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int64 neg_one = (npy_int64) -1, const_zero = (npy_int64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int64) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int64) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int64) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int64),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int64));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE npy_int64 __Pyx_PyInt_As_npy_int64(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int64 neg_one = (npy_int64) -1, const_zero = (npy_int64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_int64) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_int64, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int64) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int64, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 2 * PyLong_SHIFT)) {
                                return (npy_int64) (((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 3 * PyLong_SHIFT)) {
                                return (npy_int64) (((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 4 * PyLong_SHIFT)) {
                                return (npy_int64) (((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int64) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_int64) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int64) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int64, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_int64) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_int64) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int64) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_int64 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_int64) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_int64) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_int64) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_int64) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_int64) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_int64) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_int64) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_int64) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_int64) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_int64) 1) << (sizeof(npy_int64) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_int64) -1;
        }
    } else {
        npy_int64 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int64) -1;
        val = __Pyx_PyInt_As_npy_int64(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int64");
    return (npy_int64) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int64");
    return (npy_int64) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum____pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode neg_one = (enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) -1, const_zero = (enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(enum __pyx_t_6pandas_5_libs_6tslibs_6dtypes_PeriodDtypeCode));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_NPY_DATETIMEUNIT(NPY_DATETIMEUNIT value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const NPY_DATETIMEUNIT neg_one = (NPY_DATETIMEUNIT) -1, const_zero = (NPY_DATETIMEUNIT) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(NPY_DATETIMEUNIT) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(NPY_DATETIMEUNIT) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(NPY_DATETIMEUNIT) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(NPY_DATETIMEUNIT) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(NPY_DATETIMEUNIT) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(NPY_DATETIMEUNIT),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(NPY_DATETIMEUNIT));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE NPY_DATETIMEUNIT __Pyx_PyInt_As_NPY_DATETIMEUNIT(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const NPY_DATETIMEUNIT neg_one = (NPY_DATETIMEUNIT) -1, const_zero = (NPY_DATETIMEUNIT) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(NPY_DATETIMEUNIT) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (NPY_DATETIMEUNIT) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) >= 2 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((((NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) >= 3 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((((((NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) >= 4 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((((((((NPY_DATETIMEUNIT)digits[3]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (NPY_DATETIMEUNIT) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(NPY_DATETIMEUNIT) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(NPY_DATETIMEUNIT, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(NPY_DATETIMEUNIT) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(NPY_DATETIMEUNIT, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 2 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((NPY_DATETIMEUNIT)-1)*(((((NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 2 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) ((((((NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 3 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((NPY_DATETIMEUNIT)-1)*(((((((NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 3 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) ((((((((NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 4 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) (((NPY_DATETIMEUNIT)-1)*(((((((((NPY_DATETIMEUNIT)digits[3]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(NPY_DATETIMEUNIT) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(NPY_DATETIMEUNIT, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(NPY_DATETIMEUNIT) - 1 > 4 * PyLong_SHIFT)) {
                                return (NPY_DATETIMEUNIT) ((((((((((NPY_DATETIMEUNIT)digits[3]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[2]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[1]) << PyLong_SHIFT) | (NPY_DATETIMEUNIT)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(NPY_DATETIMEUNIT) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(NPY_DATETIMEUNIT, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(NPY_DATETIMEUNIT) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(NPY_DATETIMEUNIT, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available, cannot convert large enums");
        return (NPY_DATETIMEUNIT) -1;
    } else {
        NPY_DATETIMEUNIT val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (NPY_DATETIMEUNIT) -1;
        val = __Pyx_PyInt_As_NPY_DATETIMEUNIT(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to NPY_DATETIMEUNIT");
    return (NPY_DATETIMEUNIT) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to NPY_DATETIMEUNIT");
    return (NPY_DATETIMEUNIT) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int32 neg_one = (npy_int32) -1, const_zero = (npy_int32) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int32),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int32));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__284);
    }
    return name;
}
#endif

/* PyObjectCallMethod1 */
#if !(CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2)
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && __PYX_LIMITED_VERSION_HEX >= 0x030C00A2
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_GetMethod;
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* CoroutineBase */
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(PyObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body(self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(PyObject* gen, PyObject *retval) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval))
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = __Pyx_PyObject_GetIterNextFunc(yf)(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    gen->is_running = 0;
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        Py_TYPE(gen)->tp_del(self);
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (likely(--self->ob_refcnt == 0)) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context)
{
    PyObject *frame = self->gi_frame;
    CYTHON_UNUSED_VAR(context);
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (unlikely(!module)) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) __Pyx_PyObject_GenericGetAttrNoDict},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    __pyx_GeneratorType_slots
};
#else
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_Generator_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_GeneratorType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
#endif
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* FunctionExport */
static int __Pyx_ExportFunction(const char *name, void (*f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(__pyx_m, (char *)"__pyx_capi__");
    if (!d) {
        PyErr_Clear();
        d = PyDict_New();
        if (!d)
            goto bad;
        Py_INCREF(d);
        if (PyModule_AddObject(__pyx_m, (char *)"__pyx_capi__", d) < 0)
            goto bad;
    }
    tmp.fp = f;
    cobj = PyCapsule_New(tmp.p, sig, 0);
    if (!cobj)
        goto bad;
    if (PyDict_SetItemString(d, name, cobj) < 0)
        goto bad;
    Py_DECREF(cobj);
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(cobj);
    Py_XDECREF(d);
    return -1;
}

/* VoidPtrImport */
#ifndef __PYX_HAVE_RT_ImportVoidPtr_3_0_8
#define __PYX_HAVE_RT_ImportVoidPtr_3_0_8
static int __Pyx_ImportVoidPtr_3_0_8(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C variable %.200s",
                PyModule_GetName(module), name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_0_8
#define __PYX_HAVE_RT_ImportFunction_3_0_8
static int __Pyx_ImportFunction_3_0_8(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
